""" Cisco_IOS_XR_ip_rib_ipv6_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-rib\-ipv6 package operational data.

This module contains definitions
for the following management objects\:
  ipv6\-rib\: RIB operational data
  ipv6\-rib\-stdby\: ipv6 rib stdby

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class Ipv6Rib(Entity):
    """
    RIB operational data
    
    .. attribute:: rib_table_ids
    
    	RIB table
    	**type**\:   :py:class:`RibTableIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds>`
    
    .. attribute:: vrfs
    
    	VRF table
    	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs>`
    
    

    """

    _prefix = 'ip-rib-ipv6-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Ipv6Rib, self).__init__()
        self._top_entity = None

        self.yang_name = "ipv6-rib"
        self.yang_parent_name = "Cisco-IOS-XR-ip-rib-ipv6-oper"

        self.rib_table_ids = Ipv6Rib.RibTableIds()
        self.rib_table_ids.parent = self
        self._children_name_map["rib_table_ids"] = "rib-table-ids"
        self._children_yang_names.add("rib-table-ids")

        self.vrfs = Ipv6Rib.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._children_yang_names.add("vrfs")


    class RibTableIds(Entity):
        """
        RIB table
        
        .. attribute:: rib_table_id
        
        	Specific Table
        	**type**\: list of    :py:class:`RibTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Ipv6Rib.RibTableIds, self).__init__()

            self.yang_name = "rib-table-ids"
            self.yang_parent_name = "ipv6-rib"

            self.rib_table_id = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Ipv6Rib.RibTableIds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Ipv6Rib.RibTableIds, self).__setattr__(name, value)


        class RibTableId(Entity):
            """
            Specific Table
            
            .. attribute:: tableid  <key>
            
            	Table ID
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: rib_table_itf_hndls
            
            	RIB table interface
            	**type**\:   :py:class:`RibTableItfHndls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls>`
            
            .. attribute:: summary_protos
            
            	RIB table summary
            	**type**\:   :py:class:`SummaryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6Rib.RibTableIds.RibTableId, self).__init__()

                self.yang_name = "rib-table-id"
                self.yang_parent_name = "rib-table-ids"

                self.tableid = YLeaf(YType.str, "tableid")

                self.rib_table_itf_hndls = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls()
                self.rib_table_itf_hndls.parent = self
                self._children_name_map["rib_table_itf_hndls"] = "rib-table-itf-hndls"
                self._children_yang_names.add("rib-table-itf-hndls")

                self.summary_protos = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos()
                self.summary_protos.parent = self
                self._children_name_map["summary_protos"] = "summary-protos"
                self._children_yang_names.add("summary-protos")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("tableid") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Ipv6Rib.RibTableIds.RibTableId, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Ipv6Rib.RibTableIds.RibTableId, self).__setattr__(name, value)


            class SummaryProtos(Entity):
                """
                RIB table summary
                
                .. attribute:: summary_proto
                
                	Route summary information for a specific table/protocol 
                	**type**\: list of    :py:class:`SummaryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos, self).__init__()

                    self.yang_name = "summary-protos"
                    self.yang_parent_name = "rib-table-id"

                    self.summary_proto = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos, self).__setattr__(name, value)


                class SummaryProto(Entity):
                    """
                    Route summary information for a specific
                    table/protocol 
                    
                    .. attribute:: protoid  <key>
                    
                    	Proto ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: instance
                    
                    	Instance
                    	**type**\:  str
                    
                    .. attribute:: name
                    
                    	Proto name
                    	**type**\:  str
                    
                    .. attribute:: proto_route_count
                    
                    	Count for proto. instance
                    	**type**\:   :py:class:`ProtoRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount>`
                    
                    .. attribute:: rtype_bgp_ext
                    
                    	eBGP route
                    	**type**\:   :py:class:`RtypeBgpExt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt>`
                    
                    .. attribute:: rtype_bgp_int
                    
                    	iBGP route
                    	**type**\:   :py:class:`RtypeBgpInt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt>`
                    
                    .. attribute:: rtype_bgp_loc
                    
                    	BGP local route
                    	**type**\:   :py:class:`RtypeBgpLoc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc>`
                    
                    .. attribute:: rtype_igrp2_ext
                    
                    	EIGRP external route
                    	**type**\:   :py:class:`RtypeIgrp2Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext>`
                    
                    .. attribute:: rtype_igrp2_int
                    
                    	EIGRP internal route
                    	**type**\:   :py:class:`RtypeIgrp2Int <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int>`
                    
                    .. attribute:: rtype_isis_l1
                    
                    	IS\-IS level 1 route
                    	**type**\:   :py:class:`RtypeIsisL1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1>`
                    
                    .. attribute:: rtype_isis_l1_ia
                    
                    	IS\-IS level1 inter\-area route
                    	**type**\:   :py:class:`RtypeIsisL1Ia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia>`
                    
                    .. attribute:: rtype_isis_l2
                    
                    	IS\-IS level 2 route
                    	**type**\:   :py:class:`RtypeIsisL2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2>`
                    
                    .. attribute:: rtype_isis_sum
                    
                    	IS\-IS summary route
                    	**type**\:   :py:class:`RtypeIsisSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum>`
                    
                    .. attribute:: rtype_none
                    
                    	No route type
                    	**type**\:   :py:class:`RtypeNone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone>`
                    
                    .. attribute:: rtype_ospf_extern1
                    
                    	OSPF external route of type 1
                    	**type**\:   :py:class:`RtypeOspfExtern1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1>`
                    
                    .. attribute:: rtype_ospf_extern2
                    
                    	OSPF external route of type 2
                    	**type**\:   :py:class:`RtypeOspfExtern2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2>`
                    
                    .. attribute:: rtype_ospf_inter
                    
                    	OSPF route across diff. areas
                    	**type**\:   :py:class:`RtypeOspfInter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter>`
                    
                    .. attribute:: rtype_ospf_intra
                    
                    	OSPF route within an area
                    	**type**\:   :py:class:`RtypeOspfIntra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra>`
                    
                    .. attribute:: rtype_ospf_nssa1
                    
                    	OSPF NSSA ext. route type 1
                    	**type**\:   :py:class:`RtypeOspfNssa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1>`
                    
                    .. attribute:: rtype_ospf_nssa2
                    
                    	OSPF NSSA ext. route type 2
                    	**type**\:   :py:class:`RtypeOspfNssa2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2>`
                    
                    .. attribute:: rtype_other
                    
                    	Unknown route type
                    	**type**\:   :py:class:`RtypeOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__init__()

                        self.yang_name = "summary-proto"
                        self.yang_parent_name = "summary-protos"

                        self.protoid = YLeaf(YType.int32, "protoid")

                        self.instance = YLeaf(YType.str, "instance")

                        self.name = YLeaf(YType.str, "name")

                        self.proto_route_count = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                        self.proto_route_count.parent = self
                        self._children_name_map["proto_route_count"] = "proto-route-count"
                        self._children_yang_names.add("proto-route-count")

                        self.rtype_bgp_ext = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                        self.rtype_bgp_ext.parent = self
                        self._children_name_map["rtype_bgp_ext"] = "rtype-bgp-ext"
                        self._children_yang_names.add("rtype-bgp-ext")

                        self.rtype_bgp_int = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                        self.rtype_bgp_int.parent = self
                        self._children_name_map["rtype_bgp_int"] = "rtype-bgp-int"
                        self._children_yang_names.add("rtype-bgp-int")

                        self.rtype_bgp_loc = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                        self.rtype_bgp_loc.parent = self
                        self._children_name_map["rtype_bgp_loc"] = "rtype-bgp-loc"
                        self._children_yang_names.add("rtype-bgp-loc")

                        self.rtype_igrp2_ext = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                        self.rtype_igrp2_ext.parent = self
                        self._children_name_map["rtype_igrp2_ext"] = "rtype-igrp2-ext"
                        self._children_yang_names.add("rtype-igrp2-ext")

                        self.rtype_igrp2_int = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                        self.rtype_igrp2_int.parent = self
                        self._children_name_map["rtype_igrp2_int"] = "rtype-igrp2-int"
                        self._children_yang_names.add("rtype-igrp2-int")

                        self.rtype_isis_l1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                        self.rtype_isis_l1.parent = self
                        self._children_name_map["rtype_isis_l1"] = "rtype-isis-l1"
                        self._children_yang_names.add("rtype-isis-l1")

                        self.rtype_isis_l1_ia = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                        self.rtype_isis_l1_ia.parent = self
                        self._children_name_map["rtype_isis_l1_ia"] = "rtype-isis-l1-ia"
                        self._children_yang_names.add("rtype-isis-l1-ia")

                        self.rtype_isis_l2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                        self.rtype_isis_l2.parent = self
                        self._children_name_map["rtype_isis_l2"] = "rtype-isis-l2"
                        self._children_yang_names.add("rtype-isis-l2")

                        self.rtype_isis_sum = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                        self.rtype_isis_sum.parent = self
                        self._children_name_map["rtype_isis_sum"] = "rtype-isis-sum"
                        self._children_yang_names.add("rtype-isis-sum")

                        self.rtype_none = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                        self.rtype_none.parent = self
                        self._children_name_map["rtype_none"] = "rtype-none"
                        self._children_yang_names.add("rtype-none")

                        self.rtype_ospf_extern1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                        self.rtype_ospf_extern1.parent = self
                        self._children_name_map["rtype_ospf_extern1"] = "rtype-ospf-extern1"
                        self._children_yang_names.add("rtype-ospf-extern1")

                        self.rtype_ospf_extern2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                        self.rtype_ospf_extern2.parent = self
                        self._children_name_map["rtype_ospf_extern2"] = "rtype-ospf-extern2"
                        self._children_yang_names.add("rtype-ospf-extern2")

                        self.rtype_ospf_inter = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                        self.rtype_ospf_inter.parent = self
                        self._children_name_map["rtype_ospf_inter"] = "rtype-ospf-inter"
                        self._children_yang_names.add("rtype-ospf-inter")

                        self.rtype_ospf_intra = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                        self.rtype_ospf_intra.parent = self
                        self._children_name_map["rtype_ospf_intra"] = "rtype-ospf-intra"
                        self._children_yang_names.add("rtype-ospf-intra")

                        self.rtype_ospf_nssa1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                        self.rtype_ospf_nssa1.parent = self
                        self._children_name_map["rtype_ospf_nssa1"] = "rtype-ospf-nssa1"
                        self._children_yang_names.add("rtype-ospf-nssa1")

                        self.rtype_ospf_nssa2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                        self.rtype_ospf_nssa2.parent = self
                        self._children_name_map["rtype_ospf_nssa2"] = "rtype-ospf-nssa2"
                        self._children_yang_names.add("rtype-ospf-nssa2")

                        self.rtype_other = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                        self.rtype_other.parent = self
                        self._children_name_map["rtype_other"] = "rtype-other"
                        self._children_yang_names.add("rtype-other")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("protoid",
                                        "instance",
                                        "name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__setattr__(name, value)


                    class ProtoRouteCount(Entity):
                        """
                        Count for proto. instance
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__init__()

                            self.yang_name = "proto-route-count"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "proto-route-count" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeNone(Entity):
                        """
                        No route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__init__()

                            self.yang_name = "rtype-none"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-none" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOther(Entity):
                        """
                        Unknown route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__init__()

                            self.yang_name = "rtype-other"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-other" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfIntra(Entity):
                        """
                        OSPF route within an area
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__init__()

                            self.yang_name = "rtype-ospf-intra"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-intra" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfInter(Entity):
                        """
                        OSPF route across diff. areas
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__init__()

                            self.yang_name = "rtype-ospf-inter"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-inter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfExtern1(Entity):
                        """
                        OSPF external route of type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__init__()

                            self.yang_name = "rtype-ospf-extern1"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-extern1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfExtern2(Entity):
                        """
                        OSPF external route of type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__init__()

                            self.yang_name = "rtype-ospf-extern2"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-extern2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIsisSum(Entity):
                        """
                        IS\-IS summary route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__init__()

                            self.yang_name = "rtype-isis-sum"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-isis-sum" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIsisL1(Entity):
                        """
                        IS\-IS level 1 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__init__()

                            self.yang_name = "rtype-isis-l1"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-isis-l1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIsisL2(Entity):
                        """
                        IS\-IS level 2 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__init__()

                            self.yang_name = "rtype-isis-l2"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-isis-l2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIsisL1Ia(Entity):
                        """
                        IS\-IS level1 inter\-area route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__init__()

                            self.yang_name = "rtype-isis-l1-ia"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-isis-l1-ia" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeBgpInt(Entity):
                        """
                        iBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__init__()

                            self.yang_name = "rtype-bgp-int"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-bgp-int" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeBgpExt(Entity):
                        """
                        eBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__init__()

                            self.yang_name = "rtype-bgp-ext"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-bgp-ext" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeBgpLoc(Entity):
                        """
                        BGP local route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__init__()

                            self.yang_name = "rtype-bgp-loc"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-bgp-loc" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfNssa1(Entity):
                        """
                        OSPF NSSA ext. route type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__init__()

                            self.yang_name = "rtype-ospf-nssa1"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-nssa1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfNssa2(Entity):
                        """
                        OSPF NSSA ext. route type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__init__()

                            self.yang_name = "rtype-ospf-nssa2"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-nssa2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIgrp2Int(Entity):
                        """
                        EIGRP internal route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__init__()

                            self.yang_name = "rtype-igrp2-int"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-igrp2-int" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIgrp2Ext(Entity):
                        """
                        EIGRP external route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__init__()

                            self.yang_name = "rtype-igrp2-ext"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-igrp2-ext" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.protoid.is_set or
                            self.instance.is_set or
                            self.name.is_set or
                            (self.proto_route_count is not None and self.proto_route_count.has_data()) or
                            (self.rtype_bgp_ext is not None and self.rtype_bgp_ext.has_data()) or
                            (self.rtype_bgp_int is not None and self.rtype_bgp_int.has_data()) or
                            (self.rtype_bgp_loc is not None and self.rtype_bgp_loc.has_data()) or
                            (self.rtype_igrp2_ext is not None and self.rtype_igrp2_ext.has_data()) or
                            (self.rtype_igrp2_int is not None and self.rtype_igrp2_int.has_data()) or
                            (self.rtype_isis_l1 is not None and self.rtype_isis_l1.has_data()) or
                            (self.rtype_isis_l1_ia is not None and self.rtype_isis_l1_ia.has_data()) or
                            (self.rtype_isis_l2 is not None and self.rtype_isis_l2.has_data()) or
                            (self.rtype_isis_sum is not None and self.rtype_isis_sum.has_data()) or
                            (self.rtype_none is not None and self.rtype_none.has_data()) or
                            (self.rtype_ospf_extern1 is not None and self.rtype_ospf_extern1.has_data()) or
                            (self.rtype_ospf_extern2 is not None and self.rtype_ospf_extern2.has_data()) or
                            (self.rtype_ospf_inter is not None and self.rtype_ospf_inter.has_data()) or
                            (self.rtype_ospf_intra is not None and self.rtype_ospf_intra.has_data()) or
                            (self.rtype_ospf_nssa1 is not None and self.rtype_ospf_nssa1.has_data()) or
                            (self.rtype_ospf_nssa2 is not None and self.rtype_ospf_nssa2.has_data()) or
                            (self.rtype_other is not None and self.rtype_other.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.protoid.yfilter != YFilter.not_set or
                            self.instance.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            (self.proto_route_count is not None and self.proto_route_count.has_operation()) or
                            (self.rtype_bgp_ext is not None and self.rtype_bgp_ext.has_operation()) or
                            (self.rtype_bgp_int is not None and self.rtype_bgp_int.has_operation()) or
                            (self.rtype_bgp_loc is not None and self.rtype_bgp_loc.has_operation()) or
                            (self.rtype_igrp2_ext is not None and self.rtype_igrp2_ext.has_operation()) or
                            (self.rtype_igrp2_int is not None and self.rtype_igrp2_int.has_operation()) or
                            (self.rtype_isis_l1 is not None and self.rtype_isis_l1.has_operation()) or
                            (self.rtype_isis_l1_ia is not None and self.rtype_isis_l1_ia.has_operation()) or
                            (self.rtype_isis_l2 is not None and self.rtype_isis_l2.has_operation()) or
                            (self.rtype_isis_sum is not None and self.rtype_isis_sum.has_operation()) or
                            (self.rtype_none is not None and self.rtype_none.has_operation()) or
                            (self.rtype_ospf_extern1 is not None and self.rtype_ospf_extern1.has_operation()) or
                            (self.rtype_ospf_extern2 is not None and self.rtype_ospf_extern2.has_operation()) or
                            (self.rtype_ospf_inter is not None and self.rtype_ospf_inter.has_operation()) or
                            (self.rtype_ospf_intra is not None and self.rtype_ospf_intra.has_operation()) or
                            (self.rtype_ospf_nssa1 is not None and self.rtype_ospf_nssa1.has_operation()) or
                            (self.rtype_ospf_nssa2 is not None and self.rtype_ospf_nssa2.has_operation()) or
                            (self.rtype_other is not None and self.rtype_other.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary-proto" + "[protoid='" + self.protoid.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.protoid.is_set or self.protoid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protoid.get_name_leafdata())
                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.instance.get_name_leafdata())
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "proto-route-count"):
                            if (self.proto_route_count is None):
                                self.proto_route_count = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                                self.proto_route_count.parent = self
                                self._children_name_map["proto_route_count"] = "proto-route-count"
                            return self.proto_route_count

                        if (child_yang_name == "rtype-bgp-ext"):
                            if (self.rtype_bgp_ext is None):
                                self.rtype_bgp_ext = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                                self.rtype_bgp_ext.parent = self
                                self._children_name_map["rtype_bgp_ext"] = "rtype-bgp-ext"
                            return self.rtype_bgp_ext

                        if (child_yang_name == "rtype-bgp-int"):
                            if (self.rtype_bgp_int is None):
                                self.rtype_bgp_int = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                                self.rtype_bgp_int.parent = self
                                self._children_name_map["rtype_bgp_int"] = "rtype-bgp-int"
                            return self.rtype_bgp_int

                        if (child_yang_name == "rtype-bgp-loc"):
                            if (self.rtype_bgp_loc is None):
                                self.rtype_bgp_loc = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                                self.rtype_bgp_loc.parent = self
                                self._children_name_map["rtype_bgp_loc"] = "rtype-bgp-loc"
                            return self.rtype_bgp_loc

                        if (child_yang_name == "rtype-igrp2-ext"):
                            if (self.rtype_igrp2_ext is None):
                                self.rtype_igrp2_ext = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                                self.rtype_igrp2_ext.parent = self
                                self._children_name_map["rtype_igrp2_ext"] = "rtype-igrp2-ext"
                            return self.rtype_igrp2_ext

                        if (child_yang_name == "rtype-igrp2-int"):
                            if (self.rtype_igrp2_int is None):
                                self.rtype_igrp2_int = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                                self.rtype_igrp2_int.parent = self
                                self._children_name_map["rtype_igrp2_int"] = "rtype-igrp2-int"
                            return self.rtype_igrp2_int

                        if (child_yang_name == "rtype-isis-l1"):
                            if (self.rtype_isis_l1 is None):
                                self.rtype_isis_l1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                                self.rtype_isis_l1.parent = self
                                self._children_name_map["rtype_isis_l1"] = "rtype-isis-l1"
                            return self.rtype_isis_l1

                        if (child_yang_name == "rtype-isis-l1-ia"):
                            if (self.rtype_isis_l1_ia is None):
                                self.rtype_isis_l1_ia = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                                self.rtype_isis_l1_ia.parent = self
                                self._children_name_map["rtype_isis_l1_ia"] = "rtype-isis-l1-ia"
                            return self.rtype_isis_l1_ia

                        if (child_yang_name == "rtype-isis-l2"):
                            if (self.rtype_isis_l2 is None):
                                self.rtype_isis_l2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                                self.rtype_isis_l2.parent = self
                                self._children_name_map["rtype_isis_l2"] = "rtype-isis-l2"
                            return self.rtype_isis_l2

                        if (child_yang_name == "rtype-isis-sum"):
                            if (self.rtype_isis_sum is None):
                                self.rtype_isis_sum = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                                self.rtype_isis_sum.parent = self
                                self._children_name_map["rtype_isis_sum"] = "rtype-isis-sum"
                            return self.rtype_isis_sum

                        if (child_yang_name == "rtype-none"):
                            if (self.rtype_none is None):
                                self.rtype_none = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                                self.rtype_none.parent = self
                                self._children_name_map["rtype_none"] = "rtype-none"
                            return self.rtype_none

                        if (child_yang_name == "rtype-ospf-extern1"):
                            if (self.rtype_ospf_extern1 is None):
                                self.rtype_ospf_extern1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                                self.rtype_ospf_extern1.parent = self
                                self._children_name_map["rtype_ospf_extern1"] = "rtype-ospf-extern1"
                            return self.rtype_ospf_extern1

                        if (child_yang_name == "rtype-ospf-extern2"):
                            if (self.rtype_ospf_extern2 is None):
                                self.rtype_ospf_extern2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                                self.rtype_ospf_extern2.parent = self
                                self._children_name_map["rtype_ospf_extern2"] = "rtype-ospf-extern2"
                            return self.rtype_ospf_extern2

                        if (child_yang_name == "rtype-ospf-inter"):
                            if (self.rtype_ospf_inter is None):
                                self.rtype_ospf_inter = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                                self.rtype_ospf_inter.parent = self
                                self._children_name_map["rtype_ospf_inter"] = "rtype-ospf-inter"
                            return self.rtype_ospf_inter

                        if (child_yang_name == "rtype-ospf-intra"):
                            if (self.rtype_ospf_intra is None):
                                self.rtype_ospf_intra = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                                self.rtype_ospf_intra.parent = self
                                self._children_name_map["rtype_ospf_intra"] = "rtype-ospf-intra"
                            return self.rtype_ospf_intra

                        if (child_yang_name == "rtype-ospf-nssa1"):
                            if (self.rtype_ospf_nssa1 is None):
                                self.rtype_ospf_nssa1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                                self.rtype_ospf_nssa1.parent = self
                                self._children_name_map["rtype_ospf_nssa1"] = "rtype-ospf-nssa1"
                            return self.rtype_ospf_nssa1

                        if (child_yang_name == "rtype-ospf-nssa2"):
                            if (self.rtype_ospf_nssa2 is None):
                                self.rtype_ospf_nssa2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                                self.rtype_ospf_nssa2.parent = self
                                self._children_name_map["rtype_ospf_nssa2"] = "rtype-ospf-nssa2"
                            return self.rtype_ospf_nssa2

                        if (child_yang_name == "rtype-other"):
                            if (self.rtype_other is None):
                                self.rtype_other = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                                self.rtype_other.parent = self
                                self._children_name_map["rtype_other"] = "rtype-other"
                            return self.rtype_other

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "proto-route-count" or name == "rtype-bgp-ext" or name == "rtype-bgp-int" or name == "rtype-bgp-loc" or name == "rtype-igrp2-ext" or name == "rtype-igrp2-int" or name == "rtype-isis-l1" or name == "rtype-isis-l1-ia" or name == "rtype-isis-l2" or name == "rtype-isis-sum" or name == "rtype-none" or name == "rtype-ospf-extern1" or name == "rtype-ospf-extern2" or name == "rtype-ospf-inter" or name == "rtype-ospf-intra" or name == "rtype-ospf-nssa1" or name == "rtype-ospf-nssa2" or name == "rtype-other" or name == "protoid" or name == "instance" or name == "name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "protoid"):
                            self.protoid = value
                            self.protoid.value_namespace = name_space
                            self.protoid.value_namespace_prefix = name_space_prefix
                        if(value_path == "instance"):
                            self.instance = value
                            self.instance.value_namespace = name_space
                            self.instance.value_namespace_prefix = name_space_prefix
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.summary_proto:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.summary_proto:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary-protos" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "summary-proto"):
                        for c in self.summary_proto:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.summary_proto.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "summary-proto"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RibTableItfHndls(Entity):
                """
                RIB table interface
                
                .. attribute:: rib_table_itf_hndl
                
                	Interface handle
                	**type**\: list of    :py:class:`RibTableItfHndl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls, self).__init__()

                    self.yang_name = "rib-table-itf-hndls"
                    self.yang_parent_name = "rib-table-id"

                    self.rib_table_itf_hndl = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls, self).__setattr__(name, value)


                class RibTableItfHndl(Entity):
                    """
                    Interface handle
                    
                    .. attribute:: handle  <key>
                    
                    	Itf Handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: itf_route
                    
                    	Route information for a specific table/interface 
                    	**type**\: list of    :py:class:`ItfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__init__()

                        self.yang_name = "rib-table-itf-hndl"
                        self.yang_parent_name = "rib-table-itf-hndls"

                        self.handle = YLeaf(YType.int32, "handle")

                        self.itf_route = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("handle") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__setattr__(name, value)


                    class ItfRoute(Entity):
                        """
                        Route information for a specific
                        table/interface 
                        
                        .. attribute:: address  <key>
                        
                        	Network Address 
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: active
                        
                        	Is the route active or backup
                        	**type**\:  bool
                        
                        .. attribute:: attribute_identity
                        
                        	BGP Attribute ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client_id
                        
                        	Client adding the route to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distance
                        
                        	Distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion
                        
                        	Route has a diversion path
                        	**type**\:  bool
                        
                        .. attribute:: diversion_distance
                        
                        	Diversion distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion_proto_name
                        
                        	Diversion route protocol name
                        	**type**\:  str
                        
                        .. attribute:: extended_flags
                        
                        	Extended Route flags
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: flags
                        
                        	Route flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_tag
                        
                        	Flow tag
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fwd_class
                        
                        	Forward Class
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: instance
                        
                        	Instance name
                        	**type**\:  str
                        
                        .. attribute:: metric
                        
                        	Route metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_count
                        
                        	Number of paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pic_count
                        
                        	Number of pic paths in this route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length_xr
                        
                        	Length of prefix
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: priority
                        
                        	Route priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: protocol_id
                        
                        	Protocol advertising the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_name
                        
                        	 Name of Protocol
                        	**type**\:  str
                        
                        .. attribute:: qos_group
                        
                        	Route qos group
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_age
                        
                        	Age of route (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: route_label
                        
                        	Local label of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_modify_time
                        
                        	Route modification time(nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: route_path
                        
                        	Path(s) of the route
                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath>`
                        
                        .. attribute:: route_precedence
                        
                        	Route ip precedence
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_type
                        
                        	Route type
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: route_version
                        
                        	Route version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: svd_type
                        
                        	SVD Type of route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tag
                        
                        	Opaque proto specific info
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tbl_version
                        
                        	Table Version
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: traffic_index
                        
                        	BGP Traffic Index
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: version
                        
                        	Route Version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__init__()

                            self.yang_name = "itf-route"
                            self.yang_parent_name = "rib-table-itf-hndl"

                            self.address = YLeaf(YType.str, "address")

                            self.active = YLeaf(YType.boolean, "active")

                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                            self.client_id = YLeaf(YType.uint32, "client-id")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.diversion = YLeaf(YType.boolean, "diversion")

                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                            self.flags = YLeaf(YType.uint32, "flags")

                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                            self.instance = YLeaf(YType.str, "instance")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.priority = YLeaf(YType.uint8, "priority")

                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                            self.route_age = YLeaf(YType.uint32, "route-age")

                            self.route_label = YLeaf(YType.uint32, "route-label")

                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                            self.route_type = YLeaf(YType.uint16, "route-type")

                            self.route_version = YLeaf(YType.uint32, "route-version")

                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                            self.tag = YLeaf(YType.uint32, "tag")

                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                            self.version = YLeaf(YType.uint32, "version")

                            self.route_path = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                            self.route_path.parent = self
                            self._children_name_map["route_path"] = "route-path"
                            self._children_yang_names.add("route-path")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "active",
                                            "attribute_identity",
                                            "client_id",
                                            "distance",
                                            "diversion",
                                            "diversion_distance",
                                            "diversion_proto_name",
                                            "extended_flags",
                                            "flags",
                                            "flow_tag",
                                            "fwd_class",
                                            "instance",
                                            "metric",
                                            "paths_count",
                                            "pic_count",
                                            "prefix",
                                            "prefix_length_xr",
                                            "priority",
                                            "protocol_id",
                                            "protocol_name",
                                            "qos_group",
                                            "route_age",
                                            "route_label",
                                            "route_modify_time",
                                            "route_precedence",
                                            "route_type",
                                            "route_version",
                                            "svd_type",
                                            "tag",
                                            "tbl_version",
                                            "traffic_index",
                                            "version") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__setattr__(name, value)


                        class RoutePath(Entity):
                            """
                            Path(s) of the route
                            
                            .. attribute:: ipv6_rib_edm_path
                            
                            	ipv6 rib edm path
                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "itf-route"

                                self.ipv6_rib_edm_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__setattr__(name, value)


                            class Ipv6RibEdmPath(Entity):
                                """
                                ipv6 rib edm path
                                
                                .. attribute:: address
                                
                                	Nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pathid
                                
                                	Path id of this path's backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_label
                                
                                	binding Label for this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: flags64
                                
                                	Flags extended to 64 bits
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: has_labelstk
                                
                                	Path has a label stack
                                	**type**\:  bool
                                
                                .. attribute:: information_source
                                
                                	Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: labelstk
                                
                                	Labels for this path
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_metric
                                
                                	Load Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: looped
                                
                                	Looping path
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_feid
                                
                                	Fib mpls encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: mvpn_present
                                
                                	MVPN attribute present
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_afi
                                
                                	NH afi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id
                                
                                	NHID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id_refcount
                                
                                	NHID references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_safi
                                
                                	NH safi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_id
                                
                                	Nexthop tableid
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_name
                                
                                	NH table name
                                	**type**\:  str
                                
                                .. attribute:: next_hop_vrf_name
                                
                                	VRF Name of the nh table
                                	**type**\:  str
                                
                                .. attribute:: nhid_feid
                                
                                	Fib nhid encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: num_labels
                                
                                	Number of labels in stack
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: number_of_extended_communities
                                
                                	Number of extended communities
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_area_id
                                
                                	OSPF area associated with the path
                                	**type**\:  str
                                
                                .. attribute:: path_rt_present
                                
                                	Path RT present
                                	**type**\:  bool
                                
                                .. attribute:: pathid
                                
                                	Path id of this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: private_flags
                                
                                	Private Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ref_cnt_of_backup
                                
                                	Refcnt of backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_backup_addr
                                
                                	Remote backup node address
                                	**type**\:  list of str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_label
                                
                                	Label associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: segmented_nexthop_present
                                
                                	SegmentedNexthopPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_asrt_present
                                
                                	SOURCEASRTPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_rd_present
                                
                                	SOURCERDPresent
                                	**type**\:  bool
                                
                                .. attribute:: tunnel_id
                                
                                	Tunnel ID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: v6_information_source
                                
                                	V6 Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_nexthop
                                
                                	V6 nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vrf_import_rt_present
                                
                                	VRFIMPORTRTPresent
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                    self.yang_name = "ipv6-rib-edm-path"
                                    self.yang_parent_name = "route-path"

                                    self.address = YLeaf(YType.str, "address")

                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                    self.flags = YLeaf(YType.uint16, "flags")

                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                    self.information_source = YLeaf(YType.str, "information-source")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                    self.looped = YLeaf(YType.boolean, "looped")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "backup_pathid",
                                                    "binding_label",
                                                    "flags",
                                                    "flags64",
                                                    "has_labelstk",
                                                    "information_source",
                                                    "interface_name",
                                                    "labelstk",
                                                    "load_metric",
                                                    "looped",
                                                    "metric",
                                                    "mpls_feid",
                                                    "mvpn_present",
                                                    "next_hop_afi",
                                                    "next_hop_id",
                                                    "next_hop_id_refcount",
                                                    "next_hop_safi",
                                                    "next_hop_table_id",
                                                    "next_hop_table_name",
                                                    "next_hop_vrf_name",
                                                    "nhid_feid",
                                                    "num_labels",
                                                    "number_of_extended_communities",
                                                    "ospf_area_id",
                                                    "path_rt_present",
                                                    "pathid",
                                                    "private_flags",
                                                    "ref_cnt_of_backup",
                                                    "remote_backup_addr",
                                                    "route_label",
                                                    "segmented_nexthop_present",
                                                    "source_asrt_present",
                                                    "source_rd_present",
                                                    "tunnel_id",
                                                    "v6_information_source",
                                                    "v6_nexthop",
                                                    "vrf_import_rt_present") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                def has_data(self):
                                    for leaf in self.labelstk.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    for leaf in self.remote_backup_addr.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.address.is_set or
                                        self.backup_pathid.is_set or
                                        self.binding_label.is_set or
                                        self.flags.is_set or
                                        self.flags64.is_set or
                                        self.has_labelstk.is_set or
                                        self.information_source.is_set or
                                        self.interface_name.is_set or
                                        self.load_metric.is_set or
                                        self.looped.is_set or
                                        self.metric.is_set or
                                        self.mpls_feid.is_set or
                                        self.mvpn_present.is_set or
                                        self.next_hop_afi.is_set or
                                        self.next_hop_id.is_set or
                                        self.next_hop_id_refcount.is_set or
                                        self.next_hop_safi.is_set or
                                        self.next_hop_table_id.is_set or
                                        self.next_hop_table_name.is_set or
                                        self.next_hop_vrf_name.is_set or
                                        self.nhid_feid.is_set or
                                        self.num_labels.is_set or
                                        self.number_of_extended_communities.is_set or
                                        self.ospf_area_id.is_set or
                                        self.path_rt_present.is_set or
                                        self.pathid.is_set or
                                        self.private_flags.is_set or
                                        self.ref_cnt_of_backup.is_set or
                                        self.route_label.is_set or
                                        self.segmented_nexthop_present.is_set or
                                        self.source_asrt_present.is_set or
                                        self.source_rd_present.is_set or
                                        self.tunnel_id.is_set or
                                        self.v6_information_source.is_set or
                                        self.v6_nexthop.is_set or
                                        self.vrf_import_rt_present.is_set)

                                def has_operation(self):
                                    for leaf in self.labelstk.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    for leaf in self.remote_backup_addr.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.backup_pathid.yfilter != YFilter.not_set or
                                        self.binding_label.yfilter != YFilter.not_set or
                                        self.flags.yfilter != YFilter.not_set or
                                        self.flags64.yfilter != YFilter.not_set or
                                        self.has_labelstk.yfilter != YFilter.not_set or
                                        self.information_source.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.labelstk.yfilter != YFilter.not_set or
                                        self.load_metric.yfilter != YFilter.not_set or
                                        self.looped.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        self.mpls_feid.yfilter != YFilter.not_set or
                                        self.mvpn_present.yfilter != YFilter.not_set or
                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                        self.next_hop_id.yfilter != YFilter.not_set or
                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                        self.nhid_feid.yfilter != YFilter.not_set or
                                        self.num_labels.yfilter != YFilter.not_set or
                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                        self.path_rt_present.yfilter != YFilter.not_set or
                                        self.pathid.yfilter != YFilter.not_set or
                                        self.private_flags.yfilter != YFilter.not_set or
                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                        self.route_label.yfilter != YFilter.not_set or
                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                        self.source_rd_present.yfilter != YFilter.not_set or
                                        self.tunnel_id.yfilter != YFilter.not_set or
                                        self.v6_information_source.yfilter != YFilter.not_set or
                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pathid"):
                                        self.backup_pathid = value
                                        self.backup_pathid.value_namespace = name_space
                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "binding-label"):
                                        self.binding_label = value
                                        self.binding_label.value_namespace = name_space
                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flags"):
                                        self.flags = value
                                        self.flags.value_namespace = name_space
                                        self.flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flags64"):
                                        self.flags64 = value
                                        self.flags64.value_namespace = name_space
                                        self.flags64.value_namespace_prefix = name_space_prefix
                                    if(value_path == "has-labelstk"):
                                        self.has_labelstk = value
                                        self.has_labelstk.value_namespace = name_space
                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                    if(value_path == "information-source"):
                                        self.information_source = value
                                        self.information_source.value_namespace = name_space
                                        self.information_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "labelstk"):
                                        self.labelstk.append(value)
                                    if(value_path == "load-metric"):
                                        self.load_metric = value
                                        self.load_metric.value_namespace = name_space
                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "looped"):
                                        self.looped = value
                                        self.looped.value_namespace = name_space
                                        self.looped.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-feid"):
                                        self.mpls_feid = value
                                        self.mpls_feid.value_namespace = name_space
                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mvpn-present"):
                                        self.mvpn_present = value
                                        self.mvpn_present.value_namespace = name_space
                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-afi"):
                                        self.next_hop_afi = value
                                        self.next_hop_afi.value_namespace = name_space
                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-id"):
                                        self.next_hop_id = value
                                        self.next_hop_id.value_namespace = name_space
                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-id-refcount"):
                                        self.next_hop_id_refcount = value
                                        self.next_hop_id_refcount.value_namespace = name_space
                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-safi"):
                                        self.next_hop_safi = value
                                        self.next_hop_safi.value_namespace = name_space
                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-table-id"):
                                        self.next_hop_table_id = value
                                        self.next_hop_table_id.value_namespace = name_space
                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-table-name"):
                                        self.next_hop_table_name = value
                                        self.next_hop_table_name.value_namespace = name_space
                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-vrf-name"):
                                        self.next_hop_vrf_name = value
                                        self.next_hop_vrf_name.value_namespace = name_space
                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nhid-feid"):
                                        self.nhid_feid = value
                                        self.nhid_feid.value_namespace = name_space
                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "num-labels"):
                                        self.num_labels = value
                                        self.num_labels.value_namespace = name_space
                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-of-extended-communities"):
                                        self.number_of_extended_communities = value
                                        self.number_of_extended_communities.value_namespace = name_space
                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-area-id"):
                                        self.ospf_area_id = value
                                        self.ospf_area_id.value_namespace = name_space
                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-rt-present"):
                                        self.path_rt_present = value
                                        self.path_rt_present.value_namespace = name_space
                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pathid"):
                                        self.pathid = value
                                        self.pathid.value_namespace = name_space
                                        self.pathid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "private-flags"):
                                        self.private_flags = value
                                        self.private_flags.value_namespace = name_space
                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ref-cnt-of-backup"):
                                        self.ref_cnt_of_backup = value
                                        self.ref_cnt_of_backup.value_namespace = name_space
                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-backup-addr"):
                                        self.remote_backup_addr.append(value)
                                    if(value_path == "route-label"):
                                        self.route_label = value
                                        self.route_label.value_namespace = name_space
                                        self.route_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "segmented-nexthop-present"):
                                        self.segmented_nexthop_present = value
                                        self.segmented_nexthop_present.value_namespace = name_space
                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-asrt-present"):
                                        self.source_asrt_present = value
                                        self.source_asrt_present.value_namespace = name_space
                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-rd-present"):
                                        self.source_rd_present = value
                                        self.source_rd_present.value_namespace = name_space
                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-id"):
                                        self.tunnel_id = value
                                        self.tunnel_id.value_namespace = name_space
                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "v6-information-source"):
                                        self.v6_information_source = value
                                        self.v6_information_source.value_namespace = name_space
                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "v6-nexthop"):
                                        self.v6_nexthop = value
                                        self.v6_nexthop.value_namespace = name_space
                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vrf-import-rt-present"):
                                        self.vrf_import_rt_present = value
                                        self.vrf_import_rt_present.value_namespace = name_space
                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ipv6_rib_edm_path:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.ipv6_rib_edm_path:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ipv6-rib-edm-path"):
                                    for c in self.ipv6_rib_edm_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ipv6_rib_edm_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv6-rib-edm-path"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.active.is_set or
                                self.attribute_identity.is_set or
                                self.client_id.is_set or
                                self.distance.is_set or
                                self.diversion.is_set or
                                self.diversion_distance.is_set or
                                self.diversion_proto_name.is_set or
                                self.extended_flags.is_set or
                                self.flags.is_set or
                                self.flow_tag.is_set or
                                self.fwd_class.is_set or
                                self.instance.is_set or
                                self.metric.is_set or
                                self.paths_count.is_set or
                                self.pic_count.is_set or
                                self.prefix.is_set or
                                self.prefix_length_xr.is_set or
                                self.priority.is_set or
                                self.protocol_id.is_set or
                                self.protocol_name.is_set or
                                self.qos_group.is_set or
                                self.route_age.is_set or
                                self.route_label.is_set or
                                self.route_modify_time.is_set or
                                self.route_precedence.is_set or
                                self.route_type.is_set or
                                self.route_version.is_set or
                                self.svd_type.is_set or
                                self.tag.is_set or
                                self.tbl_version.is_set or
                                self.traffic_index.is_set or
                                self.version.is_set or
                                (self.route_path is not None and self.route_path.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.active.yfilter != YFilter.not_set or
                                self.attribute_identity.yfilter != YFilter.not_set or
                                self.client_id.yfilter != YFilter.not_set or
                                self.distance.yfilter != YFilter.not_set or
                                self.diversion.yfilter != YFilter.not_set or
                                self.diversion_distance.yfilter != YFilter.not_set or
                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                self.extended_flags.yfilter != YFilter.not_set or
                                self.flags.yfilter != YFilter.not_set or
                                self.flow_tag.yfilter != YFilter.not_set or
                                self.fwd_class.yfilter != YFilter.not_set or
                                self.instance.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.paths_count.yfilter != YFilter.not_set or
                                self.pic_count.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol_id.yfilter != YFilter.not_set or
                                self.protocol_name.yfilter != YFilter.not_set or
                                self.qos_group.yfilter != YFilter.not_set or
                                self.route_age.yfilter != YFilter.not_set or
                                self.route_label.yfilter != YFilter.not_set or
                                self.route_modify_time.yfilter != YFilter.not_set or
                                self.route_precedence.yfilter != YFilter.not_set or
                                self.route_type.yfilter != YFilter.not_set or
                                self.route_version.yfilter != YFilter.not_set or
                                self.svd_type.yfilter != YFilter.not_set or
                                self.tag.yfilter != YFilter.not_set or
                                self.tbl_version.yfilter != YFilter.not_set or
                                self.traffic_index.yfilter != YFilter.not_set or
                                self.version.yfilter != YFilter.not_set or
                                (self.route_path is not None and self.route_path.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "itf-route" + "[address='" + self.address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active.get_name_leafdata())
                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client_id.get_name_leafdata())
                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.distance.get_name_leafdata())
                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diversion.get_name_leafdata())
                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flags.get_name_leafdata())
                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_age.get_name_leafdata())
                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_label.get_name_leafdata())
                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_type.get_name_leafdata())
                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_version.get_name_leafdata())
                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag.get_name_leafdata())
                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.version.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route-path"):
                                if (self.route_path is None):
                                    self.route_path = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                                    self.route_path.parent = self
                                    self._children_name_map["route_path"] = "route-path"
                                return self.route_path

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route-path" or name == "address" or name == "active" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "active"):
                                self.active = value
                                self.active.value_namespace = name_space
                                self.active.value_namespace_prefix = name_space_prefix
                            if(value_path == "attribute-identity"):
                                self.attribute_identity = value
                                self.attribute_identity.value_namespace = name_space
                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                            if(value_path == "client-id"):
                                self.client_id = value
                                self.client_id.value_namespace = name_space
                                self.client_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "distance"):
                                self.distance = value
                                self.distance.value_namespace = name_space
                                self.distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "diversion"):
                                self.diversion = value
                                self.diversion.value_namespace = name_space
                                self.diversion.value_namespace_prefix = name_space_prefix
                            if(value_path == "diversion-distance"):
                                self.diversion_distance = value
                                self.diversion_distance.value_namespace = name_space
                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "diversion-proto-name"):
                                self.diversion_proto_name = value
                                self.diversion_proto_name.value_namespace = name_space
                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-flags"):
                                self.extended_flags = value
                                self.extended_flags.value_namespace = name_space
                                self.extended_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "flags"):
                                self.flags = value
                                self.flags.value_namespace = name_space
                                self.flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-tag"):
                                self.flow_tag = value
                                self.flow_tag.value_namespace = name_space
                                self.flow_tag.value_namespace_prefix = name_space_prefix
                            if(value_path == "fwd-class"):
                                self.fwd_class = value
                                self.fwd_class.value_namespace = name_space
                                self.fwd_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "instance"):
                                self.instance = value
                                self.instance.value_namespace = name_space
                                self.instance.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "paths-count"):
                                self.paths_count = value
                                self.paths_count.value_namespace = name_space
                                self.paths_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "pic-count"):
                                self.pic_count = value
                                self.pic_count.value_namespace = name_space
                                self.pic_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length-xr"):
                                self.prefix_length_xr = value
                                self.prefix_length_xr.value_namespace = name_space
                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol-id"):
                                self.protocol_id = value
                                self.protocol_id.value_namespace = name_space
                                self.protocol_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol-name"):
                                self.protocol_name = value
                                self.protocol_name.value_namespace = name_space
                                self.protocol_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "qos-group"):
                                self.qos_group = value
                                self.qos_group.value_namespace = name_space
                                self.qos_group.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-age"):
                                self.route_age = value
                                self.route_age.value_namespace = name_space
                                self.route_age.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-label"):
                                self.route_label = value
                                self.route_label.value_namespace = name_space
                                self.route_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-modify-time"):
                                self.route_modify_time = value
                                self.route_modify_time.value_namespace = name_space
                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-precedence"):
                                self.route_precedence = value
                                self.route_precedence.value_namespace = name_space
                                self.route_precedence.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-type"):
                                self.route_type = value
                                self.route_type.value_namespace = name_space
                                self.route_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-version"):
                                self.route_version = value
                                self.route_version.value_namespace = name_space
                                self.route_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "svd-type"):
                                self.svd_type = value
                                self.svd_type.value_namespace = name_space
                                self.svd_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag"):
                                self.tag = value
                                self.tag.value_namespace = name_space
                                self.tag.value_namespace_prefix = name_space_prefix
                            if(value_path == "tbl-version"):
                                self.tbl_version = value
                                self.tbl_version.value_namespace = name_space
                                self.tbl_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-index"):
                                self.traffic_index = value
                                self.traffic_index.value_namespace = name_space
                                self.traffic_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "version"):
                                self.version = value
                                self.version.value_namespace = name_space
                                self.version.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.itf_route:
                            if (c.has_data()):
                                return True
                        return self.handle.is_set

                    def has_operation(self):
                        for c in self.itf_route:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.handle.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rib-table-itf-hndl" + "[handle='" + self.handle.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.handle.is_set or self.handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.handle.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "itf-route"):
                            for c in self.itf_route:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.itf_route.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "itf-route" or name == "handle"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "handle"):
                            self.handle = value
                            self.handle.value_namespace = name_space
                            self.handle.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.rib_table_itf_hndl:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.rib_table_itf_hndl:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rib-table-itf-hndls" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rib-table-itf-hndl"):
                        for c in self.rib_table_itf_hndl:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.rib_table_itf_hndl.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rib-table-itf-hndl"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.tableid.is_set or
                    (self.rib_table_itf_hndls is not None and self.rib_table_itf_hndls.has_data()) or
                    (self.summary_protos is not None and self.summary_protos.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.tableid.yfilter != YFilter.not_set or
                    (self.rib_table_itf_hndls is not None and self.rib_table_itf_hndls.has_operation()) or
                    (self.summary_protos is not None and self.summary_protos.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "rib-table-id" + "[tableid='" + self.tableid.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/rib-table-ids/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.tableid.is_set or self.tableid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tableid.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "rib-table-itf-hndls"):
                    if (self.rib_table_itf_hndls is None):
                        self.rib_table_itf_hndls = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls()
                        self.rib_table_itf_hndls.parent = self
                        self._children_name_map["rib_table_itf_hndls"] = "rib-table-itf-hndls"
                    return self.rib_table_itf_hndls

                if (child_yang_name == "summary-protos"):
                    if (self.summary_protos is None):
                        self.summary_protos = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos()
                        self.summary_protos.parent = self
                        self._children_name_map["summary_protos"] = "summary-protos"
                    return self.summary_protos

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "rib-table-itf-hndls" or name == "summary-protos" or name == "tableid"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "tableid"):
                    self.tableid = value
                    self.tableid.value_namespace = name_space
                    self.tableid.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.rib_table_id:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.rib_table_id:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "rib-table-ids" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "rib-table-id"):
                for c in self.rib_table_id:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Ipv6Rib.RibTableIds.RibTableId()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.rib_table_id.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "rib-table-id"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Vrfs(Entity):
        """
        VRF table
        
        .. attribute:: vrf
        
        	Specific VRF
        	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Ipv6Rib.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "ipv6-rib"

            self.vrf = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Ipv6Rib.Vrfs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Ipv6Rib.Vrfs, self).__setattr__(name, value)


        class Vrf(Entity):
            """
            Specific VRF
            
            .. attribute:: vrf_name  <key>
            
            	Name of the VRF
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: afs
            
            	Address Family (AF) table
            	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6Rib.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.afs = Ipv6Rib.Vrfs.Vrf.Afs()
                self.afs.parent = self
                self._children_name_map["afs"] = "afs"
                self._children_yang_names.add("afs")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Ipv6Rib.Vrfs.Vrf, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Ipv6Rib.Vrfs.Vrf, self).__setattr__(name, value)


            class Afs(Entity):
                """
                Address Family (AF) table
                
                .. attribute:: af
                
                	Specific AF information
                	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Rib.Vrfs.Vrf.Afs, self).__init__()

                    self.yang_name = "afs"
                    self.yang_parent_name = "vrf"

                    self.af = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Rib.Vrfs.Vrf.Afs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Rib.Vrfs.Vrf.Afs, self).__setattr__(name, value)


                class Af(Entity):
                    """
                    Specific AF information
                    
                    .. attribute:: af_name  <key>
                    
                    	Name of the AF \- 'IPv6'
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: safs
                    
                    	Subsequent Address Family (SAF) table
                    	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af, self).__init__()

                        self.yang_name = "af"
                        self.yang_parent_name = "afs"

                        self.af_name = YLeaf(YType.str, "af-name")

                        self.safs = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                        self._children_yang_names.add("safs")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af, self).__setattr__(name, value)


                    class Safs(Entity):
                        """
                        Subsequent Address Family (SAF) table
                        
                        .. attribute:: saf
                        
                        	Specific SAF information
                        	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf>`
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs, self).__init__()

                            self.yang_name = "safs"
                            self.yang_parent_name = "af"

                            self.saf = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs, self).__setattr__(name, value)


                        class Saf(Entity):
                            """
                            Specific SAF information
                            
                            .. attribute:: saf_name  <key>
                            
                            	Name of the SAF
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: ip_rib_route_table_names
                            
                            	Global container of routes
                            	**type**\:   :py:class:`IpRibRouteTableNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__init__()

                                self.yang_name = "saf"
                                self.yang_parent_name = "safs"

                                self.saf_name = YLeaf(YType.str, "saf-name")

                                self.ip_rib_route_table_names = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                self.ip_rib_route_table_names.parent = self
                                self._children_name_map["ip_rib_route_table_names"] = "ip-rib-route-table-names"
                                self._children_yang_names.add("ip-rib-route-table-names")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("saf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__setattr__(name, value)


                            class IpRibRouteTableNames(Entity):
                                """
                                Global container of routes
                                
                                .. attribute:: ip_rib_route_table_name
                                
                                	IP RIB Route table name for a topology
                                	**type**\: list of    :py:class:`IpRibRouteTableName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__init__()

                                    self.yang_name = "ip-rib-route-table-names"
                                    self.yang_parent_name = "saf"

                                    self.ip_rib_route_table_name = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__setattr__(name, value)


                                class IpRibRouteTableName(Entity):
                                    """
                                    IP RIB Route table name for a topology
                                    
                                    .. attribute:: route_table_name  <key>
                                    
                                    	Name of the route table 
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: adverts
                                    
                                    	Route advertiser information 
                                    	**type**\:   :py:class:`Adverts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts>`
                                    
                                    .. attribute:: backup_routes
                                    
                                    	Backup route information for the given table
                                    	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes>`
                                    
                                    .. attribute:: deleted_routes
                                    
                                    	Deleted
                                    	**type**\:   :py:class:`DeletedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes>`
                                    
                                    .. attribute:: destination_kw
                                    
                                    	Destination KW
                                    	**type**\:   :py:class:`DestinationKw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Contains the classification of routes by protocol
                                    	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol>`
                                    
                                    .. attribute:: q_routes
                                    
                                    	Quarantine
                                    	**type**\:   :py:class:`QRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes>`
                                    
                                    .. attribute:: routes
                                    
                                    	Route information 
                                    	**type**\:   :py:class:`Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes>`
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__init__()

                                        self.yang_name = "ip-rib-route-table-name"
                                        self.yang_parent_name = "ip-rib-route-table-names"

                                        self.route_table_name = YLeaf(YType.str, "route-table-name")

                                        self.adverts = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                        self.adverts.parent = self
                                        self._children_name_map["adverts"] = "adverts"
                                        self._children_yang_names.add("adverts")

                                        self.backup_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                        self.backup_routes.parent = self
                                        self._children_name_map["backup_routes"] = "backup-routes"
                                        self._children_yang_names.add("backup-routes")

                                        self.deleted_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                        self.deleted_routes.parent = self
                                        self._children_name_map["deleted_routes"] = "deleted-routes"
                                        self._children_yang_names.add("deleted-routes")

                                        self.destination_kw = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                        self.destination_kw.parent = self
                                        self._children_name_map["destination_kw"] = "destination-kw"
                                        self._children_yang_names.add("destination-kw")

                                        self.protocol = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                        self.protocol.parent = self
                                        self._children_name_map["protocol"] = "protocol"
                                        self._children_yang_names.add("protocol")

                                        self.q_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                        self.q_routes.parent = self
                                        self._children_name_map["q_routes"] = "q-routes"
                                        self._children_yang_names.add("q-routes")

                                        self.routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                        self.routes.parent = self
                                        self._children_name_map["routes"] = "routes"
                                        self._children_yang_names.add("routes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_table_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__setattr__(name, value)


                                    class DestinationKw(Entity):
                                        """
                                        Destination KW
                                        
                                        .. attribute:: dest_backup_routes
                                        
                                        	Backup
                                        	**type**\:   :py:class:`DestBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes>`
                                        
                                        .. attribute:: dest_best_routes
                                        
                                        	Best Local
                                        	**type**\:   :py:class:`DestBestRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes>`
                                        
                                        .. attribute:: dest_next_hop_routes
                                        
                                        	Resolving next hop
                                        	**type**\:   :py:class:`DestNextHopRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes>`
                                        
                                        .. attribute:: dest_q_routes
                                        
                                        	Quarantine
                                        	**type**\:   :py:class:`DestQRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw, self).__init__()

                                            self.yang_name = "destination-kw"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.dest_backup_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                            self.dest_backup_routes.parent = self
                                            self._children_name_map["dest_backup_routes"] = "dest-backup-routes"
                                            self._children_yang_names.add("dest-backup-routes")

                                            self.dest_best_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                            self.dest_best_routes.parent = self
                                            self._children_name_map["dest_best_routes"] = "dest-best-routes"
                                            self._children_yang_names.add("dest-best-routes")

                                            self.dest_next_hop_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                            self.dest_next_hop_routes.parent = self
                                            self._children_name_map["dest_next_hop_routes"] = "dest-next-hop-routes"
                                            self._children_yang_names.add("dest-next-hop-routes")

                                            self.dest_q_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                            self.dest_q_routes.parent = self
                                            self._children_name_map["dest_q_routes"] = "dest-q-routes"
                                            self._children_yang_names.add("dest-q-routes")


                                        class DestQRoutes(Entity):
                                            """
                                            Quarantine
                                            
                                            .. attribute:: dest_q_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestQRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__init__()

                                                self.yang_name = "dest-q-routes"
                                                self.yang_parent_name = "destination-kw"

                                                self.dest_q_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__setattr__(name, value)


                                            class DestQRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__init__()

                                                    self.yang_name = "dest-q-route"
                                                    self.yang_parent_name = "dest-q-routes"

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("active",
                                                                    "address",
                                                                    "attribute_identity",
                                                                    "client_id",
                                                                    "distance",
                                                                    "diversion",
                                                                    "diversion_distance",
                                                                    "diversion_proto_name",
                                                                    "extended_flags",
                                                                    "flags",
                                                                    "flow_tag",
                                                                    "fwd_class",
                                                                    "instance",
                                                                    "metric",
                                                                    "paths_count",
                                                                    "pic_count",
                                                                    "prefix",
                                                                    "prefix_length",
                                                                    "prefix_length_xr",
                                                                    "priority",
                                                                    "protocol_id",
                                                                    "protocol_name",
                                                                    "qos_group",
                                                                    "route_age",
                                                                    "route_label",
                                                                    "route_modify_time",
                                                                    "route_precedence",
                                                                    "route_type",
                                                                    "route_version",
                                                                    "svd_type",
                                                                    "tag",
                                                                    "tbl_version",
                                                                    "traffic_index",
                                                                    "version") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__setattr__(name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-q-route"

                                                        self.ipv6_rib_edm_path = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__setattr__(name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("address",
                                                                            "backup_pathid",
                                                                            "binding_label",
                                                                            "flags",
                                                                            "flags64",
                                                                            "has_labelstk",
                                                                            "information_source",
                                                                            "interface_name",
                                                                            "labelstk",
                                                                            "load_metric",
                                                                            "looped",
                                                                            "metric",
                                                                            "mpls_feid",
                                                                            "mvpn_present",
                                                                            "next_hop_afi",
                                                                            "next_hop_id",
                                                                            "next_hop_id_refcount",
                                                                            "next_hop_safi",
                                                                            "next_hop_table_id",
                                                                            "next_hop_table_name",
                                                                            "next_hop_vrf_name",
                                                                            "nhid_feid",
                                                                            "num_labels",
                                                                            "number_of_extended_communities",
                                                                            "ospf_area_id",
                                                                            "path_rt_present",
                                                                            "pathid",
                                                                            "private_flags",
                                                                            "ref_cnt_of_backup",
                                                                            "remote_backup_addr",
                                                                            "route_label",
                                                                            "segmented_nexthop_present",
                                                                            "source_asrt_present",
                                                                            "source_rd_present",
                                                                            "tunnel_id",
                                                                            "v6_information_source",
                                                                            "v6_nexthop",
                                                                            "vrf_import_rt_present") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            return (
                                                                self.address.is_set or
                                                                self.backup_pathid.is_set or
                                                                self.binding_label.is_set or
                                                                self.flags.is_set or
                                                                self.flags64.is_set or
                                                                self.has_labelstk.is_set or
                                                                self.information_source.is_set or
                                                                self.interface_name.is_set or
                                                                self.load_metric.is_set or
                                                                self.looped.is_set or
                                                                self.metric.is_set or
                                                                self.mpls_feid.is_set or
                                                                self.mvpn_present.is_set or
                                                                self.next_hop_afi.is_set or
                                                                self.next_hop_id.is_set or
                                                                self.next_hop_id_refcount.is_set or
                                                                self.next_hop_safi.is_set or
                                                                self.next_hop_table_id.is_set or
                                                                self.next_hop_table_name.is_set or
                                                                self.next_hop_vrf_name.is_set or
                                                                self.nhid_feid.is_set or
                                                                self.num_labels.is_set or
                                                                self.number_of_extended_communities.is_set or
                                                                self.ospf_area_id.is_set or
                                                                self.path_rt_present.is_set or
                                                                self.pathid.is_set or
                                                                self.private_flags.is_set or
                                                                self.ref_cnt_of_backup.is_set or
                                                                self.route_label.is_set or
                                                                self.segmented_nexthop_present.is_set or
                                                                self.source_asrt_present.is_set or
                                                                self.source_rd_present.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.v6_information_source.is_set or
                                                                self.v6_nexthop.is_set or
                                                                self.vrf_import_rt_present.is_set)

                                                        def has_operation(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.backup_pathid.yfilter != YFilter.not_set or
                                                                self.binding_label.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flags64.yfilter != YFilter.not_set or
                                                                self.has_labelstk.yfilter != YFilter.not_set or
                                                                self.information_source.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.labelstk.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.looped.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.mpls_feid.yfilter != YFilter.not_set or
                                                                self.mvpn_present.yfilter != YFilter.not_set or
                                                                self.next_hop_afi.yfilter != YFilter.not_set or
                                                                self.next_hop_id.yfilter != YFilter.not_set or
                                                                self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                self.next_hop_safi.yfilter != YFilter.not_set or
                                                                self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                self.nhid_feid.yfilter != YFilter.not_set or
                                                                self.num_labels.yfilter != YFilter.not_set or
                                                                self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                self.ospf_area_id.yfilter != YFilter.not_set or
                                                                self.path_rt_present.yfilter != YFilter.not_set or
                                                                self.pathid.yfilter != YFilter.not_set or
                                                                self.private_flags.yfilter != YFilter.not_set or
                                                                self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                self.source_asrt_present.yfilter != YFilter.not_set or
                                                                self.source_rd_present.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.v6_information_source.yfilter != YFilter.not_set or
                                                                self.v6_nexthop.yfilter != YFilter.not_set or
                                                                self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                            if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags64.get_name_leafdata())
                                                            if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                            if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.information_source.get_name_leafdata())
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.looped.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                            if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                            if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                            if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                            if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                            if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                            if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                            if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                            if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                            if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                            if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                            if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                            if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                            if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                            if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pathid.get_name_leafdata())
                                                            if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                            if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                            if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                            if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                            if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                            if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                            leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                            leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "backup-pathid"):
                                                                self.backup_pathid = value
                                                                self.backup_pathid.value_namespace = name_space
                                                                self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "binding-label"):
                                                                self.binding_label = value
                                                                self.binding_label.value_namespace = name_space
                                                                self.binding_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags64"):
                                                                self.flags64 = value
                                                                self.flags64.value_namespace = name_space
                                                                self.flags64.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "has-labelstk"):
                                                                self.has_labelstk = value
                                                                self.has_labelstk.value_namespace = name_space
                                                                self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "information-source"):
                                                                self.information_source = value
                                                                self.information_source.value_namespace = name_space
                                                                self.information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "labelstk"):
                                                                self.labelstk.append(value)
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "looped"):
                                                                self.looped = value
                                                                self.looped.value_namespace = name_space
                                                                self.looped.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mpls-feid"):
                                                                self.mpls_feid = value
                                                                self.mpls_feid.value_namespace = name_space
                                                                self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mvpn-present"):
                                                                self.mvpn_present = value
                                                                self.mvpn_present.value_namespace = name_space
                                                                self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-afi"):
                                                                self.next_hop_afi = value
                                                                self.next_hop_afi.value_namespace = name_space
                                                                self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id"):
                                                                self.next_hop_id = value
                                                                self.next_hop_id.value_namespace = name_space
                                                                self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id-refcount"):
                                                                self.next_hop_id_refcount = value
                                                                self.next_hop_id_refcount.value_namespace = name_space
                                                                self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-safi"):
                                                                self.next_hop_safi = value
                                                                self.next_hop_safi.value_namespace = name_space
                                                                self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-id"):
                                                                self.next_hop_table_id = value
                                                                self.next_hop_table_id.value_namespace = name_space
                                                                self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-name"):
                                                                self.next_hop_table_name = value
                                                                self.next_hop_table_name.value_namespace = name_space
                                                                self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-vrf-name"):
                                                                self.next_hop_vrf_name = value
                                                                self.next_hop_vrf_name.value_namespace = name_space
                                                                self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "nhid-feid"):
                                                                self.nhid_feid = value
                                                                self.nhid_feid.value_namespace = name_space
                                                                self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "num-labels"):
                                                                self.num_labels = value
                                                                self.num_labels.value_namespace = name_space
                                                                self.num_labels.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "number-of-extended-communities"):
                                                                self.number_of_extended_communities = value
                                                                self.number_of_extended_communities.value_namespace = name_space
                                                                self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ospf-area-id"):
                                                                self.ospf_area_id = value
                                                                self.ospf_area_id.value_namespace = name_space
                                                                self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "path-rt-present"):
                                                                self.path_rt_present = value
                                                                self.path_rt_present.value_namespace = name_space
                                                                self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pathid"):
                                                                self.pathid = value
                                                                self.pathid.value_namespace = name_space
                                                                self.pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "private-flags"):
                                                                self.private_flags = value
                                                                self.private_flags.value_namespace = name_space
                                                                self.private_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ref-cnt-of-backup"):
                                                                self.ref_cnt_of_backup = value
                                                                self.ref_cnt_of_backup.value_namespace = name_space
                                                                self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "remote-backup-addr"):
                                                                self.remote_backup_addr.append(value)
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "segmented-nexthop-present"):
                                                                self.segmented_nexthop_present = value
                                                                self.segmented_nexthop_present.value_namespace = name_space
                                                                self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-asrt-present"):
                                                                self.source_asrt_present = value
                                                                self.source_asrt_present.value_namespace = name_space
                                                                self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-rd-present"):
                                                                self.source_rd_present = value
                                                                self.source_rd_present.value_namespace = name_space
                                                                self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-information-source"):
                                                                self.v6_information_source = value
                                                                self.v6_information_source.value_namespace = name_space
                                                                self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-nexthop"):
                                                                self.v6_nexthop = value
                                                                self.v6_nexthop.value_namespace = name_space
                                                                self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-import-rt-present"):
                                                                self.vrf_import_rt_present = value
                                                                self.vrf_import_rt_present.value_namespace = name_space
                                                                self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "route-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv6-rib-edm-path"):
                                                            for c in self.ipv6_rib_edm_path:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.ipv6_rib_edm_path.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv6-rib-edm-path"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.active.is_set or
                                                        self.address.is_set or
                                                        self.attribute_identity.is_set or
                                                        self.client_id.is_set or
                                                        self.distance.is_set or
                                                        self.diversion.is_set or
                                                        self.diversion_distance.is_set or
                                                        self.diversion_proto_name.is_set or
                                                        self.extended_flags.is_set or
                                                        self.flags.is_set or
                                                        self.flow_tag.is_set or
                                                        self.fwd_class.is_set or
                                                        self.instance.is_set or
                                                        self.metric.is_set or
                                                        self.paths_count.is_set or
                                                        self.pic_count.is_set or
                                                        self.prefix.is_set or
                                                        self.prefix_length.is_set or
                                                        self.prefix_length_xr.is_set or
                                                        self.priority.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_name.is_set or
                                                        self.qos_group.is_set or
                                                        self.route_age.is_set or
                                                        self.route_label.is_set or
                                                        self.route_modify_time.is_set or
                                                        self.route_precedence.is_set or
                                                        self.route_type.is_set or
                                                        self.route_version.is_set or
                                                        self.svd_type.is_set or
                                                        self.tag.is_set or
                                                        self.tbl_version.is_set or
                                                        self.traffic_index.is_set or
                                                        self.version.is_set or
                                                        (self.route_path is not None and self.route_path.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.active.yfilter != YFilter.not_set or
                                                        self.address.yfilter != YFilter.not_set or
                                                        self.attribute_identity.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.distance.yfilter != YFilter.not_set or
                                                        self.diversion.yfilter != YFilter.not_set or
                                                        self.diversion_distance.yfilter != YFilter.not_set or
                                                        self.diversion_proto_name.yfilter != YFilter.not_set or
                                                        self.extended_flags.yfilter != YFilter.not_set or
                                                        self.flags.yfilter != YFilter.not_set or
                                                        self.flow_tag.yfilter != YFilter.not_set or
                                                        self.fwd_class.yfilter != YFilter.not_set or
                                                        self.instance.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.paths_count.yfilter != YFilter.not_set or
                                                        self.pic_count.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length.yfilter != YFilter.not_set or
                                                        self.prefix_length_xr.yfilter != YFilter.not_set or
                                                        self.priority.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_name.yfilter != YFilter.not_set or
                                                        self.qos_group.yfilter != YFilter.not_set or
                                                        self.route_age.yfilter != YFilter.not_set or
                                                        self.route_label.yfilter != YFilter.not_set or
                                                        self.route_modify_time.yfilter != YFilter.not_set or
                                                        self.route_precedence.yfilter != YFilter.not_set or
                                                        self.route_type.yfilter != YFilter.not_set or
                                                        self.route_version.yfilter != YFilter.not_set or
                                                        self.svd_type.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tbl_version.yfilter != YFilter.not_set or
                                                        self.traffic_index.yfilter != YFilter.not_set or
                                                        self.version.yfilter != YFilter.not_set or
                                                        (self.route_path is not None and self.route_path.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dest-q-route" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.active.get_name_leafdata())
                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                    if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                                    if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion.get_name_leafdata())
                                                    if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                    if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                    if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                    if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                    if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                    if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                    if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                    if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                    if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_age.get_name_leafdata())
                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                    if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                    if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_type.get_name_leafdata())
                                                    if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_version.get_name_leafdata())
                                                    if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                    if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                    if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.version.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "route-path"):
                                                        if (self.route_path is None):
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                        return self.route_path

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "active"):
                                                        self.active = value
                                                        self.active.value_namespace = name_space
                                                        self.active.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "address"):
                                                        self.address = value
                                                        self.address.value_namespace = name_space
                                                        self.address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "attribute-identity"):
                                                        self.attribute_identity = value
                                                        self.attribute_identity.value_namespace = name_space
                                                        self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "distance"):
                                                        self.distance = value
                                                        self.distance.value_namespace = name_space
                                                        self.distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion"):
                                                        self.diversion = value
                                                        self.diversion.value_namespace = name_space
                                                        self.diversion.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-distance"):
                                                        self.diversion_distance = value
                                                        self.diversion_distance.value_namespace = name_space
                                                        self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-proto-name"):
                                                        self.diversion_proto_name = value
                                                        self.diversion_proto_name.value_namespace = name_space
                                                        self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-flags"):
                                                        self.extended_flags = value
                                                        self.extended_flags.value_namespace = name_space
                                                        self.extended_flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flags"):
                                                        self.flags = value
                                                        self.flags.value_namespace = name_space
                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flow-tag"):
                                                        self.flow_tag = value
                                                        self.flow_tag.value_namespace = name_space
                                                        self.flow_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fwd-class"):
                                                        self.fwd_class = value
                                                        self.fwd_class.value_namespace = name_space
                                                        self.fwd_class.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance"):
                                                        self.instance = value
                                                        self.instance.value_namespace = name_space
                                                        self.instance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "paths-count"):
                                                        self.paths_count = value
                                                        self.paths_count.value_namespace = name_space
                                                        self.paths_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pic-count"):
                                                        self.pic_count = value
                                                        self.pic_count.value_namespace = name_space
                                                        self.pic_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length"):
                                                        self.prefix_length = value
                                                        self.prefix_length.value_namespace = name_space
                                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length-xr"):
                                                        self.prefix_length_xr = value
                                                        self.prefix_length_xr.value_namespace = name_space
                                                        self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "priority"):
                                                        self.priority = value
                                                        self.priority.value_namespace = name_space
                                                        self.priority.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-name"):
                                                        self.protocol_name = value
                                                        self.protocol_name.value_namespace = name_space
                                                        self.protocol_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "qos-group"):
                                                        self.qos_group = value
                                                        self.qos_group.value_namespace = name_space
                                                        self.qos_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-age"):
                                                        self.route_age = value
                                                        self.route_age.value_namespace = name_space
                                                        self.route_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-label"):
                                                        self.route_label = value
                                                        self.route_label.value_namespace = name_space
                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-modify-time"):
                                                        self.route_modify_time = value
                                                        self.route_modify_time.value_namespace = name_space
                                                        self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-precedence"):
                                                        self.route_precedence = value
                                                        self.route_precedence.value_namespace = name_space
                                                        self.route_precedence.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-type"):
                                                        self.route_type = value
                                                        self.route_type.value_namespace = name_space
                                                        self.route_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-version"):
                                                        self.route_version = value
                                                        self.route_version.value_namespace = name_space
                                                        self.route_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "svd-type"):
                                                        self.svd_type = value
                                                        self.svd_type.value_namespace = name_space
                                                        self.svd_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tbl-version"):
                                                        self.tbl_version = value
                                                        self.tbl_version.value_namespace = name_space
                                                        self.tbl_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "traffic-index"):
                                                        self.traffic_index = value
                                                        self.traffic_index.value_namespace = name_space
                                                        self.traffic_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "version"):
                                                        self.version = value
                                                        self.version.value_namespace = name_space
                                                        self.version.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.dest_q_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.dest_q_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dest-q-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "dest-q-route"):
                                                    for c in self.dest_q_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.dest_q_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dest-q-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DestBackupRoutes(Entity):
                                            """
                                            Backup
                                            
                                            .. attribute:: dest_backup_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__init__()

                                                self.yang_name = "dest-backup-routes"
                                                self.yang_parent_name = "destination-kw"

                                                self.dest_backup_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__setattr__(name, value)


                                            class DestBackupRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__init__()

                                                    self.yang_name = "dest-backup-route"
                                                    self.yang_parent_name = "dest-backup-routes"

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("active",
                                                                    "address",
                                                                    "attribute_identity",
                                                                    "client_id",
                                                                    "distance",
                                                                    "diversion",
                                                                    "diversion_distance",
                                                                    "diversion_proto_name",
                                                                    "extended_flags",
                                                                    "flags",
                                                                    "flow_tag",
                                                                    "fwd_class",
                                                                    "instance",
                                                                    "metric",
                                                                    "paths_count",
                                                                    "pic_count",
                                                                    "prefix",
                                                                    "prefix_length",
                                                                    "prefix_length_xr",
                                                                    "priority",
                                                                    "protocol_id",
                                                                    "protocol_name",
                                                                    "qos_group",
                                                                    "route_age",
                                                                    "route_label",
                                                                    "route_modify_time",
                                                                    "route_precedence",
                                                                    "route_type",
                                                                    "route_version",
                                                                    "svd_type",
                                                                    "tag",
                                                                    "tbl_version",
                                                                    "traffic_index",
                                                                    "version") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__setattr__(name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-backup-route"

                                                        self.ipv6_rib_edm_path = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__setattr__(name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("address",
                                                                            "backup_pathid",
                                                                            "binding_label",
                                                                            "flags",
                                                                            "flags64",
                                                                            "has_labelstk",
                                                                            "information_source",
                                                                            "interface_name",
                                                                            "labelstk",
                                                                            "load_metric",
                                                                            "looped",
                                                                            "metric",
                                                                            "mpls_feid",
                                                                            "mvpn_present",
                                                                            "next_hop_afi",
                                                                            "next_hop_id",
                                                                            "next_hop_id_refcount",
                                                                            "next_hop_safi",
                                                                            "next_hop_table_id",
                                                                            "next_hop_table_name",
                                                                            "next_hop_vrf_name",
                                                                            "nhid_feid",
                                                                            "num_labels",
                                                                            "number_of_extended_communities",
                                                                            "ospf_area_id",
                                                                            "path_rt_present",
                                                                            "pathid",
                                                                            "private_flags",
                                                                            "ref_cnt_of_backup",
                                                                            "remote_backup_addr",
                                                                            "route_label",
                                                                            "segmented_nexthop_present",
                                                                            "source_asrt_present",
                                                                            "source_rd_present",
                                                                            "tunnel_id",
                                                                            "v6_information_source",
                                                                            "v6_nexthop",
                                                                            "vrf_import_rt_present") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            return (
                                                                self.address.is_set or
                                                                self.backup_pathid.is_set or
                                                                self.binding_label.is_set or
                                                                self.flags.is_set or
                                                                self.flags64.is_set or
                                                                self.has_labelstk.is_set or
                                                                self.information_source.is_set or
                                                                self.interface_name.is_set or
                                                                self.load_metric.is_set or
                                                                self.looped.is_set or
                                                                self.metric.is_set or
                                                                self.mpls_feid.is_set or
                                                                self.mvpn_present.is_set or
                                                                self.next_hop_afi.is_set or
                                                                self.next_hop_id.is_set or
                                                                self.next_hop_id_refcount.is_set or
                                                                self.next_hop_safi.is_set or
                                                                self.next_hop_table_id.is_set or
                                                                self.next_hop_table_name.is_set or
                                                                self.next_hop_vrf_name.is_set or
                                                                self.nhid_feid.is_set or
                                                                self.num_labels.is_set or
                                                                self.number_of_extended_communities.is_set or
                                                                self.ospf_area_id.is_set or
                                                                self.path_rt_present.is_set or
                                                                self.pathid.is_set or
                                                                self.private_flags.is_set or
                                                                self.ref_cnt_of_backup.is_set or
                                                                self.route_label.is_set or
                                                                self.segmented_nexthop_present.is_set or
                                                                self.source_asrt_present.is_set or
                                                                self.source_rd_present.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.v6_information_source.is_set or
                                                                self.v6_nexthop.is_set or
                                                                self.vrf_import_rt_present.is_set)

                                                        def has_operation(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.backup_pathid.yfilter != YFilter.not_set or
                                                                self.binding_label.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flags64.yfilter != YFilter.not_set or
                                                                self.has_labelstk.yfilter != YFilter.not_set or
                                                                self.information_source.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.labelstk.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.looped.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.mpls_feid.yfilter != YFilter.not_set or
                                                                self.mvpn_present.yfilter != YFilter.not_set or
                                                                self.next_hop_afi.yfilter != YFilter.not_set or
                                                                self.next_hop_id.yfilter != YFilter.not_set or
                                                                self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                self.next_hop_safi.yfilter != YFilter.not_set or
                                                                self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                self.nhid_feid.yfilter != YFilter.not_set or
                                                                self.num_labels.yfilter != YFilter.not_set or
                                                                self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                self.ospf_area_id.yfilter != YFilter.not_set or
                                                                self.path_rt_present.yfilter != YFilter.not_set or
                                                                self.pathid.yfilter != YFilter.not_set or
                                                                self.private_flags.yfilter != YFilter.not_set or
                                                                self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                self.source_asrt_present.yfilter != YFilter.not_set or
                                                                self.source_rd_present.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.v6_information_source.yfilter != YFilter.not_set or
                                                                self.v6_nexthop.yfilter != YFilter.not_set or
                                                                self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                            if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags64.get_name_leafdata())
                                                            if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                            if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.information_source.get_name_leafdata())
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.looped.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                            if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                            if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                            if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                            if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                            if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                            if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                            if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                            if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                            if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                            if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                            if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                            if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                            if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                            if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pathid.get_name_leafdata())
                                                            if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                            if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                            if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                            if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                            if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                            if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                            leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                            leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "backup-pathid"):
                                                                self.backup_pathid = value
                                                                self.backup_pathid.value_namespace = name_space
                                                                self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "binding-label"):
                                                                self.binding_label = value
                                                                self.binding_label.value_namespace = name_space
                                                                self.binding_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags64"):
                                                                self.flags64 = value
                                                                self.flags64.value_namespace = name_space
                                                                self.flags64.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "has-labelstk"):
                                                                self.has_labelstk = value
                                                                self.has_labelstk.value_namespace = name_space
                                                                self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "information-source"):
                                                                self.information_source = value
                                                                self.information_source.value_namespace = name_space
                                                                self.information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "labelstk"):
                                                                self.labelstk.append(value)
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "looped"):
                                                                self.looped = value
                                                                self.looped.value_namespace = name_space
                                                                self.looped.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mpls-feid"):
                                                                self.mpls_feid = value
                                                                self.mpls_feid.value_namespace = name_space
                                                                self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mvpn-present"):
                                                                self.mvpn_present = value
                                                                self.mvpn_present.value_namespace = name_space
                                                                self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-afi"):
                                                                self.next_hop_afi = value
                                                                self.next_hop_afi.value_namespace = name_space
                                                                self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id"):
                                                                self.next_hop_id = value
                                                                self.next_hop_id.value_namespace = name_space
                                                                self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id-refcount"):
                                                                self.next_hop_id_refcount = value
                                                                self.next_hop_id_refcount.value_namespace = name_space
                                                                self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-safi"):
                                                                self.next_hop_safi = value
                                                                self.next_hop_safi.value_namespace = name_space
                                                                self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-id"):
                                                                self.next_hop_table_id = value
                                                                self.next_hop_table_id.value_namespace = name_space
                                                                self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-name"):
                                                                self.next_hop_table_name = value
                                                                self.next_hop_table_name.value_namespace = name_space
                                                                self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-vrf-name"):
                                                                self.next_hop_vrf_name = value
                                                                self.next_hop_vrf_name.value_namespace = name_space
                                                                self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "nhid-feid"):
                                                                self.nhid_feid = value
                                                                self.nhid_feid.value_namespace = name_space
                                                                self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "num-labels"):
                                                                self.num_labels = value
                                                                self.num_labels.value_namespace = name_space
                                                                self.num_labels.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "number-of-extended-communities"):
                                                                self.number_of_extended_communities = value
                                                                self.number_of_extended_communities.value_namespace = name_space
                                                                self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ospf-area-id"):
                                                                self.ospf_area_id = value
                                                                self.ospf_area_id.value_namespace = name_space
                                                                self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "path-rt-present"):
                                                                self.path_rt_present = value
                                                                self.path_rt_present.value_namespace = name_space
                                                                self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pathid"):
                                                                self.pathid = value
                                                                self.pathid.value_namespace = name_space
                                                                self.pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "private-flags"):
                                                                self.private_flags = value
                                                                self.private_flags.value_namespace = name_space
                                                                self.private_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ref-cnt-of-backup"):
                                                                self.ref_cnt_of_backup = value
                                                                self.ref_cnt_of_backup.value_namespace = name_space
                                                                self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "remote-backup-addr"):
                                                                self.remote_backup_addr.append(value)
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "segmented-nexthop-present"):
                                                                self.segmented_nexthop_present = value
                                                                self.segmented_nexthop_present.value_namespace = name_space
                                                                self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-asrt-present"):
                                                                self.source_asrt_present = value
                                                                self.source_asrt_present.value_namespace = name_space
                                                                self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-rd-present"):
                                                                self.source_rd_present = value
                                                                self.source_rd_present.value_namespace = name_space
                                                                self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-information-source"):
                                                                self.v6_information_source = value
                                                                self.v6_information_source.value_namespace = name_space
                                                                self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-nexthop"):
                                                                self.v6_nexthop = value
                                                                self.v6_nexthop.value_namespace = name_space
                                                                self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-import-rt-present"):
                                                                self.vrf_import_rt_present = value
                                                                self.vrf_import_rt_present.value_namespace = name_space
                                                                self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "route-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv6-rib-edm-path"):
                                                            for c in self.ipv6_rib_edm_path:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.ipv6_rib_edm_path.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv6-rib-edm-path"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.active.is_set or
                                                        self.address.is_set or
                                                        self.attribute_identity.is_set or
                                                        self.client_id.is_set or
                                                        self.distance.is_set or
                                                        self.diversion.is_set or
                                                        self.diversion_distance.is_set or
                                                        self.diversion_proto_name.is_set or
                                                        self.extended_flags.is_set or
                                                        self.flags.is_set or
                                                        self.flow_tag.is_set or
                                                        self.fwd_class.is_set or
                                                        self.instance.is_set or
                                                        self.metric.is_set or
                                                        self.paths_count.is_set or
                                                        self.pic_count.is_set or
                                                        self.prefix.is_set or
                                                        self.prefix_length.is_set or
                                                        self.prefix_length_xr.is_set or
                                                        self.priority.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_name.is_set or
                                                        self.qos_group.is_set or
                                                        self.route_age.is_set or
                                                        self.route_label.is_set or
                                                        self.route_modify_time.is_set or
                                                        self.route_precedence.is_set or
                                                        self.route_type.is_set or
                                                        self.route_version.is_set or
                                                        self.svd_type.is_set or
                                                        self.tag.is_set or
                                                        self.tbl_version.is_set or
                                                        self.traffic_index.is_set or
                                                        self.version.is_set or
                                                        (self.route_path is not None and self.route_path.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.active.yfilter != YFilter.not_set or
                                                        self.address.yfilter != YFilter.not_set or
                                                        self.attribute_identity.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.distance.yfilter != YFilter.not_set or
                                                        self.diversion.yfilter != YFilter.not_set or
                                                        self.diversion_distance.yfilter != YFilter.not_set or
                                                        self.diversion_proto_name.yfilter != YFilter.not_set or
                                                        self.extended_flags.yfilter != YFilter.not_set or
                                                        self.flags.yfilter != YFilter.not_set or
                                                        self.flow_tag.yfilter != YFilter.not_set or
                                                        self.fwd_class.yfilter != YFilter.not_set or
                                                        self.instance.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.paths_count.yfilter != YFilter.not_set or
                                                        self.pic_count.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length.yfilter != YFilter.not_set or
                                                        self.prefix_length_xr.yfilter != YFilter.not_set or
                                                        self.priority.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_name.yfilter != YFilter.not_set or
                                                        self.qos_group.yfilter != YFilter.not_set or
                                                        self.route_age.yfilter != YFilter.not_set or
                                                        self.route_label.yfilter != YFilter.not_set or
                                                        self.route_modify_time.yfilter != YFilter.not_set or
                                                        self.route_precedence.yfilter != YFilter.not_set or
                                                        self.route_type.yfilter != YFilter.not_set or
                                                        self.route_version.yfilter != YFilter.not_set or
                                                        self.svd_type.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tbl_version.yfilter != YFilter.not_set or
                                                        self.traffic_index.yfilter != YFilter.not_set or
                                                        self.version.yfilter != YFilter.not_set or
                                                        (self.route_path is not None and self.route_path.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dest-backup-route" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.active.get_name_leafdata())
                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                    if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                                    if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion.get_name_leafdata())
                                                    if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                    if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                    if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                    if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                    if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                    if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                    if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                    if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                    if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_age.get_name_leafdata())
                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                    if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                    if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_type.get_name_leafdata())
                                                    if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_version.get_name_leafdata())
                                                    if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                    if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                    if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.version.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "route-path"):
                                                        if (self.route_path is None):
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                        return self.route_path

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "active"):
                                                        self.active = value
                                                        self.active.value_namespace = name_space
                                                        self.active.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "address"):
                                                        self.address = value
                                                        self.address.value_namespace = name_space
                                                        self.address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "attribute-identity"):
                                                        self.attribute_identity = value
                                                        self.attribute_identity.value_namespace = name_space
                                                        self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "distance"):
                                                        self.distance = value
                                                        self.distance.value_namespace = name_space
                                                        self.distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion"):
                                                        self.diversion = value
                                                        self.diversion.value_namespace = name_space
                                                        self.diversion.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-distance"):
                                                        self.diversion_distance = value
                                                        self.diversion_distance.value_namespace = name_space
                                                        self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-proto-name"):
                                                        self.diversion_proto_name = value
                                                        self.diversion_proto_name.value_namespace = name_space
                                                        self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-flags"):
                                                        self.extended_flags = value
                                                        self.extended_flags.value_namespace = name_space
                                                        self.extended_flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flags"):
                                                        self.flags = value
                                                        self.flags.value_namespace = name_space
                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flow-tag"):
                                                        self.flow_tag = value
                                                        self.flow_tag.value_namespace = name_space
                                                        self.flow_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fwd-class"):
                                                        self.fwd_class = value
                                                        self.fwd_class.value_namespace = name_space
                                                        self.fwd_class.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance"):
                                                        self.instance = value
                                                        self.instance.value_namespace = name_space
                                                        self.instance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "paths-count"):
                                                        self.paths_count = value
                                                        self.paths_count.value_namespace = name_space
                                                        self.paths_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pic-count"):
                                                        self.pic_count = value
                                                        self.pic_count.value_namespace = name_space
                                                        self.pic_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length"):
                                                        self.prefix_length = value
                                                        self.prefix_length.value_namespace = name_space
                                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length-xr"):
                                                        self.prefix_length_xr = value
                                                        self.prefix_length_xr.value_namespace = name_space
                                                        self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "priority"):
                                                        self.priority = value
                                                        self.priority.value_namespace = name_space
                                                        self.priority.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-name"):
                                                        self.protocol_name = value
                                                        self.protocol_name.value_namespace = name_space
                                                        self.protocol_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "qos-group"):
                                                        self.qos_group = value
                                                        self.qos_group.value_namespace = name_space
                                                        self.qos_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-age"):
                                                        self.route_age = value
                                                        self.route_age.value_namespace = name_space
                                                        self.route_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-label"):
                                                        self.route_label = value
                                                        self.route_label.value_namespace = name_space
                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-modify-time"):
                                                        self.route_modify_time = value
                                                        self.route_modify_time.value_namespace = name_space
                                                        self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-precedence"):
                                                        self.route_precedence = value
                                                        self.route_precedence.value_namespace = name_space
                                                        self.route_precedence.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-type"):
                                                        self.route_type = value
                                                        self.route_type.value_namespace = name_space
                                                        self.route_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-version"):
                                                        self.route_version = value
                                                        self.route_version.value_namespace = name_space
                                                        self.route_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "svd-type"):
                                                        self.svd_type = value
                                                        self.svd_type.value_namespace = name_space
                                                        self.svd_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tbl-version"):
                                                        self.tbl_version = value
                                                        self.tbl_version.value_namespace = name_space
                                                        self.tbl_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "traffic-index"):
                                                        self.traffic_index = value
                                                        self.traffic_index.value_namespace = name_space
                                                        self.traffic_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "version"):
                                                        self.version = value
                                                        self.version.value_namespace = name_space
                                                        self.version.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.dest_backup_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.dest_backup_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dest-backup-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "dest-backup-route"):
                                                    for c in self.dest_backup_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.dest_backup_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dest-backup-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DestBestRoutes(Entity):
                                            """
                                            Best Local
                                            
                                            .. attribute:: dest_best_route
                                            
                                            	Best local route information for a specific Address 
                                            	**type**\: list of    :py:class:`DestBestRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__init__()

                                                self.yang_name = "dest-best-routes"
                                                self.yang_parent_name = "destination-kw"

                                                self.dest_best_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__setattr__(name, value)


                                            class DestBestRoute(Entity):
                                                """
                                                Best local route information for a
                                                specific Address 
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__init__()

                                                    self.yang_name = "dest-best-route"
                                                    self.yang_parent_name = "dest-best-routes"

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("address",
                                                                    "active",
                                                                    "attribute_identity",
                                                                    "client_id",
                                                                    "distance",
                                                                    "diversion",
                                                                    "diversion_distance",
                                                                    "diversion_proto_name",
                                                                    "extended_flags",
                                                                    "flags",
                                                                    "flow_tag",
                                                                    "fwd_class",
                                                                    "instance",
                                                                    "metric",
                                                                    "paths_count",
                                                                    "pic_count",
                                                                    "prefix",
                                                                    "prefix_length_xr",
                                                                    "priority",
                                                                    "protocol_id",
                                                                    "protocol_name",
                                                                    "qos_group",
                                                                    "route_age",
                                                                    "route_label",
                                                                    "route_modify_time",
                                                                    "route_precedence",
                                                                    "route_type",
                                                                    "route_version",
                                                                    "svd_type",
                                                                    "tag",
                                                                    "tbl_version",
                                                                    "traffic_index",
                                                                    "version") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__setattr__(name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-best-route"

                                                        self.ipv6_rib_edm_path = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__setattr__(name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("address",
                                                                            "backup_pathid",
                                                                            "binding_label",
                                                                            "flags",
                                                                            "flags64",
                                                                            "has_labelstk",
                                                                            "information_source",
                                                                            "interface_name",
                                                                            "labelstk",
                                                                            "load_metric",
                                                                            "looped",
                                                                            "metric",
                                                                            "mpls_feid",
                                                                            "mvpn_present",
                                                                            "next_hop_afi",
                                                                            "next_hop_id",
                                                                            "next_hop_id_refcount",
                                                                            "next_hop_safi",
                                                                            "next_hop_table_id",
                                                                            "next_hop_table_name",
                                                                            "next_hop_vrf_name",
                                                                            "nhid_feid",
                                                                            "num_labels",
                                                                            "number_of_extended_communities",
                                                                            "ospf_area_id",
                                                                            "path_rt_present",
                                                                            "pathid",
                                                                            "private_flags",
                                                                            "ref_cnt_of_backup",
                                                                            "remote_backup_addr",
                                                                            "route_label",
                                                                            "segmented_nexthop_present",
                                                                            "source_asrt_present",
                                                                            "source_rd_present",
                                                                            "tunnel_id",
                                                                            "v6_information_source",
                                                                            "v6_nexthop",
                                                                            "vrf_import_rt_present") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            return (
                                                                self.address.is_set or
                                                                self.backup_pathid.is_set or
                                                                self.binding_label.is_set or
                                                                self.flags.is_set or
                                                                self.flags64.is_set or
                                                                self.has_labelstk.is_set or
                                                                self.information_source.is_set or
                                                                self.interface_name.is_set or
                                                                self.load_metric.is_set or
                                                                self.looped.is_set or
                                                                self.metric.is_set or
                                                                self.mpls_feid.is_set or
                                                                self.mvpn_present.is_set or
                                                                self.next_hop_afi.is_set or
                                                                self.next_hop_id.is_set or
                                                                self.next_hop_id_refcount.is_set or
                                                                self.next_hop_safi.is_set or
                                                                self.next_hop_table_id.is_set or
                                                                self.next_hop_table_name.is_set or
                                                                self.next_hop_vrf_name.is_set or
                                                                self.nhid_feid.is_set or
                                                                self.num_labels.is_set or
                                                                self.number_of_extended_communities.is_set or
                                                                self.ospf_area_id.is_set or
                                                                self.path_rt_present.is_set or
                                                                self.pathid.is_set or
                                                                self.private_flags.is_set or
                                                                self.ref_cnt_of_backup.is_set or
                                                                self.route_label.is_set or
                                                                self.segmented_nexthop_present.is_set or
                                                                self.source_asrt_present.is_set or
                                                                self.source_rd_present.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.v6_information_source.is_set or
                                                                self.v6_nexthop.is_set or
                                                                self.vrf_import_rt_present.is_set)

                                                        def has_operation(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.backup_pathid.yfilter != YFilter.not_set or
                                                                self.binding_label.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flags64.yfilter != YFilter.not_set or
                                                                self.has_labelstk.yfilter != YFilter.not_set or
                                                                self.information_source.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.labelstk.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.looped.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.mpls_feid.yfilter != YFilter.not_set or
                                                                self.mvpn_present.yfilter != YFilter.not_set or
                                                                self.next_hop_afi.yfilter != YFilter.not_set or
                                                                self.next_hop_id.yfilter != YFilter.not_set or
                                                                self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                self.next_hop_safi.yfilter != YFilter.not_set or
                                                                self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                self.nhid_feid.yfilter != YFilter.not_set or
                                                                self.num_labels.yfilter != YFilter.not_set or
                                                                self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                self.ospf_area_id.yfilter != YFilter.not_set or
                                                                self.path_rt_present.yfilter != YFilter.not_set or
                                                                self.pathid.yfilter != YFilter.not_set or
                                                                self.private_flags.yfilter != YFilter.not_set or
                                                                self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                self.source_asrt_present.yfilter != YFilter.not_set or
                                                                self.source_rd_present.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.v6_information_source.yfilter != YFilter.not_set or
                                                                self.v6_nexthop.yfilter != YFilter.not_set or
                                                                self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                            if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags64.get_name_leafdata())
                                                            if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                            if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.information_source.get_name_leafdata())
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.looped.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                            if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                            if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                            if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                            if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                            if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                            if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                            if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                            if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                            if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                            if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                            if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                            if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                            if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                            if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pathid.get_name_leafdata())
                                                            if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                            if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                            if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                            if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                            if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                            if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                            leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                            leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "backup-pathid"):
                                                                self.backup_pathid = value
                                                                self.backup_pathid.value_namespace = name_space
                                                                self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "binding-label"):
                                                                self.binding_label = value
                                                                self.binding_label.value_namespace = name_space
                                                                self.binding_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags64"):
                                                                self.flags64 = value
                                                                self.flags64.value_namespace = name_space
                                                                self.flags64.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "has-labelstk"):
                                                                self.has_labelstk = value
                                                                self.has_labelstk.value_namespace = name_space
                                                                self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "information-source"):
                                                                self.information_source = value
                                                                self.information_source.value_namespace = name_space
                                                                self.information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "labelstk"):
                                                                self.labelstk.append(value)
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "looped"):
                                                                self.looped = value
                                                                self.looped.value_namespace = name_space
                                                                self.looped.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mpls-feid"):
                                                                self.mpls_feid = value
                                                                self.mpls_feid.value_namespace = name_space
                                                                self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mvpn-present"):
                                                                self.mvpn_present = value
                                                                self.mvpn_present.value_namespace = name_space
                                                                self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-afi"):
                                                                self.next_hop_afi = value
                                                                self.next_hop_afi.value_namespace = name_space
                                                                self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id"):
                                                                self.next_hop_id = value
                                                                self.next_hop_id.value_namespace = name_space
                                                                self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id-refcount"):
                                                                self.next_hop_id_refcount = value
                                                                self.next_hop_id_refcount.value_namespace = name_space
                                                                self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-safi"):
                                                                self.next_hop_safi = value
                                                                self.next_hop_safi.value_namespace = name_space
                                                                self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-id"):
                                                                self.next_hop_table_id = value
                                                                self.next_hop_table_id.value_namespace = name_space
                                                                self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-name"):
                                                                self.next_hop_table_name = value
                                                                self.next_hop_table_name.value_namespace = name_space
                                                                self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-vrf-name"):
                                                                self.next_hop_vrf_name = value
                                                                self.next_hop_vrf_name.value_namespace = name_space
                                                                self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "nhid-feid"):
                                                                self.nhid_feid = value
                                                                self.nhid_feid.value_namespace = name_space
                                                                self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "num-labels"):
                                                                self.num_labels = value
                                                                self.num_labels.value_namespace = name_space
                                                                self.num_labels.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "number-of-extended-communities"):
                                                                self.number_of_extended_communities = value
                                                                self.number_of_extended_communities.value_namespace = name_space
                                                                self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ospf-area-id"):
                                                                self.ospf_area_id = value
                                                                self.ospf_area_id.value_namespace = name_space
                                                                self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "path-rt-present"):
                                                                self.path_rt_present = value
                                                                self.path_rt_present.value_namespace = name_space
                                                                self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pathid"):
                                                                self.pathid = value
                                                                self.pathid.value_namespace = name_space
                                                                self.pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "private-flags"):
                                                                self.private_flags = value
                                                                self.private_flags.value_namespace = name_space
                                                                self.private_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ref-cnt-of-backup"):
                                                                self.ref_cnt_of_backup = value
                                                                self.ref_cnt_of_backup.value_namespace = name_space
                                                                self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "remote-backup-addr"):
                                                                self.remote_backup_addr.append(value)
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "segmented-nexthop-present"):
                                                                self.segmented_nexthop_present = value
                                                                self.segmented_nexthop_present.value_namespace = name_space
                                                                self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-asrt-present"):
                                                                self.source_asrt_present = value
                                                                self.source_asrt_present.value_namespace = name_space
                                                                self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-rd-present"):
                                                                self.source_rd_present = value
                                                                self.source_rd_present.value_namespace = name_space
                                                                self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-information-source"):
                                                                self.v6_information_source = value
                                                                self.v6_information_source.value_namespace = name_space
                                                                self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-nexthop"):
                                                                self.v6_nexthop = value
                                                                self.v6_nexthop.value_namespace = name_space
                                                                self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-import-rt-present"):
                                                                self.vrf_import_rt_present = value
                                                                self.vrf_import_rt_present.value_namespace = name_space
                                                                self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "route-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv6-rib-edm-path"):
                                                            for c in self.ipv6_rib_edm_path:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.ipv6_rib_edm_path.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv6-rib-edm-path"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.address.is_set or
                                                        self.active.is_set or
                                                        self.attribute_identity.is_set or
                                                        self.client_id.is_set or
                                                        self.distance.is_set or
                                                        self.diversion.is_set or
                                                        self.diversion_distance.is_set or
                                                        self.diversion_proto_name.is_set or
                                                        self.extended_flags.is_set or
                                                        self.flags.is_set or
                                                        self.flow_tag.is_set or
                                                        self.fwd_class.is_set or
                                                        self.instance.is_set or
                                                        self.metric.is_set or
                                                        self.paths_count.is_set or
                                                        self.pic_count.is_set or
                                                        self.prefix.is_set or
                                                        self.prefix_length_xr.is_set or
                                                        self.priority.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_name.is_set or
                                                        self.qos_group.is_set or
                                                        self.route_age.is_set or
                                                        self.route_label.is_set or
                                                        self.route_modify_time.is_set or
                                                        self.route_precedence.is_set or
                                                        self.route_type.is_set or
                                                        self.route_version.is_set or
                                                        self.svd_type.is_set or
                                                        self.tag.is_set or
                                                        self.tbl_version.is_set or
                                                        self.traffic_index.is_set or
                                                        self.version.is_set or
                                                        (self.route_path is not None and self.route_path.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.address.yfilter != YFilter.not_set or
                                                        self.active.yfilter != YFilter.not_set or
                                                        self.attribute_identity.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.distance.yfilter != YFilter.not_set or
                                                        self.diversion.yfilter != YFilter.not_set or
                                                        self.diversion_distance.yfilter != YFilter.not_set or
                                                        self.diversion_proto_name.yfilter != YFilter.not_set or
                                                        self.extended_flags.yfilter != YFilter.not_set or
                                                        self.flags.yfilter != YFilter.not_set or
                                                        self.flow_tag.yfilter != YFilter.not_set or
                                                        self.fwd_class.yfilter != YFilter.not_set or
                                                        self.instance.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.paths_count.yfilter != YFilter.not_set or
                                                        self.pic_count.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length_xr.yfilter != YFilter.not_set or
                                                        self.priority.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_name.yfilter != YFilter.not_set or
                                                        self.qos_group.yfilter != YFilter.not_set or
                                                        self.route_age.yfilter != YFilter.not_set or
                                                        self.route_label.yfilter != YFilter.not_set or
                                                        self.route_modify_time.yfilter != YFilter.not_set or
                                                        self.route_precedence.yfilter != YFilter.not_set or
                                                        self.route_type.yfilter != YFilter.not_set or
                                                        self.route_version.yfilter != YFilter.not_set or
                                                        self.svd_type.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tbl_version.yfilter != YFilter.not_set or
                                                        self.traffic_index.yfilter != YFilter.not_set or
                                                        self.version.yfilter != YFilter.not_set or
                                                        (self.route_path is not None and self.route_path.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dest-best-route" + "[address='" + self.address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.active.get_name_leafdata())
                                                    if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                                    if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion.get_name_leafdata())
                                                    if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                    if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                    if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                    if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                    if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                    if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                    if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                    if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_age.get_name_leafdata())
                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                    if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                    if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_type.get_name_leafdata())
                                                    if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_version.get_name_leafdata())
                                                    if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                    if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                    if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.version.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "route-path"):
                                                        if (self.route_path is None):
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                        return self.route_path

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "route-path" or name == "address" or name == "active" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "address"):
                                                        self.address = value
                                                        self.address.value_namespace = name_space
                                                        self.address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "active"):
                                                        self.active = value
                                                        self.active.value_namespace = name_space
                                                        self.active.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "attribute-identity"):
                                                        self.attribute_identity = value
                                                        self.attribute_identity.value_namespace = name_space
                                                        self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "distance"):
                                                        self.distance = value
                                                        self.distance.value_namespace = name_space
                                                        self.distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion"):
                                                        self.diversion = value
                                                        self.diversion.value_namespace = name_space
                                                        self.diversion.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-distance"):
                                                        self.diversion_distance = value
                                                        self.diversion_distance.value_namespace = name_space
                                                        self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-proto-name"):
                                                        self.diversion_proto_name = value
                                                        self.diversion_proto_name.value_namespace = name_space
                                                        self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-flags"):
                                                        self.extended_flags = value
                                                        self.extended_flags.value_namespace = name_space
                                                        self.extended_flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flags"):
                                                        self.flags = value
                                                        self.flags.value_namespace = name_space
                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flow-tag"):
                                                        self.flow_tag = value
                                                        self.flow_tag.value_namespace = name_space
                                                        self.flow_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fwd-class"):
                                                        self.fwd_class = value
                                                        self.fwd_class.value_namespace = name_space
                                                        self.fwd_class.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance"):
                                                        self.instance = value
                                                        self.instance.value_namespace = name_space
                                                        self.instance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "paths-count"):
                                                        self.paths_count = value
                                                        self.paths_count.value_namespace = name_space
                                                        self.paths_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pic-count"):
                                                        self.pic_count = value
                                                        self.pic_count.value_namespace = name_space
                                                        self.pic_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length-xr"):
                                                        self.prefix_length_xr = value
                                                        self.prefix_length_xr.value_namespace = name_space
                                                        self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "priority"):
                                                        self.priority = value
                                                        self.priority.value_namespace = name_space
                                                        self.priority.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-name"):
                                                        self.protocol_name = value
                                                        self.protocol_name.value_namespace = name_space
                                                        self.protocol_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "qos-group"):
                                                        self.qos_group = value
                                                        self.qos_group.value_namespace = name_space
                                                        self.qos_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-age"):
                                                        self.route_age = value
                                                        self.route_age.value_namespace = name_space
                                                        self.route_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-label"):
                                                        self.route_label = value
                                                        self.route_label.value_namespace = name_space
                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-modify-time"):
                                                        self.route_modify_time = value
                                                        self.route_modify_time.value_namespace = name_space
                                                        self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-precedence"):
                                                        self.route_precedence = value
                                                        self.route_precedence.value_namespace = name_space
                                                        self.route_precedence.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-type"):
                                                        self.route_type = value
                                                        self.route_type.value_namespace = name_space
                                                        self.route_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-version"):
                                                        self.route_version = value
                                                        self.route_version.value_namespace = name_space
                                                        self.route_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "svd-type"):
                                                        self.svd_type = value
                                                        self.svd_type.value_namespace = name_space
                                                        self.svd_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tbl-version"):
                                                        self.tbl_version = value
                                                        self.tbl_version.value_namespace = name_space
                                                        self.tbl_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "traffic-index"):
                                                        self.traffic_index = value
                                                        self.traffic_index.value_namespace = name_space
                                                        self.traffic_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "version"):
                                                        self.version = value
                                                        self.version.value_namespace = name_space
                                                        self.version.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.dest_best_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.dest_best_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dest-best-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "dest-best-route"):
                                                    for c in self.dest_best_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.dest_best_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dest-best-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DestNextHopRoutes(Entity):
                                            """
                                            Resolving next hop
                                            
                                            .. attribute:: dest_next_hop_route
                                            
                                            	Nexthop information for a specific address
                                            	**type**\: list of    :py:class:`DestNextHopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__init__()

                                                self.yang_name = "dest-next-hop-routes"
                                                self.yang_parent_name = "destination-kw"

                                                self.dest_next_hop_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__setattr__(name, value)


                                            class DestNextHopRoute(Entity):
                                                """
                                                Nexthop information for a specific
                                                address
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__init__()

                                                    self.yang_name = "dest-next-hop-route"
                                                    self.yang_parent_name = "dest-next-hop-routes"

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("address",
                                                                    "active",
                                                                    "attribute_identity",
                                                                    "client_id",
                                                                    "distance",
                                                                    "diversion",
                                                                    "diversion_distance",
                                                                    "diversion_proto_name",
                                                                    "extended_flags",
                                                                    "flags",
                                                                    "flow_tag",
                                                                    "fwd_class",
                                                                    "instance",
                                                                    "metric",
                                                                    "paths_count",
                                                                    "pic_count",
                                                                    "prefix",
                                                                    "prefix_length_xr",
                                                                    "priority",
                                                                    "protocol_id",
                                                                    "protocol_name",
                                                                    "qos_group",
                                                                    "route_age",
                                                                    "route_label",
                                                                    "route_modify_time",
                                                                    "route_precedence",
                                                                    "route_type",
                                                                    "route_version",
                                                                    "svd_type",
                                                                    "tag",
                                                                    "tbl_version",
                                                                    "traffic_index",
                                                                    "version") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__setattr__(name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-next-hop-route"

                                                        self.ipv6_rib_edm_path = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__setattr__(name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("address",
                                                                            "backup_pathid",
                                                                            "binding_label",
                                                                            "flags",
                                                                            "flags64",
                                                                            "has_labelstk",
                                                                            "information_source",
                                                                            "interface_name",
                                                                            "labelstk",
                                                                            "load_metric",
                                                                            "looped",
                                                                            "metric",
                                                                            "mpls_feid",
                                                                            "mvpn_present",
                                                                            "next_hop_afi",
                                                                            "next_hop_id",
                                                                            "next_hop_id_refcount",
                                                                            "next_hop_safi",
                                                                            "next_hop_table_id",
                                                                            "next_hop_table_name",
                                                                            "next_hop_vrf_name",
                                                                            "nhid_feid",
                                                                            "num_labels",
                                                                            "number_of_extended_communities",
                                                                            "ospf_area_id",
                                                                            "path_rt_present",
                                                                            "pathid",
                                                                            "private_flags",
                                                                            "ref_cnt_of_backup",
                                                                            "remote_backup_addr",
                                                                            "route_label",
                                                                            "segmented_nexthop_present",
                                                                            "source_asrt_present",
                                                                            "source_rd_present",
                                                                            "tunnel_id",
                                                                            "v6_information_source",
                                                                            "v6_nexthop",
                                                                            "vrf_import_rt_present") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            return (
                                                                self.address.is_set or
                                                                self.backup_pathid.is_set or
                                                                self.binding_label.is_set or
                                                                self.flags.is_set or
                                                                self.flags64.is_set or
                                                                self.has_labelstk.is_set or
                                                                self.information_source.is_set or
                                                                self.interface_name.is_set or
                                                                self.load_metric.is_set or
                                                                self.looped.is_set or
                                                                self.metric.is_set or
                                                                self.mpls_feid.is_set or
                                                                self.mvpn_present.is_set or
                                                                self.next_hop_afi.is_set or
                                                                self.next_hop_id.is_set or
                                                                self.next_hop_id_refcount.is_set or
                                                                self.next_hop_safi.is_set or
                                                                self.next_hop_table_id.is_set or
                                                                self.next_hop_table_name.is_set or
                                                                self.next_hop_vrf_name.is_set or
                                                                self.nhid_feid.is_set or
                                                                self.num_labels.is_set or
                                                                self.number_of_extended_communities.is_set or
                                                                self.ospf_area_id.is_set or
                                                                self.path_rt_present.is_set or
                                                                self.pathid.is_set or
                                                                self.private_flags.is_set or
                                                                self.ref_cnt_of_backup.is_set or
                                                                self.route_label.is_set or
                                                                self.segmented_nexthop_present.is_set or
                                                                self.source_asrt_present.is_set or
                                                                self.source_rd_present.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.v6_information_source.is_set or
                                                                self.v6_nexthop.is_set or
                                                                self.vrf_import_rt_present.is_set)

                                                        def has_operation(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.backup_pathid.yfilter != YFilter.not_set or
                                                                self.binding_label.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flags64.yfilter != YFilter.not_set or
                                                                self.has_labelstk.yfilter != YFilter.not_set or
                                                                self.information_source.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.labelstk.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.looped.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.mpls_feid.yfilter != YFilter.not_set or
                                                                self.mvpn_present.yfilter != YFilter.not_set or
                                                                self.next_hop_afi.yfilter != YFilter.not_set or
                                                                self.next_hop_id.yfilter != YFilter.not_set or
                                                                self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                self.next_hop_safi.yfilter != YFilter.not_set or
                                                                self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                self.nhid_feid.yfilter != YFilter.not_set or
                                                                self.num_labels.yfilter != YFilter.not_set or
                                                                self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                self.ospf_area_id.yfilter != YFilter.not_set or
                                                                self.path_rt_present.yfilter != YFilter.not_set or
                                                                self.pathid.yfilter != YFilter.not_set or
                                                                self.private_flags.yfilter != YFilter.not_set or
                                                                self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                self.source_asrt_present.yfilter != YFilter.not_set or
                                                                self.source_rd_present.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.v6_information_source.yfilter != YFilter.not_set or
                                                                self.v6_nexthop.yfilter != YFilter.not_set or
                                                                self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                            if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags64.get_name_leafdata())
                                                            if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                            if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.information_source.get_name_leafdata())
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.looped.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                            if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                            if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                            if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                            if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                            if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                            if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                            if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                            if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                            if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                            if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                            if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                            if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                            if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                            if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pathid.get_name_leafdata())
                                                            if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                            if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                            if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                            if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                            if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                            if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                            leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                            leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "backup-pathid"):
                                                                self.backup_pathid = value
                                                                self.backup_pathid.value_namespace = name_space
                                                                self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "binding-label"):
                                                                self.binding_label = value
                                                                self.binding_label.value_namespace = name_space
                                                                self.binding_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags64"):
                                                                self.flags64 = value
                                                                self.flags64.value_namespace = name_space
                                                                self.flags64.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "has-labelstk"):
                                                                self.has_labelstk = value
                                                                self.has_labelstk.value_namespace = name_space
                                                                self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "information-source"):
                                                                self.information_source = value
                                                                self.information_source.value_namespace = name_space
                                                                self.information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "labelstk"):
                                                                self.labelstk.append(value)
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "looped"):
                                                                self.looped = value
                                                                self.looped.value_namespace = name_space
                                                                self.looped.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mpls-feid"):
                                                                self.mpls_feid = value
                                                                self.mpls_feid.value_namespace = name_space
                                                                self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mvpn-present"):
                                                                self.mvpn_present = value
                                                                self.mvpn_present.value_namespace = name_space
                                                                self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-afi"):
                                                                self.next_hop_afi = value
                                                                self.next_hop_afi.value_namespace = name_space
                                                                self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id"):
                                                                self.next_hop_id = value
                                                                self.next_hop_id.value_namespace = name_space
                                                                self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id-refcount"):
                                                                self.next_hop_id_refcount = value
                                                                self.next_hop_id_refcount.value_namespace = name_space
                                                                self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-safi"):
                                                                self.next_hop_safi = value
                                                                self.next_hop_safi.value_namespace = name_space
                                                                self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-id"):
                                                                self.next_hop_table_id = value
                                                                self.next_hop_table_id.value_namespace = name_space
                                                                self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-name"):
                                                                self.next_hop_table_name = value
                                                                self.next_hop_table_name.value_namespace = name_space
                                                                self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-vrf-name"):
                                                                self.next_hop_vrf_name = value
                                                                self.next_hop_vrf_name.value_namespace = name_space
                                                                self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "nhid-feid"):
                                                                self.nhid_feid = value
                                                                self.nhid_feid.value_namespace = name_space
                                                                self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "num-labels"):
                                                                self.num_labels = value
                                                                self.num_labels.value_namespace = name_space
                                                                self.num_labels.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "number-of-extended-communities"):
                                                                self.number_of_extended_communities = value
                                                                self.number_of_extended_communities.value_namespace = name_space
                                                                self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ospf-area-id"):
                                                                self.ospf_area_id = value
                                                                self.ospf_area_id.value_namespace = name_space
                                                                self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "path-rt-present"):
                                                                self.path_rt_present = value
                                                                self.path_rt_present.value_namespace = name_space
                                                                self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pathid"):
                                                                self.pathid = value
                                                                self.pathid.value_namespace = name_space
                                                                self.pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "private-flags"):
                                                                self.private_flags = value
                                                                self.private_flags.value_namespace = name_space
                                                                self.private_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ref-cnt-of-backup"):
                                                                self.ref_cnt_of_backup = value
                                                                self.ref_cnt_of_backup.value_namespace = name_space
                                                                self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "remote-backup-addr"):
                                                                self.remote_backup_addr.append(value)
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "segmented-nexthop-present"):
                                                                self.segmented_nexthop_present = value
                                                                self.segmented_nexthop_present.value_namespace = name_space
                                                                self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-asrt-present"):
                                                                self.source_asrt_present = value
                                                                self.source_asrt_present.value_namespace = name_space
                                                                self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-rd-present"):
                                                                self.source_rd_present = value
                                                                self.source_rd_present.value_namespace = name_space
                                                                self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-information-source"):
                                                                self.v6_information_source = value
                                                                self.v6_information_source.value_namespace = name_space
                                                                self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-nexthop"):
                                                                self.v6_nexthop = value
                                                                self.v6_nexthop.value_namespace = name_space
                                                                self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-import-rt-present"):
                                                                self.vrf_import_rt_present = value
                                                                self.vrf_import_rt_present.value_namespace = name_space
                                                                self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "route-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv6-rib-edm-path"):
                                                            for c in self.ipv6_rib_edm_path:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.ipv6_rib_edm_path.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv6-rib-edm-path"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.address.is_set or
                                                        self.active.is_set or
                                                        self.attribute_identity.is_set or
                                                        self.client_id.is_set or
                                                        self.distance.is_set or
                                                        self.diversion.is_set or
                                                        self.diversion_distance.is_set or
                                                        self.diversion_proto_name.is_set or
                                                        self.extended_flags.is_set or
                                                        self.flags.is_set or
                                                        self.flow_tag.is_set or
                                                        self.fwd_class.is_set or
                                                        self.instance.is_set or
                                                        self.metric.is_set or
                                                        self.paths_count.is_set or
                                                        self.pic_count.is_set or
                                                        self.prefix.is_set or
                                                        self.prefix_length_xr.is_set or
                                                        self.priority.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_name.is_set or
                                                        self.qos_group.is_set or
                                                        self.route_age.is_set or
                                                        self.route_label.is_set or
                                                        self.route_modify_time.is_set or
                                                        self.route_precedence.is_set or
                                                        self.route_type.is_set or
                                                        self.route_version.is_set or
                                                        self.svd_type.is_set or
                                                        self.tag.is_set or
                                                        self.tbl_version.is_set or
                                                        self.traffic_index.is_set or
                                                        self.version.is_set or
                                                        (self.route_path is not None and self.route_path.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.address.yfilter != YFilter.not_set or
                                                        self.active.yfilter != YFilter.not_set or
                                                        self.attribute_identity.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.distance.yfilter != YFilter.not_set or
                                                        self.diversion.yfilter != YFilter.not_set or
                                                        self.diversion_distance.yfilter != YFilter.not_set or
                                                        self.diversion_proto_name.yfilter != YFilter.not_set or
                                                        self.extended_flags.yfilter != YFilter.not_set or
                                                        self.flags.yfilter != YFilter.not_set or
                                                        self.flow_tag.yfilter != YFilter.not_set or
                                                        self.fwd_class.yfilter != YFilter.not_set or
                                                        self.instance.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.paths_count.yfilter != YFilter.not_set or
                                                        self.pic_count.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length_xr.yfilter != YFilter.not_set or
                                                        self.priority.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_name.yfilter != YFilter.not_set or
                                                        self.qos_group.yfilter != YFilter.not_set or
                                                        self.route_age.yfilter != YFilter.not_set or
                                                        self.route_label.yfilter != YFilter.not_set or
                                                        self.route_modify_time.yfilter != YFilter.not_set or
                                                        self.route_precedence.yfilter != YFilter.not_set or
                                                        self.route_type.yfilter != YFilter.not_set or
                                                        self.route_version.yfilter != YFilter.not_set or
                                                        self.svd_type.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tbl_version.yfilter != YFilter.not_set or
                                                        self.traffic_index.yfilter != YFilter.not_set or
                                                        self.version.yfilter != YFilter.not_set or
                                                        (self.route_path is not None and self.route_path.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dest-next-hop-route" + "[address='" + self.address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.active.get_name_leafdata())
                                                    if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                                    if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion.get_name_leafdata())
                                                    if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                    if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                    if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                    if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                    if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                    if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                    if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                    if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_age.get_name_leafdata())
                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                    if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                    if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_type.get_name_leafdata())
                                                    if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_version.get_name_leafdata())
                                                    if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                    if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                    if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.version.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "route-path"):
                                                        if (self.route_path is None):
                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                        return self.route_path

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "route-path" or name == "address" or name == "active" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "address"):
                                                        self.address = value
                                                        self.address.value_namespace = name_space
                                                        self.address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "active"):
                                                        self.active = value
                                                        self.active.value_namespace = name_space
                                                        self.active.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "attribute-identity"):
                                                        self.attribute_identity = value
                                                        self.attribute_identity.value_namespace = name_space
                                                        self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "distance"):
                                                        self.distance = value
                                                        self.distance.value_namespace = name_space
                                                        self.distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion"):
                                                        self.diversion = value
                                                        self.diversion.value_namespace = name_space
                                                        self.diversion.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-distance"):
                                                        self.diversion_distance = value
                                                        self.diversion_distance.value_namespace = name_space
                                                        self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-proto-name"):
                                                        self.diversion_proto_name = value
                                                        self.diversion_proto_name.value_namespace = name_space
                                                        self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-flags"):
                                                        self.extended_flags = value
                                                        self.extended_flags.value_namespace = name_space
                                                        self.extended_flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flags"):
                                                        self.flags = value
                                                        self.flags.value_namespace = name_space
                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flow-tag"):
                                                        self.flow_tag = value
                                                        self.flow_tag.value_namespace = name_space
                                                        self.flow_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fwd-class"):
                                                        self.fwd_class = value
                                                        self.fwd_class.value_namespace = name_space
                                                        self.fwd_class.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance"):
                                                        self.instance = value
                                                        self.instance.value_namespace = name_space
                                                        self.instance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "paths-count"):
                                                        self.paths_count = value
                                                        self.paths_count.value_namespace = name_space
                                                        self.paths_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pic-count"):
                                                        self.pic_count = value
                                                        self.pic_count.value_namespace = name_space
                                                        self.pic_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length-xr"):
                                                        self.prefix_length_xr = value
                                                        self.prefix_length_xr.value_namespace = name_space
                                                        self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "priority"):
                                                        self.priority = value
                                                        self.priority.value_namespace = name_space
                                                        self.priority.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-name"):
                                                        self.protocol_name = value
                                                        self.protocol_name.value_namespace = name_space
                                                        self.protocol_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "qos-group"):
                                                        self.qos_group = value
                                                        self.qos_group.value_namespace = name_space
                                                        self.qos_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-age"):
                                                        self.route_age = value
                                                        self.route_age.value_namespace = name_space
                                                        self.route_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-label"):
                                                        self.route_label = value
                                                        self.route_label.value_namespace = name_space
                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-modify-time"):
                                                        self.route_modify_time = value
                                                        self.route_modify_time.value_namespace = name_space
                                                        self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-precedence"):
                                                        self.route_precedence = value
                                                        self.route_precedence.value_namespace = name_space
                                                        self.route_precedence.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-type"):
                                                        self.route_type = value
                                                        self.route_type.value_namespace = name_space
                                                        self.route_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-version"):
                                                        self.route_version = value
                                                        self.route_version.value_namespace = name_space
                                                        self.route_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "svd-type"):
                                                        self.svd_type = value
                                                        self.svd_type.value_namespace = name_space
                                                        self.svd_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tbl-version"):
                                                        self.tbl_version = value
                                                        self.tbl_version.value_namespace = name_space
                                                        self.tbl_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "traffic-index"):
                                                        self.traffic_index = value
                                                        self.traffic_index.value_namespace = name_space
                                                        self.traffic_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "version"):
                                                        self.version = value
                                                        self.version.value_namespace = name_space
                                                        self.version.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.dest_next_hop_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.dest_next_hop_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dest-next-hop-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "dest-next-hop-route"):
                                                    for c in self.dest_next_hop_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.dest_next_hop_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dest-next-hop-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                (self.dest_backup_routes is not None and self.dest_backup_routes.has_data()) or
                                                (self.dest_best_routes is not None and self.dest_best_routes.has_data()) or
                                                (self.dest_next_hop_routes is not None and self.dest_next_hop_routes.has_data()) or
                                                (self.dest_q_routes is not None and self.dest_q_routes.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.dest_backup_routes is not None and self.dest_backup_routes.has_operation()) or
                                                (self.dest_best_routes is not None and self.dest_best_routes.has_operation()) or
                                                (self.dest_next_hop_routes is not None and self.dest_next_hop_routes.has_operation()) or
                                                (self.dest_q_routes is not None and self.dest_q_routes.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "destination-kw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dest-backup-routes"):
                                                if (self.dest_backup_routes is None):
                                                    self.dest_backup_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                                    self.dest_backup_routes.parent = self
                                                    self._children_name_map["dest_backup_routes"] = "dest-backup-routes"
                                                return self.dest_backup_routes

                                            if (child_yang_name == "dest-best-routes"):
                                                if (self.dest_best_routes is None):
                                                    self.dest_best_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                                    self.dest_best_routes.parent = self
                                                    self._children_name_map["dest_best_routes"] = "dest-best-routes"
                                                return self.dest_best_routes

                                            if (child_yang_name == "dest-next-hop-routes"):
                                                if (self.dest_next_hop_routes is None):
                                                    self.dest_next_hop_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                                    self.dest_next_hop_routes.parent = self
                                                    self._children_name_map["dest_next_hop_routes"] = "dest-next-hop-routes"
                                                return self.dest_next_hop_routes

                                            if (child_yang_name == "dest-q-routes"):
                                                if (self.dest_q_routes is None):
                                                    self.dest_q_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                                    self.dest_q_routes.parent = self
                                                    self._children_name_map["dest_q_routes"] = "dest-q-routes"
                                                return self.dest_q_routes

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dest-backup-routes" or name == "dest-best-routes" or name == "dest-next-hop-routes" or name == "dest-q-routes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Adverts(Entity):
                                        """
                                        Route advertiser information 
                                        
                                        .. attribute:: advert
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Advert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__init__()

                                            self.yang_name = "adverts"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.advert = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__setattr__(name, value)


                                        class Advert(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_rib_edm_advert
                                            
                                            	ipv6 rib edm advert
                                            	**type**\: list of    :py:class:`Ipv6RibEdmAdvert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__init__()

                                                self.yang_name = "advert"
                                                self.yang_parent_name = "adverts"

                                                self.address = YLeaf(YType.str, "address")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.ipv6_rib_edm_advert = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("address",
                                                                "prefix_length") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__setattr__(name, value)


                                            class Ipv6RibEdmAdvert(Entity):
                                                """
                                                ipv6 rib edm advert
                                                
                                                .. attribute:: client_id
                                                
                                                	  Client advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: code
                                                
                                                	Protocol code
                                                	**type**\:  int
                                                
                                                	**range:** \-128..127
                                                
                                                .. attribute:: extended_communities
                                                
                                                	Extended communities
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: instance_name
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                	**length:** 0..41
                                                
                                                .. attribute:: number_of_extended_communities
                                                
                                                	Number of extended communities
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque
                                                
                                                	OSPF area\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque_flags
                                                
                                                	OSPF area\-id flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, self).__init__()

                                                    self.yang_name = "ipv6-rib-edm-advert"
                                                    self.yang_parent_name = "advert"

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.code = YLeaf(YType.int8, "code")

                                                    self.extended_communities = YLeaf(YType.str, "extended-communities")

                                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_opaque = YLeaf(YType.uint32, "protocol-opaque")

                                                    self.protocol_opaque_flags = YLeaf(YType.uint8, "protocol-opaque-flags")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("client_id",
                                                                    "code",
                                                                    "extended_communities",
                                                                    "instance_name",
                                                                    "number_of_extended_communities",
                                                                    "protocol_id",
                                                                    "protocol_opaque",
                                                                    "protocol_opaque_flags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.client_id.is_set or
                                                        self.code.is_set or
                                                        self.extended_communities.is_set or
                                                        self.instance_name.is_set or
                                                        self.number_of_extended_communities.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_opaque.is_set or
                                                        self.protocol_opaque_flags.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.code.yfilter != YFilter.not_set or
                                                        self.extended_communities.yfilter != YFilter.not_set or
                                                        self.instance_name.yfilter != YFilter.not_set or
                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_opaque.yfilter != YFilter.not_set or
                                                        self.protocol_opaque_flags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ipv6-rib-edm-advert" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.code.is_set or self.code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.code.get_name_leafdata())
                                                    if (self.extended_communities.is_set or self.extended_communities.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_communities.get_name_leafdata())
                                                    if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance_name.get_name_leafdata())
                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_opaque.is_set or self.protocol_opaque.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_opaque.get_name_leafdata())
                                                    if (self.protocol_opaque_flags.is_set or self.protocol_opaque_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_opaque_flags.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "client-id" or name == "code" or name == "extended-communities" or name == "instance-name" or name == "number-of-extended-communities" or name == "protocol-id" or name == "protocol-opaque" or name == "protocol-opaque-flags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "code"):
                                                        self.code = value
                                                        self.code.value_namespace = name_space
                                                        self.code.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-communities"):
                                                        self.extended_communities = value
                                                        self.extended_communities.value_namespace = name_space
                                                        self.extended_communities.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance-name"):
                                                        self.instance_name = value
                                                        self.instance_name.value_namespace = name_space
                                                        self.instance_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "number-of-extended-communities"):
                                                        self.number_of_extended_communities = value
                                                        self.number_of_extended_communities.value_namespace = name_space
                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-opaque"):
                                                        self.protocol_opaque = value
                                                        self.protocol_opaque.value_namespace = name_space
                                                        self.protocol_opaque.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-opaque-flags"):
                                                        self.protocol_opaque_flags = value
                                                        self.protocol_opaque_flags.value_namespace = name_space
                                                        self.protocol_opaque_flags.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.ipv6_rib_edm_advert:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.address.is_set or
                                                    self.prefix_length.is_set)

                                            def has_operation(self):
                                                for c in self.ipv6_rib_edm_advert:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advert" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ipv6-rib-edm-advert"):
                                                    for c in self.ipv6_rib_edm_advert:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.ipv6_rib_edm_advert.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv6-rib-edm-advert" or name == "address" or name == "prefix-length"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.advert:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.advert:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "adverts" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "advert"):
                                                for c in self.advert:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.advert.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advert"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DeletedRoutes(Entity):
                                        """
                                        Deleted
                                        
                                        .. attribute:: deleted_route
                                        
                                        	Route information for a specific deleted address 
                                        	**type**\: list of    :py:class:`DeletedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__init__()

                                            self.yang_name = "deleted-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.deleted_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__setattr__(name, value)


                                        class DeletedRoute(Entity):
                                            """
                                            Route information for a specific
                                            deleted address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__init__()

                                                self.yang_name = "deleted-route"
                                                self.yang_parent_name = "deleted-routes"

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("active",
                                                                "address",
                                                                "attribute_identity",
                                                                "client_id",
                                                                "distance",
                                                                "diversion",
                                                                "diversion_distance",
                                                                "diversion_proto_name",
                                                                "extended_flags",
                                                                "flags",
                                                                "flow_tag",
                                                                "fwd_class",
                                                                "instance",
                                                                "metric",
                                                                "paths_count",
                                                                "pic_count",
                                                                "prefix",
                                                                "prefix_length",
                                                                "prefix_length_xr",
                                                                "priority",
                                                                "protocol_id",
                                                                "protocol_name",
                                                                "qos_group",
                                                                "route_age",
                                                                "route_label",
                                                                "route_modify_time",
                                                                "route_precedence",
                                                                "route_type",
                                                                "route_version",
                                                                "svd_type",
                                                                "tag",
                                                                "tbl_version",
                                                                "traffic_index",
                                                                "version") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__setattr__(name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "deleted-route"

                                                    self.ipv6_rib_edm_path = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__setattr__(name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("address",
                                                                        "backup_pathid",
                                                                        "binding_label",
                                                                        "flags",
                                                                        "flags64",
                                                                        "has_labelstk",
                                                                        "information_source",
                                                                        "interface_name",
                                                                        "labelstk",
                                                                        "load_metric",
                                                                        "looped",
                                                                        "metric",
                                                                        "mpls_feid",
                                                                        "mvpn_present",
                                                                        "next_hop_afi",
                                                                        "next_hop_id",
                                                                        "next_hop_id_refcount",
                                                                        "next_hop_safi",
                                                                        "next_hop_table_id",
                                                                        "next_hop_table_name",
                                                                        "next_hop_vrf_name",
                                                                        "nhid_feid",
                                                                        "num_labels",
                                                                        "number_of_extended_communities",
                                                                        "ospf_area_id",
                                                                        "path_rt_present",
                                                                        "pathid",
                                                                        "private_flags",
                                                                        "ref_cnt_of_backup",
                                                                        "remote_backup_addr",
                                                                        "route_label",
                                                                        "segmented_nexthop_present",
                                                                        "source_asrt_present",
                                                                        "source_rd_present",
                                                                        "tunnel_id",
                                                                        "v6_information_source",
                                                                        "v6_nexthop",
                                                                        "vrf_import_rt_present") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        return (
                                                            self.address.is_set or
                                                            self.backup_pathid.is_set or
                                                            self.binding_label.is_set or
                                                            self.flags.is_set or
                                                            self.flags64.is_set or
                                                            self.has_labelstk.is_set or
                                                            self.information_source.is_set or
                                                            self.interface_name.is_set or
                                                            self.load_metric.is_set or
                                                            self.looped.is_set or
                                                            self.metric.is_set or
                                                            self.mpls_feid.is_set or
                                                            self.mvpn_present.is_set or
                                                            self.next_hop_afi.is_set or
                                                            self.next_hop_id.is_set or
                                                            self.next_hop_id_refcount.is_set or
                                                            self.next_hop_safi.is_set or
                                                            self.next_hop_table_id.is_set or
                                                            self.next_hop_table_name.is_set or
                                                            self.next_hop_vrf_name.is_set or
                                                            self.nhid_feid.is_set or
                                                            self.num_labels.is_set or
                                                            self.number_of_extended_communities.is_set or
                                                            self.ospf_area_id.is_set or
                                                            self.path_rt_present.is_set or
                                                            self.pathid.is_set or
                                                            self.private_flags.is_set or
                                                            self.ref_cnt_of_backup.is_set or
                                                            self.route_label.is_set or
                                                            self.segmented_nexthop_present.is_set or
                                                            self.source_asrt_present.is_set or
                                                            self.source_rd_present.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.v6_information_source.is_set or
                                                            self.v6_nexthop.is_set or
                                                            self.vrf_import_rt_present.is_set)

                                                    def has_operation(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.address.yfilter != YFilter.not_set or
                                                            self.backup_pathid.yfilter != YFilter.not_set or
                                                            self.binding_label.yfilter != YFilter.not_set or
                                                            self.flags.yfilter != YFilter.not_set or
                                                            self.flags64.yfilter != YFilter.not_set or
                                                            self.has_labelstk.yfilter != YFilter.not_set or
                                                            self.information_source.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.labelstk.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.looped.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.mpls_feid.yfilter != YFilter.not_set or
                                                            self.mvpn_present.yfilter != YFilter.not_set or
                                                            self.next_hop_afi.yfilter != YFilter.not_set or
                                                            self.next_hop_id.yfilter != YFilter.not_set or
                                                            self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                            self.next_hop_safi.yfilter != YFilter.not_set or
                                                            self.next_hop_table_id.yfilter != YFilter.not_set or
                                                            self.next_hop_table_name.yfilter != YFilter.not_set or
                                                            self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                            self.nhid_feid.yfilter != YFilter.not_set or
                                                            self.num_labels.yfilter != YFilter.not_set or
                                                            self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                            self.ospf_area_id.yfilter != YFilter.not_set or
                                                            self.path_rt_present.yfilter != YFilter.not_set or
                                                            self.pathid.yfilter != YFilter.not_set or
                                                            self.private_flags.yfilter != YFilter.not_set or
                                                            self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                            self.remote_backup_addr.yfilter != YFilter.not_set or
                                                            self.route_label.yfilter != YFilter.not_set or
                                                            self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                            self.source_asrt_present.yfilter != YFilter.not_set or
                                                            self.source_rd_present.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.v6_information_source.yfilter != YFilter.not_set or
                                                            self.v6_nexthop.yfilter != YFilter.not_set or
                                                            self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.address.get_name_leafdata())
                                                        if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                        if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                        if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags.get_name_leafdata())
                                                        if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags64.get_name_leafdata())
                                                        if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                        if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.information_source.get_name_leafdata())
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.looped.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                        if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                        if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                        if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                        if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                        if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                        if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                        if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                        if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                        if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                        if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                        if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                        if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                        if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                        if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pathid.get_name_leafdata())
                                                        if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                        if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                        if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.route_label.get_name_leafdata())
                                                        if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                        if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                        if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                        if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                        if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                        leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                        leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "address"):
                                                            self.address = value
                                                            self.address.value_namespace = name_space
                                                            self.address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-pathid"):
                                                            self.backup_pathid = value
                                                            self.backup_pathid.value_namespace = name_space
                                                            self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "binding-label"):
                                                            self.binding_label = value
                                                            self.binding_label.value_namespace = name_space
                                                            self.binding_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags"):
                                                            self.flags = value
                                                            self.flags.value_namespace = name_space
                                                            self.flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags64"):
                                                            self.flags64 = value
                                                            self.flags64.value_namespace = name_space
                                                            self.flags64.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "has-labelstk"):
                                                            self.has_labelstk = value
                                                            self.has_labelstk.value_namespace = name_space
                                                            self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "information-source"):
                                                            self.information_source = value
                                                            self.information_source.value_namespace = name_space
                                                            self.information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "labelstk"):
                                                            self.labelstk.append(value)
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "looped"):
                                                            self.looped = value
                                                            self.looped.value_namespace = name_space
                                                            self.looped.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-feid"):
                                                            self.mpls_feid = value
                                                            self.mpls_feid.value_namespace = name_space
                                                            self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mvpn-present"):
                                                            self.mvpn_present = value
                                                            self.mvpn_present.value_namespace = name_space
                                                            self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-afi"):
                                                            self.next_hop_afi = value
                                                            self.next_hop_afi.value_namespace = name_space
                                                            self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id"):
                                                            self.next_hop_id = value
                                                            self.next_hop_id.value_namespace = name_space
                                                            self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id-refcount"):
                                                            self.next_hop_id_refcount = value
                                                            self.next_hop_id_refcount.value_namespace = name_space
                                                            self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-safi"):
                                                            self.next_hop_safi = value
                                                            self.next_hop_safi.value_namespace = name_space
                                                            self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-id"):
                                                            self.next_hop_table_id = value
                                                            self.next_hop_table_id.value_namespace = name_space
                                                            self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-name"):
                                                            self.next_hop_table_name = value
                                                            self.next_hop_table_name.value_namespace = name_space
                                                            self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-vrf-name"):
                                                            self.next_hop_vrf_name = value
                                                            self.next_hop_vrf_name.value_namespace = name_space
                                                            self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "nhid-feid"):
                                                            self.nhid_feid = value
                                                            self.nhid_feid.value_namespace = name_space
                                                            self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-labels"):
                                                            self.num_labels = value
                                                            self.num_labels.value_namespace = name_space
                                                            self.num_labels.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "number-of-extended-communities"):
                                                            self.number_of_extended_communities = value
                                                            self.number_of_extended_communities.value_namespace = name_space
                                                            self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ospf-area-id"):
                                                            self.ospf_area_id = value
                                                            self.ospf_area_id.value_namespace = name_space
                                                            self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "path-rt-present"):
                                                            self.path_rt_present = value
                                                            self.path_rt_present.value_namespace = name_space
                                                            self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pathid"):
                                                            self.pathid = value
                                                            self.pathid.value_namespace = name_space
                                                            self.pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "private-flags"):
                                                            self.private_flags = value
                                                            self.private_flags.value_namespace = name_space
                                                            self.private_flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ref-cnt-of-backup"):
                                                            self.ref_cnt_of_backup = value
                                                            self.ref_cnt_of_backup.value_namespace = name_space
                                                            self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-backup-addr"):
                                                            self.remote_backup_addr.append(value)
                                                        if(value_path == "route-label"):
                                                            self.route_label = value
                                                            self.route_label.value_namespace = name_space
                                                            self.route_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segmented-nexthop-present"):
                                                            self.segmented_nexthop_present = value
                                                            self.segmented_nexthop_present.value_namespace = name_space
                                                            self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-asrt-present"):
                                                            self.source_asrt_present = value
                                                            self.source_asrt_present.value_namespace = name_space
                                                            self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-rd-present"):
                                                            self.source_rd_present = value
                                                            self.source_rd_present.value_namespace = name_space
                                                            self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-information-source"):
                                                            self.v6_information_source = value
                                                            self.v6_information_source.value_namespace = name_space
                                                            self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-nexthop"):
                                                            self.v6_nexthop = value
                                                            self.v6_nexthop.value_namespace = name_space
                                                            self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-import-rt-present"):
                                                            self.vrf_import_rt_present = value
                                                            self.vrf_import_rt_present.value_namespace = name_space
                                                            self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv6-rib-edm-path"):
                                                        for c in self.ipv6_rib_edm_path:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.ipv6_rib_edm_path.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv6-rib-edm-path"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.active.is_set or
                                                    self.address.is_set or
                                                    self.attribute_identity.is_set or
                                                    self.client_id.is_set or
                                                    self.distance.is_set or
                                                    self.diversion.is_set or
                                                    self.diversion_distance.is_set or
                                                    self.diversion_proto_name.is_set or
                                                    self.extended_flags.is_set or
                                                    self.flags.is_set or
                                                    self.flow_tag.is_set or
                                                    self.fwd_class.is_set or
                                                    self.instance.is_set or
                                                    self.metric.is_set or
                                                    self.paths_count.is_set or
                                                    self.pic_count.is_set or
                                                    self.prefix.is_set or
                                                    self.prefix_length.is_set or
                                                    self.prefix_length_xr.is_set or
                                                    self.priority.is_set or
                                                    self.protocol_id.is_set or
                                                    self.protocol_name.is_set or
                                                    self.qos_group.is_set or
                                                    self.route_age.is_set or
                                                    self.route_label.is_set or
                                                    self.route_modify_time.is_set or
                                                    self.route_precedence.is_set or
                                                    self.route_type.is_set or
                                                    self.route_version.is_set or
                                                    self.svd_type.is_set or
                                                    self.tag.is_set or
                                                    self.tbl_version.is_set or
                                                    self.traffic_index.is_set or
                                                    self.version.is_set or
                                                    (self.route_path is not None and self.route_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.active.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.attribute_identity.yfilter != YFilter.not_set or
                                                    self.client_id.yfilter != YFilter.not_set or
                                                    self.distance.yfilter != YFilter.not_set or
                                                    self.diversion.yfilter != YFilter.not_set or
                                                    self.diversion_distance.yfilter != YFilter.not_set or
                                                    self.diversion_proto_name.yfilter != YFilter.not_set or
                                                    self.extended_flags.yfilter != YFilter.not_set or
                                                    self.flags.yfilter != YFilter.not_set or
                                                    self.flow_tag.yfilter != YFilter.not_set or
                                                    self.fwd_class.yfilter != YFilter.not_set or
                                                    self.instance.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.paths_count.yfilter != YFilter.not_set or
                                                    self.pic_count.yfilter != YFilter.not_set or
                                                    self.prefix.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set or
                                                    self.prefix_length_xr.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set or
                                                    self.protocol_id.yfilter != YFilter.not_set or
                                                    self.protocol_name.yfilter != YFilter.not_set or
                                                    self.qos_group.yfilter != YFilter.not_set or
                                                    self.route_age.yfilter != YFilter.not_set or
                                                    self.route_label.yfilter != YFilter.not_set or
                                                    self.route_modify_time.yfilter != YFilter.not_set or
                                                    self.route_precedence.yfilter != YFilter.not_set or
                                                    self.route_type.yfilter != YFilter.not_set or
                                                    self.route_version.yfilter != YFilter.not_set or
                                                    self.svd_type.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tbl_version.yfilter != YFilter.not_set or
                                                    self.traffic_index.yfilter != YFilter.not_set or
                                                    self.version.yfilter != YFilter.not_set or
                                                    (self.route_path is not None and self.route_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "deleted-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.active.get_name_leafdata())
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.client_id.get_name_leafdata())
                                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.distance.get_name_leafdata())
                                                if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion.get_name_leafdata())
                                                if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                                if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                                if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_age.get_name_leafdata())
                                                if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_label.get_name_leafdata())
                                                if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_type.get_name_leafdata())
                                                if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_version.get_name_leafdata())
                                                if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.version.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-path"):
                                                    if (self.route_path is None):
                                                        self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                        self.route_path.parent = self
                                                        self._children_name_map["route_path"] = "route-path"
                                                    return self.route_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "active"):
                                                    self.active = value
                                                    self.active.value_namespace = name_space
                                                    self.active.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "attribute-identity"):
                                                    self.attribute_identity = value
                                                    self.attribute_identity.value_namespace = name_space
                                                    self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                if(value_path == "client-id"):
                                                    self.client_id = value
                                                    self.client_id.value_namespace = name_space
                                                    self.client_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "distance"):
                                                    self.distance = value
                                                    self.distance.value_namespace = name_space
                                                    self.distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion"):
                                                    self.diversion = value
                                                    self.diversion.value_namespace = name_space
                                                    self.diversion.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-distance"):
                                                    self.diversion_distance = value
                                                    self.diversion_distance.value_namespace = name_space
                                                    self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-proto-name"):
                                                    self.diversion_proto_name = value
                                                    self.diversion_proto_name.value_namespace = name_space
                                                    self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "extended-flags"):
                                                    self.extended_flags = value
                                                    self.extended_flags.value_namespace = name_space
                                                    self.extended_flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flags"):
                                                    self.flags = value
                                                    self.flags.value_namespace = name_space
                                                    self.flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flow-tag"):
                                                    self.flow_tag = value
                                                    self.flow_tag.value_namespace = name_space
                                                    self.flow_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fwd-class"):
                                                    self.fwd_class = value
                                                    self.fwd_class.value_namespace = name_space
                                                    self.fwd_class.value_namespace_prefix = name_space_prefix
                                                if(value_path == "instance"):
                                                    self.instance = value
                                                    self.instance.value_namespace = name_space
                                                    self.instance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "paths-count"):
                                                    self.paths_count = value
                                                    self.paths_count.value_namespace = name_space
                                                    self.paths_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pic-count"):
                                                    self.pic_count = value
                                                    self.pic_count.value_namespace = name_space
                                                    self.pic_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix"):
                                                    self.prefix = value
                                                    self.prefix.value_namespace = name_space
                                                    self.prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length-xr"):
                                                    self.prefix_length_xr = value
                                                    self.prefix_length_xr.value_namespace = name_space
                                                    self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-id"):
                                                    self.protocol_id = value
                                                    self.protocol_id.value_namespace = name_space
                                                    self.protocol_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-name"):
                                                    self.protocol_name = value
                                                    self.protocol_name.value_namespace = name_space
                                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "qos-group"):
                                                    self.qos_group = value
                                                    self.qos_group.value_namespace = name_space
                                                    self.qos_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-age"):
                                                    self.route_age = value
                                                    self.route_age.value_namespace = name_space
                                                    self.route_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-label"):
                                                    self.route_label = value
                                                    self.route_label.value_namespace = name_space
                                                    self.route_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-modify-time"):
                                                    self.route_modify_time = value
                                                    self.route_modify_time.value_namespace = name_space
                                                    self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-precedence"):
                                                    self.route_precedence = value
                                                    self.route_precedence.value_namespace = name_space
                                                    self.route_precedence.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-type"):
                                                    self.route_type = value
                                                    self.route_type.value_namespace = name_space
                                                    self.route_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-version"):
                                                    self.route_version = value
                                                    self.route_version.value_namespace = name_space
                                                    self.route_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "svd-type"):
                                                    self.svd_type = value
                                                    self.svd_type.value_namespace = name_space
                                                    self.svd_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tbl-version"):
                                                    self.tbl_version = value
                                                    self.tbl_version.value_namespace = name_space
                                                    self.tbl_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "traffic-index"):
                                                    self.traffic_index = value
                                                    self.traffic_index.value_namespace = name_space
                                                    self.traffic_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "version"):
                                                    self.version = value
                                                    self.version.value_namespace = name_space
                                                    self.version.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.deleted_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.deleted_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "deleted-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "deleted-route"):
                                                for c in self.deleted_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.deleted_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "deleted-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Protocol(Entity):
                                        """
                                        Contains the classification of routes by
                                        protocol
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP Protocol
                                        	**type**\:   :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected Protocol
                                        	**type**\:   :py:class:`Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	EIGRP Protocol
                                        	**type**\:   :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISIS Protocol
                                        	**type**\:   :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis>`
                                        
                                        .. attribute:: local
                                        
                                        	Local Protocol
                                        	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile Protocol
                                        	**type**\:   :py:class:`Mobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile>`
                                        
                                        .. attribute:: ospf
                                        
                                        	OSPF Protocol
                                        	**type**\:   :py:class:`Ospf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf>`
                                        
                                        .. attribute:: rpl
                                        
                                        	RPL Protocol
                                        	**type**\:   :py:class:`Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl>`
                                        
                                        .. attribute:: static
                                        
                                        	Static Protocol
                                        	**type**\:   :py:class:`Static <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static>`
                                        
                                        .. attribute:: subscriber
                                        
                                        	Subscriber Protocol
                                        	**type**\:   :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber>`
                                        
                                        .. attribute:: te_client
                                        
                                        	TEClient protocol
                                        	**type**\:   :py:class:`TeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol, self).__init__()

                                            self.yang_name = "protocol"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.bgp = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"
                                            self._children_yang_names.add("bgp")

                                            self.connected = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"
                                            self._children_yang_names.add("connected")

                                            self.eigrp = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"
                                            self._children_yang_names.add("eigrp")

                                            self.isis = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"
                                            self._children_yang_names.add("isis")

                                            self.local = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                            self.local.parent = self
                                            self._children_name_map["local"] = "local"
                                            self._children_yang_names.add("local")

                                            self.mobile = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                            self.mobile.parent = self
                                            self._children_name_map["mobile"] = "mobile"
                                            self._children_yang_names.add("mobile")

                                            self.ospf = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                            self.ospf.parent = self
                                            self._children_name_map["ospf"] = "ospf"
                                            self._children_yang_names.add("ospf")

                                            self.rpl = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                            self.rpl.parent = self
                                            self._children_name_map["rpl"] = "rpl"
                                            self._children_yang_names.add("rpl")

                                            self.static = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"
                                            self._children_yang_names.add("static")

                                            self.subscriber = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                            self.subscriber.parent = self
                                            self._children_name_map["subscriber"] = "subscriber"
                                            self._children_yang_names.add("subscriber")

                                            self.te_client = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                            self.te_client.parent = self
                                            self._children_name_map["te_client"] = "te-client"
                                            self._children_yang_names.add("te-client")


                                        class Local(Entity):
                                            """
                                            Local Protocol
                                            
                                            .. attribute:: lspv
                                            
                                            	LSPV(Label Switched Path Verification) protocol
                                            	**type**\:   :py:class:`Lspv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local, self).__init__()

                                                self.yang_name = "local"
                                                self.yang_parent_name = "protocol"

                                                self.lspv = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                self.lspv.parent = self
                                                self._children_name_map["lspv"] = "lspv"
                                                self._children_yang_names.add("lspv")

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class Lspv(Entity):
                                                """
                                                LSPV(Label Switched Path Verification)
                                                protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv, self).__init__()

                                                    self.yang_name = "lspv"
                                                    self.yang_parent_name = "local"

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "lspv"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "lspv"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lspv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "local"

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    (self.lspv is not None and self.lspv.has_data()) or
                                                    (self.non_as is not None and self.non_as.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.lspv is not None and self.lspv.has_operation()) or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "local" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "lspv"):
                                                    if (self.lspv is None):
                                                        self.lspv = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                        self.lspv.parent = self
                                                        self._children_name_map["lspv"] = "lspv"
                                                    return self.lspv

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lspv" or name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Bgp(Entity):
                                            """
                                            BGP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "bgp"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bgp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Mobile(Entity):
                                            """
                                            Mobile Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "protocol"

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "mobile"

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.non_as is not None and self.non_as.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mobile" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Eigrp(Entity):
                                            """
                                            EIGRP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "eigrp"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "eigrp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Rpl(Entity):
                                            """
                                            RPL Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__init__()

                                                self.yang_name = "rpl"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "rpl"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "rpl" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Static(Entity):
                                            """
                                            Static Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "protocol"

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "static"

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.non_as is not None and self.non_as.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "static" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class TeClient(Entity):
                                            """
                                            TEClient protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient, self).__init__()

                                                self.yang_name = "te-client"
                                                self.yang_parent_name = "protocol"

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "te-client"

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.non_as is not None and self.non_as.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "te-client" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Subscriber(Entity):
                                            """
                                            Subscriber Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber, self).__init__()

                                                self.yang_name = "subscriber"
                                                self.yang_parent_name = "protocol"

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "subscriber"

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.non_as is not None and self.non_as.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "subscriber" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Ospf(Entity):
                                            """
                                            OSPF Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "ospf"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ospf" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Connected(Entity):
                                            """
                                            Connected Protocol
                                            
                                            .. attribute:: l2vpn
                                            
                                            	L2VPN
                                            	**type**\:   :py:class:`L2Vpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "protocol"

                                                self.l2vpn = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn()
                                                self.l2vpn.parent = self
                                                self._children_name_map["l2vpn"] = "l2vpn"
                                                self._children_yang_names.add("l2vpn")

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class L2Vpn(Entity):
                                                """
                                                L2VPN
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn, self).__init__()

                                                    self.yang_name = "l2vpn"
                                                    self.yang_parent_name = "connected"

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "l2vpn"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "l2vpn"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "l2vpn" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "connected"

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    (self.l2vpn is not None and self.l2vpn.has_data()) or
                                                    (self.non_as is not None and self.non_as.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.l2vpn is not None and self.l2vpn.has_operation()) or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "connected" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "l2vpn"):
                                                    if (self.l2vpn is None):
                                                        self.l2vpn = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn()
                                                        self.l2vpn.parent = self
                                                        self._children_name_map["l2vpn"] = "l2vpn"
                                                    return self.l2vpn

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "l2vpn" or name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Isis(Entity):
                                            """
                                            ISIS Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "isis"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "isis" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                (self.bgp is not None and self.bgp.has_data()) or
                                                (self.connected is not None and self.connected.has_data()) or
                                                (self.eigrp is not None and self.eigrp.has_data()) or
                                                (self.isis is not None and self.isis.has_data()) or
                                                (self.local is not None and self.local.has_data()) or
                                                (self.mobile is not None and self.mobile.has_data()) or
                                                (self.ospf is not None and self.ospf.has_data()) or
                                                (self.rpl is not None and self.rpl.has_data()) or
                                                (self.static is not None and self.static.has_data()) or
                                                (self.subscriber is not None and self.subscriber.has_data()) or
                                                (self.te_client is not None and self.te_client.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.bgp is not None and self.bgp.has_operation()) or
                                                (self.connected is not None and self.connected.has_operation()) or
                                                (self.eigrp is not None and self.eigrp.has_operation()) or
                                                (self.isis is not None and self.isis.has_operation()) or
                                                (self.local is not None and self.local.has_operation()) or
                                                (self.mobile is not None and self.mobile.has_operation()) or
                                                (self.ospf is not None and self.ospf.has_operation()) or
                                                (self.rpl is not None and self.rpl.has_operation()) or
                                                (self.static is not None and self.static.has_operation()) or
                                                (self.subscriber is not None and self.subscriber.has_operation()) or
                                                (self.te_client is not None and self.te_client.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "protocol" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bgp"):
                                                if (self.bgp is None):
                                                    self.bgp = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                                    self.bgp.parent = self
                                                    self._children_name_map["bgp"] = "bgp"
                                                return self.bgp

                                            if (child_yang_name == "connected"):
                                                if (self.connected is None):
                                                    self.connected = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                                    self.connected.parent = self
                                                    self._children_name_map["connected"] = "connected"
                                                return self.connected

                                            if (child_yang_name == "eigrp"):
                                                if (self.eigrp is None):
                                                    self.eigrp = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                                    self.eigrp.parent = self
                                                    self._children_name_map["eigrp"] = "eigrp"
                                                return self.eigrp

                                            if (child_yang_name == "isis"):
                                                if (self.isis is None):
                                                    self.isis = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"
                                                return self.isis

                                            if (child_yang_name == "local"):
                                                if (self.local is None):
                                                    self.local = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                                    self.local.parent = self
                                                    self._children_name_map["local"] = "local"
                                                return self.local

                                            if (child_yang_name == "mobile"):
                                                if (self.mobile is None):
                                                    self.mobile = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                                    self.mobile.parent = self
                                                    self._children_name_map["mobile"] = "mobile"
                                                return self.mobile

                                            if (child_yang_name == "ospf"):
                                                if (self.ospf is None):
                                                    self.ospf = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                                    self.ospf.parent = self
                                                    self._children_name_map["ospf"] = "ospf"
                                                return self.ospf

                                            if (child_yang_name == "rpl"):
                                                if (self.rpl is None):
                                                    self.rpl = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                                    self.rpl.parent = self
                                                    self._children_name_map["rpl"] = "rpl"
                                                return self.rpl

                                            if (child_yang_name == "static"):
                                                if (self.static is None):
                                                    self.static = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                                    self.static.parent = self
                                                    self._children_name_map["static"] = "static"
                                                return self.static

                                            if (child_yang_name == "subscriber"):
                                                if (self.subscriber is None):
                                                    self.subscriber = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                                    self.subscriber.parent = self
                                                    self._children_name_map["subscriber"] = "subscriber"
                                                return self.subscriber

                                            if (child_yang_name == "te-client"):
                                                if (self.te_client is None):
                                                    self.te_client = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                                    self.te_client.parent = self
                                                    self._children_name_map["te_client"] = "te-client"
                                                return self.te_client

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bgp" or name == "connected" or name == "eigrp" or name == "isis" or name == "local" or name == "mobile" or name == "ospf" or name == "rpl" or name == "static" or name == "subscriber" or name == "te-client"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Routes(Entity):
                                        """
                                        Route information 
                                        
                                        .. attribute:: route
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__init__()

                                            self.yang_name = "routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__setattr__(name, value)


                                        class Route(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: interface_name
                                            
                                            	Outgoing Interface 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	NextHop Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__init__()

                                                self.yang_name = "route"
                                                self.yang_parent_name = "routes"

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("active",
                                                                "address",
                                                                "attribute_identity",
                                                                "client_id",
                                                                "distance",
                                                                "diversion",
                                                                "diversion_distance",
                                                                "diversion_proto_name",
                                                                "extended_flags",
                                                                "flags",
                                                                "flow_tag",
                                                                "fwd_class",
                                                                "instance",
                                                                "interface_name",
                                                                "metric",
                                                                "next_hop_address",
                                                                "paths_count",
                                                                "pic_count",
                                                                "prefix",
                                                                "prefix_length",
                                                                "prefix_length_xr",
                                                                "priority",
                                                                "protocol_id",
                                                                "protocol_name",
                                                                "qos_group",
                                                                "route_age",
                                                                "route_label",
                                                                "route_modify_time",
                                                                "route_precedence",
                                                                "route_type",
                                                                "route_version",
                                                                "svd_type",
                                                                "tag",
                                                                "tbl_version",
                                                                "traffic_index",
                                                                "version") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__setattr__(name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "route"

                                                    self.ipv6_rib_edm_path = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__setattr__(name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("address",
                                                                        "backup_pathid",
                                                                        "binding_label",
                                                                        "flags",
                                                                        "flags64",
                                                                        "has_labelstk",
                                                                        "information_source",
                                                                        "interface_name",
                                                                        "labelstk",
                                                                        "load_metric",
                                                                        "looped",
                                                                        "metric",
                                                                        "mpls_feid",
                                                                        "mvpn_present",
                                                                        "next_hop_afi",
                                                                        "next_hop_id",
                                                                        "next_hop_id_refcount",
                                                                        "next_hop_safi",
                                                                        "next_hop_table_id",
                                                                        "next_hop_table_name",
                                                                        "next_hop_vrf_name",
                                                                        "nhid_feid",
                                                                        "num_labels",
                                                                        "number_of_extended_communities",
                                                                        "ospf_area_id",
                                                                        "path_rt_present",
                                                                        "pathid",
                                                                        "private_flags",
                                                                        "ref_cnt_of_backup",
                                                                        "remote_backup_addr",
                                                                        "route_label",
                                                                        "segmented_nexthop_present",
                                                                        "source_asrt_present",
                                                                        "source_rd_present",
                                                                        "tunnel_id",
                                                                        "v6_information_source",
                                                                        "v6_nexthop",
                                                                        "vrf_import_rt_present") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        return (
                                                            self.address.is_set or
                                                            self.backup_pathid.is_set or
                                                            self.binding_label.is_set or
                                                            self.flags.is_set or
                                                            self.flags64.is_set or
                                                            self.has_labelstk.is_set or
                                                            self.information_source.is_set or
                                                            self.interface_name.is_set or
                                                            self.load_metric.is_set or
                                                            self.looped.is_set or
                                                            self.metric.is_set or
                                                            self.mpls_feid.is_set or
                                                            self.mvpn_present.is_set or
                                                            self.next_hop_afi.is_set or
                                                            self.next_hop_id.is_set or
                                                            self.next_hop_id_refcount.is_set or
                                                            self.next_hop_safi.is_set or
                                                            self.next_hop_table_id.is_set or
                                                            self.next_hop_table_name.is_set or
                                                            self.next_hop_vrf_name.is_set or
                                                            self.nhid_feid.is_set or
                                                            self.num_labels.is_set or
                                                            self.number_of_extended_communities.is_set or
                                                            self.ospf_area_id.is_set or
                                                            self.path_rt_present.is_set or
                                                            self.pathid.is_set or
                                                            self.private_flags.is_set or
                                                            self.ref_cnt_of_backup.is_set or
                                                            self.route_label.is_set or
                                                            self.segmented_nexthop_present.is_set or
                                                            self.source_asrt_present.is_set or
                                                            self.source_rd_present.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.v6_information_source.is_set or
                                                            self.v6_nexthop.is_set or
                                                            self.vrf_import_rt_present.is_set)

                                                    def has_operation(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.address.yfilter != YFilter.not_set or
                                                            self.backup_pathid.yfilter != YFilter.not_set or
                                                            self.binding_label.yfilter != YFilter.not_set or
                                                            self.flags.yfilter != YFilter.not_set or
                                                            self.flags64.yfilter != YFilter.not_set or
                                                            self.has_labelstk.yfilter != YFilter.not_set or
                                                            self.information_source.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.labelstk.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.looped.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.mpls_feid.yfilter != YFilter.not_set or
                                                            self.mvpn_present.yfilter != YFilter.not_set or
                                                            self.next_hop_afi.yfilter != YFilter.not_set or
                                                            self.next_hop_id.yfilter != YFilter.not_set or
                                                            self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                            self.next_hop_safi.yfilter != YFilter.not_set or
                                                            self.next_hop_table_id.yfilter != YFilter.not_set or
                                                            self.next_hop_table_name.yfilter != YFilter.not_set or
                                                            self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                            self.nhid_feid.yfilter != YFilter.not_set or
                                                            self.num_labels.yfilter != YFilter.not_set or
                                                            self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                            self.ospf_area_id.yfilter != YFilter.not_set or
                                                            self.path_rt_present.yfilter != YFilter.not_set or
                                                            self.pathid.yfilter != YFilter.not_set or
                                                            self.private_flags.yfilter != YFilter.not_set or
                                                            self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                            self.remote_backup_addr.yfilter != YFilter.not_set or
                                                            self.route_label.yfilter != YFilter.not_set or
                                                            self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                            self.source_asrt_present.yfilter != YFilter.not_set or
                                                            self.source_rd_present.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.v6_information_source.yfilter != YFilter.not_set or
                                                            self.v6_nexthop.yfilter != YFilter.not_set or
                                                            self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.address.get_name_leafdata())
                                                        if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                        if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                        if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags.get_name_leafdata())
                                                        if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags64.get_name_leafdata())
                                                        if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                        if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.information_source.get_name_leafdata())
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.looped.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                        if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                        if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                        if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                        if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                        if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                        if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                        if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                        if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                        if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                        if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                        if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                        if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                        if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                        if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pathid.get_name_leafdata())
                                                        if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                        if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                        if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.route_label.get_name_leafdata())
                                                        if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                        if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                        if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                        if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                        if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                        leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                        leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "address"):
                                                            self.address = value
                                                            self.address.value_namespace = name_space
                                                            self.address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-pathid"):
                                                            self.backup_pathid = value
                                                            self.backup_pathid.value_namespace = name_space
                                                            self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "binding-label"):
                                                            self.binding_label = value
                                                            self.binding_label.value_namespace = name_space
                                                            self.binding_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags"):
                                                            self.flags = value
                                                            self.flags.value_namespace = name_space
                                                            self.flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags64"):
                                                            self.flags64 = value
                                                            self.flags64.value_namespace = name_space
                                                            self.flags64.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "has-labelstk"):
                                                            self.has_labelstk = value
                                                            self.has_labelstk.value_namespace = name_space
                                                            self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "information-source"):
                                                            self.information_source = value
                                                            self.information_source.value_namespace = name_space
                                                            self.information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "labelstk"):
                                                            self.labelstk.append(value)
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "looped"):
                                                            self.looped = value
                                                            self.looped.value_namespace = name_space
                                                            self.looped.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-feid"):
                                                            self.mpls_feid = value
                                                            self.mpls_feid.value_namespace = name_space
                                                            self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mvpn-present"):
                                                            self.mvpn_present = value
                                                            self.mvpn_present.value_namespace = name_space
                                                            self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-afi"):
                                                            self.next_hop_afi = value
                                                            self.next_hop_afi.value_namespace = name_space
                                                            self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id"):
                                                            self.next_hop_id = value
                                                            self.next_hop_id.value_namespace = name_space
                                                            self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id-refcount"):
                                                            self.next_hop_id_refcount = value
                                                            self.next_hop_id_refcount.value_namespace = name_space
                                                            self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-safi"):
                                                            self.next_hop_safi = value
                                                            self.next_hop_safi.value_namespace = name_space
                                                            self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-id"):
                                                            self.next_hop_table_id = value
                                                            self.next_hop_table_id.value_namespace = name_space
                                                            self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-name"):
                                                            self.next_hop_table_name = value
                                                            self.next_hop_table_name.value_namespace = name_space
                                                            self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-vrf-name"):
                                                            self.next_hop_vrf_name = value
                                                            self.next_hop_vrf_name.value_namespace = name_space
                                                            self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "nhid-feid"):
                                                            self.nhid_feid = value
                                                            self.nhid_feid.value_namespace = name_space
                                                            self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-labels"):
                                                            self.num_labels = value
                                                            self.num_labels.value_namespace = name_space
                                                            self.num_labels.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "number-of-extended-communities"):
                                                            self.number_of_extended_communities = value
                                                            self.number_of_extended_communities.value_namespace = name_space
                                                            self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ospf-area-id"):
                                                            self.ospf_area_id = value
                                                            self.ospf_area_id.value_namespace = name_space
                                                            self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "path-rt-present"):
                                                            self.path_rt_present = value
                                                            self.path_rt_present.value_namespace = name_space
                                                            self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pathid"):
                                                            self.pathid = value
                                                            self.pathid.value_namespace = name_space
                                                            self.pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "private-flags"):
                                                            self.private_flags = value
                                                            self.private_flags.value_namespace = name_space
                                                            self.private_flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ref-cnt-of-backup"):
                                                            self.ref_cnt_of_backup = value
                                                            self.ref_cnt_of_backup.value_namespace = name_space
                                                            self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-backup-addr"):
                                                            self.remote_backup_addr.append(value)
                                                        if(value_path == "route-label"):
                                                            self.route_label = value
                                                            self.route_label.value_namespace = name_space
                                                            self.route_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segmented-nexthop-present"):
                                                            self.segmented_nexthop_present = value
                                                            self.segmented_nexthop_present.value_namespace = name_space
                                                            self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-asrt-present"):
                                                            self.source_asrt_present = value
                                                            self.source_asrt_present.value_namespace = name_space
                                                            self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-rd-present"):
                                                            self.source_rd_present = value
                                                            self.source_rd_present.value_namespace = name_space
                                                            self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-information-source"):
                                                            self.v6_information_source = value
                                                            self.v6_information_source.value_namespace = name_space
                                                            self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-nexthop"):
                                                            self.v6_nexthop = value
                                                            self.v6_nexthop.value_namespace = name_space
                                                            self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-import-rt-present"):
                                                            self.vrf_import_rt_present = value
                                                            self.vrf_import_rt_present.value_namespace = name_space
                                                            self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv6-rib-edm-path"):
                                                        for c in self.ipv6_rib_edm_path:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.ipv6_rib_edm_path.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv6-rib-edm-path"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.active.is_set or
                                                    self.address.is_set or
                                                    self.attribute_identity.is_set or
                                                    self.client_id.is_set or
                                                    self.distance.is_set or
                                                    self.diversion.is_set or
                                                    self.diversion_distance.is_set or
                                                    self.diversion_proto_name.is_set or
                                                    self.extended_flags.is_set or
                                                    self.flags.is_set or
                                                    self.flow_tag.is_set or
                                                    self.fwd_class.is_set or
                                                    self.instance.is_set or
                                                    self.interface_name.is_set or
                                                    self.metric.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.paths_count.is_set or
                                                    self.pic_count.is_set or
                                                    self.prefix.is_set or
                                                    self.prefix_length.is_set or
                                                    self.prefix_length_xr.is_set or
                                                    self.priority.is_set or
                                                    self.protocol_id.is_set or
                                                    self.protocol_name.is_set or
                                                    self.qos_group.is_set or
                                                    self.route_age.is_set or
                                                    self.route_label.is_set or
                                                    self.route_modify_time.is_set or
                                                    self.route_precedence.is_set or
                                                    self.route_type.is_set or
                                                    self.route_version.is_set or
                                                    self.svd_type.is_set or
                                                    self.tag.is_set or
                                                    self.tbl_version.is_set or
                                                    self.traffic_index.is_set or
                                                    self.version.is_set or
                                                    (self.route_path is not None and self.route_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.active.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.attribute_identity.yfilter != YFilter.not_set or
                                                    self.client_id.yfilter != YFilter.not_set or
                                                    self.distance.yfilter != YFilter.not_set or
                                                    self.diversion.yfilter != YFilter.not_set or
                                                    self.diversion_distance.yfilter != YFilter.not_set or
                                                    self.diversion_proto_name.yfilter != YFilter.not_set or
                                                    self.extended_flags.yfilter != YFilter.not_set or
                                                    self.flags.yfilter != YFilter.not_set or
                                                    self.flow_tag.yfilter != YFilter.not_set or
                                                    self.fwd_class.yfilter != YFilter.not_set or
                                                    self.instance.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.paths_count.yfilter != YFilter.not_set or
                                                    self.pic_count.yfilter != YFilter.not_set or
                                                    self.prefix.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set or
                                                    self.prefix_length_xr.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set or
                                                    self.protocol_id.yfilter != YFilter.not_set or
                                                    self.protocol_name.yfilter != YFilter.not_set or
                                                    self.qos_group.yfilter != YFilter.not_set or
                                                    self.route_age.yfilter != YFilter.not_set or
                                                    self.route_label.yfilter != YFilter.not_set or
                                                    self.route_modify_time.yfilter != YFilter.not_set or
                                                    self.route_precedence.yfilter != YFilter.not_set or
                                                    self.route_type.yfilter != YFilter.not_set or
                                                    self.route_version.yfilter != YFilter.not_set or
                                                    self.svd_type.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tbl_version.yfilter != YFilter.not_set or
                                                    self.traffic_index.yfilter != YFilter.not_set or
                                                    self.version.yfilter != YFilter.not_set or
                                                    (self.route_path is not None and self.route_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.active.get_name_leafdata())
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.client_id.get_name_leafdata())
                                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.distance.get_name_leafdata())
                                                if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion.get_name_leafdata())
                                                if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                                if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                                if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_age.get_name_leafdata())
                                                if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_label.get_name_leafdata())
                                                if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_type.get_name_leafdata())
                                                if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_version.get_name_leafdata())
                                                if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.version.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-path"):
                                                    if (self.route_path is None):
                                                        self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                        self.route_path.parent = self
                                                        self._children_name_map["route_path"] = "route-path"
                                                    return self.route_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "interface-name" or name == "metric" or name == "next-hop-address" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "active"):
                                                    self.active = value
                                                    self.active.value_namespace = name_space
                                                    self.active.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "attribute-identity"):
                                                    self.attribute_identity = value
                                                    self.attribute_identity.value_namespace = name_space
                                                    self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                if(value_path == "client-id"):
                                                    self.client_id = value
                                                    self.client_id.value_namespace = name_space
                                                    self.client_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "distance"):
                                                    self.distance = value
                                                    self.distance.value_namespace = name_space
                                                    self.distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion"):
                                                    self.diversion = value
                                                    self.diversion.value_namespace = name_space
                                                    self.diversion.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-distance"):
                                                    self.diversion_distance = value
                                                    self.diversion_distance.value_namespace = name_space
                                                    self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-proto-name"):
                                                    self.diversion_proto_name = value
                                                    self.diversion_proto_name.value_namespace = name_space
                                                    self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "extended-flags"):
                                                    self.extended_flags = value
                                                    self.extended_flags.value_namespace = name_space
                                                    self.extended_flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flags"):
                                                    self.flags = value
                                                    self.flags.value_namespace = name_space
                                                    self.flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flow-tag"):
                                                    self.flow_tag = value
                                                    self.flow_tag.value_namespace = name_space
                                                    self.flow_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fwd-class"):
                                                    self.fwd_class = value
                                                    self.fwd_class.value_namespace = name_space
                                                    self.fwd_class.value_namespace_prefix = name_space_prefix
                                                if(value_path == "instance"):
                                                    self.instance = value
                                                    self.instance.value_namespace = name_space
                                                    self.instance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "paths-count"):
                                                    self.paths_count = value
                                                    self.paths_count.value_namespace = name_space
                                                    self.paths_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pic-count"):
                                                    self.pic_count = value
                                                    self.pic_count.value_namespace = name_space
                                                    self.pic_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix"):
                                                    self.prefix = value
                                                    self.prefix.value_namespace = name_space
                                                    self.prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length-xr"):
                                                    self.prefix_length_xr = value
                                                    self.prefix_length_xr.value_namespace = name_space
                                                    self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-id"):
                                                    self.protocol_id = value
                                                    self.protocol_id.value_namespace = name_space
                                                    self.protocol_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-name"):
                                                    self.protocol_name = value
                                                    self.protocol_name.value_namespace = name_space
                                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "qos-group"):
                                                    self.qos_group = value
                                                    self.qos_group.value_namespace = name_space
                                                    self.qos_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-age"):
                                                    self.route_age = value
                                                    self.route_age.value_namespace = name_space
                                                    self.route_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-label"):
                                                    self.route_label = value
                                                    self.route_label.value_namespace = name_space
                                                    self.route_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-modify-time"):
                                                    self.route_modify_time = value
                                                    self.route_modify_time.value_namespace = name_space
                                                    self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-precedence"):
                                                    self.route_precedence = value
                                                    self.route_precedence.value_namespace = name_space
                                                    self.route_precedence.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-type"):
                                                    self.route_type = value
                                                    self.route_type.value_namespace = name_space
                                                    self.route_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-version"):
                                                    self.route_version = value
                                                    self.route_version.value_namespace = name_space
                                                    self.route_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "svd-type"):
                                                    self.svd_type = value
                                                    self.svd_type.value_namespace = name_space
                                                    self.svd_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tbl-version"):
                                                    self.tbl_version = value
                                                    self.tbl_version.value_namespace = name_space
                                                    self.tbl_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "traffic-index"):
                                                    self.traffic_index = value
                                                    self.traffic_index.value_namespace = name_space
                                                    self.traffic_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "version"):
                                                    self.version = value
                                                    self.version.value_namespace = name_space
                                                    self.version.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route"):
                                                for c in self.route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class QRoutes(Entity):
                                        """
                                        Quarantine
                                        
                                        .. attribute:: q_route
                                        
                                        	Route information for a specific quarantined address 
                                        	**type**\: list of    :py:class:`QRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__init__()

                                            self.yang_name = "q-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.q_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__setattr__(name, value)


                                        class QRoute(Entity):
                                            """
                                            Route information for a specific
                                            quarantined address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__init__()

                                                self.yang_name = "q-route"
                                                self.yang_parent_name = "q-routes"

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("active",
                                                                "address",
                                                                "attribute_identity",
                                                                "client_id",
                                                                "distance",
                                                                "diversion",
                                                                "diversion_distance",
                                                                "diversion_proto_name",
                                                                "extended_flags",
                                                                "flags",
                                                                "flow_tag",
                                                                "fwd_class",
                                                                "instance",
                                                                "metric",
                                                                "paths_count",
                                                                "pic_count",
                                                                "prefix",
                                                                "prefix_length",
                                                                "prefix_length_xr",
                                                                "priority",
                                                                "protocol_id",
                                                                "protocol_name",
                                                                "qos_group",
                                                                "route_age",
                                                                "route_label",
                                                                "route_modify_time",
                                                                "route_precedence",
                                                                "route_type",
                                                                "route_version",
                                                                "svd_type",
                                                                "tag",
                                                                "tbl_version",
                                                                "traffic_index",
                                                                "version") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__setattr__(name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "q-route"

                                                    self.ipv6_rib_edm_path = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__setattr__(name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("address",
                                                                        "backup_pathid",
                                                                        "binding_label",
                                                                        "flags",
                                                                        "flags64",
                                                                        "has_labelstk",
                                                                        "information_source",
                                                                        "interface_name",
                                                                        "labelstk",
                                                                        "load_metric",
                                                                        "looped",
                                                                        "metric",
                                                                        "mpls_feid",
                                                                        "mvpn_present",
                                                                        "next_hop_afi",
                                                                        "next_hop_id",
                                                                        "next_hop_id_refcount",
                                                                        "next_hop_safi",
                                                                        "next_hop_table_id",
                                                                        "next_hop_table_name",
                                                                        "next_hop_vrf_name",
                                                                        "nhid_feid",
                                                                        "num_labels",
                                                                        "number_of_extended_communities",
                                                                        "ospf_area_id",
                                                                        "path_rt_present",
                                                                        "pathid",
                                                                        "private_flags",
                                                                        "ref_cnt_of_backup",
                                                                        "remote_backup_addr",
                                                                        "route_label",
                                                                        "segmented_nexthop_present",
                                                                        "source_asrt_present",
                                                                        "source_rd_present",
                                                                        "tunnel_id",
                                                                        "v6_information_source",
                                                                        "v6_nexthop",
                                                                        "vrf_import_rt_present") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        return (
                                                            self.address.is_set or
                                                            self.backup_pathid.is_set or
                                                            self.binding_label.is_set or
                                                            self.flags.is_set or
                                                            self.flags64.is_set or
                                                            self.has_labelstk.is_set or
                                                            self.information_source.is_set or
                                                            self.interface_name.is_set or
                                                            self.load_metric.is_set or
                                                            self.looped.is_set or
                                                            self.metric.is_set or
                                                            self.mpls_feid.is_set or
                                                            self.mvpn_present.is_set or
                                                            self.next_hop_afi.is_set or
                                                            self.next_hop_id.is_set or
                                                            self.next_hop_id_refcount.is_set or
                                                            self.next_hop_safi.is_set or
                                                            self.next_hop_table_id.is_set or
                                                            self.next_hop_table_name.is_set or
                                                            self.next_hop_vrf_name.is_set or
                                                            self.nhid_feid.is_set or
                                                            self.num_labels.is_set or
                                                            self.number_of_extended_communities.is_set or
                                                            self.ospf_area_id.is_set or
                                                            self.path_rt_present.is_set or
                                                            self.pathid.is_set or
                                                            self.private_flags.is_set or
                                                            self.ref_cnt_of_backup.is_set or
                                                            self.route_label.is_set or
                                                            self.segmented_nexthop_present.is_set or
                                                            self.source_asrt_present.is_set or
                                                            self.source_rd_present.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.v6_information_source.is_set or
                                                            self.v6_nexthop.is_set or
                                                            self.vrf_import_rt_present.is_set)

                                                    def has_operation(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.address.yfilter != YFilter.not_set or
                                                            self.backup_pathid.yfilter != YFilter.not_set or
                                                            self.binding_label.yfilter != YFilter.not_set or
                                                            self.flags.yfilter != YFilter.not_set or
                                                            self.flags64.yfilter != YFilter.not_set or
                                                            self.has_labelstk.yfilter != YFilter.not_set or
                                                            self.information_source.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.labelstk.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.looped.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.mpls_feid.yfilter != YFilter.not_set or
                                                            self.mvpn_present.yfilter != YFilter.not_set or
                                                            self.next_hop_afi.yfilter != YFilter.not_set or
                                                            self.next_hop_id.yfilter != YFilter.not_set or
                                                            self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                            self.next_hop_safi.yfilter != YFilter.not_set or
                                                            self.next_hop_table_id.yfilter != YFilter.not_set or
                                                            self.next_hop_table_name.yfilter != YFilter.not_set or
                                                            self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                            self.nhid_feid.yfilter != YFilter.not_set or
                                                            self.num_labels.yfilter != YFilter.not_set or
                                                            self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                            self.ospf_area_id.yfilter != YFilter.not_set or
                                                            self.path_rt_present.yfilter != YFilter.not_set or
                                                            self.pathid.yfilter != YFilter.not_set or
                                                            self.private_flags.yfilter != YFilter.not_set or
                                                            self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                            self.remote_backup_addr.yfilter != YFilter.not_set or
                                                            self.route_label.yfilter != YFilter.not_set or
                                                            self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                            self.source_asrt_present.yfilter != YFilter.not_set or
                                                            self.source_rd_present.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.v6_information_source.yfilter != YFilter.not_set or
                                                            self.v6_nexthop.yfilter != YFilter.not_set or
                                                            self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.address.get_name_leafdata())
                                                        if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                        if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                        if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags.get_name_leafdata())
                                                        if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags64.get_name_leafdata())
                                                        if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                        if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.information_source.get_name_leafdata())
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.looped.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                        if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                        if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                        if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                        if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                        if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                        if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                        if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                        if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                        if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                        if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                        if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                        if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                        if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                        if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pathid.get_name_leafdata())
                                                        if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                        if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                        if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.route_label.get_name_leafdata())
                                                        if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                        if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                        if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                        if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                        if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                        leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                        leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "address"):
                                                            self.address = value
                                                            self.address.value_namespace = name_space
                                                            self.address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-pathid"):
                                                            self.backup_pathid = value
                                                            self.backup_pathid.value_namespace = name_space
                                                            self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "binding-label"):
                                                            self.binding_label = value
                                                            self.binding_label.value_namespace = name_space
                                                            self.binding_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags"):
                                                            self.flags = value
                                                            self.flags.value_namespace = name_space
                                                            self.flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags64"):
                                                            self.flags64 = value
                                                            self.flags64.value_namespace = name_space
                                                            self.flags64.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "has-labelstk"):
                                                            self.has_labelstk = value
                                                            self.has_labelstk.value_namespace = name_space
                                                            self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "information-source"):
                                                            self.information_source = value
                                                            self.information_source.value_namespace = name_space
                                                            self.information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "labelstk"):
                                                            self.labelstk.append(value)
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "looped"):
                                                            self.looped = value
                                                            self.looped.value_namespace = name_space
                                                            self.looped.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-feid"):
                                                            self.mpls_feid = value
                                                            self.mpls_feid.value_namespace = name_space
                                                            self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mvpn-present"):
                                                            self.mvpn_present = value
                                                            self.mvpn_present.value_namespace = name_space
                                                            self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-afi"):
                                                            self.next_hop_afi = value
                                                            self.next_hop_afi.value_namespace = name_space
                                                            self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id"):
                                                            self.next_hop_id = value
                                                            self.next_hop_id.value_namespace = name_space
                                                            self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id-refcount"):
                                                            self.next_hop_id_refcount = value
                                                            self.next_hop_id_refcount.value_namespace = name_space
                                                            self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-safi"):
                                                            self.next_hop_safi = value
                                                            self.next_hop_safi.value_namespace = name_space
                                                            self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-id"):
                                                            self.next_hop_table_id = value
                                                            self.next_hop_table_id.value_namespace = name_space
                                                            self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-name"):
                                                            self.next_hop_table_name = value
                                                            self.next_hop_table_name.value_namespace = name_space
                                                            self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-vrf-name"):
                                                            self.next_hop_vrf_name = value
                                                            self.next_hop_vrf_name.value_namespace = name_space
                                                            self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "nhid-feid"):
                                                            self.nhid_feid = value
                                                            self.nhid_feid.value_namespace = name_space
                                                            self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-labels"):
                                                            self.num_labels = value
                                                            self.num_labels.value_namespace = name_space
                                                            self.num_labels.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "number-of-extended-communities"):
                                                            self.number_of_extended_communities = value
                                                            self.number_of_extended_communities.value_namespace = name_space
                                                            self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ospf-area-id"):
                                                            self.ospf_area_id = value
                                                            self.ospf_area_id.value_namespace = name_space
                                                            self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "path-rt-present"):
                                                            self.path_rt_present = value
                                                            self.path_rt_present.value_namespace = name_space
                                                            self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pathid"):
                                                            self.pathid = value
                                                            self.pathid.value_namespace = name_space
                                                            self.pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "private-flags"):
                                                            self.private_flags = value
                                                            self.private_flags.value_namespace = name_space
                                                            self.private_flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ref-cnt-of-backup"):
                                                            self.ref_cnt_of_backup = value
                                                            self.ref_cnt_of_backup.value_namespace = name_space
                                                            self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-backup-addr"):
                                                            self.remote_backup_addr.append(value)
                                                        if(value_path == "route-label"):
                                                            self.route_label = value
                                                            self.route_label.value_namespace = name_space
                                                            self.route_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segmented-nexthop-present"):
                                                            self.segmented_nexthop_present = value
                                                            self.segmented_nexthop_present.value_namespace = name_space
                                                            self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-asrt-present"):
                                                            self.source_asrt_present = value
                                                            self.source_asrt_present.value_namespace = name_space
                                                            self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-rd-present"):
                                                            self.source_rd_present = value
                                                            self.source_rd_present.value_namespace = name_space
                                                            self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-information-source"):
                                                            self.v6_information_source = value
                                                            self.v6_information_source.value_namespace = name_space
                                                            self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-nexthop"):
                                                            self.v6_nexthop = value
                                                            self.v6_nexthop.value_namespace = name_space
                                                            self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-import-rt-present"):
                                                            self.vrf_import_rt_present = value
                                                            self.vrf_import_rt_present.value_namespace = name_space
                                                            self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv6-rib-edm-path"):
                                                        for c in self.ipv6_rib_edm_path:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.ipv6_rib_edm_path.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv6-rib-edm-path"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.active.is_set or
                                                    self.address.is_set or
                                                    self.attribute_identity.is_set or
                                                    self.client_id.is_set or
                                                    self.distance.is_set or
                                                    self.diversion.is_set or
                                                    self.diversion_distance.is_set or
                                                    self.diversion_proto_name.is_set or
                                                    self.extended_flags.is_set or
                                                    self.flags.is_set or
                                                    self.flow_tag.is_set or
                                                    self.fwd_class.is_set or
                                                    self.instance.is_set or
                                                    self.metric.is_set or
                                                    self.paths_count.is_set or
                                                    self.pic_count.is_set or
                                                    self.prefix.is_set or
                                                    self.prefix_length.is_set or
                                                    self.prefix_length_xr.is_set or
                                                    self.priority.is_set or
                                                    self.protocol_id.is_set or
                                                    self.protocol_name.is_set or
                                                    self.qos_group.is_set or
                                                    self.route_age.is_set or
                                                    self.route_label.is_set or
                                                    self.route_modify_time.is_set or
                                                    self.route_precedence.is_set or
                                                    self.route_type.is_set or
                                                    self.route_version.is_set or
                                                    self.svd_type.is_set or
                                                    self.tag.is_set or
                                                    self.tbl_version.is_set or
                                                    self.traffic_index.is_set or
                                                    self.version.is_set or
                                                    (self.route_path is not None and self.route_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.active.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.attribute_identity.yfilter != YFilter.not_set or
                                                    self.client_id.yfilter != YFilter.not_set or
                                                    self.distance.yfilter != YFilter.not_set or
                                                    self.diversion.yfilter != YFilter.not_set or
                                                    self.diversion_distance.yfilter != YFilter.not_set or
                                                    self.diversion_proto_name.yfilter != YFilter.not_set or
                                                    self.extended_flags.yfilter != YFilter.not_set or
                                                    self.flags.yfilter != YFilter.not_set or
                                                    self.flow_tag.yfilter != YFilter.not_set or
                                                    self.fwd_class.yfilter != YFilter.not_set or
                                                    self.instance.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.paths_count.yfilter != YFilter.not_set or
                                                    self.pic_count.yfilter != YFilter.not_set or
                                                    self.prefix.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set or
                                                    self.prefix_length_xr.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set or
                                                    self.protocol_id.yfilter != YFilter.not_set or
                                                    self.protocol_name.yfilter != YFilter.not_set or
                                                    self.qos_group.yfilter != YFilter.not_set or
                                                    self.route_age.yfilter != YFilter.not_set or
                                                    self.route_label.yfilter != YFilter.not_set or
                                                    self.route_modify_time.yfilter != YFilter.not_set or
                                                    self.route_precedence.yfilter != YFilter.not_set or
                                                    self.route_type.yfilter != YFilter.not_set or
                                                    self.route_version.yfilter != YFilter.not_set or
                                                    self.svd_type.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tbl_version.yfilter != YFilter.not_set or
                                                    self.traffic_index.yfilter != YFilter.not_set or
                                                    self.version.yfilter != YFilter.not_set or
                                                    (self.route_path is not None and self.route_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "q-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.active.get_name_leafdata())
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.client_id.get_name_leafdata())
                                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.distance.get_name_leafdata())
                                                if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion.get_name_leafdata())
                                                if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                                if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                                if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_age.get_name_leafdata())
                                                if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_label.get_name_leafdata())
                                                if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_type.get_name_leafdata())
                                                if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_version.get_name_leafdata())
                                                if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.version.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-path"):
                                                    if (self.route_path is None):
                                                        self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                        self.route_path.parent = self
                                                        self._children_name_map["route_path"] = "route-path"
                                                    return self.route_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "active"):
                                                    self.active = value
                                                    self.active.value_namespace = name_space
                                                    self.active.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "attribute-identity"):
                                                    self.attribute_identity = value
                                                    self.attribute_identity.value_namespace = name_space
                                                    self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                if(value_path == "client-id"):
                                                    self.client_id = value
                                                    self.client_id.value_namespace = name_space
                                                    self.client_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "distance"):
                                                    self.distance = value
                                                    self.distance.value_namespace = name_space
                                                    self.distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion"):
                                                    self.diversion = value
                                                    self.diversion.value_namespace = name_space
                                                    self.diversion.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-distance"):
                                                    self.diversion_distance = value
                                                    self.diversion_distance.value_namespace = name_space
                                                    self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-proto-name"):
                                                    self.diversion_proto_name = value
                                                    self.diversion_proto_name.value_namespace = name_space
                                                    self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "extended-flags"):
                                                    self.extended_flags = value
                                                    self.extended_flags.value_namespace = name_space
                                                    self.extended_flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flags"):
                                                    self.flags = value
                                                    self.flags.value_namespace = name_space
                                                    self.flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flow-tag"):
                                                    self.flow_tag = value
                                                    self.flow_tag.value_namespace = name_space
                                                    self.flow_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fwd-class"):
                                                    self.fwd_class = value
                                                    self.fwd_class.value_namespace = name_space
                                                    self.fwd_class.value_namespace_prefix = name_space_prefix
                                                if(value_path == "instance"):
                                                    self.instance = value
                                                    self.instance.value_namespace = name_space
                                                    self.instance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "paths-count"):
                                                    self.paths_count = value
                                                    self.paths_count.value_namespace = name_space
                                                    self.paths_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pic-count"):
                                                    self.pic_count = value
                                                    self.pic_count.value_namespace = name_space
                                                    self.pic_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix"):
                                                    self.prefix = value
                                                    self.prefix.value_namespace = name_space
                                                    self.prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length-xr"):
                                                    self.prefix_length_xr = value
                                                    self.prefix_length_xr.value_namespace = name_space
                                                    self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-id"):
                                                    self.protocol_id = value
                                                    self.protocol_id.value_namespace = name_space
                                                    self.protocol_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-name"):
                                                    self.protocol_name = value
                                                    self.protocol_name.value_namespace = name_space
                                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "qos-group"):
                                                    self.qos_group = value
                                                    self.qos_group.value_namespace = name_space
                                                    self.qos_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-age"):
                                                    self.route_age = value
                                                    self.route_age.value_namespace = name_space
                                                    self.route_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-label"):
                                                    self.route_label = value
                                                    self.route_label.value_namespace = name_space
                                                    self.route_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-modify-time"):
                                                    self.route_modify_time = value
                                                    self.route_modify_time.value_namespace = name_space
                                                    self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-precedence"):
                                                    self.route_precedence = value
                                                    self.route_precedence.value_namespace = name_space
                                                    self.route_precedence.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-type"):
                                                    self.route_type = value
                                                    self.route_type.value_namespace = name_space
                                                    self.route_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-version"):
                                                    self.route_version = value
                                                    self.route_version.value_namespace = name_space
                                                    self.route_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "svd-type"):
                                                    self.svd_type = value
                                                    self.svd_type.value_namespace = name_space
                                                    self.svd_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tbl-version"):
                                                    self.tbl_version = value
                                                    self.tbl_version.value_namespace = name_space
                                                    self.tbl_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "traffic-index"):
                                                    self.traffic_index = value
                                                    self.traffic_index.value_namespace = name_space
                                                    self.traffic_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "version"):
                                                    self.version = value
                                                    self.version.value_namespace = name_space
                                                    self.version.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.q_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.q_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "q-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "q-route"):
                                                for c in self.q_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.q_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "q-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class BackupRoutes(Entity):
                                        """
                                        Backup route information for the given
                                        table
                                        
                                        .. attribute:: backup_route
                                        
                                        	Route information for a specific backup address 
                                        	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__init__()

                                            self.yang_name = "backup-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.backup_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__setattr__(name, value)


                                        class BackupRoute(Entity):
                                            """
                                            Route information for a specific backup
                                            address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: protoid
                                            
                                            	Proto ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__init__()

                                                self.yang_name = "backup-route"
                                                self.yang_parent_name = "backup-routes"

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.protoid = YLeaf(YType.int32, "protoid")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("active",
                                                                "address",
                                                                "attribute_identity",
                                                                "client_id",
                                                                "distance",
                                                                "diversion",
                                                                "diversion_distance",
                                                                "diversion_proto_name",
                                                                "extended_flags",
                                                                "flags",
                                                                "flow_tag",
                                                                "fwd_class",
                                                                "instance",
                                                                "metric",
                                                                "paths_count",
                                                                "pic_count",
                                                                "prefix",
                                                                "prefix_length",
                                                                "prefix_length_xr",
                                                                "priority",
                                                                "protocol_id",
                                                                "protocol_name",
                                                                "protoid",
                                                                "qos_group",
                                                                "route_age",
                                                                "route_label",
                                                                "route_modify_time",
                                                                "route_precedence",
                                                                "route_type",
                                                                "route_version",
                                                                "svd_type",
                                                                "tag",
                                                                "tbl_version",
                                                                "traffic_index",
                                                                "version") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__setattr__(name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "backup-route"

                                                    self.ipv6_rib_edm_path = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__setattr__(name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("address",
                                                                        "backup_pathid",
                                                                        "binding_label",
                                                                        "flags",
                                                                        "flags64",
                                                                        "has_labelstk",
                                                                        "information_source",
                                                                        "interface_name",
                                                                        "labelstk",
                                                                        "load_metric",
                                                                        "looped",
                                                                        "metric",
                                                                        "mpls_feid",
                                                                        "mvpn_present",
                                                                        "next_hop_afi",
                                                                        "next_hop_id",
                                                                        "next_hop_id_refcount",
                                                                        "next_hop_safi",
                                                                        "next_hop_table_id",
                                                                        "next_hop_table_name",
                                                                        "next_hop_vrf_name",
                                                                        "nhid_feid",
                                                                        "num_labels",
                                                                        "number_of_extended_communities",
                                                                        "ospf_area_id",
                                                                        "path_rt_present",
                                                                        "pathid",
                                                                        "private_flags",
                                                                        "ref_cnt_of_backup",
                                                                        "remote_backup_addr",
                                                                        "route_label",
                                                                        "segmented_nexthop_present",
                                                                        "source_asrt_present",
                                                                        "source_rd_present",
                                                                        "tunnel_id",
                                                                        "v6_information_source",
                                                                        "v6_nexthop",
                                                                        "vrf_import_rt_present") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        return (
                                                            self.address.is_set or
                                                            self.backup_pathid.is_set or
                                                            self.binding_label.is_set or
                                                            self.flags.is_set or
                                                            self.flags64.is_set or
                                                            self.has_labelstk.is_set or
                                                            self.information_source.is_set or
                                                            self.interface_name.is_set or
                                                            self.load_metric.is_set or
                                                            self.looped.is_set or
                                                            self.metric.is_set or
                                                            self.mpls_feid.is_set or
                                                            self.mvpn_present.is_set or
                                                            self.next_hop_afi.is_set or
                                                            self.next_hop_id.is_set or
                                                            self.next_hop_id_refcount.is_set or
                                                            self.next_hop_safi.is_set or
                                                            self.next_hop_table_id.is_set or
                                                            self.next_hop_table_name.is_set or
                                                            self.next_hop_vrf_name.is_set or
                                                            self.nhid_feid.is_set or
                                                            self.num_labels.is_set or
                                                            self.number_of_extended_communities.is_set or
                                                            self.ospf_area_id.is_set or
                                                            self.path_rt_present.is_set or
                                                            self.pathid.is_set or
                                                            self.private_flags.is_set or
                                                            self.ref_cnt_of_backup.is_set or
                                                            self.route_label.is_set or
                                                            self.segmented_nexthop_present.is_set or
                                                            self.source_asrt_present.is_set or
                                                            self.source_rd_present.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.v6_information_source.is_set or
                                                            self.v6_nexthop.is_set or
                                                            self.vrf_import_rt_present.is_set)

                                                    def has_operation(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.address.yfilter != YFilter.not_set or
                                                            self.backup_pathid.yfilter != YFilter.not_set or
                                                            self.binding_label.yfilter != YFilter.not_set or
                                                            self.flags.yfilter != YFilter.not_set or
                                                            self.flags64.yfilter != YFilter.not_set or
                                                            self.has_labelstk.yfilter != YFilter.not_set or
                                                            self.information_source.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.labelstk.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.looped.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.mpls_feid.yfilter != YFilter.not_set or
                                                            self.mvpn_present.yfilter != YFilter.not_set or
                                                            self.next_hop_afi.yfilter != YFilter.not_set or
                                                            self.next_hop_id.yfilter != YFilter.not_set or
                                                            self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                            self.next_hop_safi.yfilter != YFilter.not_set or
                                                            self.next_hop_table_id.yfilter != YFilter.not_set or
                                                            self.next_hop_table_name.yfilter != YFilter.not_set or
                                                            self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                            self.nhid_feid.yfilter != YFilter.not_set or
                                                            self.num_labels.yfilter != YFilter.not_set or
                                                            self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                            self.ospf_area_id.yfilter != YFilter.not_set or
                                                            self.path_rt_present.yfilter != YFilter.not_set or
                                                            self.pathid.yfilter != YFilter.not_set or
                                                            self.private_flags.yfilter != YFilter.not_set or
                                                            self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                            self.remote_backup_addr.yfilter != YFilter.not_set or
                                                            self.route_label.yfilter != YFilter.not_set or
                                                            self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                            self.source_asrt_present.yfilter != YFilter.not_set or
                                                            self.source_rd_present.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.v6_information_source.yfilter != YFilter.not_set or
                                                            self.v6_nexthop.yfilter != YFilter.not_set or
                                                            self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.address.get_name_leafdata())
                                                        if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                        if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                        if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags.get_name_leafdata())
                                                        if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags64.get_name_leafdata())
                                                        if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                        if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.information_source.get_name_leafdata())
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.looped.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                        if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                        if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                        if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                        if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                        if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                        if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                        if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                        if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                        if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                        if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                        if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                        if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                        if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                        if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pathid.get_name_leafdata())
                                                        if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                        if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                        if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.route_label.get_name_leafdata())
                                                        if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                        if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                        if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                        if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                        if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                        leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                        leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "address"):
                                                            self.address = value
                                                            self.address.value_namespace = name_space
                                                            self.address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-pathid"):
                                                            self.backup_pathid = value
                                                            self.backup_pathid.value_namespace = name_space
                                                            self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "binding-label"):
                                                            self.binding_label = value
                                                            self.binding_label.value_namespace = name_space
                                                            self.binding_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags"):
                                                            self.flags = value
                                                            self.flags.value_namespace = name_space
                                                            self.flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags64"):
                                                            self.flags64 = value
                                                            self.flags64.value_namespace = name_space
                                                            self.flags64.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "has-labelstk"):
                                                            self.has_labelstk = value
                                                            self.has_labelstk.value_namespace = name_space
                                                            self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "information-source"):
                                                            self.information_source = value
                                                            self.information_source.value_namespace = name_space
                                                            self.information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "labelstk"):
                                                            self.labelstk.append(value)
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "looped"):
                                                            self.looped = value
                                                            self.looped.value_namespace = name_space
                                                            self.looped.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-feid"):
                                                            self.mpls_feid = value
                                                            self.mpls_feid.value_namespace = name_space
                                                            self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mvpn-present"):
                                                            self.mvpn_present = value
                                                            self.mvpn_present.value_namespace = name_space
                                                            self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-afi"):
                                                            self.next_hop_afi = value
                                                            self.next_hop_afi.value_namespace = name_space
                                                            self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id"):
                                                            self.next_hop_id = value
                                                            self.next_hop_id.value_namespace = name_space
                                                            self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id-refcount"):
                                                            self.next_hop_id_refcount = value
                                                            self.next_hop_id_refcount.value_namespace = name_space
                                                            self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-safi"):
                                                            self.next_hop_safi = value
                                                            self.next_hop_safi.value_namespace = name_space
                                                            self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-id"):
                                                            self.next_hop_table_id = value
                                                            self.next_hop_table_id.value_namespace = name_space
                                                            self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-name"):
                                                            self.next_hop_table_name = value
                                                            self.next_hop_table_name.value_namespace = name_space
                                                            self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-vrf-name"):
                                                            self.next_hop_vrf_name = value
                                                            self.next_hop_vrf_name.value_namespace = name_space
                                                            self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "nhid-feid"):
                                                            self.nhid_feid = value
                                                            self.nhid_feid.value_namespace = name_space
                                                            self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-labels"):
                                                            self.num_labels = value
                                                            self.num_labels.value_namespace = name_space
                                                            self.num_labels.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "number-of-extended-communities"):
                                                            self.number_of_extended_communities = value
                                                            self.number_of_extended_communities.value_namespace = name_space
                                                            self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ospf-area-id"):
                                                            self.ospf_area_id = value
                                                            self.ospf_area_id.value_namespace = name_space
                                                            self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "path-rt-present"):
                                                            self.path_rt_present = value
                                                            self.path_rt_present.value_namespace = name_space
                                                            self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pathid"):
                                                            self.pathid = value
                                                            self.pathid.value_namespace = name_space
                                                            self.pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "private-flags"):
                                                            self.private_flags = value
                                                            self.private_flags.value_namespace = name_space
                                                            self.private_flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ref-cnt-of-backup"):
                                                            self.ref_cnt_of_backup = value
                                                            self.ref_cnt_of_backup.value_namespace = name_space
                                                            self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-backup-addr"):
                                                            self.remote_backup_addr.append(value)
                                                        if(value_path == "route-label"):
                                                            self.route_label = value
                                                            self.route_label.value_namespace = name_space
                                                            self.route_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segmented-nexthop-present"):
                                                            self.segmented_nexthop_present = value
                                                            self.segmented_nexthop_present.value_namespace = name_space
                                                            self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-asrt-present"):
                                                            self.source_asrt_present = value
                                                            self.source_asrt_present.value_namespace = name_space
                                                            self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-rd-present"):
                                                            self.source_rd_present = value
                                                            self.source_rd_present.value_namespace = name_space
                                                            self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-information-source"):
                                                            self.v6_information_source = value
                                                            self.v6_information_source.value_namespace = name_space
                                                            self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-nexthop"):
                                                            self.v6_nexthop = value
                                                            self.v6_nexthop.value_namespace = name_space
                                                            self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-import-rt-present"):
                                                            self.vrf_import_rt_present = value
                                                            self.vrf_import_rt_present.value_namespace = name_space
                                                            self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv6-rib-edm-path"):
                                                        for c in self.ipv6_rib_edm_path:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.ipv6_rib_edm_path.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv6-rib-edm-path"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.active.is_set or
                                                    self.address.is_set or
                                                    self.attribute_identity.is_set or
                                                    self.client_id.is_set or
                                                    self.distance.is_set or
                                                    self.diversion.is_set or
                                                    self.diversion_distance.is_set or
                                                    self.diversion_proto_name.is_set or
                                                    self.extended_flags.is_set or
                                                    self.flags.is_set or
                                                    self.flow_tag.is_set or
                                                    self.fwd_class.is_set or
                                                    self.instance.is_set or
                                                    self.metric.is_set or
                                                    self.paths_count.is_set or
                                                    self.pic_count.is_set or
                                                    self.prefix.is_set or
                                                    self.prefix_length.is_set or
                                                    self.prefix_length_xr.is_set or
                                                    self.priority.is_set or
                                                    self.protocol_id.is_set or
                                                    self.protocol_name.is_set or
                                                    self.protoid.is_set or
                                                    self.qos_group.is_set or
                                                    self.route_age.is_set or
                                                    self.route_label.is_set or
                                                    self.route_modify_time.is_set or
                                                    self.route_precedence.is_set or
                                                    self.route_type.is_set or
                                                    self.route_version.is_set or
                                                    self.svd_type.is_set or
                                                    self.tag.is_set or
                                                    self.tbl_version.is_set or
                                                    self.traffic_index.is_set or
                                                    self.version.is_set or
                                                    (self.route_path is not None and self.route_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.active.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.attribute_identity.yfilter != YFilter.not_set or
                                                    self.client_id.yfilter != YFilter.not_set or
                                                    self.distance.yfilter != YFilter.not_set or
                                                    self.diversion.yfilter != YFilter.not_set or
                                                    self.diversion_distance.yfilter != YFilter.not_set or
                                                    self.diversion_proto_name.yfilter != YFilter.not_set or
                                                    self.extended_flags.yfilter != YFilter.not_set or
                                                    self.flags.yfilter != YFilter.not_set or
                                                    self.flow_tag.yfilter != YFilter.not_set or
                                                    self.fwd_class.yfilter != YFilter.not_set or
                                                    self.instance.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.paths_count.yfilter != YFilter.not_set or
                                                    self.pic_count.yfilter != YFilter.not_set or
                                                    self.prefix.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set or
                                                    self.prefix_length_xr.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set or
                                                    self.protocol_id.yfilter != YFilter.not_set or
                                                    self.protocol_name.yfilter != YFilter.not_set or
                                                    self.protoid.yfilter != YFilter.not_set or
                                                    self.qos_group.yfilter != YFilter.not_set or
                                                    self.route_age.yfilter != YFilter.not_set or
                                                    self.route_label.yfilter != YFilter.not_set or
                                                    self.route_modify_time.yfilter != YFilter.not_set or
                                                    self.route_precedence.yfilter != YFilter.not_set or
                                                    self.route_type.yfilter != YFilter.not_set or
                                                    self.route_version.yfilter != YFilter.not_set or
                                                    self.svd_type.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tbl_version.yfilter != YFilter.not_set or
                                                    self.traffic_index.yfilter != YFilter.not_set or
                                                    self.version.yfilter != YFilter.not_set or
                                                    (self.route_path is not None and self.route_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "backup-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.active.get_name_leafdata())
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.client_id.get_name_leafdata())
                                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.distance.get_name_leafdata())
                                                if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion.get_name_leafdata())
                                                if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                                if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                                if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                if (self.protoid.is_set or self.protoid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protoid.get_name_leafdata())
                                                if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_age.get_name_leafdata())
                                                if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_label.get_name_leafdata())
                                                if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_type.get_name_leafdata())
                                                if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_version.get_name_leafdata())
                                                if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.version.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-path"):
                                                    if (self.route_path is None):
                                                        self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                        self.route_path.parent = self
                                                        self._children_name_map["route_path"] = "route-path"
                                                    return self.route_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "protoid" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "active"):
                                                    self.active = value
                                                    self.active.value_namespace = name_space
                                                    self.active.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "attribute-identity"):
                                                    self.attribute_identity = value
                                                    self.attribute_identity.value_namespace = name_space
                                                    self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                if(value_path == "client-id"):
                                                    self.client_id = value
                                                    self.client_id.value_namespace = name_space
                                                    self.client_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "distance"):
                                                    self.distance = value
                                                    self.distance.value_namespace = name_space
                                                    self.distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion"):
                                                    self.diversion = value
                                                    self.diversion.value_namespace = name_space
                                                    self.diversion.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-distance"):
                                                    self.diversion_distance = value
                                                    self.diversion_distance.value_namespace = name_space
                                                    self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-proto-name"):
                                                    self.diversion_proto_name = value
                                                    self.diversion_proto_name.value_namespace = name_space
                                                    self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "extended-flags"):
                                                    self.extended_flags = value
                                                    self.extended_flags.value_namespace = name_space
                                                    self.extended_flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flags"):
                                                    self.flags = value
                                                    self.flags.value_namespace = name_space
                                                    self.flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flow-tag"):
                                                    self.flow_tag = value
                                                    self.flow_tag.value_namespace = name_space
                                                    self.flow_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fwd-class"):
                                                    self.fwd_class = value
                                                    self.fwd_class.value_namespace = name_space
                                                    self.fwd_class.value_namespace_prefix = name_space_prefix
                                                if(value_path == "instance"):
                                                    self.instance = value
                                                    self.instance.value_namespace = name_space
                                                    self.instance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "paths-count"):
                                                    self.paths_count = value
                                                    self.paths_count.value_namespace = name_space
                                                    self.paths_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pic-count"):
                                                    self.pic_count = value
                                                    self.pic_count.value_namespace = name_space
                                                    self.pic_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix"):
                                                    self.prefix = value
                                                    self.prefix.value_namespace = name_space
                                                    self.prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length-xr"):
                                                    self.prefix_length_xr = value
                                                    self.prefix_length_xr.value_namespace = name_space
                                                    self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-id"):
                                                    self.protocol_id = value
                                                    self.protocol_id.value_namespace = name_space
                                                    self.protocol_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-name"):
                                                    self.protocol_name = value
                                                    self.protocol_name.value_namespace = name_space
                                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protoid"):
                                                    self.protoid = value
                                                    self.protoid.value_namespace = name_space
                                                    self.protoid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "qos-group"):
                                                    self.qos_group = value
                                                    self.qos_group.value_namespace = name_space
                                                    self.qos_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-age"):
                                                    self.route_age = value
                                                    self.route_age.value_namespace = name_space
                                                    self.route_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-label"):
                                                    self.route_label = value
                                                    self.route_label.value_namespace = name_space
                                                    self.route_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-modify-time"):
                                                    self.route_modify_time = value
                                                    self.route_modify_time.value_namespace = name_space
                                                    self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-precedence"):
                                                    self.route_precedence = value
                                                    self.route_precedence.value_namespace = name_space
                                                    self.route_precedence.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-type"):
                                                    self.route_type = value
                                                    self.route_type.value_namespace = name_space
                                                    self.route_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-version"):
                                                    self.route_version = value
                                                    self.route_version.value_namespace = name_space
                                                    self.route_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "svd-type"):
                                                    self.svd_type = value
                                                    self.svd_type.value_namespace = name_space
                                                    self.svd_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tbl-version"):
                                                    self.tbl_version = value
                                                    self.tbl_version.value_namespace = name_space
                                                    self.tbl_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "traffic-index"):
                                                    self.traffic_index = value
                                                    self.traffic_index.value_namespace = name_space
                                                    self.traffic_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "version"):
                                                    self.version = value
                                                    self.version.value_namespace = name_space
                                                    self.version.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.backup_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.backup_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "backup-route"):
                                                for c in self.backup_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.backup_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "backup-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.route_table_name.is_set or
                                            (self.adverts is not None and self.adverts.has_data()) or
                                            (self.backup_routes is not None and self.backup_routes.has_data()) or
                                            (self.deleted_routes is not None and self.deleted_routes.has_data()) or
                                            (self.destination_kw is not None and self.destination_kw.has_data()) or
                                            (self.protocol is not None and self.protocol.has_data()) or
                                            (self.q_routes is not None and self.q_routes.has_data()) or
                                            (self.routes is not None and self.routes.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_table_name.yfilter != YFilter.not_set or
                                            (self.adverts is not None and self.adverts.has_operation()) or
                                            (self.backup_routes is not None and self.backup_routes.has_operation()) or
                                            (self.deleted_routes is not None and self.deleted_routes.has_operation()) or
                                            (self.destination_kw is not None and self.destination_kw.has_operation()) or
                                            (self.protocol is not None and self.protocol.has_operation()) or
                                            (self.q_routes is not None and self.q_routes.has_operation()) or
                                            (self.routes is not None and self.routes.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ip-rib-route-table-name" + "[route-table-name='" + self.route_table_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_table_name.is_set or self.route_table_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_table_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "adverts"):
                                            if (self.adverts is None):
                                                self.adverts = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                                self.adverts.parent = self
                                                self._children_name_map["adverts"] = "adverts"
                                            return self.adverts

                                        if (child_yang_name == "backup-routes"):
                                            if (self.backup_routes is None):
                                                self.backup_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                                self.backup_routes.parent = self
                                                self._children_name_map["backup_routes"] = "backup-routes"
                                            return self.backup_routes

                                        if (child_yang_name == "deleted-routes"):
                                            if (self.deleted_routes is None):
                                                self.deleted_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                                self.deleted_routes.parent = self
                                                self._children_name_map["deleted_routes"] = "deleted-routes"
                                            return self.deleted_routes

                                        if (child_yang_name == "destination-kw"):
                                            if (self.destination_kw is None):
                                                self.destination_kw = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                                self.destination_kw.parent = self
                                                self._children_name_map["destination_kw"] = "destination-kw"
                                            return self.destination_kw

                                        if (child_yang_name == "protocol"):
                                            if (self.protocol is None):
                                                self.protocol = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                                self.protocol.parent = self
                                                self._children_name_map["protocol"] = "protocol"
                                            return self.protocol

                                        if (child_yang_name == "q-routes"):
                                            if (self.q_routes is None):
                                                self.q_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                                self.q_routes.parent = self
                                                self._children_name_map["q_routes"] = "q-routes"
                                            return self.q_routes

                                        if (child_yang_name == "routes"):
                                            if (self.routes is None):
                                                self.routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                                self.routes.parent = self
                                                self._children_name_map["routes"] = "routes"
                                            return self.routes

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "adverts" or name == "backup-routes" or name == "deleted-routes" or name == "destination-kw" or name == "protocol" or name == "q-routes" or name == "routes" or name == "route-table-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-table-name"):
                                            self.route_table_name = value
                                            self.route_table_name.value_namespace = name_space
                                            self.route_table_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.ip_rib_route_table_name:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.ip_rib_route_table_name:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ip-rib-route-table-names" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ip-rib-route-table-name"):
                                        for c in self.ip_rib_route_table_name:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ip_rib_route_table_name.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-rib-route-table-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.saf_name.is_set or
                                    (self.ip_rib_route_table_names is not None and self.ip_rib_route_table_names.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.saf_name.yfilter != YFilter.not_set or
                                    (self.ip_rib_route_table_names is not None and self.ip_rib_route_table_names.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "saf" + "[saf-name='" + self.saf_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ip-rib-route-table-names"):
                                    if (self.ip_rib_route_table_names is None):
                                        self.ip_rib_route_table_names = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                        self.ip_rib_route_table_names.parent = self
                                        self._children_name_map["ip_rib_route_table_names"] = "ip-rib-route-table-names"
                                    return self.ip_rib_route_table_names

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-rib-route-table-names" or name == "saf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "saf-name"):
                                    self.saf_name = value
                                    self.saf_name.value_namespace = name_space
                                    self.saf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.saf:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.saf:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "safs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "saf"):
                                for c in self.saf:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.saf.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "saf"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            (self.safs is not None and self.safs.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            (self.safs is not None and self.safs.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "safs"):
                            if (self.safs is None):
                                self.safs = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs()
                                self.safs.parent = self
                                self._children_name_map["safs"] = "safs"
                            return self.safs

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "safs" or name == "af-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.af:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.af:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "afs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "af"):
                        for c in self.af:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Rib.Vrfs.Vrf.Afs.Af()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.af.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "af"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.vrf_name.is_set or
                    (self.afs is not None and self.afs.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.afs is not None and self.afs.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/vrfs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "afs"):
                    if (self.afs is None):
                        self.afs = Ipv6Rib.Vrfs.Vrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"
                    return self.afs

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "afs" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.vrf:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.vrf:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "vrfs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "vrf"):
                for c in self.vrf:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Ipv6Rib.Vrfs.Vrf()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.vrf.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "vrf"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.rib_table_ids is not None and self.rib_table_ids.has_data()) or
            (self.vrfs is not None and self.vrfs.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.rib_table_ids is not None and self.rib_table_ids.has_operation()) or
            (self.vrfs is not None and self.vrfs.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "rib-table-ids"):
            if (self.rib_table_ids is None):
                self.rib_table_ids = Ipv6Rib.RibTableIds()
                self.rib_table_ids.parent = self
                self._children_name_map["rib_table_ids"] = "rib-table-ids"
            return self.rib_table_ids

        if (child_yang_name == "vrfs"):
            if (self.vrfs is None):
                self.vrfs = Ipv6Rib.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
            return self.vrfs

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "rib-table-ids" or name == "vrfs"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Ipv6Rib()
        return self._top_entity

class Ipv6RibStdby(Entity):
    """
    ipv6 rib stdby
    
    .. attribute:: rib_table_ids
    
    	RIB table
    	**type**\:   :py:class:`RibTableIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds>`
    
    .. attribute:: vrfs
    
    	VRF table
    	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs>`
    
    

    """

    _prefix = 'ip-rib-ipv6-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Ipv6RibStdby, self).__init__()
        self._top_entity = None

        self.yang_name = "ipv6-rib-stdby"
        self.yang_parent_name = "Cisco-IOS-XR-ip-rib-ipv6-oper"

        self.rib_table_ids = Ipv6RibStdby.RibTableIds()
        self.rib_table_ids.parent = self
        self._children_name_map["rib_table_ids"] = "rib-table-ids"
        self._children_yang_names.add("rib-table-ids")

        self.vrfs = Ipv6RibStdby.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._children_yang_names.add("vrfs")


    class RibTableIds(Entity):
        """
        RIB table
        
        .. attribute:: rib_table_id
        
        	Specific Table
        	**type**\: list of    :py:class:`RibTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Ipv6RibStdby.RibTableIds, self).__init__()

            self.yang_name = "rib-table-ids"
            self.yang_parent_name = "ipv6-rib-stdby"

            self.rib_table_id = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Ipv6RibStdby.RibTableIds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Ipv6RibStdby.RibTableIds, self).__setattr__(name, value)


        class RibTableId(Entity):
            """
            Specific Table
            
            .. attribute:: tableid  <key>
            
            	Table ID
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: rib_table_itf_hndls
            
            	RIB table interface
            	**type**\:   :py:class:`RibTableItfHndls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls>`
            
            .. attribute:: summary_protos
            
            	RIB table summary
            	**type**\:   :py:class:`SummaryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6RibStdby.RibTableIds.RibTableId, self).__init__()

                self.yang_name = "rib-table-id"
                self.yang_parent_name = "rib-table-ids"

                self.tableid = YLeaf(YType.str, "tableid")

                self.rib_table_itf_hndls = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls()
                self.rib_table_itf_hndls.parent = self
                self._children_name_map["rib_table_itf_hndls"] = "rib-table-itf-hndls"
                self._children_yang_names.add("rib-table-itf-hndls")

                self.summary_protos = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos()
                self.summary_protos.parent = self
                self._children_name_map["summary_protos"] = "summary-protos"
                self._children_yang_names.add("summary-protos")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("tableid") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Ipv6RibStdby.RibTableIds.RibTableId, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Ipv6RibStdby.RibTableIds.RibTableId, self).__setattr__(name, value)


            class SummaryProtos(Entity):
                """
                RIB table summary
                
                .. attribute:: summary_proto
                
                	Route summary information for a specific table/protocol 
                	**type**\: list of    :py:class:`SummaryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos, self).__init__()

                    self.yang_name = "summary-protos"
                    self.yang_parent_name = "rib-table-id"

                    self.summary_proto = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos, self).__setattr__(name, value)


                class SummaryProto(Entity):
                    """
                    Route summary information for a specific
                    table/protocol 
                    
                    .. attribute:: protoid  <key>
                    
                    	Proto ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: instance
                    
                    	Instance
                    	**type**\:  str
                    
                    .. attribute:: name
                    
                    	Proto name
                    	**type**\:  str
                    
                    .. attribute:: proto_route_count
                    
                    	Count for proto. instance
                    	**type**\:   :py:class:`ProtoRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount>`
                    
                    .. attribute:: rtype_bgp_ext
                    
                    	eBGP route
                    	**type**\:   :py:class:`RtypeBgpExt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt>`
                    
                    .. attribute:: rtype_bgp_int
                    
                    	iBGP route
                    	**type**\:   :py:class:`RtypeBgpInt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt>`
                    
                    .. attribute:: rtype_bgp_loc
                    
                    	BGP local route
                    	**type**\:   :py:class:`RtypeBgpLoc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc>`
                    
                    .. attribute:: rtype_igrp2_ext
                    
                    	EIGRP external route
                    	**type**\:   :py:class:`RtypeIgrp2Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext>`
                    
                    .. attribute:: rtype_igrp2_int
                    
                    	EIGRP internal route
                    	**type**\:   :py:class:`RtypeIgrp2Int <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int>`
                    
                    .. attribute:: rtype_isis_l1
                    
                    	IS\-IS level 1 route
                    	**type**\:   :py:class:`RtypeIsisL1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1>`
                    
                    .. attribute:: rtype_isis_l1_ia
                    
                    	IS\-IS level1 inter\-area route
                    	**type**\:   :py:class:`RtypeIsisL1Ia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia>`
                    
                    .. attribute:: rtype_isis_l2
                    
                    	IS\-IS level 2 route
                    	**type**\:   :py:class:`RtypeIsisL2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2>`
                    
                    .. attribute:: rtype_isis_sum
                    
                    	IS\-IS summary route
                    	**type**\:   :py:class:`RtypeIsisSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum>`
                    
                    .. attribute:: rtype_none
                    
                    	No route type
                    	**type**\:   :py:class:`RtypeNone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone>`
                    
                    .. attribute:: rtype_ospf_extern1
                    
                    	OSPF external route of type 1
                    	**type**\:   :py:class:`RtypeOspfExtern1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1>`
                    
                    .. attribute:: rtype_ospf_extern2
                    
                    	OSPF external route of type 2
                    	**type**\:   :py:class:`RtypeOspfExtern2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2>`
                    
                    .. attribute:: rtype_ospf_inter
                    
                    	OSPF route across diff. areas
                    	**type**\:   :py:class:`RtypeOspfInter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter>`
                    
                    .. attribute:: rtype_ospf_intra
                    
                    	OSPF route within an area
                    	**type**\:   :py:class:`RtypeOspfIntra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra>`
                    
                    .. attribute:: rtype_ospf_nssa1
                    
                    	OSPF NSSA ext. route type 1
                    	**type**\:   :py:class:`RtypeOspfNssa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1>`
                    
                    .. attribute:: rtype_ospf_nssa2
                    
                    	OSPF NSSA ext. route type 2
                    	**type**\:   :py:class:`RtypeOspfNssa2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2>`
                    
                    .. attribute:: rtype_other
                    
                    	Unknown route type
                    	**type**\:   :py:class:`RtypeOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__init__()

                        self.yang_name = "summary-proto"
                        self.yang_parent_name = "summary-protos"

                        self.protoid = YLeaf(YType.int32, "protoid")

                        self.instance = YLeaf(YType.str, "instance")

                        self.name = YLeaf(YType.str, "name")

                        self.proto_route_count = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                        self.proto_route_count.parent = self
                        self._children_name_map["proto_route_count"] = "proto-route-count"
                        self._children_yang_names.add("proto-route-count")

                        self.rtype_bgp_ext = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                        self.rtype_bgp_ext.parent = self
                        self._children_name_map["rtype_bgp_ext"] = "rtype-bgp-ext"
                        self._children_yang_names.add("rtype-bgp-ext")

                        self.rtype_bgp_int = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                        self.rtype_bgp_int.parent = self
                        self._children_name_map["rtype_bgp_int"] = "rtype-bgp-int"
                        self._children_yang_names.add("rtype-bgp-int")

                        self.rtype_bgp_loc = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                        self.rtype_bgp_loc.parent = self
                        self._children_name_map["rtype_bgp_loc"] = "rtype-bgp-loc"
                        self._children_yang_names.add("rtype-bgp-loc")

                        self.rtype_igrp2_ext = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                        self.rtype_igrp2_ext.parent = self
                        self._children_name_map["rtype_igrp2_ext"] = "rtype-igrp2-ext"
                        self._children_yang_names.add("rtype-igrp2-ext")

                        self.rtype_igrp2_int = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                        self.rtype_igrp2_int.parent = self
                        self._children_name_map["rtype_igrp2_int"] = "rtype-igrp2-int"
                        self._children_yang_names.add("rtype-igrp2-int")

                        self.rtype_isis_l1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                        self.rtype_isis_l1.parent = self
                        self._children_name_map["rtype_isis_l1"] = "rtype-isis-l1"
                        self._children_yang_names.add("rtype-isis-l1")

                        self.rtype_isis_l1_ia = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                        self.rtype_isis_l1_ia.parent = self
                        self._children_name_map["rtype_isis_l1_ia"] = "rtype-isis-l1-ia"
                        self._children_yang_names.add("rtype-isis-l1-ia")

                        self.rtype_isis_l2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                        self.rtype_isis_l2.parent = self
                        self._children_name_map["rtype_isis_l2"] = "rtype-isis-l2"
                        self._children_yang_names.add("rtype-isis-l2")

                        self.rtype_isis_sum = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                        self.rtype_isis_sum.parent = self
                        self._children_name_map["rtype_isis_sum"] = "rtype-isis-sum"
                        self._children_yang_names.add("rtype-isis-sum")

                        self.rtype_none = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                        self.rtype_none.parent = self
                        self._children_name_map["rtype_none"] = "rtype-none"
                        self._children_yang_names.add("rtype-none")

                        self.rtype_ospf_extern1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                        self.rtype_ospf_extern1.parent = self
                        self._children_name_map["rtype_ospf_extern1"] = "rtype-ospf-extern1"
                        self._children_yang_names.add("rtype-ospf-extern1")

                        self.rtype_ospf_extern2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                        self.rtype_ospf_extern2.parent = self
                        self._children_name_map["rtype_ospf_extern2"] = "rtype-ospf-extern2"
                        self._children_yang_names.add("rtype-ospf-extern2")

                        self.rtype_ospf_inter = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                        self.rtype_ospf_inter.parent = self
                        self._children_name_map["rtype_ospf_inter"] = "rtype-ospf-inter"
                        self._children_yang_names.add("rtype-ospf-inter")

                        self.rtype_ospf_intra = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                        self.rtype_ospf_intra.parent = self
                        self._children_name_map["rtype_ospf_intra"] = "rtype-ospf-intra"
                        self._children_yang_names.add("rtype-ospf-intra")

                        self.rtype_ospf_nssa1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                        self.rtype_ospf_nssa1.parent = self
                        self._children_name_map["rtype_ospf_nssa1"] = "rtype-ospf-nssa1"
                        self._children_yang_names.add("rtype-ospf-nssa1")

                        self.rtype_ospf_nssa2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                        self.rtype_ospf_nssa2.parent = self
                        self._children_name_map["rtype_ospf_nssa2"] = "rtype-ospf-nssa2"
                        self._children_yang_names.add("rtype-ospf-nssa2")

                        self.rtype_other = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                        self.rtype_other.parent = self
                        self._children_name_map["rtype_other"] = "rtype-other"
                        self._children_yang_names.add("rtype-other")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("protoid",
                                        "instance",
                                        "name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__setattr__(name, value)


                    class ProtoRouteCount(Entity):
                        """
                        Count for proto. instance
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__init__()

                            self.yang_name = "proto-route-count"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "proto-route-count" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeNone(Entity):
                        """
                        No route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__init__()

                            self.yang_name = "rtype-none"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-none" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOther(Entity):
                        """
                        Unknown route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__init__()

                            self.yang_name = "rtype-other"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-other" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfIntra(Entity):
                        """
                        OSPF route within an area
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__init__()

                            self.yang_name = "rtype-ospf-intra"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-intra" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfInter(Entity):
                        """
                        OSPF route across diff. areas
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__init__()

                            self.yang_name = "rtype-ospf-inter"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-inter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfExtern1(Entity):
                        """
                        OSPF external route of type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__init__()

                            self.yang_name = "rtype-ospf-extern1"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-extern1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfExtern2(Entity):
                        """
                        OSPF external route of type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__init__()

                            self.yang_name = "rtype-ospf-extern2"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-extern2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIsisSum(Entity):
                        """
                        IS\-IS summary route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__init__()

                            self.yang_name = "rtype-isis-sum"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-isis-sum" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIsisL1(Entity):
                        """
                        IS\-IS level 1 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__init__()

                            self.yang_name = "rtype-isis-l1"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-isis-l1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIsisL2(Entity):
                        """
                        IS\-IS level 2 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__init__()

                            self.yang_name = "rtype-isis-l2"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-isis-l2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIsisL1Ia(Entity):
                        """
                        IS\-IS level1 inter\-area route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__init__()

                            self.yang_name = "rtype-isis-l1-ia"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-isis-l1-ia" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeBgpInt(Entity):
                        """
                        iBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__init__()

                            self.yang_name = "rtype-bgp-int"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-bgp-int" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeBgpExt(Entity):
                        """
                        eBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__init__()

                            self.yang_name = "rtype-bgp-ext"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-bgp-ext" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeBgpLoc(Entity):
                        """
                        BGP local route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__init__()

                            self.yang_name = "rtype-bgp-loc"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-bgp-loc" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfNssa1(Entity):
                        """
                        OSPF NSSA ext. route type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__init__()

                            self.yang_name = "rtype-ospf-nssa1"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-nssa1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeOspfNssa2(Entity):
                        """
                        OSPF NSSA ext. route type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__init__()

                            self.yang_name = "rtype-ospf-nssa2"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-ospf-nssa2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIgrp2Int(Entity):
                        """
                        EIGRP internal route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__init__()

                            self.yang_name = "rtype-igrp2-int"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-igrp2-int" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix


                    class RtypeIgrp2Ext(Entity):
                        """
                        EIGRP external route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__init__()

                            self.yang_name = "rtype-igrp2-ext"
                            self.yang_parent_name = "summary-proto"

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_routes_count",
                                            "num_active_paths",
                                            "num_backup_paths",
                                            "num_backup_routes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active_routes_count.is_set or
                                self.num_active_paths.is_set or
                                self.num_backup_paths.is_set or
                                self.num_backup_routes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_routes_count.yfilter != YFilter.not_set or
                                self.num_active_paths.yfilter != YFilter.not_set or
                                self.num_backup_paths.yfilter != YFilter.not_set or
                                self.num_backup_routes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rtype-igrp2-ext" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                            if (self.num_active_paths.is_set or self.num_active_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_active_paths.get_name_leafdata())
                            if (self.num_backup_paths.is_set or self.num_backup_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_paths.get_name_leafdata())
                            if (self.num_backup_routes.is_set or self.num_backup_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_backup_routes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active-routes-count" or name == "num-active-paths" or name == "num-backup-paths" or name == "num-backup-routes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-routes-count"):
                                self.active_routes_count = value
                                self.active_routes_count.value_namespace = name_space
                                self.active_routes_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-active-paths"):
                                self.num_active_paths = value
                                self.num_active_paths.value_namespace = name_space
                                self.num_active_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-paths"):
                                self.num_backup_paths = value
                                self.num_backup_paths.value_namespace = name_space
                                self.num_backup_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-backup-routes"):
                                self.num_backup_routes = value
                                self.num_backup_routes.value_namespace = name_space
                                self.num_backup_routes.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.protoid.is_set or
                            self.instance.is_set or
                            self.name.is_set or
                            (self.proto_route_count is not None and self.proto_route_count.has_data()) or
                            (self.rtype_bgp_ext is not None and self.rtype_bgp_ext.has_data()) or
                            (self.rtype_bgp_int is not None and self.rtype_bgp_int.has_data()) or
                            (self.rtype_bgp_loc is not None and self.rtype_bgp_loc.has_data()) or
                            (self.rtype_igrp2_ext is not None and self.rtype_igrp2_ext.has_data()) or
                            (self.rtype_igrp2_int is not None and self.rtype_igrp2_int.has_data()) or
                            (self.rtype_isis_l1 is not None and self.rtype_isis_l1.has_data()) or
                            (self.rtype_isis_l1_ia is not None and self.rtype_isis_l1_ia.has_data()) or
                            (self.rtype_isis_l2 is not None and self.rtype_isis_l2.has_data()) or
                            (self.rtype_isis_sum is not None and self.rtype_isis_sum.has_data()) or
                            (self.rtype_none is not None and self.rtype_none.has_data()) or
                            (self.rtype_ospf_extern1 is not None and self.rtype_ospf_extern1.has_data()) or
                            (self.rtype_ospf_extern2 is not None and self.rtype_ospf_extern2.has_data()) or
                            (self.rtype_ospf_inter is not None and self.rtype_ospf_inter.has_data()) or
                            (self.rtype_ospf_intra is not None and self.rtype_ospf_intra.has_data()) or
                            (self.rtype_ospf_nssa1 is not None and self.rtype_ospf_nssa1.has_data()) or
                            (self.rtype_ospf_nssa2 is not None and self.rtype_ospf_nssa2.has_data()) or
                            (self.rtype_other is not None and self.rtype_other.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.protoid.yfilter != YFilter.not_set or
                            self.instance.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            (self.proto_route_count is not None and self.proto_route_count.has_operation()) or
                            (self.rtype_bgp_ext is not None and self.rtype_bgp_ext.has_operation()) or
                            (self.rtype_bgp_int is not None and self.rtype_bgp_int.has_operation()) or
                            (self.rtype_bgp_loc is not None and self.rtype_bgp_loc.has_operation()) or
                            (self.rtype_igrp2_ext is not None and self.rtype_igrp2_ext.has_operation()) or
                            (self.rtype_igrp2_int is not None and self.rtype_igrp2_int.has_operation()) or
                            (self.rtype_isis_l1 is not None and self.rtype_isis_l1.has_operation()) or
                            (self.rtype_isis_l1_ia is not None and self.rtype_isis_l1_ia.has_operation()) or
                            (self.rtype_isis_l2 is not None and self.rtype_isis_l2.has_operation()) or
                            (self.rtype_isis_sum is not None and self.rtype_isis_sum.has_operation()) or
                            (self.rtype_none is not None and self.rtype_none.has_operation()) or
                            (self.rtype_ospf_extern1 is not None and self.rtype_ospf_extern1.has_operation()) or
                            (self.rtype_ospf_extern2 is not None and self.rtype_ospf_extern2.has_operation()) or
                            (self.rtype_ospf_inter is not None and self.rtype_ospf_inter.has_operation()) or
                            (self.rtype_ospf_intra is not None and self.rtype_ospf_intra.has_operation()) or
                            (self.rtype_ospf_nssa1 is not None and self.rtype_ospf_nssa1.has_operation()) or
                            (self.rtype_ospf_nssa2 is not None and self.rtype_ospf_nssa2.has_operation()) or
                            (self.rtype_other is not None and self.rtype_other.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary-proto" + "[protoid='" + self.protoid.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.protoid.is_set or self.protoid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protoid.get_name_leafdata())
                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.instance.get_name_leafdata())
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "proto-route-count"):
                            if (self.proto_route_count is None):
                                self.proto_route_count = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                                self.proto_route_count.parent = self
                                self._children_name_map["proto_route_count"] = "proto-route-count"
                            return self.proto_route_count

                        if (child_yang_name == "rtype-bgp-ext"):
                            if (self.rtype_bgp_ext is None):
                                self.rtype_bgp_ext = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                                self.rtype_bgp_ext.parent = self
                                self._children_name_map["rtype_bgp_ext"] = "rtype-bgp-ext"
                            return self.rtype_bgp_ext

                        if (child_yang_name == "rtype-bgp-int"):
                            if (self.rtype_bgp_int is None):
                                self.rtype_bgp_int = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                                self.rtype_bgp_int.parent = self
                                self._children_name_map["rtype_bgp_int"] = "rtype-bgp-int"
                            return self.rtype_bgp_int

                        if (child_yang_name == "rtype-bgp-loc"):
                            if (self.rtype_bgp_loc is None):
                                self.rtype_bgp_loc = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                                self.rtype_bgp_loc.parent = self
                                self._children_name_map["rtype_bgp_loc"] = "rtype-bgp-loc"
                            return self.rtype_bgp_loc

                        if (child_yang_name == "rtype-igrp2-ext"):
                            if (self.rtype_igrp2_ext is None):
                                self.rtype_igrp2_ext = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                                self.rtype_igrp2_ext.parent = self
                                self._children_name_map["rtype_igrp2_ext"] = "rtype-igrp2-ext"
                            return self.rtype_igrp2_ext

                        if (child_yang_name == "rtype-igrp2-int"):
                            if (self.rtype_igrp2_int is None):
                                self.rtype_igrp2_int = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                                self.rtype_igrp2_int.parent = self
                                self._children_name_map["rtype_igrp2_int"] = "rtype-igrp2-int"
                            return self.rtype_igrp2_int

                        if (child_yang_name == "rtype-isis-l1"):
                            if (self.rtype_isis_l1 is None):
                                self.rtype_isis_l1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                                self.rtype_isis_l1.parent = self
                                self._children_name_map["rtype_isis_l1"] = "rtype-isis-l1"
                            return self.rtype_isis_l1

                        if (child_yang_name == "rtype-isis-l1-ia"):
                            if (self.rtype_isis_l1_ia is None):
                                self.rtype_isis_l1_ia = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                                self.rtype_isis_l1_ia.parent = self
                                self._children_name_map["rtype_isis_l1_ia"] = "rtype-isis-l1-ia"
                            return self.rtype_isis_l1_ia

                        if (child_yang_name == "rtype-isis-l2"):
                            if (self.rtype_isis_l2 is None):
                                self.rtype_isis_l2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                                self.rtype_isis_l2.parent = self
                                self._children_name_map["rtype_isis_l2"] = "rtype-isis-l2"
                            return self.rtype_isis_l2

                        if (child_yang_name == "rtype-isis-sum"):
                            if (self.rtype_isis_sum is None):
                                self.rtype_isis_sum = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                                self.rtype_isis_sum.parent = self
                                self._children_name_map["rtype_isis_sum"] = "rtype-isis-sum"
                            return self.rtype_isis_sum

                        if (child_yang_name == "rtype-none"):
                            if (self.rtype_none is None):
                                self.rtype_none = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                                self.rtype_none.parent = self
                                self._children_name_map["rtype_none"] = "rtype-none"
                            return self.rtype_none

                        if (child_yang_name == "rtype-ospf-extern1"):
                            if (self.rtype_ospf_extern1 is None):
                                self.rtype_ospf_extern1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                                self.rtype_ospf_extern1.parent = self
                                self._children_name_map["rtype_ospf_extern1"] = "rtype-ospf-extern1"
                            return self.rtype_ospf_extern1

                        if (child_yang_name == "rtype-ospf-extern2"):
                            if (self.rtype_ospf_extern2 is None):
                                self.rtype_ospf_extern2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                                self.rtype_ospf_extern2.parent = self
                                self._children_name_map["rtype_ospf_extern2"] = "rtype-ospf-extern2"
                            return self.rtype_ospf_extern2

                        if (child_yang_name == "rtype-ospf-inter"):
                            if (self.rtype_ospf_inter is None):
                                self.rtype_ospf_inter = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                                self.rtype_ospf_inter.parent = self
                                self._children_name_map["rtype_ospf_inter"] = "rtype-ospf-inter"
                            return self.rtype_ospf_inter

                        if (child_yang_name == "rtype-ospf-intra"):
                            if (self.rtype_ospf_intra is None):
                                self.rtype_ospf_intra = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                                self.rtype_ospf_intra.parent = self
                                self._children_name_map["rtype_ospf_intra"] = "rtype-ospf-intra"
                            return self.rtype_ospf_intra

                        if (child_yang_name == "rtype-ospf-nssa1"):
                            if (self.rtype_ospf_nssa1 is None):
                                self.rtype_ospf_nssa1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                                self.rtype_ospf_nssa1.parent = self
                                self._children_name_map["rtype_ospf_nssa1"] = "rtype-ospf-nssa1"
                            return self.rtype_ospf_nssa1

                        if (child_yang_name == "rtype-ospf-nssa2"):
                            if (self.rtype_ospf_nssa2 is None):
                                self.rtype_ospf_nssa2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                                self.rtype_ospf_nssa2.parent = self
                                self._children_name_map["rtype_ospf_nssa2"] = "rtype-ospf-nssa2"
                            return self.rtype_ospf_nssa2

                        if (child_yang_name == "rtype-other"):
                            if (self.rtype_other is None):
                                self.rtype_other = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                                self.rtype_other.parent = self
                                self._children_name_map["rtype_other"] = "rtype-other"
                            return self.rtype_other

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "proto-route-count" or name == "rtype-bgp-ext" or name == "rtype-bgp-int" or name == "rtype-bgp-loc" or name == "rtype-igrp2-ext" or name == "rtype-igrp2-int" or name == "rtype-isis-l1" or name == "rtype-isis-l1-ia" or name == "rtype-isis-l2" or name == "rtype-isis-sum" or name == "rtype-none" or name == "rtype-ospf-extern1" or name == "rtype-ospf-extern2" or name == "rtype-ospf-inter" or name == "rtype-ospf-intra" or name == "rtype-ospf-nssa1" or name == "rtype-ospf-nssa2" or name == "rtype-other" or name == "protoid" or name == "instance" or name == "name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "protoid"):
                            self.protoid = value
                            self.protoid.value_namespace = name_space
                            self.protoid.value_namespace_prefix = name_space_prefix
                        if(value_path == "instance"):
                            self.instance = value
                            self.instance.value_namespace = name_space
                            self.instance.value_namespace_prefix = name_space_prefix
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.summary_proto:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.summary_proto:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary-protos" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "summary-proto"):
                        for c in self.summary_proto:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.summary_proto.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "summary-proto"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RibTableItfHndls(Entity):
                """
                RIB table interface
                
                .. attribute:: rib_table_itf_hndl
                
                	Interface handle
                	**type**\: list of    :py:class:`RibTableItfHndl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls, self).__init__()

                    self.yang_name = "rib-table-itf-hndls"
                    self.yang_parent_name = "rib-table-id"

                    self.rib_table_itf_hndl = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls, self).__setattr__(name, value)


                class RibTableItfHndl(Entity):
                    """
                    Interface handle
                    
                    .. attribute:: handle  <key>
                    
                    	Itf Handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: itf_route
                    
                    	Route information for a specific table/interface 
                    	**type**\: list of    :py:class:`ItfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__init__()

                        self.yang_name = "rib-table-itf-hndl"
                        self.yang_parent_name = "rib-table-itf-hndls"

                        self.handle = YLeaf(YType.int32, "handle")

                        self.itf_route = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("handle") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__setattr__(name, value)


                    class ItfRoute(Entity):
                        """
                        Route information for a specific
                        table/interface 
                        
                        .. attribute:: address  <key>
                        
                        	Network Address 
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: active
                        
                        	Is the route active or backup
                        	**type**\:  bool
                        
                        .. attribute:: attribute_identity
                        
                        	BGP Attribute ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client_id
                        
                        	Client adding the route to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distance
                        
                        	Distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion
                        
                        	Route has a diversion path
                        	**type**\:  bool
                        
                        .. attribute:: diversion_distance
                        
                        	Diversion distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion_proto_name
                        
                        	Diversion route protocol name
                        	**type**\:  str
                        
                        .. attribute:: extended_flags
                        
                        	Extended Route flags
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: flags
                        
                        	Route flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_tag
                        
                        	Flow tag
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fwd_class
                        
                        	Forward Class
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: instance
                        
                        	Instance name
                        	**type**\:  str
                        
                        .. attribute:: metric
                        
                        	Route metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_count
                        
                        	Number of paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pic_count
                        
                        	Number of pic paths in this route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length_xr
                        
                        	Length of prefix
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: priority
                        
                        	Route priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: protocol_id
                        
                        	Protocol advertising the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_name
                        
                        	 Name of Protocol
                        	**type**\:  str
                        
                        .. attribute:: qos_group
                        
                        	Route qos group
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_age
                        
                        	Age of route (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: route_label
                        
                        	Local label of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_modify_time
                        
                        	Route modification time(nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: route_path
                        
                        	Path(s) of the route
                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath>`
                        
                        .. attribute:: route_precedence
                        
                        	Route ip precedence
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_type
                        
                        	Route type
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: route_version
                        
                        	Route version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: svd_type
                        
                        	SVD Type of route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tag
                        
                        	Opaque proto specific info
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tbl_version
                        
                        	Table Version
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: traffic_index
                        
                        	BGP Traffic Index
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: version
                        
                        	Route Version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__init__()

                            self.yang_name = "itf-route"
                            self.yang_parent_name = "rib-table-itf-hndl"

                            self.address = YLeaf(YType.str, "address")

                            self.active = YLeaf(YType.boolean, "active")

                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                            self.client_id = YLeaf(YType.uint32, "client-id")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.diversion = YLeaf(YType.boolean, "diversion")

                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                            self.flags = YLeaf(YType.uint32, "flags")

                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                            self.instance = YLeaf(YType.str, "instance")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.priority = YLeaf(YType.uint8, "priority")

                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                            self.route_age = YLeaf(YType.uint32, "route-age")

                            self.route_label = YLeaf(YType.uint32, "route-label")

                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                            self.route_type = YLeaf(YType.uint16, "route-type")

                            self.route_version = YLeaf(YType.uint32, "route-version")

                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                            self.tag = YLeaf(YType.uint32, "tag")

                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                            self.version = YLeaf(YType.uint32, "version")

                            self.route_path = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                            self.route_path.parent = self
                            self._children_name_map["route_path"] = "route-path"
                            self._children_yang_names.add("route-path")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "active",
                                            "attribute_identity",
                                            "client_id",
                                            "distance",
                                            "diversion",
                                            "diversion_distance",
                                            "diversion_proto_name",
                                            "extended_flags",
                                            "flags",
                                            "flow_tag",
                                            "fwd_class",
                                            "instance",
                                            "metric",
                                            "paths_count",
                                            "pic_count",
                                            "prefix",
                                            "prefix_length_xr",
                                            "priority",
                                            "protocol_id",
                                            "protocol_name",
                                            "qos_group",
                                            "route_age",
                                            "route_label",
                                            "route_modify_time",
                                            "route_precedence",
                                            "route_type",
                                            "route_version",
                                            "svd_type",
                                            "tag",
                                            "tbl_version",
                                            "traffic_index",
                                            "version") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__setattr__(name, value)


                        class RoutePath(Entity):
                            """
                            Path(s) of the route
                            
                            .. attribute:: ipv6_rib_edm_path
                            
                            	ipv6 rib edm path
                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "itf-route"

                                self.ipv6_rib_edm_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__setattr__(name, value)


                            class Ipv6RibEdmPath(Entity):
                                """
                                ipv6 rib edm path
                                
                                .. attribute:: address
                                
                                	Nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pathid
                                
                                	Path id of this path's backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_label
                                
                                	binding Label for this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: flags64
                                
                                	Flags extended to 64 bits
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: has_labelstk
                                
                                	Path has a label stack
                                	**type**\:  bool
                                
                                .. attribute:: information_source
                                
                                	Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: labelstk
                                
                                	Labels for this path
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_metric
                                
                                	Load Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: looped
                                
                                	Looping path
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_feid
                                
                                	Fib mpls encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: mvpn_present
                                
                                	MVPN attribute present
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_afi
                                
                                	NH afi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id
                                
                                	NHID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id_refcount
                                
                                	NHID references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_safi
                                
                                	NH safi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_id
                                
                                	Nexthop tableid
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_name
                                
                                	NH table name
                                	**type**\:  str
                                
                                .. attribute:: next_hop_vrf_name
                                
                                	VRF Name of the nh table
                                	**type**\:  str
                                
                                .. attribute:: nhid_feid
                                
                                	Fib nhid encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: num_labels
                                
                                	Number of labels in stack
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: number_of_extended_communities
                                
                                	Number of extended communities
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_area_id
                                
                                	OSPF area associated with the path
                                	**type**\:  str
                                
                                .. attribute:: path_rt_present
                                
                                	Path RT present
                                	**type**\:  bool
                                
                                .. attribute:: pathid
                                
                                	Path id of this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: private_flags
                                
                                	Private Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ref_cnt_of_backup
                                
                                	Refcnt of backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_backup_addr
                                
                                	Remote backup node address
                                	**type**\:  list of str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_label
                                
                                	Label associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: segmented_nexthop_present
                                
                                	SegmentedNexthopPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_asrt_present
                                
                                	SOURCEASRTPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_rd_present
                                
                                	SOURCERDPresent
                                	**type**\:  bool
                                
                                .. attribute:: tunnel_id
                                
                                	Tunnel ID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: v6_information_source
                                
                                	V6 Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_nexthop
                                
                                	V6 nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vrf_import_rt_present
                                
                                	VRFIMPORTRTPresent
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                    self.yang_name = "ipv6-rib-edm-path"
                                    self.yang_parent_name = "route-path"

                                    self.address = YLeaf(YType.str, "address")

                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                    self.flags = YLeaf(YType.uint16, "flags")

                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                    self.information_source = YLeaf(YType.str, "information-source")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                    self.looped = YLeaf(YType.boolean, "looped")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "backup_pathid",
                                                    "binding_label",
                                                    "flags",
                                                    "flags64",
                                                    "has_labelstk",
                                                    "information_source",
                                                    "interface_name",
                                                    "labelstk",
                                                    "load_metric",
                                                    "looped",
                                                    "metric",
                                                    "mpls_feid",
                                                    "mvpn_present",
                                                    "next_hop_afi",
                                                    "next_hop_id",
                                                    "next_hop_id_refcount",
                                                    "next_hop_safi",
                                                    "next_hop_table_id",
                                                    "next_hop_table_name",
                                                    "next_hop_vrf_name",
                                                    "nhid_feid",
                                                    "num_labels",
                                                    "number_of_extended_communities",
                                                    "ospf_area_id",
                                                    "path_rt_present",
                                                    "pathid",
                                                    "private_flags",
                                                    "ref_cnt_of_backup",
                                                    "remote_backup_addr",
                                                    "route_label",
                                                    "segmented_nexthop_present",
                                                    "source_asrt_present",
                                                    "source_rd_present",
                                                    "tunnel_id",
                                                    "v6_information_source",
                                                    "v6_nexthop",
                                                    "vrf_import_rt_present") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                def has_data(self):
                                    for leaf in self.labelstk.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    for leaf in self.remote_backup_addr.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.address.is_set or
                                        self.backup_pathid.is_set or
                                        self.binding_label.is_set or
                                        self.flags.is_set or
                                        self.flags64.is_set or
                                        self.has_labelstk.is_set or
                                        self.information_source.is_set or
                                        self.interface_name.is_set or
                                        self.load_metric.is_set or
                                        self.looped.is_set or
                                        self.metric.is_set or
                                        self.mpls_feid.is_set or
                                        self.mvpn_present.is_set or
                                        self.next_hop_afi.is_set or
                                        self.next_hop_id.is_set or
                                        self.next_hop_id_refcount.is_set or
                                        self.next_hop_safi.is_set or
                                        self.next_hop_table_id.is_set or
                                        self.next_hop_table_name.is_set or
                                        self.next_hop_vrf_name.is_set or
                                        self.nhid_feid.is_set or
                                        self.num_labels.is_set or
                                        self.number_of_extended_communities.is_set or
                                        self.ospf_area_id.is_set or
                                        self.path_rt_present.is_set or
                                        self.pathid.is_set or
                                        self.private_flags.is_set or
                                        self.ref_cnt_of_backup.is_set or
                                        self.route_label.is_set or
                                        self.segmented_nexthop_present.is_set or
                                        self.source_asrt_present.is_set or
                                        self.source_rd_present.is_set or
                                        self.tunnel_id.is_set or
                                        self.v6_information_source.is_set or
                                        self.v6_nexthop.is_set or
                                        self.vrf_import_rt_present.is_set)

                                def has_operation(self):
                                    for leaf in self.labelstk.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    for leaf in self.remote_backup_addr.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.backup_pathid.yfilter != YFilter.not_set or
                                        self.binding_label.yfilter != YFilter.not_set or
                                        self.flags.yfilter != YFilter.not_set or
                                        self.flags64.yfilter != YFilter.not_set or
                                        self.has_labelstk.yfilter != YFilter.not_set or
                                        self.information_source.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.labelstk.yfilter != YFilter.not_set or
                                        self.load_metric.yfilter != YFilter.not_set or
                                        self.looped.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        self.mpls_feid.yfilter != YFilter.not_set or
                                        self.mvpn_present.yfilter != YFilter.not_set or
                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                        self.next_hop_id.yfilter != YFilter.not_set or
                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                        self.nhid_feid.yfilter != YFilter.not_set or
                                        self.num_labels.yfilter != YFilter.not_set or
                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                        self.path_rt_present.yfilter != YFilter.not_set or
                                        self.pathid.yfilter != YFilter.not_set or
                                        self.private_flags.yfilter != YFilter.not_set or
                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                        self.route_label.yfilter != YFilter.not_set or
                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                        self.source_rd_present.yfilter != YFilter.not_set or
                                        self.tunnel_id.yfilter != YFilter.not_set or
                                        self.v6_information_source.yfilter != YFilter.not_set or
                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pathid"):
                                        self.backup_pathid = value
                                        self.backup_pathid.value_namespace = name_space
                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "binding-label"):
                                        self.binding_label = value
                                        self.binding_label.value_namespace = name_space
                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flags"):
                                        self.flags = value
                                        self.flags.value_namespace = name_space
                                        self.flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flags64"):
                                        self.flags64 = value
                                        self.flags64.value_namespace = name_space
                                        self.flags64.value_namespace_prefix = name_space_prefix
                                    if(value_path == "has-labelstk"):
                                        self.has_labelstk = value
                                        self.has_labelstk.value_namespace = name_space
                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                    if(value_path == "information-source"):
                                        self.information_source = value
                                        self.information_source.value_namespace = name_space
                                        self.information_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "labelstk"):
                                        self.labelstk.append(value)
                                    if(value_path == "load-metric"):
                                        self.load_metric = value
                                        self.load_metric.value_namespace = name_space
                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "looped"):
                                        self.looped = value
                                        self.looped.value_namespace = name_space
                                        self.looped.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-feid"):
                                        self.mpls_feid = value
                                        self.mpls_feid.value_namespace = name_space
                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mvpn-present"):
                                        self.mvpn_present = value
                                        self.mvpn_present.value_namespace = name_space
                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-afi"):
                                        self.next_hop_afi = value
                                        self.next_hop_afi.value_namespace = name_space
                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-id"):
                                        self.next_hop_id = value
                                        self.next_hop_id.value_namespace = name_space
                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-id-refcount"):
                                        self.next_hop_id_refcount = value
                                        self.next_hop_id_refcount.value_namespace = name_space
                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-safi"):
                                        self.next_hop_safi = value
                                        self.next_hop_safi.value_namespace = name_space
                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-table-id"):
                                        self.next_hop_table_id = value
                                        self.next_hop_table_id.value_namespace = name_space
                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-table-name"):
                                        self.next_hop_table_name = value
                                        self.next_hop_table_name.value_namespace = name_space
                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-vrf-name"):
                                        self.next_hop_vrf_name = value
                                        self.next_hop_vrf_name.value_namespace = name_space
                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nhid-feid"):
                                        self.nhid_feid = value
                                        self.nhid_feid.value_namespace = name_space
                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "num-labels"):
                                        self.num_labels = value
                                        self.num_labels.value_namespace = name_space
                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-of-extended-communities"):
                                        self.number_of_extended_communities = value
                                        self.number_of_extended_communities.value_namespace = name_space
                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-area-id"):
                                        self.ospf_area_id = value
                                        self.ospf_area_id.value_namespace = name_space
                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-rt-present"):
                                        self.path_rt_present = value
                                        self.path_rt_present.value_namespace = name_space
                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pathid"):
                                        self.pathid = value
                                        self.pathid.value_namespace = name_space
                                        self.pathid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "private-flags"):
                                        self.private_flags = value
                                        self.private_flags.value_namespace = name_space
                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ref-cnt-of-backup"):
                                        self.ref_cnt_of_backup = value
                                        self.ref_cnt_of_backup.value_namespace = name_space
                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-backup-addr"):
                                        self.remote_backup_addr.append(value)
                                    if(value_path == "route-label"):
                                        self.route_label = value
                                        self.route_label.value_namespace = name_space
                                        self.route_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "segmented-nexthop-present"):
                                        self.segmented_nexthop_present = value
                                        self.segmented_nexthop_present.value_namespace = name_space
                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-asrt-present"):
                                        self.source_asrt_present = value
                                        self.source_asrt_present.value_namespace = name_space
                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-rd-present"):
                                        self.source_rd_present = value
                                        self.source_rd_present.value_namespace = name_space
                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-id"):
                                        self.tunnel_id = value
                                        self.tunnel_id.value_namespace = name_space
                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "v6-information-source"):
                                        self.v6_information_source = value
                                        self.v6_information_source.value_namespace = name_space
                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "v6-nexthop"):
                                        self.v6_nexthop = value
                                        self.v6_nexthop.value_namespace = name_space
                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vrf-import-rt-present"):
                                        self.vrf_import_rt_present = value
                                        self.vrf_import_rt_present.value_namespace = name_space
                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ipv6_rib_edm_path:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.ipv6_rib_edm_path:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ipv6-rib-edm-path"):
                                    for c in self.ipv6_rib_edm_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ipv6_rib_edm_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv6-rib-edm-path"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.active.is_set or
                                self.attribute_identity.is_set or
                                self.client_id.is_set or
                                self.distance.is_set or
                                self.diversion.is_set or
                                self.diversion_distance.is_set or
                                self.diversion_proto_name.is_set or
                                self.extended_flags.is_set or
                                self.flags.is_set or
                                self.flow_tag.is_set or
                                self.fwd_class.is_set or
                                self.instance.is_set or
                                self.metric.is_set or
                                self.paths_count.is_set or
                                self.pic_count.is_set or
                                self.prefix.is_set or
                                self.prefix_length_xr.is_set or
                                self.priority.is_set or
                                self.protocol_id.is_set or
                                self.protocol_name.is_set or
                                self.qos_group.is_set or
                                self.route_age.is_set or
                                self.route_label.is_set or
                                self.route_modify_time.is_set or
                                self.route_precedence.is_set or
                                self.route_type.is_set or
                                self.route_version.is_set or
                                self.svd_type.is_set or
                                self.tag.is_set or
                                self.tbl_version.is_set or
                                self.traffic_index.is_set or
                                self.version.is_set or
                                (self.route_path is not None and self.route_path.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.active.yfilter != YFilter.not_set or
                                self.attribute_identity.yfilter != YFilter.not_set or
                                self.client_id.yfilter != YFilter.not_set or
                                self.distance.yfilter != YFilter.not_set or
                                self.diversion.yfilter != YFilter.not_set or
                                self.diversion_distance.yfilter != YFilter.not_set or
                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                self.extended_flags.yfilter != YFilter.not_set or
                                self.flags.yfilter != YFilter.not_set or
                                self.flow_tag.yfilter != YFilter.not_set or
                                self.fwd_class.yfilter != YFilter.not_set or
                                self.instance.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.paths_count.yfilter != YFilter.not_set or
                                self.pic_count.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol_id.yfilter != YFilter.not_set or
                                self.protocol_name.yfilter != YFilter.not_set or
                                self.qos_group.yfilter != YFilter.not_set or
                                self.route_age.yfilter != YFilter.not_set or
                                self.route_label.yfilter != YFilter.not_set or
                                self.route_modify_time.yfilter != YFilter.not_set or
                                self.route_precedence.yfilter != YFilter.not_set or
                                self.route_type.yfilter != YFilter.not_set or
                                self.route_version.yfilter != YFilter.not_set or
                                self.svd_type.yfilter != YFilter.not_set or
                                self.tag.yfilter != YFilter.not_set or
                                self.tbl_version.yfilter != YFilter.not_set or
                                self.traffic_index.yfilter != YFilter.not_set or
                                self.version.yfilter != YFilter.not_set or
                                (self.route_path is not None and self.route_path.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "itf-route" + "[address='" + self.address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active.get_name_leafdata())
                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client_id.get_name_leafdata())
                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.distance.get_name_leafdata())
                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diversion.get_name_leafdata())
                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flags.get_name_leafdata())
                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_age.get_name_leafdata())
                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_label.get_name_leafdata())
                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_type.get_name_leafdata())
                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_version.get_name_leafdata())
                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag.get_name_leafdata())
                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.version.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route-path"):
                                if (self.route_path is None):
                                    self.route_path = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                                    self.route_path.parent = self
                                    self._children_name_map["route_path"] = "route-path"
                                return self.route_path

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route-path" or name == "address" or name == "active" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "active"):
                                self.active = value
                                self.active.value_namespace = name_space
                                self.active.value_namespace_prefix = name_space_prefix
                            if(value_path == "attribute-identity"):
                                self.attribute_identity = value
                                self.attribute_identity.value_namespace = name_space
                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                            if(value_path == "client-id"):
                                self.client_id = value
                                self.client_id.value_namespace = name_space
                                self.client_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "distance"):
                                self.distance = value
                                self.distance.value_namespace = name_space
                                self.distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "diversion"):
                                self.diversion = value
                                self.diversion.value_namespace = name_space
                                self.diversion.value_namespace_prefix = name_space_prefix
                            if(value_path == "diversion-distance"):
                                self.diversion_distance = value
                                self.diversion_distance.value_namespace = name_space
                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "diversion-proto-name"):
                                self.diversion_proto_name = value
                                self.diversion_proto_name.value_namespace = name_space
                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-flags"):
                                self.extended_flags = value
                                self.extended_flags.value_namespace = name_space
                                self.extended_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "flags"):
                                self.flags = value
                                self.flags.value_namespace = name_space
                                self.flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-tag"):
                                self.flow_tag = value
                                self.flow_tag.value_namespace = name_space
                                self.flow_tag.value_namespace_prefix = name_space_prefix
                            if(value_path == "fwd-class"):
                                self.fwd_class = value
                                self.fwd_class.value_namespace = name_space
                                self.fwd_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "instance"):
                                self.instance = value
                                self.instance.value_namespace = name_space
                                self.instance.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "paths-count"):
                                self.paths_count = value
                                self.paths_count.value_namespace = name_space
                                self.paths_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "pic-count"):
                                self.pic_count = value
                                self.pic_count.value_namespace = name_space
                                self.pic_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length-xr"):
                                self.prefix_length_xr = value
                                self.prefix_length_xr.value_namespace = name_space
                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol-id"):
                                self.protocol_id = value
                                self.protocol_id.value_namespace = name_space
                                self.protocol_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol-name"):
                                self.protocol_name = value
                                self.protocol_name.value_namespace = name_space
                                self.protocol_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "qos-group"):
                                self.qos_group = value
                                self.qos_group.value_namespace = name_space
                                self.qos_group.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-age"):
                                self.route_age = value
                                self.route_age.value_namespace = name_space
                                self.route_age.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-label"):
                                self.route_label = value
                                self.route_label.value_namespace = name_space
                                self.route_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-modify-time"):
                                self.route_modify_time = value
                                self.route_modify_time.value_namespace = name_space
                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-precedence"):
                                self.route_precedence = value
                                self.route_precedence.value_namespace = name_space
                                self.route_precedence.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-type"):
                                self.route_type = value
                                self.route_type.value_namespace = name_space
                                self.route_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-version"):
                                self.route_version = value
                                self.route_version.value_namespace = name_space
                                self.route_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "svd-type"):
                                self.svd_type = value
                                self.svd_type.value_namespace = name_space
                                self.svd_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag"):
                                self.tag = value
                                self.tag.value_namespace = name_space
                                self.tag.value_namespace_prefix = name_space_prefix
                            if(value_path == "tbl-version"):
                                self.tbl_version = value
                                self.tbl_version.value_namespace = name_space
                                self.tbl_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-index"):
                                self.traffic_index = value
                                self.traffic_index.value_namespace = name_space
                                self.traffic_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "version"):
                                self.version = value
                                self.version.value_namespace = name_space
                                self.version.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.itf_route:
                            if (c.has_data()):
                                return True
                        return self.handle.is_set

                    def has_operation(self):
                        for c in self.itf_route:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.handle.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rib-table-itf-hndl" + "[handle='" + self.handle.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.handle.is_set or self.handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.handle.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "itf-route"):
                            for c in self.itf_route:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.itf_route.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "itf-route" or name == "handle"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "handle"):
                            self.handle = value
                            self.handle.value_namespace = name_space
                            self.handle.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.rib_table_itf_hndl:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.rib_table_itf_hndl:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rib-table-itf-hndls" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rib-table-itf-hndl"):
                        for c in self.rib_table_itf_hndl:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.rib_table_itf_hndl.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rib-table-itf-hndl"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.tableid.is_set or
                    (self.rib_table_itf_hndls is not None and self.rib_table_itf_hndls.has_data()) or
                    (self.summary_protos is not None and self.summary_protos.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.tableid.yfilter != YFilter.not_set or
                    (self.rib_table_itf_hndls is not None and self.rib_table_itf_hndls.has_operation()) or
                    (self.summary_protos is not None and self.summary_protos.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "rib-table-id" + "[tableid='" + self.tableid.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/rib-table-ids/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.tableid.is_set or self.tableid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tableid.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "rib-table-itf-hndls"):
                    if (self.rib_table_itf_hndls is None):
                        self.rib_table_itf_hndls = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls()
                        self.rib_table_itf_hndls.parent = self
                        self._children_name_map["rib_table_itf_hndls"] = "rib-table-itf-hndls"
                    return self.rib_table_itf_hndls

                if (child_yang_name == "summary-protos"):
                    if (self.summary_protos is None):
                        self.summary_protos = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos()
                        self.summary_protos.parent = self
                        self._children_name_map["summary_protos"] = "summary-protos"
                    return self.summary_protos

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "rib-table-itf-hndls" or name == "summary-protos" or name == "tableid"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "tableid"):
                    self.tableid = value
                    self.tableid.value_namespace = name_space
                    self.tableid.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.rib_table_id:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.rib_table_id:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "rib-table-ids" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "rib-table-id"):
                for c in self.rib_table_id:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Ipv6RibStdby.RibTableIds.RibTableId()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.rib_table_id.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "rib-table-id"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Vrfs(Entity):
        """
        VRF table
        
        .. attribute:: vrf
        
        	Specific VRF
        	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Ipv6RibStdby.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "ipv6-rib-stdby"

            self.vrf = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Ipv6RibStdby.Vrfs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Ipv6RibStdby.Vrfs, self).__setattr__(name, value)


        class Vrf(Entity):
            """
            Specific VRF
            
            .. attribute:: vrf_name  <key>
            
            	Name of the VRF
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: afs
            
            	Address Family (AF) table
            	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6RibStdby.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.afs = Ipv6RibStdby.Vrfs.Vrf.Afs()
                self.afs.parent = self
                self._children_name_map["afs"] = "afs"
                self._children_yang_names.add("afs")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Ipv6RibStdby.Vrfs.Vrf, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Ipv6RibStdby.Vrfs.Vrf, self).__setattr__(name, value)


            class Afs(Entity):
                """
                Address Family (AF) table
                
                .. attribute:: af
                
                	Specific AF information
                	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6RibStdby.Vrfs.Vrf.Afs, self).__init__()

                    self.yang_name = "afs"
                    self.yang_parent_name = "vrf"

                    self.af = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6RibStdby.Vrfs.Vrf.Afs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6RibStdby.Vrfs.Vrf.Afs, self).__setattr__(name, value)


                class Af(Entity):
                    """
                    Specific AF information
                    
                    .. attribute:: af_name  <key>
                    
                    	Name of the AF \- 'IPv6'
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: safs
                    
                    	Subsequent Address Family (SAF) table
                    	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af, self).__init__()

                        self.yang_name = "af"
                        self.yang_parent_name = "afs"

                        self.af_name = YLeaf(YType.str, "af-name")

                        self.safs = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                        self._children_yang_names.add("safs")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af, self).__setattr__(name, value)


                    class Safs(Entity):
                        """
                        Subsequent Address Family (SAF) table
                        
                        .. attribute:: saf
                        
                        	Specific SAF information
                        	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf>`
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs, self).__init__()

                            self.yang_name = "safs"
                            self.yang_parent_name = "af"

                            self.saf = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs, self).__setattr__(name, value)


                        class Saf(Entity):
                            """
                            Specific SAF information
                            
                            .. attribute:: saf_name  <key>
                            
                            	Name of the SAF
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: ip_rib_route_table_names
                            
                            	Global container of routes
                            	**type**\:   :py:class:`IpRibRouteTableNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__init__()

                                self.yang_name = "saf"
                                self.yang_parent_name = "safs"

                                self.saf_name = YLeaf(YType.str, "saf-name")

                                self.ip_rib_route_table_names = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                self.ip_rib_route_table_names.parent = self
                                self._children_name_map["ip_rib_route_table_names"] = "ip-rib-route-table-names"
                                self._children_yang_names.add("ip-rib-route-table-names")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("saf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__setattr__(name, value)


                            class IpRibRouteTableNames(Entity):
                                """
                                Global container of routes
                                
                                .. attribute:: ip_rib_route_table_name
                                
                                	IP RIB Route table name for a topology
                                	**type**\: list of    :py:class:`IpRibRouteTableName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__init__()

                                    self.yang_name = "ip-rib-route-table-names"
                                    self.yang_parent_name = "saf"

                                    self.ip_rib_route_table_name = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__setattr__(name, value)


                                class IpRibRouteTableName(Entity):
                                    """
                                    IP RIB Route table name for a topology
                                    
                                    .. attribute:: route_table_name  <key>
                                    
                                    	Name of the route table 
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: adverts
                                    
                                    	Route advertiser information 
                                    	**type**\:   :py:class:`Adverts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts>`
                                    
                                    .. attribute:: backup_routes
                                    
                                    	Backup route information for the given table
                                    	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes>`
                                    
                                    .. attribute:: deleted_routes
                                    
                                    	Deleted
                                    	**type**\:   :py:class:`DeletedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes>`
                                    
                                    .. attribute:: destination_kw
                                    
                                    	Destination KW
                                    	**type**\:   :py:class:`DestinationKw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Contains the classification of routes by protocol
                                    	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol>`
                                    
                                    .. attribute:: q_routes
                                    
                                    	Quarantine
                                    	**type**\:   :py:class:`QRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes>`
                                    
                                    .. attribute:: routes
                                    
                                    	Route information 
                                    	**type**\:   :py:class:`Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes>`
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__init__()

                                        self.yang_name = "ip-rib-route-table-name"
                                        self.yang_parent_name = "ip-rib-route-table-names"

                                        self.route_table_name = YLeaf(YType.str, "route-table-name")

                                        self.adverts = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                        self.adverts.parent = self
                                        self._children_name_map["adverts"] = "adverts"
                                        self._children_yang_names.add("adverts")

                                        self.backup_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                        self.backup_routes.parent = self
                                        self._children_name_map["backup_routes"] = "backup-routes"
                                        self._children_yang_names.add("backup-routes")

                                        self.deleted_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                        self.deleted_routes.parent = self
                                        self._children_name_map["deleted_routes"] = "deleted-routes"
                                        self._children_yang_names.add("deleted-routes")

                                        self.destination_kw = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                        self.destination_kw.parent = self
                                        self._children_name_map["destination_kw"] = "destination-kw"
                                        self._children_yang_names.add("destination-kw")

                                        self.protocol = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                        self.protocol.parent = self
                                        self._children_name_map["protocol"] = "protocol"
                                        self._children_yang_names.add("protocol")

                                        self.q_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                        self.q_routes.parent = self
                                        self._children_name_map["q_routes"] = "q-routes"
                                        self._children_yang_names.add("q-routes")

                                        self.routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                        self.routes.parent = self
                                        self._children_name_map["routes"] = "routes"
                                        self._children_yang_names.add("routes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_table_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__setattr__(name, value)


                                    class DestinationKw(Entity):
                                        """
                                        Destination KW
                                        
                                        .. attribute:: dest_backup_routes
                                        
                                        	Backup
                                        	**type**\:   :py:class:`DestBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes>`
                                        
                                        .. attribute:: dest_best_routes
                                        
                                        	Best Local
                                        	**type**\:   :py:class:`DestBestRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes>`
                                        
                                        .. attribute:: dest_next_hop_routes
                                        
                                        	Resolving next hop
                                        	**type**\:   :py:class:`DestNextHopRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes>`
                                        
                                        .. attribute:: dest_q_routes
                                        
                                        	Quarantine
                                        	**type**\:   :py:class:`DestQRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw, self).__init__()

                                            self.yang_name = "destination-kw"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.dest_backup_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                            self.dest_backup_routes.parent = self
                                            self._children_name_map["dest_backup_routes"] = "dest-backup-routes"
                                            self._children_yang_names.add("dest-backup-routes")

                                            self.dest_best_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                            self.dest_best_routes.parent = self
                                            self._children_name_map["dest_best_routes"] = "dest-best-routes"
                                            self._children_yang_names.add("dest-best-routes")

                                            self.dest_next_hop_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                            self.dest_next_hop_routes.parent = self
                                            self._children_name_map["dest_next_hop_routes"] = "dest-next-hop-routes"
                                            self._children_yang_names.add("dest-next-hop-routes")

                                            self.dest_q_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                            self.dest_q_routes.parent = self
                                            self._children_name_map["dest_q_routes"] = "dest-q-routes"
                                            self._children_yang_names.add("dest-q-routes")


                                        class DestQRoutes(Entity):
                                            """
                                            Quarantine
                                            
                                            .. attribute:: dest_q_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestQRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__init__()

                                                self.yang_name = "dest-q-routes"
                                                self.yang_parent_name = "destination-kw"

                                                self.dest_q_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__setattr__(name, value)


                                            class DestQRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__init__()

                                                    self.yang_name = "dest-q-route"
                                                    self.yang_parent_name = "dest-q-routes"

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("active",
                                                                    "address",
                                                                    "attribute_identity",
                                                                    "client_id",
                                                                    "distance",
                                                                    "diversion",
                                                                    "diversion_distance",
                                                                    "diversion_proto_name",
                                                                    "extended_flags",
                                                                    "flags",
                                                                    "flow_tag",
                                                                    "fwd_class",
                                                                    "instance",
                                                                    "metric",
                                                                    "paths_count",
                                                                    "pic_count",
                                                                    "prefix",
                                                                    "prefix_length",
                                                                    "prefix_length_xr",
                                                                    "priority",
                                                                    "protocol_id",
                                                                    "protocol_name",
                                                                    "qos_group",
                                                                    "route_age",
                                                                    "route_label",
                                                                    "route_modify_time",
                                                                    "route_precedence",
                                                                    "route_type",
                                                                    "route_version",
                                                                    "svd_type",
                                                                    "tag",
                                                                    "tbl_version",
                                                                    "traffic_index",
                                                                    "version") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__setattr__(name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-q-route"

                                                        self.ipv6_rib_edm_path = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__setattr__(name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("address",
                                                                            "backup_pathid",
                                                                            "binding_label",
                                                                            "flags",
                                                                            "flags64",
                                                                            "has_labelstk",
                                                                            "information_source",
                                                                            "interface_name",
                                                                            "labelstk",
                                                                            "load_metric",
                                                                            "looped",
                                                                            "metric",
                                                                            "mpls_feid",
                                                                            "mvpn_present",
                                                                            "next_hop_afi",
                                                                            "next_hop_id",
                                                                            "next_hop_id_refcount",
                                                                            "next_hop_safi",
                                                                            "next_hop_table_id",
                                                                            "next_hop_table_name",
                                                                            "next_hop_vrf_name",
                                                                            "nhid_feid",
                                                                            "num_labels",
                                                                            "number_of_extended_communities",
                                                                            "ospf_area_id",
                                                                            "path_rt_present",
                                                                            "pathid",
                                                                            "private_flags",
                                                                            "ref_cnt_of_backup",
                                                                            "remote_backup_addr",
                                                                            "route_label",
                                                                            "segmented_nexthop_present",
                                                                            "source_asrt_present",
                                                                            "source_rd_present",
                                                                            "tunnel_id",
                                                                            "v6_information_source",
                                                                            "v6_nexthop",
                                                                            "vrf_import_rt_present") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            return (
                                                                self.address.is_set or
                                                                self.backup_pathid.is_set or
                                                                self.binding_label.is_set or
                                                                self.flags.is_set or
                                                                self.flags64.is_set or
                                                                self.has_labelstk.is_set or
                                                                self.information_source.is_set or
                                                                self.interface_name.is_set or
                                                                self.load_metric.is_set or
                                                                self.looped.is_set or
                                                                self.metric.is_set or
                                                                self.mpls_feid.is_set or
                                                                self.mvpn_present.is_set or
                                                                self.next_hop_afi.is_set or
                                                                self.next_hop_id.is_set or
                                                                self.next_hop_id_refcount.is_set or
                                                                self.next_hop_safi.is_set or
                                                                self.next_hop_table_id.is_set or
                                                                self.next_hop_table_name.is_set or
                                                                self.next_hop_vrf_name.is_set or
                                                                self.nhid_feid.is_set or
                                                                self.num_labels.is_set or
                                                                self.number_of_extended_communities.is_set or
                                                                self.ospf_area_id.is_set or
                                                                self.path_rt_present.is_set or
                                                                self.pathid.is_set or
                                                                self.private_flags.is_set or
                                                                self.ref_cnt_of_backup.is_set or
                                                                self.route_label.is_set or
                                                                self.segmented_nexthop_present.is_set or
                                                                self.source_asrt_present.is_set or
                                                                self.source_rd_present.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.v6_information_source.is_set or
                                                                self.v6_nexthop.is_set or
                                                                self.vrf_import_rt_present.is_set)

                                                        def has_operation(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.backup_pathid.yfilter != YFilter.not_set or
                                                                self.binding_label.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flags64.yfilter != YFilter.not_set or
                                                                self.has_labelstk.yfilter != YFilter.not_set or
                                                                self.information_source.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.labelstk.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.looped.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.mpls_feid.yfilter != YFilter.not_set or
                                                                self.mvpn_present.yfilter != YFilter.not_set or
                                                                self.next_hop_afi.yfilter != YFilter.not_set or
                                                                self.next_hop_id.yfilter != YFilter.not_set or
                                                                self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                self.next_hop_safi.yfilter != YFilter.not_set or
                                                                self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                self.nhid_feid.yfilter != YFilter.not_set or
                                                                self.num_labels.yfilter != YFilter.not_set or
                                                                self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                self.ospf_area_id.yfilter != YFilter.not_set or
                                                                self.path_rt_present.yfilter != YFilter.not_set or
                                                                self.pathid.yfilter != YFilter.not_set or
                                                                self.private_flags.yfilter != YFilter.not_set or
                                                                self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                self.source_asrt_present.yfilter != YFilter.not_set or
                                                                self.source_rd_present.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.v6_information_source.yfilter != YFilter.not_set or
                                                                self.v6_nexthop.yfilter != YFilter.not_set or
                                                                self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                            if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags64.get_name_leafdata())
                                                            if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                            if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.information_source.get_name_leafdata())
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.looped.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                            if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                            if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                            if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                            if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                            if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                            if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                            if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                            if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                            if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                            if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                            if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                            if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                            if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                            if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pathid.get_name_leafdata())
                                                            if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                            if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                            if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                            if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                            if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                            if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                            leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                            leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "backup-pathid"):
                                                                self.backup_pathid = value
                                                                self.backup_pathid.value_namespace = name_space
                                                                self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "binding-label"):
                                                                self.binding_label = value
                                                                self.binding_label.value_namespace = name_space
                                                                self.binding_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags64"):
                                                                self.flags64 = value
                                                                self.flags64.value_namespace = name_space
                                                                self.flags64.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "has-labelstk"):
                                                                self.has_labelstk = value
                                                                self.has_labelstk.value_namespace = name_space
                                                                self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "information-source"):
                                                                self.information_source = value
                                                                self.information_source.value_namespace = name_space
                                                                self.information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "labelstk"):
                                                                self.labelstk.append(value)
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "looped"):
                                                                self.looped = value
                                                                self.looped.value_namespace = name_space
                                                                self.looped.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mpls-feid"):
                                                                self.mpls_feid = value
                                                                self.mpls_feid.value_namespace = name_space
                                                                self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mvpn-present"):
                                                                self.mvpn_present = value
                                                                self.mvpn_present.value_namespace = name_space
                                                                self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-afi"):
                                                                self.next_hop_afi = value
                                                                self.next_hop_afi.value_namespace = name_space
                                                                self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id"):
                                                                self.next_hop_id = value
                                                                self.next_hop_id.value_namespace = name_space
                                                                self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id-refcount"):
                                                                self.next_hop_id_refcount = value
                                                                self.next_hop_id_refcount.value_namespace = name_space
                                                                self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-safi"):
                                                                self.next_hop_safi = value
                                                                self.next_hop_safi.value_namespace = name_space
                                                                self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-id"):
                                                                self.next_hop_table_id = value
                                                                self.next_hop_table_id.value_namespace = name_space
                                                                self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-name"):
                                                                self.next_hop_table_name = value
                                                                self.next_hop_table_name.value_namespace = name_space
                                                                self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-vrf-name"):
                                                                self.next_hop_vrf_name = value
                                                                self.next_hop_vrf_name.value_namespace = name_space
                                                                self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "nhid-feid"):
                                                                self.nhid_feid = value
                                                                self.nhid_feid.value_namespace = name_space
                                                                self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "num-labels"):
                                                                self.num_labels = value
                                                                self.num_labels.value_namespace = name_space
                                                                self.num_labels.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "number-of-extended-communities"):
                                                                self.number_of_extended_communities = value
                                                                self.number_of_extended_communities.value_namespace = name_space
                                                                self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ospf-area-id"):
                                                                self.ospf_area_id = value
                                                                self.ospf_area_id.value_namespace = name_space
                                                                self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "path-rt-present"):
                                                                self.path_rt_present = value
                                                                self.path_rt_present.value_namespace = name_space
                                                                self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pathid"):
                                                                self.pathid = value
                                                                self.pathid.value_namespace = name_space
                                                                self.pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "private-flags"):
                                                                self.private_flags = value
                                                                self.private_flags.value_namespace = name_space
                                                                self.private_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ref-cnt-of-backup"):
                                                                self.ref_cnt_of_backup = value
                                                                self.ref_cnt_of_backup.value_namespace = name_space
                                                                self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "remote-backup-addr"):
                                                                self.remote_backup_addr.append(value)
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "segmented-nexthop-present"):
                                                                self.segmented_nexthop_present = value
                                                                self.segmented_nexthop_present.value_namespace = name_space
                                                                self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-asrt-present"):
                                                                self.source_asrt_present = value
                                                                self.source_asrt_present.value_namespace = name_space
                                                                self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-rd-present"):
                                                                self.source_rd_present = value
                                                                self.source_rd_present.value_namespace = name_space
                                                                self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-information-source"):
                                                                self.v6_information_source = value
                                                                self.v6_information_source.value_namespace = name_space
                                                                self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-nexthop"):
                                                                self.v6_nexthop = value
                                                                self.v6_nexthop.value_namespace = name_space
                                                                self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-import-rt-present"):
                                                                self.vrf_import_rt_present = value
                                                                self.vrf_import_rt_present.value_namespace = name_space
                                                                self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "route-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv6-rib-edm-path"):
                                                            for c in self.ipv6_rib_edm_path:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.ipv6_rib_edm_path.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv6-rib-edm-path"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.active.is_set or
                                                        self.address.is_set or
                                                        self.attribute_identity.is_set or
                                                        self.client_id.is_set or
                                                        self.distance.is_set or
                                                        self.diversion.is_set or
                                                        self.diversion_distance.is_set or
                                                        self.diversion_proto_name.is_set or
                                                        self.extended_flags.is_set or
                                                        self.flags.is_set or
                                                        self.flow_tag.is_set or
                                                        self.fwd_class.is_set or
                                                        self.instance.is_set or
                                                        self.metric.is_set or
                                                        self.paths_count.is_set or
                                                        self.pic_count.is_set or
                                                        self.prefix.is_set or
                                                        self.prefix_length.is_set or
                                                        self.prefix_length_xr.is_set or
                                                        self.priority.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_name.is_set or
                                                        self.qos_group.is_set or
                                                        self.route_age.is_set or
                                                        self.route_label.is_set or
                                                        self.route_modify_time.is_set or
                                                        self.route_precedence.is_set or
                                                        self.route_type.is_set or
                                                        self.route_version.is_set or
                                                        self.svd_type.is_set or
                                                        self.tag.is_set or
                                                        self.tbl_version.is_set or
                                                        self.traffic_index.is_set or
                                                        self.version.is_set or
                                                        (self.route_path is not None and self.route_path.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.active.yfilter != YFilter.not_set or
                                                        self.address.yfilter != YFilter.not_set or
                                                        self.attribute_identity.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.distance.yfilter != YFilter.not_set or
                                                        self.diversion.yfilter != YFilter.not_set or
                                                        self.diversion_distance.yfilter != YFilter.not_set or
                                                        self.diversion_proto_name.yfilter != YFilter.not_set or
                                                        self.extended_flags.yfilter != YFilter.not_set or
                                                        self.flags.yfilter != YFilter.not_set or
                                                        self.flow_tag.yfilter != YFilter.not_set or
                                                        self.fwd_class.yfilter != YFilter.not_set or
                                                        self.instance.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.paths_count.yfilter != YFilter.not_set or
                                                        self.pic_count.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length.yfilter != YFilter.not_set or
                                                        self.prefix_length_xr.yfilter != YFilter.not_set or
                                                        self.priority.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_name.yfilter != YFilter.not_set or
                                                        self.qos_group.yfilter != YFilter.not_set or
                                                        self.route_age.yfilter != YFilter.not_set or
                                                        self.route_label.yfilter != YFilter.not_set or
                                                        self.route_modify_time.yfilter != YFilter.not_set or
                                                        self.route_precedence.yfilter != YFilter.not_set or
                                                        self.route_type.yfilter != YFilter.not_set or
                                                        self.route_version.yfilter != YFilter.not_set or
                                                        self.svd_type.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tbl_version.yfilter != YFilter.not_set or
                                                        self.traffic_index.yfilter != YFilter.not_set or
                                                        self.version.yfilter != YFilter.not_set or
                                                        (self.route_path is not None and self.route_path.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dest-q-route" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.active.get_name_leafdata())
                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                    if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                                    if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion.get_name_leafdata())
                                                    if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                    if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                    if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                    if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                    if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                    if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                    if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                    if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                    if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_age.get_name_leafdata())
                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                    if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                    if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_type.get_name_leafdata())
                                                    if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_version.get_name_leafdata())
                                                    if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                    if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                    if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.version.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "route-path"):
                                                        if (self.route_path is None):
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                        return self.route_path

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "active"):
                                                        self.active = value
                                                        self.active.value_namespace = name_space
                                                        self.active.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "address"):
                                                        self.address = value
                                                        self.address.value_namespace = name_space
                                                        self.address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "attribute-identity"):
                                                        self.attribute_identity = value
                                                        self.attribute_identity.value_namespace = name_space
                                                        self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "distance"):
                                                        self.distance = value
                                                        self.distance.value_namespace = name_space
                                                        self.distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion"):
                                                        self.diversion = value
                                                        self.diversion.value_namespace = name_space
                                                        self.diversion.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-distance"):
                                                        self.diversion_distance = value
                                                        self.diversion_distance.value_namespace = name_space
                                                        self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-proto-name"):
                                                        self.diversion_proto_name = value
                                                        self.diversion_proto_name.value_namespace = name_space
                                                        self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-flags"):
                                                        self.extended_flags = value
                                                        self.extended_flags.value_namespace = name_space
                                                        self.extended_flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flags"):
                                                        self.flags = value
                                                        self.flags.value_namespace = name_space
                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flow-tag"):
                                                        self.flow_tag = value
                                                        self.flow_tag.value_namespace = name_space
                                                        self.flow_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fwd-class"):
                                                        self.fwd_class = value
                                                        self.fwd_class.value_namespace = name_space
                                                        self.fwd_class.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance"):
                                                        self.instance = value
                                                        self.instance.value_namespace = name_space
                                                        self.instance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "paths-count"):
                                                        self.paths_count = value
                                                        self.paths_count.value_namespace = name_space
                                                        self.paths_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pic-count"):
                                                        self.pic_count = value
                                                        self.pic_count.value_namespace = name_space
                                                        self.pic_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length"):
                                                        self.prefix_length = value
                                                        self.prefix_length.value_namespace = name_space
                                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length-xr"):
                                                        self.prefix_length_xr = value
                                                        self.prefix_length_xr.value_namespace = name_space
                                                        self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "priority"):
                                                        self.priority = value
                                                        self.priority.value_namespace = name_space
                                                        self.priority.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-name"):
                                                        self.protocol_name = value
                                                        self.protocol_name.value_namespace = name_space
                                                        self.protocol_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "qos-group"):
                                                        self.qos_group = value
                                                        self.qos_group.value_namespace = name_space
                                                        self.qos_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-age"):
                                                        self.route_age = value
                                                        self.route_age.value_namespace = name_space
                                                        self.route_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-label"):
                                                        self.route_label = value
                                                        self.route_label.value_namespace = name_space
                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-modify-time"):
                                                        self.route_modify_time = value
                                                        self.route_modify_time.value_namespace = name_space
                                                        self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-precedence"):
                                                        self.route_precedence = value
                                                        self.route_precedence.value_namespace = name_space
                                                        self.route_precedence.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-type"):
                                                        self.route_type = value
                                                        self.route_type.value_namespace = name_space
                                                        self.route_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-version"):
                                                        self.route_version = value
                                                        self.route_version.value_namespace = name_space
                                                        self.route_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "svd-type"):
                                                        self.svd_type = value
                                                        self.svd_type.value_namespace = name_space
                                                        self.svd_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tbl-version"):
                                                        self.tbl_version = value
                                                        self.tbl_version.value_namespace = name_space
                                                        self.tbl_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "traffic-index"):
                                                        self.traffic_index = value
                                                        self.traffic_index.value_namespace = name_space
                                                        self.traffic_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "version"):
                                                        self.version = value
                                                        self.version.value_namespace = name_space
                                                        self.version.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.dest_q_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.dest_q_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dest-q-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "dest-q-route"):
                                                    for c in self.dest_q_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.dest_q_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dest-q-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DestBackupRoutes(Entity):
                                            """
                                            Backup
                                            
                                            .. attribute:: dest_backup_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__init__()

                                                self.yang_name = "dest-backup-routes"
                                                self.yang_parent_name = "destination-kw"

                                                self.dest_backup_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__setattr__(name, value)


                                            class DestBackupRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__init__()

                                                    self.yang_name = "dest-backup-route"
                                                    self.yang_parent_name = "dest-backup-routes"

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("active",
                                                                    "address",
                                                                    "attribute_identity",
                                                                    "client_id",
                                                                    "distance",
                                                                    "diversion",
                                                                    "diversion_distance",
                                                                    "diversion_proto_name",
                                                                    "extended_flags",
                                                                    "flags",
                                                                    "flow_tag",
                                                                    "fwd_class",
                                                                    "instance",
                                                                    "metric",
                                                                    "paths_count",
                                                                    "pic_count",
                                                                    "prefix",
                                                                    "prefix_length",
                                                                    "prefix_length_xr",
                                                                    "priority",
                                                                    "protocol_id",
                                                                    "protocol_name",
                                                                    "qos_group",
                                                                    "route_age",
                                                                    "route_label",
                                                                    "route_modify_time",
                                                                    "route_precedence",
                                                                    "route_type",
                                                                    "route_version",
                                                                    "svd_type",
                                                                    "tag",
                                                                    "tbl_version",
                                                                    "traffic_index",
                                                                    "version") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__setattr__(name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-backup-route"

                                                        self.ipv6_rib_edm_path = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__setattr__(name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("address",
                                                                            "backup_pathid",
                                                                            "binding_label",
                                                                            "flags",
                                                                            "flags64",
                                                                            "has_labelstk",
                                                                            "information_source",
                                                                            "interface_name",
                                                                            "labelstk",
                                                                            "load_metric",
                                                                            "looped",
                                                                            "metric",
                                                                            "mpls_feid",
                                                                            "mvpn_present",
                                                                            "next_hop_afi",
                                                                            "next_hop_id",
                                                                            "next_hop_id_refcount",
                                                                            "next_hop_safi",
                                                                            "next_hop_table_id",
                                                                            "next_hop_table_name",
                                                                            "next_hop_vrf_name",
                                                                            "nhid_feid",
                                                                            "num_labels",
                                                                            "number_of_extended_communities",
                                                                            "ospf_area_id",
                                                                            "path_rt_present",
                                                                            "pathid",
                                                                            "private_flags",
                                                                            "ref_cnt_of_backup",
                                                                            "remote_backup_addr",
                                                                            "route_label",
                                                                            "segmented_nexthop_present",
                                                                            "source_asrt_present",
                                                                            "source_rd_present",
                                                                            "tunnel_id",
                                                                            "v6_information_source",
                                                                            "v6_nexthop",
                                                                            "vrf_import_rt_present") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            return (
                                                                self.address.is_set or
                                                                self.backup_pathid.is_set or
                                                                self.binding_label.is_set or
                                                                self.flags.is_set or
                                                                self.flags64.is_set or
                                                                self.has_labelstk.is_set or
                                                                self.information_source.is_set or
                                                                self.interface_name.is_set or
                                                                self.load_metric.is_set or
                                                                self.looped.is_set or
                                                                self.metric.is_set or
                                                                self.mpls_feid.is_set or
                                                                self.mvpn_present.is_set or
                                                                self.next_hop_afi.is_set or
                                                                self.next_hop_id.is_set or
                                                                self.next_hop_id_refcount.is_set or
                                                                self.next_hop_safi.is_set or
                                                                self.next_hop_table_id.is_set or
                                                                self.next_hop_table_name.is_set or
                                                                self.next_hop_vrf_name.is_set or
                                                                self.nhid_feid.is_set or
                                                                self.num_labels.is_set or
                                                                self.number_of_extended_communities.is_set or
                                                                self.ospf_area_id.is_set or
                                                                self.path_rt_present.is_set or
                                                                self.pathid.is_set or
                                                                self.private_flags.is_set or
                                                                self.ref_cnt_of_backup.is_set or
                                                                self.route_label.is_set or
                                                                self.segmented_nexthop_present.is_set or
                                                                self.source_asrt_present.is_set or
                                                                self.source_rd_present.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.v6_information_source.is_set or
                                                                self.v6_nexthop.is_set or
                                                                self.vrf_import_rt_present.is_set)

                                                        def has_operation(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.backup_pathid.yfilter != YFilter.not_set or
                                                                self.binding_label.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flags64.yfilter != YFilter.not_set or
                                                                self.has_labelstk.yfilter != YFilter.not_set or
                                                                self.information_source.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.labelstk.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.looped.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.mpls_feid.yfilter != YFilter.not_set or
                                                                self.mvpn_present.yfilter != YFilter.not_set or
                                                                self.next_hop_afi.yfilter != YFilter.not_set or
                                                                self.next_hop_id.yfilter != YFilter.not_set or
                                                                self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                self.next_hop_safi.yfilter != YFilter.not_set or
                                                                self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                self.nhid_feid.yfilter != YFilter.not_set or
                                                                self.num_labels.yfilter != YFilter.not_set or
                                                                self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                self.ospf_area_id.yfilter != YFilter.not_set or
                                                                self.path_rt_present.yfilter != YFilter.not_set or
                                                                self.pathid.yfilter != YFilter.not_set or
                                                                self.private_flags.yfilter != YFilter.not_set or
                                                                self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                self.source_asrt_present.yfilter != YFilter.not_set or
                                                                self.source_rd_present.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.v6_information_source.yfilter != YFilter.not_set or
                                                                self.v6_nexthop.yfilter != YFilter.not_set or
                                                                self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                            if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags64.get_name_leafdata())
                                                            if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                            if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.information_source.get_name_leafdata())
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.looped.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                            if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                            if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                            if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                            if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                            if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                            if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                            if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                            if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                            if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                            if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                            if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                            if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                            if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                            if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pathid.get_name_leafdata())
                                                            if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                            if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                            if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                            if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                            if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                            if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                            leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                            leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "backup-pathid"):
                                                                self.backup_pathid = value
                                                                self.backup_pathid.value_namespace = name_space
                                                                self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "binding-label"):
                                                                self.binding_label = value
                                                                self.binding_label.value_namespace = name_space
                                                                self.binding_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags64"):
                                                                self.flags64 = value
                                                                self.flags64.value_namespace = name_space
                                                                self.flags64.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "has-labelstk"):
                                                                self.has_labelstk = value
                                                                self.has_labelstk.value_namespace = name_space
                                                                self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "information-source"):
                                                                self.information_source = value
                                                                self.information_source.value_namespace = name_space
                                                                self.information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "labelstk"):
                                                                self.labelstk.append(value)
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "looped"):
                                                                self.looped = value
                                                                self.looped.value_namespace = name_space
                                                                self.looped.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mpls-feid"):
                                                                self.mpls_feid = value
                                                                self.mpls_feid.value_namespace = name_space
                                                                self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mvpn-present"):
                                                                self.mvpn_present = value
                                                                self.mvpn_present.value_namespace = name_space
                                                                self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-afi"):
                                                                self.next_hop_afi = value
                                                                self.next_hop_afi.value_namespace = name_space
                                                                self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id"):
                                                                self.next_hop_id = value
                                                                self.next_hop_id.value_namespace = name_space
                                                                self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id-refcount"):
                                                                self.next_hop_id_refcount = value
                                                                self.next_hop_id_refcount.value_namespace = name_space
                                                                self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-safi"):
                                                                self.next_hop_safi = value
                                                                self.next_hop_safi.value_namespace = name_space
                                                                self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-id"):
                                                                self.next_hop_table_id = value
                                                                self.next_hop_table_id.value_namespace = name_space
                                                                self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-name"):
                                                                self.next_hop_table_name = value
                                                                self.next_hop_table_name.value_namespace = name_space
                                                                self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-vrf-name"):
                                                                self.next_hop_vrf_name = value
                                                                self.next_hop_vrf_name.value_namespace = name_space
                                                                self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "nhid-feid"):
                                                                self.nhid_feid = value
                                                                self.nhid_feid.value_namespace = name_space
                                                                self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "num-labels"):
                                                                self.num_labels = value
                                                                self.num_labels.value_namespace = name_space
                                                                self.num_labels.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "number-of-extended-communities"):
                                                                self.number_of_extended_communities = value
                                                                self.number_of_extended_communities.value_namespace = name_space
                                                                self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ospf-area-id"):
                                                                self.ospf_area_id = value
                                                                self.ospf_area_id.value_namespace = name_space
                                                                self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "path-rt-present"):
                                                                self.path_rt_present = value
                                                                self.path_rt_present.value_namespace = name_space
                                                                self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pathid"):
                                                                self.pathid = value
                                                                self.pathid.value_namespace = name_space
                                                                self.pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "private-flags"):
                                                                self.private_flags = value
                                                                self.private_flags.value_namespace = name_space
                                                                self.private_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ref-cnt-of-backup"):
                                                                self.ref_cnt_of_backup = value
                                                                self.ref_cnt_of_backup.value_namespace = name_space
                                                                self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "remote-backup-addr"):
                                                                self.remote_backup_addr.append(value)
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "segmented-nexthop-present"):
                                                                self.segmented_nexthop_present = value
                                                                self.segmented_nexthop_present.value_namespace = name_space
                                                                self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-asrt-present"):
                                                                self.source_asrt_present = value
                                                                self.source_asrt_present.value_namespace = name_space
                                                                self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-rd-present"):
                                                                self.source_rd_present = value
                                                                self.source_rd_present.value_namespace = name_space
                                                                self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-information-source"):
                                                                self.v6_information_source = value
                                                                self.v6_information_source.value_namespace = name_space
                                                                self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-nexthop"):
                                                                self.v6_nexthop = value
                                                                self.v6_nexthop.value_namespace = name_space
                                                                self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-import-rt-present"):
                                                                self.vrf_import_rt_present = value
                                                                self.vrf_import_rt_present.value_namespace = name_space
                                                                self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "route-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv6-rib-edm-path"):
                                                            for c in self.ipv6_rib_edm_path:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.ipv6_rib_edm_path.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv6-rib-edm-path"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.active.is_set or
                                                        self.address.is_set or
                                                        self.attribute_identity.is_set or
                                                        self.client_id.is_set or
                                                        self.distance.is_set or
                                                        self.diversion.is_set or
                                                        self.diversion_distance.is_set or
                                                        self.diversion_proto_name.is_set or
                                                        self.extended_flags.is_set or
                                                        self.flags.is_set or
                                                        self.flow_tag.is_set or
                                                        self.fwd_class.is_set or
                                                        self.instance.is_set or
                                                        self.metric.is_set or
                                                        self.paths_count.is_set or
                                                        self.pic_count.is_set or
                                                        self.prefix.is_set or
                                                        self.prefix_length.is_set or
                                                        self.prefix_length_xr.is_set or
                                                        self.priority.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_name.is_set or
                                                        self.qos_group.is_set or
                                                        self.route_age.is_set or
                                                        self.route_label.is_set or
                                                        self.route_modify_time.is_set or
                                                        self.route_precedence.is_set or
                                                        self.route_type.is_set or
                                                        self.route_version.is_set or
                                                        self.svd_type.is_set or
                                                        self.tag.is_set or
                                                        self.tbl_version.is_set or
                                                        self.traffic_index.is_set or
                                                        self.version.is_set or
                                                        (self.route_path is not None and self.route_path.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.active.yfilter != YFilter.not_set or
                                                        self.address.yfilter != YFilter.not_set or
                                                        self.attribute_identity.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.distance.yfilter != YFilter.not_set or
                                                        self.diversion.yfilter != YFilter.not_set or
                                                        self.diversion_distance.yfilter != YFilter.not_set or
                                                        self.diversion_proto_name.yfilter != YFilter.not_set or
                                                        self.extended_flags.yfilter != YFilter.not_set or
                                                        self.flags.yfilter != YFilter.not_set or
                                                        self.flow_tag.yfilter != YFilter.not_set or
                                                        self.fwd_class.yfilter != YFilter.not_set or
                                                        self.instance.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.paths_count.yfilter != YFilter.not_set or
                                                        self.pic_count.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length.yfilter != YFilter.not_set or
                                                        self.prefix_length_xr.yfilter != YFilter.not_set or
                                                        self.priority.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_name.yfilter != YFilter.not_set or
                                                        self.qos_group.yfilter != YFilter.not_set or
                                                        self.route_age.yfilter != YFilter.not_set or
                                                        self.route_label.yfilter != YFilter.not_set or
                                                        self.route_modify_time.yfilter != YFilter.not_set or
                                                        self.route_precedence.yfilter != YFilter.not_set or
                                                        self.route_type.yfilter != YFilter.not_set or
                                                        self.route_version.yfilter != YFilter.not_set or
                                                        self.svd_type.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tbl_version.yfilter != YFilter.not_set or
                                                        self.traffic_index.yfilter != YFilter.not_set or
                                                        self.version.yfilter != YFilter.not_set or
                                                        (self.route_path is not None and self.route_path.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dest-backup-route" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.active.get_name_leafdata())
                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                    if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                                    if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion.get_name_leafdata())
                                                    if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                    if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                    if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                    if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                    if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                    if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                    if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                    if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                    if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_age.get_name_leafdata())
                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                    if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                    if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_type.get_name_leafdata())
                                                    if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_version.get_name_leafdata())
                                                    if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                    if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                    if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.version.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "route-path"):
                                                        if (self.route_path is None):
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                        return self.route_path

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "active"):
                                                        self.active = value
                                                        self.active.value_namespace = name_space
                                                        self.active.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "address"):
                                                        self.address = value
                                                        self.address.value_namespace = name_space
                                                        self.address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "attribute-identity"):
                                                        self.attribute_identity = value
                                                        self.attribute_identity.value_namespace = name_space
                                                        self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "distance"):
                                                        self.distance = value
                                                        self.distance.value_namespace = name_space
                                                        self.distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion"):
                                                        self.diversion = value
                                                        self.diversion.value_namespace = name_space
                                                        self.diversion.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-distance"):
                                                        self.diversion_distance = value
                                                        self.diversion_distance.value_namespace = name_space
                                                        self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-proto-name"):
                                                        self.diversion_proto_name = value
                                                        self.diversion_proto_name.value_namespace = name_space
                                                        self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-flags"):
                                                        self.extended_flags = value
                                                        self.extended_flags.value_namespace = name_space
                                                        self.extended_flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flags"):
                                                        self.flags = value
                                                        self.flags.value_namespace = name_space
                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flow-tag"):
                                                        self.flow_tag = value
                                                        self.flow_tag.value_namespace = name_space
                                                        self.flow_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fwd-class"):
                                                        self.fwd_class = value
                                                        self.fwd_class.value_namespace = name_space
                                                        self.fwd_class.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance"):
                                                        self.instance = value
                                                        self.instance.value_namespace = name_space
                                                        self.instance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "paths-count"):
                                                        self.paths_count = value
                                                        self.paths_count.value_namespace = name_space
                                                        self.paths_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pic-count"):
                                                        self.pic_count = value
                                                        self.pic_count.value_namespace = name_space
                                                        self.pic_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length"):
                                                        self.prefix_length = value
                                                        self.prefix_length.value_namespace = name_space
                                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length-xr"):
                                                        self.prefix_length_xr = value
                                                        self.prefix_length_xr.value_namespace = name_space
                                                        self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "priority"):
                                                        self.priority = value
                                                        self.priority.value_namespace = name_space
                                                        self.priority.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-name"):
                                                        self.protocol_name = value
                                                        self.protocol_name.value_namespace = name_space
                                                        self.protocol_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "qos-group"):
                                                        self.qos_group = value
                                                        self.qos_group.value_namespace = name_space
                                                        self.qos_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-age"):
                                                        self.route_age = value
                                                        self.route_age.value_namespace = name_space
                                                        self.route_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-label"):
                                                        self.route_label = value
                                                        self.route_label.value_namespace = name_space
                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-modify-time"):
                                                        self.route_modify_time = value
                                                        self.route_modify_time.value_namespace = name_space
                                                        self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-precedence"):
                                                        self.route_precedence = value
                                                        self.route_precedence.value_namespace = name_space
                                                        self.route_precedence.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-type"):
                                                        self.route_type = value
                                                        self.route_type.value_namespace = name_space
                                                        self.route_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-version"):
                                                        self.route_version = value
                                                        self.route_version.value_namespace = name_space
                                                        self.route_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "svd-type"):
                                                        self.svd_type = value
                                                        self.svd_type.value_namespace = name_space
                                                        self.svd_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tbl-version"):
                                                        self.tbl_version = value
                                                        self.tbl_version.value_namespace = name_space
                                                        self.tbl_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "traffic-index"):
                                                        self.traffic_index = value
                                                        self.traffic_index.value_namespace = name_space
                                                        self.traffic_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "version"):
                                                        self.version = value
                                                        self.version.value_namespace = name_space
                                                        self.version.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.dest_backup_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.dest_backup_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dest-backup-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "dest-backup-route"):
                                                    for c in self.dest_backup_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.dest_backup_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dest-backup-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DestBestRoutes(Entity):
                                            """
                                            Best Local
                                            
                                            .. attribute:: dest_best_route
                                            
                                            	Best local route information for a specific Address 
                                            	**type**\: list of    :py:class:`DestBestRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__init__()

                                                self.yang_name = "dest-best-routes"
                                                self.yang_parent_name = "destination-kw"

                                                self.dest_best_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__setattr__(name, value)


                                            class DestBestRoute(Entity):
                                                """
                                                Best local route information for a
                                                specific Address 
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__init__()

                                                    self.yang_name = "dest-best-route"
                                                    self.yang_parent_name = "dest-best-routes"

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("address",
                                                                    "active",
                                                                    "attribute_identity",
                                                                    "client_id",
                                                                    "distance",
                                                                    "diversion",
                                                                    "diversion_distance",
                                                                    "diversion_proto_name",
                                                                    "extended_flags",
                                                                    "flags",
                                                                    "flow_tag",
                                                                    "fwd_class",
                                                                    "instance",
                                                                    "metric",
                                                                    "paths_count",
                                                                    "pic_count",
                                                                    "prefix",
                                                                    "prefix_length_xr",
                                                                    "priority",
                                                                    "protocol_id",
                                                                    "protocol_name",
                                                                    "qos_group",
                                                                    "route_age",
                                                                    "route_label",
                                                                    "route_modify_time",
                                                                    "route_precedence",
                                                                    "route_type",
                                                                    "route_version",
                                                                    "svd_type",
                                                                    "tag",
                                                                    "tbl_version",
                                                                    "traffic_index",
                                                                    "version") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__setattr__(name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-best-route"

                                                        self.ipv6_rib_edm_path = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__setattr__(name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("address",
                                                                            "backup_pathid",
                                                                            "binding_label",
                                                                            "flags",
                                                                            "flags64",
                                                                            "has_labelstk",
                                                                            "information_source",
                                                                            "interface_name",
                                                                            "labelstk",
                                                                            "load_metric",
                                                                            "looped",
                                                                            "metric",
                                                                            "mpls_feid",
                                                                            "mvpn_present",
                                                                            "next_hop_afi",
                                                                            "next_hop_id",
                                                                            "next_hop_id_refcount",
                                                                            "next_hop_safi",
                                                                            "next_hop_table_id",
                                                                            "next_hop_table_name",
                                                                            "next_hop_vrf_name",
                                                                            "nhid_feid",
                                                                            "num_labels",
                                                                            "number_of_extended_communities",
                                                                            "ospf_area_id",
                                                                            "path_rt_present",
                                                                            "pathid",
                                                                            "private_flags",
                                                                            "ref_cnt_of_backup",
                                                                            "remote_backup_addr",
                                                                            "route_label",
                                                                            "segmented_nexthop_present",
                                                                            "source_asrt_present",
                                                                            "source_rd_present",
                                                                            "tunnel_id",
                                                                            "v6_information_source",
                                                                            "v6_nexthop",
                                                                            "vrf_import_rt_present") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            return (
                                                                self.address.is_set or
                                                                self.backup_pathid.is_set or
                                                                self.binding_label.is_set or
                                                                self.flags.is_set or
                                                                self.flags64.is_set or
                                                                self.has_labelstk.is_set or
                                                                self.information_source.is_set or
                                                                self.interface_name.is_set or
                                                                self.load_metric.is_set or
                                                                self.looped.is_set or
                                                                self.metric.is_set or
                                                                self.mpls_feid.is_set or
                                                                self.mvpn_present.is_set or
                                                                self.next_hop_afi.is_set or
                                                                self.next_hop_id.is_set or
                                                                self.next_hop_id_refcount.is_set or
                                                                self.next_hop_safi.is_set or
                                                                self.next_hop_table_id.is_set or
                                                                self.next_hop_table_name.is_set or
                                                                self.next_hop_vrf_name.is_set or
                                                                self.nhid_feid.is_set or
                                                                self.num_labels.is_set or
                                                                self.number_of_extended_communities.is_set or
                                                                self.ospf_area_id.is_set or
                                                                self.path_rt_present.is_set or
                                                                self.pathid.is_set or
                                                                self.private_flags.is_set or
                                                                self.ref_cnt_of_backup.is_set or
                                                                self.route_label.is_set or
                                                                self.segmented_nexthop_present.is_set or
                                                                self.source_asrt_present.is_set or
                                                                self.source_rd_present.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.v6_information_source.is_set or
                                                                self.v6_nexthop.is_set or
                                                                self.vrf_import_rt_present.is_set)

                                                        def has_operation(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.backup_pathid.yfilter != YFilter.not_set or
                                                                self.binding_label.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flags64.yfilter != YFilter.not_set or
                                                                self.has_labelstk.yfilter != YFilter.not_set or
                                                                self.information_source.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.labelstk.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.looped.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.mpls_feid.yfilter != YFilter.not_set or
                                                                self.mvpn_present.yfilter != YFilter.not_set or
                                                                self.next_hop_afi.yfilter != YFilter.not_set or
                                                                self.next_hop_id.yfilter != YFilter.not_set or
                                                                self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                self.next_hop_safi.yfilter != YFilter.not_set or
                                                                self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                self.nhid_feid.yfilter != YFilter.not_set or
                                                                self.num_labels.yfilter != YFilter.not_set or
                                                                self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                self.ospf_area_id.yfilter != YFilter.not_set or
                                                                self.path_rt_present.yfilter != YFilter.not_set or
                                                                self.pathid.yfilter != YFilter.not_set or
                                                                self.private_flags.yfilter != YFilter.not_set or
                                                                self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                self.source_asrt_present.yfilter != YFilter.not_set or
                                                                self.source_rd_present.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.v6_information_source.yfilter != YFilter.not_set or
                                                                self.v6_nexthop.yfilter != YFilter.not_set or
                                                                self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                            if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags64.get_name_leafdata())
                                                            if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                            if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.information_source.get_name_leafdata())
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.looped.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                            if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                            if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                            if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                            if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                            if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                            if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                            if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                            if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                            if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                            if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                            if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                            if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                            if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                            if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pathid.get_name_leafdata())
                                                            if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                            if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                            if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                            if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                            if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                            if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                            leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                            leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "backup-pathid"):
                                                                self.backup_pathid = value
                                                                self.backup_pathid.value_namespace = name_space
                                                                self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "binding-label"):
                                                                self.binding_label = value
                                                                self.binding_label.value_namespace = name_space
                                                                self.binding_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags64"):
                                                                self.flags64 = value
                                                                self.flags64.value_namespace = name_space
                                                                self.flags64.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "has-labelstk"):
                                                                self.has_labelstk = value
                                                                self.has_labelstk.value_namespace = name_space
                                                                self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "information-source"):
                                                                self.information_source = value
                                                                self.information_source.value_namespace = name_space
                                                                self.information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "labelstk"):
                                                                self.labelstk.append(value)
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "looped"):
                                                                self.looped = value
                                                                self.looped.value_namespace = name_space
                                                                self.looped.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mpls-feid"):
                                                                self.mpls_feid = value
                                                                self.mpls_feid.value_namespace = name_space
                                                                self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mvpn-present"):
                                                                self.mvpn_present = value
                                                                self.mvpn_present.value_namespace = name_space
                                                                self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-afi"):
                                                                self.next_hop_afi = value
                                                                self.next_hop_afi.value_namespace = name_space
                                                                self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id"):
                                                                self.next_hop_id = value
                                                                self.next_hop_id.value_namespace = name_space
                                                                self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id-refcount"):
                                                                self.next_hop_id_refcount = value
                                                                self.next_hop_id_refcount.value_namespace = name_space
                                                                self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-safi"):
                                                                self.next_hop_safi = value
                                                                self.next_hop_safi.value_namespace = name_space
                                                                self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-id"):
                                                                self.next_hop_table_id = value
                                                                self.next_hop_table_id.value_namespace = name_space
                                                                self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-name"):
                                                                self.next_hop_table_name = value
                                                                self.next_hop_table_name.value_namespace = name_space
                                                                self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-vrf-name"):
                                                                self.next_hop_vrf_name = value
                                                                self.next_hop_vrf_name.value_namespace = name_space
                                                                self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "nhid-feid"):
                                                                self.nhid_feid = value
                                                                self.nhid_feid.value_namespace = name_space
                                                                self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "num-labels"):
                                                                self.num_labels = value
                                                                self.num_labels.value_namespace = name_space
                                                                self.num_labels.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "number-of-extended-communities"):
                                                                self.number_of_extended_communities = value
                                                                self.number_of_extended_communities.value_namespace = name_space
                                                                self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ospf-area-id"):
                                                                self.ospf_area_id = value
                                                                self.ospf_area_id.value_namespace = name_space
                                                                self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "path-rt-present"):
                                                                self.path_rt_present = value
                                                                self.path_rt_present.value_namespace = name_space
                                                                self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pathid"):
                                                                self.pathid = value
                                                                self.pathid.value_namespace = name_space
                                                                self.pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "private-flags"):
                                                                self.private_flags = value
                                                                self.private_flags.value_namespace = name_space
                                                                self.private_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ref-cnt-of-backup"):
                                                                self.ref_cnt_of_backup = value
                                                                self.ref_cnt_of_backup.value_namespace = name_space
                                                                self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "remote-backup-addr"):
                                                                self.remote_backup_addr.append(value)
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "segmented-nexthop-present"):
                                                                self.segmented_nexthop_present = value
                                                                self.segmented_nexthop_present.value_namespace = name_space
                                                                self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-asrt-present"):
                                                                self.source_asrt_present = value
                                                                self.source_asrt_present.value_namespace = name_space
                                                                self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-rd-present"):
                                                                self.source_rd_present = value
                                                                self.source_rd_present.value_namespace = name_space
                                                                self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-information-source"):
                                                                self.v6_information_source = value
                                                                self.v6_information_source.value_namespace = name_space
                                                                self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-nexthop"):
                                                                self.v6_nexthop = value
                                                                self.v6_nexthop.value_namespace = name_space
                                                                self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-import-rt-present"):
                                                                self.vrf_import_rt_present = value
                                                                self.vrf_import_rt_present.value_namespace = name_space
                                                                self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "route-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv6-rib-edm-path"):
                                                            for c in self.ipv6_rib_edm_path:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.ipv6_rib_edm_path.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv6-rib-edm-path"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.address.is_set or
                                                        self.active.is_set or
                                                        self.attribute_identity.is_set or
                                                        self.client_id.is_set or
                                                        self.distance.is_set or
                                                        self.diversion.is_set or
                                                        self.diversion_distance.is_set or
                                                        self.diversion_proto_name.is_set or
                                                        self.extended_flags.is_set or
                                                        self.flags.is_set or
                                                        self.flow_tag.is_set or
                                                        self.fwd_class.is_set or
                                                        self.instance.is_set or
                                                        self.metric.is_set or
                                                        self.paths_count.is_set or
                                                        self.pic_count.is_set or
                                                        self.prefix.is_set or
                                                        self.prefix_length_xr.is_set or
                                                        self.priority.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_name.is_set or
                                                        self.qos_group.is_set or
                                                        self.route_age.is_set or
                                                        self.route_label.is_set or
                                                        self.route_modify_time.is_set or
                                                        self.route_precedence.is_set or
                                                        self.route_type.is_set or
                                                        self.route_version.is_set or
                                                        self.svd_type.is_set or
                                                        self.tag.is_set or
                                                        self.tbl_version.is_set or
                                                        self.traffic_index.is_set or
                                                        self.version.is_set or
                                                        (self.route_path is not None and self.route_path.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.address.yfilter != YFilter.not_set or
                                                        self.active.yfilter != YFilter.not_set or
                                                        self.attribute_identity.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.distance.yfilter != YFilter.not_set or
                                                        self.diversion.yfilter != YFilter.not_set or
                                                        self.diversion_distance.yfilter != YFilter.not_set or
                                                        self.diversion_proto_name.yfilter != YFilter.not_set or
                                                        self.extended_flags.yfilter != YFilter.not_set or
                                                        self.flags.yfilter != YFilter.not_set or
                                                        self.flow_tag.yfilter != YFilter.not_set or
                                                        self.fwd_class.yfilter != YFilter.not_set or
                                                        self.instance.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.paths_count.yfilter != YFilter.not_set or
                                                        self.pic_count.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length_xr.yfilter != YFilter.not_set or
                                                        self.priority.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_name.yfilter != YFilter.not_set or
                                                        self.qos_group.yfilter != YFilter.not_set or
                                                        self.route_age.yfilter != YFilter.not_set or
                                                        self.route_label.yfilter != YFilter.not_set or
                                                        self.route_modify_time.yfilter != YFilter.not_set or
                                                        self.route_precedence.yfilter != YFilter.not_set or
                                                        self.route_type.yfilter != YFilter.not_set or
                                                        self.route_version.yfilter != YFilter.not_set or
                                                        self.svd_type.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tbl_version.yfilter != YFilter.not_set or
                                                        self.traffic_index.yfilter != YFilter.not_set or
                                                        self.version.yfilter != YFilter.not_set or
                                                        (self.route_path is not None and self.route_path.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dest-best-route" + "[address='" + self.address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.active.get_name_leafdata())
                                                    if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                                    if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion.get_name_leafdata())
                                                    if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                    if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                    if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                    if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                    if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                    if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                    if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                    if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_age.get_name_leafdata())
                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                    if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                    if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_type.get_name_leafdata())
                                                    if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_version.get_name_leafdata())
                                                    if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                    if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                    if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.version.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "route-path"):
                                                        if (self.route_path is None):
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                        return self.route_path

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "route-path" or name == "address" or name == "active" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "address"):
                                                        self.address = value
                                                        self.address.value_namespace = name_space
                                                        self.address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "active"):
                                                        self.active = value
                                                        self.active.value_namespace = name_space
                                                        self.active.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "attribute-identity"):
                                                        self.attribute_identity = value
                                                        self.attribute_identity.value_namespace = name_space
                                                        self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "distance"):
                                                        self.distance = value
                                                        self.distance.value_namespace = name_space
                                                        self.distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion"):
                                                        self.diversion = value
                                                        self.diversion.value_namespace = name_space
                                                        self.diversion.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-distance"):
                                                        self.diversion_distance = value
                                                        self.diversion_distance.value_namespace = name_space
                                                        self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-proto-name"):
                                                        self.diversion_proto_name = value
                                                        self.diversion_proto_name.value_namespace = name_space
                                                        self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-flags"):
                                                        self.extended_flags = value
                                                        self.extended_flags.value_namespace = name_space
                                                        self.extended_flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flags"):
                                                        self.flags = value
                                                        self.flags.value_namespace = name_space
                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flow-tag"):
                                                        self.flow_tag = value
                                                        self.flow_tag.value_namespace = name_space
                                                        self.flow_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fwd-class"):
                                                        self.fwd_class = value
                                                        self.fwd_class.value_namespace = name_space
                                                        self.fwd_class.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance"):
                                                        self.instance = value
                                                        self.instance.value_namespace = name_space
                                                        self.instance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "paths-count"):
                                                        self.paths_count = value
                                                        self.paths_count.value_namespace = name_space
                                                        self.paths_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pic-count"):
                                                        self.pic_count = value
                                                        self.pic_count.value_namespace = name_space
                                                        self.pic_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length-xr"):
                                                        self.prefix_length_xr = value
                                                        self.prefix_length_xr.value_namespace = name_space
                                                        self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "priority"):
                                                        self.priority = value
                                                        self.priority.value_namespace = name_space
                                                        self.priority.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-name"):
                                                        self.protocol_name = value
                                                        self.protocol_name.value_namespace = name_space
                                                        self.protocol_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "qos-group"):
                                                        self.qos_group = value
                                                        self.qos_group.value_namespace = name_space
                                                        self.qos_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-age"):
                                                        self.route_age = value
                                                        self.route_age.value_namespace = name_space
                                                        self.route_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-label"):
                                                        self.route_label = value
                                                        self.route_label.value_namespace = name_space
                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-modify-time"):
                                                        self.route_modify_time = value
                                                        self.route_modify_time.value_namespace = name_space
                                                        self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-precedence"):
                                                        self.route_precedence = value
                                                        self.route_precedence.value_namespace = name_space
                                                        self.route_precedence.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-type"):
                                                        self.route_type = value
                                                        self.route_type.value_namespace = name_space
                                                        self.route_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-version"):
                                                        self.route_version = value
                                                        self.route_version.value_namespace = name_space
                                                        self.route_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "svd-type"):
                                                        self.svd_type = value
                                                        self.svd_type.value_namespace = name_space
                                                        self.svd_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tbl-version"):
                                                        self.tbl_version = value
                                                        self.tbl_version.value_namespace = name_space
                                                        self.tbl_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "traffic-index"):
                                                        self.traffic_index = value
                                                        self.traffic_index.value_namespace = name_space
                                                        self.traffic_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "version"):
                                                        self.version = value
                                                        self.version.value_namespace = name_space
                                                        self.version.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.dest_best_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.dest_best_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dest-best-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "dest-best-route"):
                                                    for c in self.dest_best_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.dest_best_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dest-best-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DestNextHopRoutes(Entity):
                                            """
                                            Resolving next hop
                                            
                                            .. attribute:: dest_next_hop_route
                                            
                                            	Nexthop information for a specific address
                                            	**type**\: list of    :py:class:`DestNextHopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__init__()

                                                self.yang_name = "dest-next-hop-routes"
                                                self.yang_parent_name = "destination-kw"

                                                self.dest_next_hop_route = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__setattr__(name, value)


                                            class DestNextHopRoute(Entity):
                                                """
                                                Nexthop information for a specific
                                                address
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__init__()

                                                    self.yang_name = "dest-next-hop-route"
                                                    self.yang_parent_name = "dest-next-hop-routes"

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("address",
                                                                    "active",
                                                                    "attribute_identity",
                                                                    "client_id",
                                                                    "distance",
                                                                    "diversion",
                                                                    "diversion_distance",
                                                                    "diversion_proto_name",
                                                                    "extended_flags",
                                                                    "flags",
                                                                    "flow_tag",
                                                                    "fwd_class",
                                                                    "instance",
                                                                    "metric",
                                                                    "paths_count",
                                                                    "pic_count",
                                                                    "prefix",
                                                                    "prefix_length_xr",
                                                                    "priority",
                                                                    "protocol_id",
                                                                    "protocol_name",
                                                                    "qos_group",
                                                                    "route_age",
                                                                    "route_label",
                                                                    "route_modify_time",
                                                                    "route_precedence",
                                                                    "route_type",
                                                                    "route_version",
                                                                    "svd_type",
                                                                    "tag",
                                                                    "tbl_version",
                                                                    "traffic_index",
                                                                    "version") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__setattr__(name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-next-hop-route"

                                                        self.ipv6_rib_edm_path = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__setattr__(name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Labels for this path
                                                        	**type**\:  list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\:  list of str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("address",
                                                                            "backup_pathid",
                                                                            "binding_label",
                                                                            "flags",
                                                                            "flags64",
                                                                            "has_labelstk",
                                                                            "information_source",
                                                                            "interface_name",
                                                                            "labelstk",
                                                                            "load_metric",
                                                                            "looped",
                                                                            "metric",
                                                                            "mpls_feid",
                                                                            "mvpn_present",
                                                                            "next_hop_afi",
                                                                            "next_hop_id",
                                                                            "next_hop_id_refcount",
                                                                            "next_hop_safi",
                                                                            "next_hop_table_id",
                                                                            "next_hop_table_name",
                                                                            "next_hop_vrf_name",
                                                                            "nhid_feid",
                                                                            "num_labels",
                                                                            "number_of_extended_communities",
                                                                            "ospf_area_id",
                                                                            "path_rt_present",
                                                                            "pathid",
                                                                            "private_flags",
                                                                            "ref_cnt_of_backup",
                                                                            "remote_backup_addr",
                                                                            "route_label",
                                                                            "segmented_nexthop_present",
                                                                            "source_asrt_present",
                                                                            "source_rd_present",
                                                                            "tunnel_id",
                                                                            "v6_information_source",
                                                                            "v6_nexthop",
                                                                            "vrf_import_rt_present") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.yfilter != YFilter.not_set):
                                                                    return True
                                                            return (
                                                                self.address.is_set or
                                                                self.backup_pathid.is_set or
                                                                self.binding_label.is_set or
                                                                self.flags.is_set or
                                                                self.flags64.is_set or
                                                                self.has_labelstk.is_set or
                                                                self.information_source.is_set or
                                                                self.interface_name.is_set or
                                                                self.load_metric.is_set or
                                                                self.looped.is_set or
                                                                self.metric.is_set or
                                                                self.mpls_feid.is_set or
                                                                self.mvpn_present.is_set or
                                                                self.next_hop_afi.is_set or
                                                                self.next_hop_id.is_set or
                                                                self.next_hop_id_refcount.is_set or
                                                                self.next_hop_safi.is_set or
                                                                self.next_hop_table_id.is_set or
                                                                self.next_hop_table_name.is_set or
                                                                self.next_hop_vrf_name.is_set or
                                                                self.nhid_feid.is_set or
                                                                self.num_labels.is_set or
                                                                self.number_of_extended_communities.is_set or
                                                                self.ospf_area_id.is_set or
                                                                self.path_rt_present.is_set or
                                                                self.pathid.is_set or
                                                                self.private_flags.is_set or
                                                                self.ref_cnt_of_backup.is_set or
                                                                self.route_label.is_set or
                                                                self.segmented_nexthop_present.is_set or
                                                                self.source_asrt_present.is_set or
                                                                self.source_rd_present.is_set or
                                                                self.tunnel_id.is_set or
                                                                self.v6_information_source.is_set or
                                                                self.v6_nexthop.is_set or
                                                                self.vrf_import_rt_present.is_set)

                                                        def has_operation(self):
                                                            for leaf in self.labelstk.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            for leaf in self.remote_backup_addr.getYLeafs():
                                                                if (leaf.is_set):
                                                                    return True
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.backup_pathid.yfilter != YFilter.not_set or
                                                                self.binding_label.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flags64.yfilter != YFilter.not_set or
                                                                self.has_labelstk.yfilter != YFilter.not_set or
                                                                self.information_source.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.labelstk.yfilter != YFilter.not_set or
                                                                self.load_metric.yfilter != YFilter.not_set or
                                                                self.looped.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.mpls_feid.yfilter != YFilter.not_set or
                                                                self.mvpn_present.yfilter != YFilter.not_set or
                                                                self.next_hop_afi.yfilter != YFilter.not_set or
                                                                self.next_hop_id.yfilter != YFilter.not_set or
                                                                self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                self.next_hop_safi.yfilter != YFilter.not_set or
                                                                self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                self.nhid_feid.yfilter != YFilter.not_set or
                                                                self.num_labels.yfilter != YFilter.not_set or
                                                                self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                self.ospf_area_id.yfilter != YFilter.not_set or
                                                                self.path_rt_present.yfilter != YFilter.not_set or
                                                                self.pathid.yfilter != YFilter.not_set or
                                                                self.private_flags.yfilter != YFilter.not_set or
                                                                self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                self.source_asrt_present.yfilter != YFilter.not_set or
                                                                self.source_rd_present.yfilter != YFilter.not_set or
                                                                self.tunnel_id.yfilter != YFilter.not_set or
                                                                self.v6_information_source.yfilter != YFilter.not_set or
                                                                self.v6_nexthop.yfilter != YFilter.not_set or
                                                                self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                            if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags64.get_name_leafdata())
                                                            if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                            if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.information_source.get_name_leafdata())
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                            if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.looped.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                            if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                            if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                            if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                            if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                            if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                            if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                            if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                            if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                            if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                            if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                            if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                            if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                            if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                            if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pathid.get_name_leafdata())
                                                            if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                            if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                            if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                            if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                            if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                            if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                            if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                            leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                            leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "backup-pathid"):
                                                                self.backup_pathid = value
                                                                self.backup_pathid.value_namespace = name_space
                                                                self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "binding-label"):
                                                                self.binding_label = value
                                                                self.binding_label.value_namespace = name_space
                                                                self.binding_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags64"):
                                                                self.flags64 = value
                                                                self.flags64.value_namespace = name_space
                                                                self.flags64.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "has-labelstk"):
                                                                self.has_labelstk = value
                                                                self.has_labelstk.value_namespace = name_space
                                                                self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "information-source"):
                                                                self.information_source = value
                                                                self.information_source.value_namespace = name_space
                                                                self.information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "labelstk"):
                                                                self.labelstk.append(value)
                                                            if(value_path == "load-metric"):
                                                                self.load_metric = value
                                                                self.load_metric.value_namespace = name_space
                                                                self.load_metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "looped"):
                                                                self.looped = value
                                                                self.looped.value_namespace = name_space
                                                                self.looped.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mpls-feid"):
                                                                self.mpls_feid = value
                                                                self.mpls_feid.value_namespace = name_space
                                                                self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "mvpn-present"):
                                                                self.mvpn_present = value
                                                                self.mvpn_present.value_namespace = name_space
                                                                self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-afi"):
                                                                self.next_hop_afi = value
                                                                self.next_hop_afi.value_namespace = name_space
                                                                self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id"):
                                                                self.next_hop_id = value
                                                                self.next_hop_id.value_namespace = name_space
                                                                self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-id-refcount"):
                                                                self.next_hop_id_refcount = value
                                                                self.next_hop_id_refcount.value_namespace = name_space
                                                                self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-safi"):
                                                                self.next_hop_safi = value
                                                                self.next_hop_safi.value_namespace = name_space
                                                                self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-id"):
                                                                self.next_hop_table_id = value
                                                                self.next_hop_table_id.value_namespace = name_space
                                                                self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-table-name"):
                                                                self.next_hop_table_name = value
                                                                self.next_hop_table_name.value_namespace = name_space
                                                                self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "next-hop-vrf-name"):
                                                                self.next_hop_vrf_name = value
                                                                self.next_hop_vrf_name.value_namespace = name_space
                                                                self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "nhid-feid"):
                                                                self.nhid_feid = value
                                                                self.nhid_feid.value_namespace = name_space
                                                                self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "num-labels"):
                                                                self.num_labels = value
                                                                self.num_labels.value_namespace = name_space
                                                                self.num_labels.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "number-of-extended-communities"):
                                                                self.number_of_extended_communities = value
                                                                self.number_of_extended_communities.value_namespace = name_space
                                                                self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ospf-area-id"):
                                                                self.ospf_area_id = value
                                                                self.ospf_area_id.value_namespace = name_space
                                                                self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "path-rt-present"):
                                                                self.path_rt_present = value
                                                                self.path_rt_present.value_namespace = name_space
                                                                self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pathid"):
                                                                self.pathid = value
                                                                self.pathid.value_namespace = name_space
                                                                self.pathid.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "private-flags"):
                                                                self.private_flags = value
                                                                self.private_flags.value_namespace = name_space
                                                                self.private_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ref-cnt-of-backup"):
                                                                self.ref_cnt_of_backup = value
                                                                self.ref_cnt_of_backup.value_namespace = name_space
                                                                self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "remote-backup-addr"):
                                                                self.remote_backup_addr.append(value)
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "segmented-nexthop-present"):
                                                                self.segmented_nexthop_present = value
                                                                self.segmented_nexthop_present.value_namespace = name_space
                                                                self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-asrt-present"):
                                                                self.source_asrt_present = value
                                                                self.source_asrt_present.value_namespace = name_space
                                                                self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "source-rd-present"):
                                                                self.source_rd_present = value
                                                                self.source_rd_present.value_namespace = name_space
                                                                self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tunnel-id"):
                                                                self.tunnel_id = value
                                                                self.tunnel_id.value_namespace = name_space
                                                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-information-source"):
                                                                self.v6_information_source = value
                                                                self.v6_information_source.value_namespace = name_space
                                                                self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "v6-nexthop"):
                                                                self.v6_nexthop = value
                                                                self.v6_nexthop.value_namespace = name_space
                                                                self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "vrf-import-rt-present"):
                                                                self.vrf_import_rt_present = value
                                                                self.vrf_import_rt_present.value_namespace = name_space
                                                                self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.ipv6_rib_edm_path:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "route-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv6-rib-edm-path"):
                                                            for c in self.ipv6_rib_edm_path:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.ipv6_rib_edm_path.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv6-rib-edm-path"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.address.is_set or
                                                        self.active.is_set or
                                                        self.attribute_identity.is_set or
                                                        self.client_id.is_set or
                                                        self.distance.is_set or
                                                        self.diversion.is_set or
                                                        self.diversion_distance.is_set or
                                                        self.diversion_proto_name.is_set or
                                                        self.extended_flags.is_set or
                                                        self.flags.is_set or
                                                        self.flow_tag.is_set or
                                                        self.fwd_class.is_set or
                                                        self.instance.is_set or
                                                        self.metric.is_set or
                                                        self.paths_count.is_set or
                                                        self.pic_count.is_set or
                                                        self.prefix.is_set or
                                                        self.prefix_length_xr.is_set or
                                                        self.priority.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_name.is_set or
                                                        self.qos_group.is_set or
                                                        self.route_age.is_set or
                                                        self.route_label.is_set or
                                                        self.route_modify_time.is_set or
                                                        self.route_precedence.is_set or
                                                        self.route_type.is_set or
                                                        self.route_version.is_set or
                                                        self.svd_type.is_set or
                                                        self.tag.is_set or
                                                        self.tbl_version.is_set or
                                                        self.traffic_index.is_set or
                                                        self.version.is_set or
                                                        (self.route_path is not None and self.route_path.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.address.yfilter != YFilter.not_set or
                                                        self.active.yfilter != YFilter.not_set or
                                                        self.attribute_identity.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.distance.yfilter != YFilter.not_set or
                                                        self.diversion.yfilter != YFilter.not_set or
                                                        self.diversion_distance.yfilter != YFilter.not_set or
                                                        self.diversion_proto_name.yfilter != YFilter.not_set or
                                                        self.extended_flags.yfilter != YFilter.not_set or
                                                        self.flags.yfilter != YFilter.not_set or
                                                        self.flow_tag.yfilter != YFilter.not_set or
                                                        self.fwd_class.yfilter != YFilter.not_set or
                                                        self.instance.yfilter != YFilter.not_set or
                                                        self.metric.yfilter != YFilter.not_set or
                                                        self.paths_count.yfilter != YFilter.not_set or
                                                        self.pic_count.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length_xr.yfilter != YFilter.not_set or
                                                        self.priority.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_name.yfilter != YFilter.not_set or
                                                        self.qos_group.yfilter != YFilter.not_set or
                                                        self.route_age.yfilter != YFilter.not_set or
                                                        self.route_label.yfilter != YFilter.not_set or
                                                        self.route_modify_time.yfilter != YFilter.not_set or
                                                        self.route_precedence.yfilter != YFilter.not_set or
                                                        self.route_type.yfilter != YFilter.not_set or
                                                        self.route_version.yfilter != YFilter.not_set or
                                                        self.svd_type.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tbl_version.yfilter != YFilter.not_set or
                                                        self.traffic_index.yfilter != YFilter.not_set or
                                                        self.version.yfilter != YFilter.not_set or
                                                        (self.route_path is not None and self.route_path.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dest-next-hop-route" + "[address='" + self.address.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.active.get_name_leafdata())
                                                    if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                                    if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion.get_name_leafdata())
                                                    if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                    if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                    if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                    if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                    if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                    if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                    if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                    if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                    if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_age.get_name_leafdata())
                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                    if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                    if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_type.get_name_leafdata())
                                                    if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.route_version.get_name_leafdata())
                                                    if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                    if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                    if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.version.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "route-path"):
                                                        if (self.route_path is None):
                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                        return self.route_path

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "route-path" or name == "address" or name == "active" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "address"):
                                                        self.address = value
                                                        self.address.value_namespace = name_space
                                                        self.address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "active"):
                                                        self.active = value
                                                        self.active.value_namespace = name_space
                                                        self.active.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "attribute-identity"):
                                                        self.attribute_identity = value
                                                        self.attribute_identity.value_namespace = name_space
                                                        self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "distance"):
                                                        self.distance = value
                                                        self.distance.value_namespace = name_space
                                                        self.distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion"):
                                                        self.diversion = value
                                                        self.diversion.value_namespace = name_space
                                                        self.diversion.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-distance"):
                                                        self.diversion_distance = value
                                                        self.diversion_distance.value_namespace = name_space
                                                        self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "diversion-proto-name"):
                                                        self.diversion_proto_name = value
                                                        self.diversion_proto_name.value_namespace = name_space
                                                        self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-flags"):
                                                        self.extended_flags = value
                                                        self.extended_flags.value_namespace = name_space
                                                        self.extended_flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flags"):
                                                        self.flags = value
                                                        self.flags.value_namespace = name_space
                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flow-tag"):
                                                        self.flow_tag = value
                                                        self.flow_tag.value_namespace = name_space
                                                        self.flow_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fwd-class"):
                                                        self.fwd_class = value
                                                        self.fwd_class.value_namespace = name_space
                                                        self.fwd_class.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance"):
                                                        self.instance = value
                                                        self.instance.value_namespace = name_space
                                                        self.instance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "metric"):
                                                        self.metric = value
                                                        self.metric.value_namespace = name_space
                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "paths-count"):
                                                        self.paths_count = value
                                                        self.paths_count.value_namespace = name_space
                                                        self.paths_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pic-count"):
                                                        self.pic_count = value
                                                        self.pic_count.value_namespace = name_space
                                                        self.pic_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length-xr"):
                                                        self.prefix_length_xr = value
                                                        self.prefix_length_xr.value_namespace = name_space
                                                        self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "priority"):
                                                        self.priority = value
                                                        self.priority.value_namespace = name_space
                                                        self.priority.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-name"):
                                                        self.protocol_name = value
                                                        self.protocol_name.value_namespace = name_space
                                                        self.protocol_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "qos-group"):
                                                        self.qos_group = value
                                                        self.qos_group.value_namespace = name_space
                                                        self.qos_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-age"):
                                                        self.route_age = value
                                                        self.route_age.value_namespace = name_space
                                                        self.route_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-label"):
                                                        self.route_label = value
                                                        self.route_label.value_namespace = name_space
                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-modify-time"):
                                                        self.route_modify_time = value
                                                        self.route_modify_time.value_namespace = name_space
                                                        self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-precedence"):
                                                        self.route_precedence = value
                                                        self.route_precedence.value_namespace = name_space
                                                        self.route_precedence.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-type"):
                                                        self.route_type = value
                                                        self.route_type.value_namespace = name_space
                                                        self.route_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "route-version"):
                                                        self.route_version = value
                                                        self.route_version.value_namespace = name_space
                                                        self.route_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "svd-type"):
                                                        self.svd_type = value
                                                        self.svd_type.value_namespace = name_space
                                                        self.svd_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tbl-version"):
                                                        self.tbl_version = value
                                                        self.tbl_version.value_namespace = name_space
                                                        self.tbl_version.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "traffic-index"):
                                                        self.traffic_index = value
                                                        self.traffic_index.value_namespace = name_space
                                                        self.traffic_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "version"):
                                                        self.version = value
                                                        self.version.value_namespace = name_space
                                                        self.version.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.dest_next_hop_route:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.dest_next_hop_route:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dest-next-hop-routes" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "dest-next-hop-route"):
                                                    for c in self.dest_next_hop_route:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.dest_next_hop_route.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dest-next-hop-route"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                (self.dest_backup_routes is not None and self.dest_backup_routes.has_data()) or
                                                (self.dest_best_routes is not None and self.dest_best_routes.has_data()) or
                                                (self.dest_next_hop_routes is not None and self.dest_next_hop_routes.has_data()) or
                                                (self.dest_q_routes is not None and self.dest_q_routes.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.dest_backup_routes is not None and self.dest_backup_routes.has_operation()) or
                                                (self.dest_best_routes is not None and self.dest_best_routes.has_operation()) or
                                                (self.dest_next_hop_routes is not None and self.dest_next_hop_routes.has_operation()) or
                                                (self.dest_q_routes is not None and self.dest_q_routes.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "destination-kw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dest-backup-routes"):
                                                if (self.dest_backup_routes is None):
                                                    self.dest_backup_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                                    self.dest_backup_routes.parent = self
                                                    self._children_name_map["dest_backup_routes"] = "dest-backup-routes"
                                                return self.dest_backup_routes

                                            if (child_yang_name == "dest-best-routes"):
                                                if (self.dest_best_routes is None):
                                                    self.dest_best_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                                    self.dest_best_routes.parent = self
                                                    self._children_name_map["dest_best_routes"] = "dest-best-routes"
                                                return self.dest_best_routes

                                            if (child_yang_name == "dest-next-hop-routes"):
                                                if (self.dest_next_hop_routes is None):
                                                    self.dest_next_hop_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                                    self.dest_next_hop_routes.parent = self
                                                    self._children_name_map["dest_next_hop_routes"] = "dest-next-hop-routes"
                                                return self.dest_next_hop_routes

                                            if (child_yang_name == "dest-q-routes"):
                                                if (self.dest_q_routes is None):
                                                    self.dest_q_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                                    self.dest_q_routes.parent = self
                                                    self._children_name_map["dest_q_routes"] = "dest-q-routes"
                                                return self.dest_q_routes

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dest-backup-routes" or name == "dest-best-routes" or name == "dest-next-hop-routes" or name == "dest-q-routes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Adverts(Entity):
                                        """
                                        Route advertiser information 
                                        
                                        .. attribute:: advert
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Advert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__init__()

                                            self.yang_name = "adverts"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.advert = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__setattr__(name, value)


                                        class Advert(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_rib_edm_advert
                                            
                                            	ipv6 rib edm advert
                                            	**type**\: list of    :py:class:`Ipv6RibEdmAdvert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__init__()

                                                self.yang_name = "advert"
                                                self.yang_parent_name = "adverts"

                                                self.address = YLeaf(YType.str, "address")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.ipv6_rib_edm_advert = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("address",
                                                                "prefix_length") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__setattr__(name, value)


                                            class Ipv6RibEdmAdvert(Entity):
                                                """
                                                ipv6 rib edm advert
                                                
                                                .. attribute:: client_id
                                                
                                                	  Client advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: code
                                                
                                                	Protocol code
                                                	**type**\:  int
                                                
                                                	**range:** \-128..127
                                                
                                                .. attribute:: extended_communities
                                                
                                                	Extended communities
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: instance_name
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                	**length:** 0..41
                                                
                                                .. attribute:: number_of_extended_communities
                                                
                                                	Number of extended communities
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque
                                                
                                                	OSPF area\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque_flags
                                                
                                                	OSPF area\-id flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, self).__init__()

                                                    self.yang_name = "ipv6-rib-edm-advert"
                                                    self.yang_parent_name = "advert"

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.code = YLeaf(YType.int8, "code")

                                                    self.extended_communities = YLeaf(YType.str, "extended-communities")

                                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_opaque = YLeaf(YType.uint32, "protocol-opaque")

                                                    self.protocol_opaque_flags = YLeaf(YType.uint8, "protocol-opaque-flags")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("client_id",
                                                                    "code",
                                                                    "extended_communities",
                                                                    "instance_name",
                                                                    "number_of_extended_communities",
                                                                    "protocol_id",
                                                                    "protocol_opaque",
                                                                    "protocol_opaque_flags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.client_id.is_set or
                                                        self.code.is_set or
                                                        self.extended_communities.is_set or
                                                        self.instance_name.is_set or
                                                        self.number_of_extended_communities.is_set or
                                                        self.protocol_id.is_set or
                                                        self.protocol_opaque.is_set or
                                                        self.protocol_opaque_flags.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.client_id.yfilter != YFilter.not_set or
                                                        self.code.yfilter != YFilter.not_set or
                                                        self.extended_communities.yfilter != YFilter.not_set or
                                                        self.instance_name.yfilter != YFilter.not_set or
                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                        self.protocol_id.yfilter != YFilter.not_set or
                                                        self.protocol_opaque.yfilter != YFilter.not_set or
                                                        self.protocol_opaque_flags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ipv6-rib-edm-advert" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.client_id.get_name_leafdata())
                                                    if (self.code.is_set or self.code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.code.get_name_leafdata())
                                                    if (self.extended_communities.is_set or self.extended_communities.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.extended_communities.get_name_leafdata())
                                                    if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.instance_name.get_name_leafdata())
                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                    if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                    if (self.protocol_opaque.is_set or self.protocol_opaque.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_opaque.get_name_leafdata())
                                                    if (self.protocol_opaque_flags.is_set or self.protocol_opaque_flags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.protocol_opaque_flags.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "client-id" or name == "code" or name == "extended-communities" or name == "instance-name" or name == "number-of-extended-communities" or name == "protocol-id" or name == "protocol-opaque" or name == "protocol-opaque-flags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "client-id"):
                                                        self.client_id = value
                                                        self.client_id.value_namespace = name_space
                                                        self.client_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "code"):
                                                        self.code = value
                                                        self.code.value_namespace = name_space
                                                        self.code.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "extended-communities"):
                                                        self.extended_communities = value
                                                        self.extended_communities.value_namespace = name_space
                                                        self.extended_communities.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "instance-name"):
                                                        self.instance_name = value
                                                        self.instance_name.value_namespace = name_space
                                                        self.instance_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "number-of-extended-communities"):
                                                        self.number_of_extended_communities = value
                                                        self.number_of_extended_communities.value_namespace = name_space
                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-id"):
                                                        self.protocol_id = value
                                                        self.protocol_id.value_namespace = name_space
                                                        self.protocol_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-opaque"):
                                                        self.protocol_opaque = value
                                                        self.protocol_opaque.value_namespace = name_space
                                                        self.protocol_opaque.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "protocol-opaque-flags"):
                                                        self.protocol_opaque_flags = value
                                                        self.protocol_opaque_flags.value_namespace = name_space
                                                        self.protocol_opaque_flags.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.ipv6_rib_edm_advert:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.address.is_set or
                                                    self.prefix_length.is_set)

                                            def has_operation(self):
                                                for c in self.ipv6_rib_edm_advert:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "advert" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ipv6-rib-edm-advert"):
                                                    for c in self.ipv6_rib_edm_advert:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.ipv6_rib_edm_advert.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv6-rib-edm-advert" or name == "address" or name == "prefix-length"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.advert:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.advert:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "adverts" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "advert"):
                                                for c in self.advert:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.advert.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advert"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DeletedRoutes(Entity):
                                        """
                                        Deleted
                                        
                                        .. attribute:: deleted_route
                                        
                                        	Route information for a specific deleted address 
                                        	**type**\: list of    :py:class:`DeletedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__init__()

                                            self.yang_name = "deleted-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.deleted_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__setattr__(name, value)


                                        class DeletedRoute(Entity):
                                            """
                                            Route information for a specific
                                            deleted address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__init__()

                                                self.yang_name = "deleted-route"
                                                self.yang_parent_name = "deleted-routes"

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("active",
                                                                "address",
                                                                "attribute_identity",
                                                                "client_id",
                                                                "distance",
                                                                "diversion",
                                                                "diversion_distance",
                                                                "diversion_proto_name",
                                                                "extended_flags",
                                                                "flags",
                                                                "flow_tag",
                                                                "fwd_class",
                                                                "instance",
                                                                "metric",
                                                                "paths_count",
                                                                "pic_count",
                                                                "prefix",
                                                                "prefix_length",
                                                                "prefix_length_xr",
                                                                "priority",
                                                                "protocol_id",
                                                                "protocol_name",
                                                                "qos_group",
                                                                "route_age",
                                                                "route_label",
                                                                "route_modify_time",
                                                                "route_precedence",
                                                                "route_type",
                                                                "route_version",
                                                                "svd_type",
                                                                "tag",
                                                                "tbl_version",
                                                                "traffic_index",
                                                                "version") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__setattr__(name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "deleted-route"

                                                    self.ipv6_rib_edm_path = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__setattr__(name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("address",
                                                                        "backup_pathid",
                                                                        "binding_label",
                                                                        "flags",
                                                                        "flags64",
                                                                        "has_labelstk",
                                                                        "information_source",
                                                                        "interface_name",
                                                                        "labelstk",
                                                                        "load_metric",
                                                                        "looped",
                                                                        "metric",
                                                                        "mpls_feid",
                                                                        "mvpn_present",
                                                                        "next_hop_afi",
                                                                        "next_hop_id",
                                                                        "next_hop_id_refcount",
                                                                        "next_hop_safi",
                                                                        "next_hop_table_id",
                                                                        "next_hop_table_name",
                                                                        "next_hop_vrf_name",
                                                                        "nhid_feid",
                                                                        "num_labels",
                                                                        "number_of_extended_communities",
                                                                        "ospf_area_id",
                                                                        "path_rt_present",
                                                                        "pathid",
                                                                        "private_flags",
                                                                        "ref_cnt_of_backup",
                                                                        "remote_backup_addr",
                                                                        "route_label",
                                                                        "segmented_nexthop_present",
                                                                        "source_asrt_present",
                                                                        "source_rd_present",
                                                                        "tunnel_id",
                                                                        "v6_information_source",
                                                                        "v6_nexthop",
                                                                        "vrf_import_rt_present") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        return (
                                                            self.address.is_set or
                                                            self.backup_pathid.is_set or
                                                            self.binding_label.is_set or
                                                            self.flags.is_set or
                                                            self.flags64.is_set or
                                                            self.has_labelstk.is_set or
                                                            self.information_source.is_set or
                                                            self.interface_name.is_set or
                                                            self.load_metric.is_set or
                                                            self.looped.is_set or
                                                            self.metric.is_set or
                                                            self.mpls_feid.is_set or
                                                            self.mvpn_present.is_set or
                                                            self.next_hop_afi.is_set or
                                                            self.next_hop_id.is_set or
                                                            self.next_hop_id_refcount.is_set or
                                                            self.next_hop_safi.is_set or
                                                            self.next_hop_table_id.is_set or
                                                            self.next_hop_table_name.is_set or
                                                            self.next_hop_vrf_name.is_set or
                                                            self.nhid_feid.is_set or
                                                            self.num_labels.is_set or
                                                            self.number_of_extended_communities.is_set or
                                                            self.ospf_area_id.is_set or
                                                            self.path_rt_present.is_set or
                                                            self.pathid.is_set or
                                                            self.private_flags.is_set or
                                                            self.ref_cnt_of_backup.is_set or
                                                            self.route_label.is_set or
                                                            self.segmented_nexthop_present.is_set or
                                                            self.source_asrt_present.is_set or
                                                            self.source_rd_present.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.v6_information_source.is_set or
                                                            self.v6_nexthop.is_set or
                                                            self.vrf_import_rt_present.is_set)

                                                    def has_operation(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.address.yfilter != YFilter.not_set or
                                                            self.backup_pathid.yfilter != YFilter.not_set or
                                                            self.binding_label.yfilter != YFilter.not_set or
                                                            self.flags.yfilter != YFilter.not_set or
                                                            self.flags64.yfilter != YFilter.not_set or
                                                            self.has_labelstk.yfilter != YFilter.not_set or
                                                            self.information_source.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.labelstk.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.looped.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.mpls_feid.yfilter != YFilter.not_set or
                                                            self.mvpn_present.yfilter != YFilter.not_set or
                                                            self.next_hop_afi.yfilter != YFilter.not_set or
                                                            self.next_hop_id.yfilter != YFilter.not_set or
                                                            self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                            self.next_hop_safi.yfilter != YFilter.not_set or
                                                            self.next_hop_table_id.yfilter != YFilter.not_set or
                                                            self.next_hop_table_name.yfilter != YFilter.not_set or
                                                            self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                            self.nhid_feid.yfilter != YFilter.not_set or
                                                            self.num_labels.yfilter != YFilter.not_set or
                                                            self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                            self.ospf_area_id.yfilter != YFilter.not_set or
                                                            self.path_rt_present.yfilter != YFilter.not_set or
                                                            self.pathid.yfilter != YFilter.not_set or
                                                            self.private_flags.yfilter != YFilter.not_set or
                                                            self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                            self.remote_backup_addr.yfilter != YFilter.not_set or
                                                            self.route_label.yfilter != YFilter.not_set or
                                                            self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                            self.source_asrt_present.yfilter != YFilter.not_set or
                                                            self.source_rd_present.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.v6_information_source.yfilter != YFilter.not_set or
                                                            self.v6_nexthop.yfilter != YFilter.not_set or
                                                            self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.address.get_name_leafdata())
                                                        if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                        if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                        if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags.get_name_leafdata())
                                                        if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags64.get_name_leafdata())
                                                        if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                        if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.information_source.get_name_leafdata())
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.looped.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                        if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                        if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                        if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                        if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                        if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                        if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                        if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                        if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                        if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                        if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                        if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                        if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                        if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                        if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pathid.get_name_leafdata())
                                                        if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                        if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                        if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.route_label.get_name_leafdata())
                                                        if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                        if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                        if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                        if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                        if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                        leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                        leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "address"):
                                                            self.address = value
                                                            self.address.value_namespace = name_space
                                                            self.address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-pathid"):
                                                            self.backup_pathid = value
                                                            self.backup_pathid.value_namespace = name_space
                                                            self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "binding-label"):
                                                            self.binding_label = value
                                                            self.binding_label.value_namespace = name_space
                                                            self.binding_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags"):
                                                            self.flags = value
                                                            self.flags.value_namespace = name_space
                                                            self.flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags64"):
                                                            self.flags64 = value
                                                            self.flags64.value_namespace = name_space
                                                            self.flags64.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "has-labelstk"):
                                                            self.has_labelstk = value
                                                            self.has_labelstk.value_namespace = name_space
                                                            self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "information-source"):
                                                            self.information_source = value
                                                            self.information_source.value_namespace = name_space
                                                            self.information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "labelstk"):
                                                            self.labelstk.append(value)
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "looped"):
                                                            self.looped = value
                                                            self.looped.value_namespace = name_space
                                                            self.looped.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-feid"):
                                                            self.mpls_feid = value
                                                            self.mpls_feid.value_namespace = name_space
                                                            self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mvpn-present"):
                                                            self.mvpn_present = value
                                                            self.mvpn_present.value_namespace = name_space
                                                            self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-afi"):
                                                            self.next_hop_afi = value
                                                            self.next_hop_afi.value_namespace = name_space
                                                            self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id"):
                                                            self.next_hop_id = value
                                                            self.next_hop_id.value_namespace = name_space
                                                            self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id-refcount"):
                                                            self.next_hop_id_refcount = value
                                                            self.next_hop_id_refcount.value_namespace = name_space
                                                            self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-safi"):
                                                            self.next_hop_safi = value
                                                            self.next_hop_safi.value_namespace = name_space
                                                            self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-id"):
                                                            self.next_hop_table_id = value
                                                            self.next_hop_table_id.value_namespace = name_space
                                                            self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-name"):
                                                            self.next_hop_table_name = value
                                                            self.next_hop_table_name.value_namespace = name_space
                                                            self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-vrf-name"):
                                                            self.next_hop_vrf_name = value
                                                            self.next_hop_vrf_name.value_namespace = name_space
                                                            self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "nhid-feid"):
                                                            self.nhid_feid = value
                                                            self.nhid_feid.value_namespace = name_space
                                                            self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-labels"):
                                                            self.num_labels = value
                                                            self.num_labels.value_namespace = name_space
                                                            self.num_labels.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "number-of-extended-communities"):
                                                            self.number_of_extended_communities = value
                                                            self.number_of_extended_communities.value_namespace = name_space
                                                            self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ospf-area-id"):
                                                            self.ospf_area_id = value
                                                            self.ospf_area_id.value_namespace = name_space
                                                            self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "path-rt-present"):
                                                            self.path_rt_present = value
                                                            self.path_rt_present.value_namespace = name_space
                                                            self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pathid"):
                                                            self.pathid = value
                                                            self.pathid.value_namespace = name_space
                                                            self.pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "private-flags"):
                                                            self.private_flags = value
                                                            self.private_flags.value_namespace = name_space
                                                            self.private_flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ref-cnt-of-backup"):
                                                            self.ref_cnt_of_backup = value
                                                            self.ref_cnt_of_backup.value_namespace = name_space
                                                            self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-backup-addr"):
                                                            self.remote_backup_addr.append(value)
                                                        if(value_path == "route-label"):
                                                            self.route_label = value
                                                            self.route_label.value_namespace = name_space
                                                            self.route_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segmented-nexthop-present"):
                                                            self.segmented_nexthop_present = value
                                                            self.segmented_nexthop_present.value_namespace = name_space
                                                            self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-asrt-present"):
                                                            self.source_asrt_present = value
                                                            self.source_asrt_present.value_namespace = name_space
                                                            self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-rd-present"):
                                                            self.source_rd_present = value
                                                            self.source_rd_present.value_namespace = name_space
                                                            self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-information-source"):
                                                            self.v6_information_source = value
                                                            self.v6_information_source.value_namespace = name_space
                                                            self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-nexthop"):
                                                            self.v6_nexthop = value
                                                            self.v6_nexthop.value_namespace = name_space
                                                            self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-import-rt-present"):
                                                            self.vrf_import_rt_present = value
                                                            self.vrf_import_rt_present.value_namespace = name_space
                                                            self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv6-rib-edm-path"):
                                                        for c in self.ipv6_rib_edm_path:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.ipv6_rib_edm_path.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv6-rib-edm-path"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.active.is_set or
                                                    self.address.is_set or
                                                    self.attribute_identity.is_set or
                                                    self.client_id.is_set or
                                                    self.distance.is_set or
                                                    self.diversion.is_set or
                                                    self.diversion_distance.is_set or
                                                    self.diversion_proto_name.is_set or
                                                    self.extended_flags.is_set or
                                                    self.flags.is_set or
                                                    self.flow_tag.is_set or
                                                    self.fwd_class.is_set or
                                                    self.instance.is_set or
                                                    self.metric.is_set or
                                                    self.paths_count.is_set or
                                                    self.pic_count.is_set or
                                                    self.prefix.is_set or
                                                    self.prefix_length.is_set or
                                                    self.prefix_length_xr.is_set or
                                                    self.priority.is_set or
                                                    self.protocol_id.is_set or
                                                    self.protocol_name.is_set or
                                                    self.qos_group.is_set or
                                                    self.route_age.is_set or
                                                    self.route_label.is_set or
                                                    self.route_modify_time.is_set or
                                                    self.route_precedence.is_set or
                                                    self.route_type.is_set or
                                                    self.route_version.is_set or
                                                    self.svd_type.is_set or
                                                    self.tag.is_set or
                                                    self.tbl_version.is_set or
                                                    self.traffic_index.is_set or
                                                    self.version.is_set or
                                                    (self.route_path is not None and self.route_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.active.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.attribute_identity.yfilter != YFilter.not_set or
                                                    self.client_id.yfilter != YFilter.not_set or
                                                    self.distance.yfilter != YFilter.not_set or
                                                    self.diversion.yfilter != YFilter.not_set or
                                                    self.diversion_distance.yfilter != YFilter.not_set or
                                                    self.diversion_proto_name.yfilter != YFilter.not_set or
                                                    self.extended_flags.yfilter != YFilter.not_set or
                                                    self.flags.yfilter != YFilter.not_set or
                                                    self.flow_tag.yfilter != YFilter.not_set or
                                                    self.fwd_class.yfilter != YFilter.not_set or
                                                    self.instance.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.paths_count.yfilter != YFilter.not_set or
                                                    self.pic_count.yfilter != YFilter.not_set or
                                                    self.prefix.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set or
                                                    self.prefix_length_xr.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set or
                                                    self.protocol_id.yfilter != YFilter.not_set or
                                                    self.protocol_name.yfilter != YFilter.not_set or
                                                    self.qos_group.yfilter != YFilter.not_set or
                                                    self.route_age.yfilter != YFilter.not_set or
                                                    self.route_label.yfilter != YFilter.not_set or
                                                    self.route_modify_time.yfilter != YFilter.not_set or
                                                    self.route_precedence.yfilter != YFilter.not_set or
                                                    self.route_type.yfilter != YFilter.not_set or
                                                    self.route_version.yfilter != YFilter.not_set or
                                                    self.svd_type.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tbl_version.yfilter != YFilter.not_set or
                                                    self.traffic_index.yfilter != YFilter.not_set or
                                                    self.version.yfilter != YFilter.not_set or
                                                    (self.route_path is not None and self.route_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "deleted-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.active.get_name_leafdata())
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.client_id.get_name_leafdata())
                                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.distance.get_name_leafdata())
                                                if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion.get_name_leafdata())
                                                if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                                if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                                if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_age.get_name_leafdata())
                                                if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_label.get_name_leafdata())
                                                if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_type.get_name_leafdata())
                                                if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_version.get_name_leafdata())
                                                if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.version.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-path"):
                                                    if (self.route_path is None):
                                                        self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                        self.route_path.parent = self
                                                        self._children_name_map["route_path"] = "route-path"
                                                    return self.route_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "active"):
                                                    self.active = value
                                                    self.active.value_namespace = name_space
                                                    self.active.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "attribute-identity"):
                                                    self.attribute_identity = value
                                                    self.attribute_identity.value_namespace = name_space
                                                    self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                if(value_path == "client-id"):
                                                    self.client_id = value
                                                    self.client_id.value_namespace = name_space
                                                    self.client_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "distance"):
                                                    self.distance = value
                                                    self.distance.value_namespace = name_space
                                                    self.distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion"):
                                                    self.diversion = value
                                                    self.diversion.value_namespace = name_space
                                                    self.diversion.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-distance"):
                                                    self.diversion_distance = value
                                                    self.diversion_distance.value_namespace = name_space
                                                    self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-proto-name"):
                                                    self.diversion_proto_name = value
                                                    self.diversion_proto_name.value_namespace = name_space
                                                    self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "extended-flags"):
                                                    self.extended_flags = value
                                                    self.extended_flags.value_namespace = name_space
                                                    self.extended_flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flags"):
                                                    self.flags = value
                                                    self.flags.value_namespace = name_space
                                                    self.flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flow-tag"):
                                                    self.flow_tag = value
                                                    self.flow_tag.value_namespace = name_space
                                                    self.flow_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fwd-class"):
                                                    self.fwd_class = value
                                                    self.fwd_class.value_namespace = name_space
                                                    self.fwd_class.value_namespace_prefix = name_space_prefix
                                                if(value_path == "instance"):
                                                    self.instance = value
                                                    self.instance.value_namespace = name_space
                                                    self.instance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "paths-count"):
                                                    self.paths_count = value
                                                    self.paths_count.value_namespace = name_space
                                                    self.paths_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pic-count"):
                                                    self.pic_count = value
                                                    self.pic_count.value_namespace = name_space
                                                    self.pic_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix"):
                                                    self.prefix = value
                                                    self.prefix.value_namespace = name_space
                                                    self.prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length-xr"):
                                                    self.prefix_length_xr = value
                                                    self.prefix_length_xr.value_namespace = name_space
                                                    self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-id"):
                                                    self.protocol_id = value
                                                    self.protocol_id.value_namespace = name_space
                                                    self.protocol_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-name"):
                                                    self.protocol_name = value
                                                    self.protocol_name.value_namespace = name_space
                                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "qos-group"):
                                                    self.qos_group = value
                                                    self.qos_group.value_namespace = name_space
                                                    self.qos_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-age"):
                                                    self.route_age = value
                                                    self.route_age.value_namespace = name_space
                                                    self.route_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-label"):
                                                    self.route_label = value
                                                    self.route_label.value_namespace = name_space
                                                    self.route_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-modify-time"):
                                                    self.route_modify_time = value
                                                    self.route_modify_time.value_namespace = name_space
                                                    self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-precedence"):
                                                    self.route_precedence = value
                                                    self.route_precedence.value_namespace = name_space
                                                    self.route_precedence.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-type"):
                                                    self.route_type = value
                                                    self.route_type.value_namespace = name_space
                                                    self.route_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-version"):
                                                    self.route_version = value
                                                    self.route_version.value_namespace = name_space
                                                    self.route_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "svd-type"):
                                                    self.svd_type = value
                                                    self.svd_type.value_namespace = name_space
                                                    self.svd_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tbl-version"):
                                                    self.tbl_version = value
                                                    self.tbl_version.value_namespace = name_space
                                                    self.tbl_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "traffic-index"):
                                                    self.traffic_index = value
                                                    self.traffic_index.value_namespace = name_space
                                                    self.traffic_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "version"):
                                                    self.version = value
                                                    self.version.value_namespace = name_space
                                                    self.version.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.deleted_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.deleted_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "deleted-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "deleted-route"):
                                                for c in self.deleted_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.deleted_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "deleted-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Protocol(Entity):
                                        """
                                        Contains the classification of routes by
                                        protocol
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP Protocol
                                        	**type**\:   :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected Protocol
                                        	**type**\:   :py:class:`Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	EIGRP Protocol
                                        	**type**\:   :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISIS Protocol
                                        	**type**\:   :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis>`
                                        
                                        .. attribute:: local
                                        
                                        	Local Protocol
                                        	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile Protocol
                                        	**type**\:   :py:class:`Mobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile>`
                                        
                                        .. attribute:: ospf
                                        
                                        	OSPF Protocol
                                        	**type**\:   :py:class:`Ospf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf>`
                                        
                                        .. attribute:: rpl
                                        
                                        	RPL Protocol
                                        	**type**\:   :py:class:`Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl>`
                                        
                                        .. attribute:: static
                                        
                                        	Static Protocol
                                        	**type**\:   :py:class:`Static <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static>`
                                        
                                        .. attribute:: subscriber
                                        
                                        	Subscriber Protocol
                                        	**type**\:   :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber>`
                                        
                                        .. attribute:: te_client
                                        
                                        	TEClient protocol
                                        	**type**\:   :py:class:`TeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol, self).__init__()

                                            self.yang_name = "protocol"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.bgp = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"
                                            self._children_yang_names.add("bgp")

                                            self.connected = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"
                                            self._children_yang_names.add("connected")

                                            self.eigrp = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"
                                            self._children_yang_names.add("eigrp")

                                            self.isis = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"
                                            self._children_yang_names.add("isis")

                                            self.local = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                            self.local.parent = self
                                            self._children_name_map["local"] = "local"
                                            self._children_yang_names.add("local")

                                            self.mobile = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                            self.mobile.parent = self
                                            self._children_name_map["mobile"] = "mobile"
                                            self._children_yang_names.add("mobile")

                                            self.ospf = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                            self.ospf.parent = self
                                            self._children_name_map["ospf"] = "ospf"
                                            self._children_yang_names.add("ospf")

                                            self.rpl = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                            self.rpl.parent = self
                                            self._children_name_map["rpl"] = "rpl"
                                            self._children_yang_names.add("rpl")

                                            self.static = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"
                                            self._children_yang_names.add("static")

                                            self.subscriber = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                            self.subscriber.parent = self
                                            self._children_name_map["subscriber"] = "subscriber"
                                            self._children_yang_names.add("subscriber")

                                            self.te_client = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                            self.te_client.parent = self
                                            self._children_name_map["te_client"] = "te-client"
                                            self._children_yang_names.add("te-client")


                                        class Local(Entity):
                                            """
                                            Local Protocol
                                            
                                            .. attribute:: lspv
                                            
                                            	LSPV(Label Switched Path Verification) protocol
                                            	**type**\:   :py:class:`Lspv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local, self).__init__()

                                                self.yang_name = "local"
                                                self.yang_parent_name = "protocol"

                                                self.lspv = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                self.lspv.parent = self
                                                self._children_name_map["lspv"] = "lspv"
                                                self._children_yang_names.add("lspv")

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class Lspv(Entity):
                                                """
                                                LSPV(Label Switched Path Verification)
                                                protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv, self).__init__()

                                                    self.yang_name = "lspv"
                                                    self.yang_parent_name = "local"

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "lspv"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "lspv"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lspv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "local"

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    (self.lspv is not None and self.lspv.has_data()) or
                                                    (self.non_as is not None and self.non_as.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.lspv is not None and self.lspv.has_operation()) or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "local" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "lspv"):
                                                    if (self.lspv is None):
                                                        self.lspv = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                        self.lspv.parent = self
                                                        self._children_name_map["lspv"] = "lspv"
                                                    return self.lspv

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lspv" or name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Bgp(Entity):
                                            """
                                            BGP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "bgp"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bgp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Mobile(Entity):
                                            """
                                            Mobile Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "protocol"

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "mobile"

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.non_as is not None and self.non_as.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mobile" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Eigrp(Entity):
                                            """
                                            EIGRP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "eigrp"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "eigrp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Rpl(Entity):
                                            """
                                            RPL Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__init__()

                                                self.yang_name = "rpl"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "rpl"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "rpl" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Static(Entity):
                                            """
                                            Static Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "protocol"

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "static"

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.non_as is not None and self.non_as.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "static" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class TeClient(Entity):
                                            """
                                            TEClient protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient, self).__init__()

                                                self.yang_name = "te-client"
                                                self.yang_parent_name = "protocol"

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "te-client"

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.non_as is not None and self.non_as.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "te-client" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Subscriber(Entity):
                                            """
                                            Subscriber Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber, self).__init__()

                                                self.yang_name = "subscriber"
                                                self.yang_parent_name = "protocol"

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "subscriber"

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (self.non_as is not None and self.non_as.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "subscriber" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Ospf(Entity):
                                            """
                                            OSPF Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "ospf"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ospf" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Connected(Entity):
                                            """
                                            Connected Protocol
                                            
                                            .. attribute:: l2vpn
                                            
                                            	L2VPN
                                            	**type**\:   :py:class:`L2Vpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "protocol"

                                                self.l2vpn = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn()
                                                self.l2vpn.parent = self
                                                self._children_name_map["l2vpn"] = "l2vpn"
                                                self._children_yang_names.add("l2vpn")

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")


                                            class L2Vpn(Entity):
                                                """
                                                L2VPN
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn, self).__init__()

                                                    self.yang_name = "l2vpn"
                                                    self.yang_parent_name = "connected"

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "l2vpn"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "l2vpn"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "l2vpn" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "connected"

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "non-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    (self.l2vpn is not None and self.l2vpn.has_data()) or
                                                    (self.non_as is not None and self.non_as.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.l2vpn is not None and self.l2vpn.has_operation()) or
                                                    (self.non_as is not None and self.non_as.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "connected" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "l2vpn"):
                                                    if (self.l2vpn is None):
                                                        self.l2vpn = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2Vpn()
                                                        self.l2vpn.parent = self
                                                        self._children_name_map["l2vpn"] = "l2vpn"
                                                    return self.l2vpn

                                                if (child_yang_name == "non-as"):
                                                    if (self.non_as is None):
                                                        self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                        self.non_as.parent = self
                                                        self._children_name_map["non_as"] = "non-as"
                                                    return self.non_as

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "l2vpn" or name == "non-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class Isis(Entity):
                                            """
                                            ISIS Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "protocol"

                                                self.as_ = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__setattr__(name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "isis"

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("as_") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, self).__setattr__(name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("active_routes_count",
                                                                        "backup_routes_count",
                                                                        "deleted_routes_count",
                                                                        "instance",
                                                                        "paths_count",
                                                                        "protocol_clients_count",
                                                                        "protocol_names",
                                                                        "protocol_route_memory",
                                                                        "redistribution_client_count",
                                                                        "routes_counts",
                                                                        "version") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.active_routes_count.is_set or
                                                            self.backup_routes_count.is_set or
                                                            self.deleted_routes_count.is_set or
                                                            self.instance.is_set or
                                                            self.paths_count.is_set or
                                                            self.protocol_clients_count.is_set or
                                                            self.protocol_names.is_set or
                                                            self.protocol_route_memory.is_set or
                                                            self.redistribution_client_count.is_set or
                                                            self.routes_counts.is_set or
                                                            self.version.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.active_routes_count.yfilter != YFilter.not_set or
                                                            self.backup_routes_count.yfilter != YFilter.not_set or
                                                            self.deleted_routes_count.yfilter != YFilter.not_set or
                                                            self.instance.yfilter != YFilter.not_set or
                                                            self.paths_count.yfilter != YFilter.not_set or
                                                            self.protocol_clients_count.yfilter != YFilter.not_set or
                                                            self.protocol_names.yfilter != YFilter.not_set or
                                                            self.protocol_route_memory.yfilter != YFilter.not_set or
                                                            self.redistribution_client_count.yfilter != YFilter.not_set or
                                                            self.routes_counts.yfilter != YFilter.not_set or
                                                            self.version.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "information" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.active_routes_count.is_set or self.active_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.active_routes_count.get_name_leafdata())
                                                        if (self.backup_routes_count.is_set or self.backup_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_routes_count.get_name_leafdata())
                                                        if (self.deleted_routes_count.is_set or self.deleted_routes_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.deleted_routes_count.get_name_leafdata())
                                                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.instance.get_name_leafdata())
                                                        if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                        if (self.protocol_clients_count.is_set or self.protocol_clients_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_clients_count.get_name_leafdata())
                                                        if (self.protocol_names.is_set or self.protocol_names.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_names.get_name_leafdata())
                                                        if (self.protocol_route_memory.is_set or self.protocol_route_memory.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.protocol_route_memory.get_name_leafdata())
                                                        if (self.redistribution_client_count.is_set or self.redistribution_client_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.redistribution_client_count.get_name_leafdata())
                                                        if (self.routes_counts.is_set or self.routes_counts.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.routes_counts.get_name_leafdata())
                                                        if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.version.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "active-routes-count" or name == "backup-routes-count" or name == "deleted-routes-count" or name == "instance" or name == "paths-count" or name == "protocol-clients-count" or name == "protocol-names" or name == "protocol-route-memory" or name == "redistribution-client-count" or name == "routes-counts" or name == "version"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "active-routes-count"):
                                                            self.active_routes_count = value
                                                            self.active_routes_count.value_namespace = name_space
                                                            self.active_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-routes-count"):
                                                            self.backup_routes_count = value
                                                            self.backup_routes_count.value_namespace = name_space
                                                            self.backup_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "deleted-routes-count"):
                                                            self.deleted_routes_count = value
                                                            self.deleted_routes_count.value_namespace = name_space
                                                            self.deleted_routes_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "instance"):
                                                            self.instance = value
                                                            self.instance.value_namespace = name_space
                                                            self.instance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "paths-count"):
                                                            self.paths_count = value
                                                            self.paths_count.value_namespace = name_space
                                                            self.paths_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-clients-count"):
                                                            self.protocol_clients_count = value
                                                            self.protocol_clients_count.value_namespace = name_space
                                                            self.protocol_clients_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-names"):
                                                            self.protocol_names = value
                                                            self.protocol_names.value_namespace = name_space
                                                            self.protocol_names.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "protocol-route-memory"):
                                                            self.protocol_route_memory = value
                                                            self.protocol_route_memory.value_namespace = name_space
                                                            self.protocol_route_memory.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "redistribution-client-count"):
                                                            self.redistribution_client_count = value
                                                            self.redistribution_client_count.value_namespace = name_space
                                                            self.redistribution_client_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "routes-counts"):
                                                            self.routes_counts = value
                                                            self.routes_counts.value_namespace = name_space
                                                            self.routes_counts.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "version"):
                                                            self.version = value
                                                            self.version.value_namespace = name_space
                                                            self.version.value_namespace_prefix = name_space_prefix


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"

                                                        self.protocol_route = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, self).__setattr__(name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("active",
                                                                            "address",
                                                                            "attribute_identity",
                                                                            "client_id",
                                                                            "distance",
                                                                            "diversion",
                                                                            "diversion_distance",
                                                                            "diversion_proto_name",
                                                                            "extended_flags",
                                                                            "flags",
                                                                            "flow_tag",
                                                                            "fwd_class",
                                                                            "instance",
                                                                            "metric",
                                                                            "paths_count",
                                                                            "pic_count",
                                                                            "prefix",
                                                                            "prefix_length",
                                                                            "prefix_length_xr",
                                                                            "priority",
                                                                            "protocol_id",
                                                                            "protocol_name",
                                                                            "qos_group",
                                                                            "route_age",
                                                                            "route_label",
                                                                            "route_modify_time",
                                                                            "route_precedence",
                                                                            "route_type",
                                                                            "route_version",
                                                                            "svd_type",
                                                                            "tag",
                                                                            "tbl_version",
                                                                            "traffic_index",
                                                                            "version") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, self).__setattr__(name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"

                                                                self.ipv6_rib_edm_path = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__setattr__(name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Labels for this path
                                                                	**type**\:  list of int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\:  list of str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("address",
                                                                                    "backup_pathid",
                                                                                    "binding_label",
                                                                                    "flags",
                                                                                    "flags64",
                                                                                    "has_labelstk",
                                                                                    "information_source",
                                                                                    "interface_name",
                                                                                    "labelstk",
                                                                                    "load_metric",
                                                                                    "looped",
                                                                                    "metric",
                                                                                    "mpls_feid",
                                                                                    "mvpn_present",
                                                                                    "next_hop_afi",
                                                                                    "next_hop_id",
                                                                                    "next_hop_id_refcount",
                                                                                    "next_hop_safi",
                                                                                    "next_hop_table_id",
                                                                                    "next_hop_table_name",
                                                                                    "next_hop_vrf_name",
                                                                                    "nhid_feid",
                                                                                    "num_labels",
                                                                                    "number_of_extended_communities",
                                                                                    "ospf_area_id",
                                                                                    "path_rt_present",
                                                                                    "pathid",
                                                                                    "private_flags",
                                                                                    "ref_cnt_of_backup",
                                                                                    "remote_backup_addr",
                                                                                    "route_label",
                                                                                    "segmented_nexthop_present",
                                                                                    "source_asrt_present",
                                                                                    "source_rd_present",
                                                                                    "tunnel_id",
                                                                                    "v6_information_source",
                                                                                    "v6_nexthop",
                                                                                    "vrf_import_rt_present") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.yfilter != YFilter.not_set):
                                                                            return True
                                                                    return (
                                                                        self.address.is_set or
                                                                        self.backup_pathid.is_set or
                                                                        self.binding_label.is_set or
                                                                        self.flags.is_set or
                                                                        self.flags64.is_set or
                                                                        self.has_labelstk.is_set or
                                                                        self.information_source.is_set or
                                                                        self.interface_name.is_set or
                                                                        self.load_metric.is_set or
                                                                        self.looped.is_set or
                                                                        self.metric.is_set or
                                                                        self.mpls_feid.is_set or
                                                                        self.mvpn_present.is_set or
                                                                        self.next_hop_afi.is_set or
                                                                        self.next_hop_id.is_set or
                                                                        self.next_hop_id_refcount.is_set or
                                                                        self.next_hop_safi.is_set or
                                                                        self.next_hop_table_id.is_set or
                                                                        self.next_hop_table_name.is_set or
                                                                        self.next_hop_vrf_name.is_set or
                                                                        self.nhid_feid.is_set or
                                                                        self.num_labels.is_set or
                                                                        self.number_of_extended_communities.is_set or
                                                                        self.ospf_area_id.is_set or
                                                                        self.path_rt_present.is_set or
                                                                        self.pathid.is_set or
                                                                        self.private_flags.is_set or
                                                                        self.ref_cnt_of_backup.is_set or
                                                                        self.route_label.is_set or
                                                                        self.segmented_nexthop_present.is_set or
                                                                        self.source_asrt_present.is_set or
                                                                        self.source_rd_present.is_set or
                                                                        self.tunnel_id.is_set or
                                                                        self.v6_information_source.is_set or
                                                                        self.v6_nexthop.is_set or
                                                                        self.vrf_import_rt_present.is_set)

                                                                def has_operation(self):
                                                                    for leaf in self.labelstk.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    for leaf in self.remote_backup_addr.getYLeafs():
                                                                        if (leaf.is_set):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.address.yfilter != YFilter.not_set or
                                                                        self.backup_pathid.yfilter != YFilter.not_set or
                                                                        self.binding_label.yfilter != YFilter.not_set or
                                                                        self.flags.yfilter != YFilter.not_set or
                                                                        self.flags64.yfilter != YFilter.not_set or
                                                                        self.has_labelstk.yfilter != YFilter.not_set or
                                                                        self.information_source.yfilter != YFilter.not_set or
                                                                        self.interface_name.yfilter != YFilter.not_set or
                                                                        self.labelstk.yfilter != YFilter.not_set or
                                                                        self.load_metric.yfilter != YFilter.not_set or
                                                                        self.looped.yfilter != YFilter.not_set or
                                                                        self.metric.yfilter != YFilter.not_set or
                                                                        self.mpls_feid.yfilter != YFilter.not_set or
                                                                        self.mvpn_present.yfilter != YFilter.not_set or
                                                                        self.next_hop_afi.yfilter != YFilter.not_set or
                                                                        self.next_hop_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                                        self.next_hop_safi.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_id.yfilter != YFilter.not_set or
                                                                        self.next_hop_table_name.yfilter != YFilter.not_set or
                                                                        self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                                        self.nhid_feid.yfilter != YFilter.not_set or
                                                                        self.num_labels.yfilter != YFilter.not_set or
                                                                        self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                                        self.ospf_area_id.yfilter != YFilter.not_set or
                                                                        self.path_rt_present.yfilter != YFilter.not_set or
                                                                        self.pathid.yfilter != YFilter.not_set or
                                                                        self.private_flags.yfilter != YFilter.not_set or
                                                                        self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                                        self.remote_backup_addr.yfilter != YFilter.not_set or
                                                                        self.route_label.yfilter != YFilter.not_set or
                                                                        self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                                        self.source_asrt_present.yfilter != YFilter.not_set or
                                                                        self.source_rd_present.yfilter != YFilter.not_set or
                                                                        self.tunnel_id.yfilter != YFilter.not_set or
                                                                        self.v6_information_source.yfilter != YFilter.not_set or
                                                                        self.v6_nexthop.yfilter != YFilter.not_set or
                                                                        self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.address.get_name_leafdata())
                                                                    if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                                    if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                                    if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags.get_name_leafdata())
                                                                    if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.flags64.get_name_leafdata())
                                                                    if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                                    if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.information_source.get_name_leafdata())
                                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                                    if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                                    if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.looped.get_name_leafdata())
                                                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                                                    if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                                    if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                                    if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                                    if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                                    if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                                    if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                                    if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                                    if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                                    if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                                    if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                                    if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                                    if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                                    if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                                    if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                                    if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pathid.get_name_leafdata())
                                                                    if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                                    if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                                    if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.route_label.get_name_leafdata())
                                                                    if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                                    if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                                    if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                                    if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                                    if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                                    if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                                    leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                                    leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "address"):
                                                                        self.address = value
                                                                        self.address.value_namespace = name_space
                                                                        self.address.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "backup-pathid"):
                                                                        self.backup_pathid = value
                                                                        self.backup_pathid.value_namespace = name_space
                                                                        self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "binding-label"):
                                                                        self.binding_label = value
                                                                        self.binding_label.value_namespace = name_space
                                                                        self.binding_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags"):
                                                                        self.flags = value
                                                                        self.flags.value_namespace = name_space
                                                                        self.flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "flags64"):
                                                                        self.flags64 = value
                                                                        self.flags64.value_namespace = name_space
                                                                        self.flags64.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "has-labelstk"):
                                                                        self.has_labelstk = value
                                                                        self.has_labelstk.value_namespace = name_space
                                                                        self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "information-source"):
                                                                        self.information_source = value
                                                                        self.information_source.value_namespace = name_space
                                                                        self.information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "interface-name"):
                                                                        self.interface_name = value
                                                                        self.interface_name.value_namespace = name_space
                                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "labelstk"):
                                                                        self.labelstk.append(value)
                                                                    if(value_path == "load-metric"):
                                                                        self.load_metric = value
                                                                        self.load_metric.value_namespace = name_space
                                                                        self.load_metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "looped"):
                                                                        self.looped = value
                                                                        self.looped.value_namespace = name_space
                                                                        self.looped.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "metric"):
                                                                        self.metric = value
                                                                        self.metric.value_namespace = name_space
                                                                        self.metric.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mpls-feid"):
                                                                        self.mpls_feid = value
                                                                        self.mpls_feid.value_namespace = name_space
                                                                        self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "mvpn-present"):
                                                                        self.mvpn_present = value
                                                                        self.mvpn_present.value_namespace = name_space
                                                                        self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-afi"):
                                                                        self.next_hop_afi = value
                                                                        self.next_hop_afi.value_namespace = name_space
                                                                        self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id"):
                                                                        self.next_hop_id = value
                                                                        self.next_hop_id.value_namespace = name_space
                                                                        self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-id-refcount"):
                                                                        self.next_hop_id_refcount = value
                                                                        self.next_hop_id_refcount.value_namespace = name_space
                                                                        self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-safi"):
                                                                        self.next_hop_safi = value
                                                                        self.next_hop_safi.value_namespace = name_space
                                                                        self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-id"):
                                                                        self.next_hop_table_id = value
                                                                        self.next_hop_table_id.value_namespace = name_space
                                                                        self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-table-name"):
                                                                        self.next_hop_table_name = value
                                                                        self.next_hop_table_name.value_namespace = name_space
                                                                        self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "next-hop-vrf-name"):
                                                                        self.next_hop_vrf_name = value
                                                                        self.next_hop_vrf_name.value_namespace = name_space
                                                                        self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "nhid-feid"):
                                                                        self.nhid_feid = value
                                                                        self.nhid_feid.value_namespace = name_space
                                                                        self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "num-labels"):
                                                                        self.num_labels = value
                                                                        self.num_labels.value_namespace = name_space
                                                                        self.num_labels.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "number-of-extended-communities"):
                                                                        self.number_of_extended_communities = value
                                                                        self.number_of_extended_communities.value_namespace = name_space
                                                                        self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ospf-area-id"):
                                                                        self.ospf_area_id = value
                                                                        self.ospf_area_id.value_namespace = name_space
                                                                        self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "path-rt-present"):
                                                                        self.path_rt_present = value
                                                                        self.path_rt_present.value_namespace = name_space
                                                                        self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "pathid"):
                                                                        self.pathid = value
                                                                        self.pathid.value_namespace = name_space
                                                                        self.pathid.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "private-flags"):
                                                                        self.private_flags = value
                                                                        self.private_flags.value_namespace = name_space
                                                                        self.private_flags.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ref-cnt-of-backup"):
                                                                        self.ref_cnt_of_backup = value
                                                                        self.ref_cnt_of_backup.value_namespace = name_space
                                                                        self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "remote-backup-addr"):
                                                                        self.remote_backup_addr.append(value)
                                                                    if(value_path == "route-label"):
                                                                        self.route_label = value
                                                                        self.route_label.value_namespace = name_space
                                                                        self.route_label.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "segmented-nexthop-present"):
                                                                        self.segmented_nexthop_present = value
                                                                        self.segmented_nexthop_present.value_namespace = name_space
                                                                        self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-asrt-present"):
                                                                        self.source_asrt_present = value
                                                                        self.source_asrt_present.value_namespace = name_space
                                                                        self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "source-rd-present"):
                                                                        self.source_rd_present = value
                                                                        self.source_rd_present.value_namespace = name_space
                                                                        self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "tunnel-id"):
                                                                        self.tunnel_id = value
                                                                        self.tunnel_id.value_namespace = name_space
                                                                        self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-information-source"):
                                                                        self.v6_information_source = value
                                                                        self.v6_information_source.value_namespace = name_space
                                                                        self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "v6-nexthop"):
                                                                        self.v6_nexthop = value
                                                                        self.v6_nexthop.value_namespace = name_space
                                                                        self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "vrf-import-rt-present"):
                                                                        self.vrf_import_rt_present = value
                                                                        self.vrf_import_rt_present.value_namespace = name_space
                                                                        self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.ipv6_rib_edm_path:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "route-path" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv6-rib-edm-path"):
                                                                    for c in self.ipv6_rib_edm_path:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.ipv6_rib_edm_path.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv6-rib-edm-path"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.active.is_set or
                                                                self.address.is_set or
                                                                self.attribute_identity.is_set or
                                                                self.client_id.is_set or
                                                                self.distance.is_set or
                                                                self.diversion.is_set or
                                                                self.diversion_distance.is_set or
                                                                self.diversion_proto_name.is_set or
                                                                self.extended_flags.is_set or
                                                                self.flags.is_set or
                                                                self.flow_tag.is_set or
                                                                self.fwd_class.is_set or
                                                                self.instance.is_set or
                                                                self.metric.is_set or
                                                                self.paths_count.is_set or
                                                                self.pic_count.is_set or
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set or
                                                                self.prefix_length_xr.is_set or
                                                                self.priority.is_set or
                                                                self.protocol_id.is_set or
                                                                self.protocol_name.is_set or
                                                                self.qos_group.is_set or
                                                                self.route_age.is_set or
                                                                self.route_label.is_set or
                                                                self.route_modify_time.is_set or
                                                                self.route_precedence.is_set or
                                                                self.route_type.is_set or
                                                                self.route_version.is_set or
                                                                self.svd_type.is_set or
                                                                self.tag.is_set or
                                                                self.tbl_version.is_set or
                                                                self.traffic_index.is_set or
                                                                self.version.is_set or
                                                                (self.route_path is not None and self.route_path.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.active.yfilter != YFilter.not_set or
                                                                self.address.yfilter != YFilter.not_set or
                                                                self.attribute_identity.yfilter != YFilter.not_set or
                                                                self.client_id.yfilter != YFilter.not_set or
                                                                self.distance.yfilter != YFilter.not_set or
                                                                self.diversion.yfilter != YFilter.not_set or
                                                                self.diversion_distance.yfilter != YFilter.not_set or
                                                                self.diversion_proto_name.yfilter != YFilter.not_set or
                                                                self.extended_flags.yfilter != YFilter.not_set or
                                                                self.flags.yfilter != YFilter.not_set or
                                                                self.flow_tag.yfilter != YFilter.not_set or
                                                                self.fwd_class.yfilter != YFilter.not_set or
                                                                self.instance.yfilter != YFilter.not_set or
                                                                self.metric.yfilter != YFilter.not_set or
                                                                self.paths_count.yfilter != YFilter.not_set or
                                                                self.pic_count.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set or
                                                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                                                self.priority.yfilter != YFilter.not_set or
                                                                self.protocol_id.yfilter != YFilter.not_set or
                                                                self.protocol_name.yfilter != YFilter.not_set or
                                                                self.qos_group.yfilter != YFilter.not_set or
                                                                self.route_age.yfilter != YFilter.not_set or
                                                                self.route_label.yfilter != YFilter.not_set or
                                                                self.route_modify_time.yfilter != YFilter.not_set or
                                                                self.route_precedence.yfilter != YFilter.not_set or
                                                                self.route_type.yfilter != YFilter.not_set or
                                                                self.route_version.yfilter != YFilter.not_set or
                                                                self.svd_type.yfilter != YFilter.not_set or
                                                                self.tag.yfilter != YFilter.not_set or
                                                                self.tbl_version.yfilter != YFilter.not_set or
                                                                self.traffic_index.yfilter != YFilter.not_set or
                                                                self.version.yfilter != YFilter.not_set or
                                                                (self.route_path is not None and self.route_path.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "protocol-route" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.active.get_name_leafdata())
                                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.address.get_name_leafdata())
                                                            if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                            if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.client_id.get_name_leafdata())
                                                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.distance.get_name_leafdata())
                                                            if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion.get_name_leafdata())
                                                            if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                            if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                            if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flags.get_name_leafdata())
                                                            if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                            if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.instance.get_name_leafdata())
                                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                                            if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                            if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.priority.get_name_leafdata())
                                                            if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                            if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                            if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_age.get_name_leafdata())
                                                            if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_label.get_name_leafdata())
                                                            if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                            if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_type.get_name_leafdata())
                                                            if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.route_version.get_name_leafdata())
                                                            if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tag.get_name_leafdata())
                                                            if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                            if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                            if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.version.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "route-path"):
                                                                if (self.route_path is None):
                                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                                    self.route_path.parent = self
                                                                    self._children_name_map["route_path"] = "route-path"
                                                                return self.route_path

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "active"):
                                                                self.active = value
                                                                self.active.value_namespace = name_space
                                                                self.active.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "address"):
                                                                self.address = value
                                                                self.address.value_namespace = name_space
                                                                self.address.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "attribute-identity"):
                                                                self.attribute_identity = value
                                                                self.attribute_identity.value_namespace = name_space
                                                                self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "client-id"):
                                                                self.client_id = value
                                                                self.client_id.value_namespace = name_space
                                                                self.client_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "distance"):
                                                                self.distance = value
                                                                self.distance.value_namespace = name_space
                                                                self.distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion"):
                                                                self.diversion = value
                                                                self.diversion.value_namespace = name_space
                                                                self.diversion.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-distance"):
                                                                self.diversion_distance = value
                                                                self.diversion_distance.value_namespace = name_space
                                                                self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "diversion-proto-name"):
                                                                self.diversion_proto_name = value
                                                                self.diversion_proto_name.value_namespace = name_space
                                                                self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "extended-flags"):
                                                                self.extended_flags = value
                                                                self.extended_flags.value_namespace = name_space
                                                                self.extended_flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flags"):
                                                                self.flags = value
                                                                self.flags.value_namespace = name_space
                                                                self.flags.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "flow-tag"):
                                                                self.flow_tag = value
                                                                self.flow_tag.value_namespace = name_space
                                                                self.flow_tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "fwd-class"):
                                                                self.fwd_class = value
                                                                self.fwd_class.value_namespace = name_space
                                                                self.fwd_class.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "instance"):
                                                                self.instance = value
                                                                self.instance.value_namespace = name_space
                                                                self.instance.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "metric"):
                                                                self.metric = value
                                                                self.metric.value_namespace = name_space
                                                                self.metric.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "paths-count"):
                                                                self.paths_count = value
                                                                self.paths_count.value_namespace = name_space
                                                                self.paths_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pic-count"):
                                                                self.pic_count = value
                                                                self.pic_count.value_namespace = name_space
                                                                self.pic_count.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length-xr"):
                                                                self.prefix_length_xr = value
                                                                self.prefix_length_xr.value_namespace = name_space
                                                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "priority"):
                                                                self.priority = value
                                                                self.priority.value_namespace = name_space
                                                                self.priority.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-id"):
                                                                self.protocol_id = value
                                                                self.protocol_id.value_namespace = name_space
                                                                self.protocol_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "protocol-name"):
                                                                self.protocol_name = value
                                                                self.protocol_name.value_namespace = name_space
                                                                self.protocol_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "qos-group"):
                                                                self.qos_group = value
                                                                self.qos_group.value_namespace = name_space
                                                                self.qos_group.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-age"):
                                                                self.route_age = value
                                                                self.route_age.value_namespace = name_space
                                                                self.route_age.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-label"):
                                                                self.route_label = value
                                                                self.route_label.value_namespace = name_space
                                                                self.route_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-modify-time"):
                                                                self.route_modify_time = value
                                                                self.route_modify_time.value_namespace = name_space
                                                                self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-precedence"):
                                                                self.route_precedence = value
                                                                self.route_precedence.value_namespace = name_space
                                                                self.route_precedence.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-type"):
                                                                self.route_type = value
                                                                self.route_type.value_namespace = name_space
                                                                self.route_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "route-version"):
                                                                self.route_version = value
                                                                self.route_version.value_namespace = name_space
                                                                self.route_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "svd-type"):
                                                                self.svd_type = value
                                                                self.svd_type.value_namespace = name_space
                                                                self.svd_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tag"):
                                                                self.tag = value
                                                                self.tag.value_namespace = name_space
                                                                self.tag.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tbl-version"):
                                                                self.tbl_version = value
                                                                self.tbl_version.value_namespace = name_space
                                                                self.tbl_version.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "traffic-index"):
                                                                self.traffic_index = value
                                                                self.traffic_index.value_namespace = name_space
                                                                self.traffic_index.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "version"):
                                                                self.version = value
                                                                self.version.value_namespace = name_space
                                                                self.version.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.protocol_route:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "protocol-routes" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "protocol-route"):
                                                            for c in self.protocol_route:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.protocol_route.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "protocol-route"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.as_.is_set or
                                                        (self.information is not None and self.information.has_data()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.as_.yfilter != YFilter.not_set or
                                                        (self.information is not None and self.information.has_operation()) or
                                                        (self.protocol_routes is not None and self.protocol_routes.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "as" + "[as='" + self.as_.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.as_.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "information"):
                                                        if (self.information is None):
                                                            self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information()
                                                            self.information.parent = self
                                                            self._children_name_map["information"] = "information"
                                                        return self.information

                                                    if (child_yang_name == "protocol-routes"):
                                                        if (self.protocol_routes is None):
                                                            self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes()
                                                            self.protocol_routes.parent = self
                                                            self._children_name_map["protocol_routes"] = "protocol-routes"
                                                        return self.protocol_routes

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "information" or name == "protocol-routes" or name == "as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "as"):
                                                        self.as_ = value
                                                        self.as_.value_namespace = name_space
                                                        self.as_.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.as_:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.as_:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "isis" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "as"):
                                                    for c in self.as_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.as_.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                (self.bgp is not None and self.bgp.has_data()) or
                                                (self.connected is not None and self.connected.has_data()) or
                                                (self.eigrp is not None and self.eigrp.has_data()) or
                                                (self.isis is not None and self.isis.has_data()) or
                                                (self.local is not None and self.local.has_data()) or
                                                (self.mobile is not None and self.mobile.has_data()) or
                                                (self.ospf is not None and self.ospf.has_data()) or
                                                (self.rpl is not None and self.rpl.has_data()) or
                                                (self.static is not None and self.static.has_data()) or
                                                (self.subscriber is not None and self.subscriber.has_data()) or
                                                (self.te_client is not None and self.te_client.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.bgp is not None and self.bgp.has_operation()) or
                                                (self.connected is not None and self.connected.has_operation()) or
                                                (self.eigrp is not None and self.eigrp.has_operation()) or
                                                (self.isis is not None and self.isis.has_operation()) or
                                                (self.local is not None and self.local.has_operation()) or
                                                (self.mobile is not None and self.mobile.has_operation()) or
                                                (self.ospf is not None and self.ospf.has_operation()) or
                                                (self.rpl is not None and self.rpl.has_operation()) or
                                                (self.static is not None and self.static.has_operation()) or
                                                (self.subscriber is not None and self.subscriber.has_operation()) or
                                                (self.te_client is not None and self.te_client.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "protocol" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bgp"):
                                                if (self.bgp is None):
                                                    self.bgp = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                                    self.bgp.parent = self
                                                    self._children_name_map["bgp"] = "bgp"
                                                return self.bgp

                                            if (child_yang_name == "connected"):
                                                if (self.connected is None):
                                                    self.connected = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                                    self.connected.parent = self
                                                    self._children_name_map["connected"] = "connected"
                                                return self.connected

                                            if (child_yang_name == "eigrp"):
                                                if (self.eigrp is None):
                                                    self.eigrp = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                                    self.eigrp.parent = self
                                                    self._children_name_map["eigrp"] = "eigrp"
                                                return self.eigrp

                                            if (child_yang_name == "isis"):
                                                if (self.isis is None):
                                                    self.isis = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"
                                                return self.isis

                                            if (child_yang_name == "local"):
                                                if (self.local is None):
                                                    self.local = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                                    self.local.parent = self
                                                    self._children_name_map["local"] = "local"
                                                return self.local

                                            if (child_yang_name == "mobile"):
                                                if (self.mobile is None):
                                                    self.mobile = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                                    self.mobile.parent = self
                                                    self._children_name_map["mobile"] = "mobile"
                                                return self.mobile

                                            if (child_yang_name == "ospf"):
                                                if (self.ospf is None):
                                                    self.ospf = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                                    self.ospf.parent = self
                                                    self._children_name_map["ospf"] = "ospf"
                                                return self.ospf

                                            if (child_yang_name == "rpl"):
                                                if (self.rpl is None):
                                                    self.rpl = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                                    self.rpl.parent = self
                                                    self._children_name_map["rpl"] = "rpl"
                                                return self.rpl

                                            if (child_yang_name == "static"):
                                                if (self.static is None):
                                                    self.static = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                                    self.static.parent = self
                                                    self._children_name_map["static"] = "static"
                                                return self.static

                                            if (child_yang_name == "subscriber"):
                                                if (self.subscriber is None):
                                                    self.subscriber = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                                    self.subscriber.parent = self
                                                    self._children_name_map["subscriber"] = "subscriber"
                                                return self.subscriber

                                            if (child_yang_name == "te-client"):
                                                if (self.te_client is None):
                                                    self.te_client = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                                    self.te_client.parent = self
                                                    self._children_name_map["te_client"] = "te-client"
                                                return self.te_client

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bgp" or name == "connected" or name == "eigrp" or name == "isis" or name == "local" or name == "mobile" or name == "ospf" or name == "rpl" or name == "static" or name == "subscriber" or name == "te-client"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Routes(Entity):
                                        """
                                        Route information 
                                        
                                        .. attribute:: route
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__init__()

                                            self.yang_name = "routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__setattr__(name, value)


                                        class Route(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: interface_name
                                            
                                            	Outgoing Interface 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	NextHop Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__init__()

                                                self.yang_name = "route"
                                                self.yang_parent_name = "routes"

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("active",
                                                                "address",
                                                                "attribute_identity",
                                                                "client_id",
                                                                "distance",
                                                                "diversion",
                                                                "diversion_distance",
                                                                "diversion_proto_name",
                                                                "extended_flags",
                                                                "flags",
                                                                "flow_tag",
                                                                "fwd_class",
                                                                "instance",
                                                                "interface_name",
                                                                "metric",
                                                                "next_hop_address",
                                                                "paths_count",
                                                                "pic_count",
                                                                "prefix",
                                                                "prefix_length",
                                                                "prefix_length_xr",
                                                                "priority",
                                                                "protocol_id",
                                                                "protocol_name",
                                                                "qos_group",
                                                                "route_age",
                                                                "route_label",
                                                                "route_modify_time",
                                                                "route_precedence",
                                                                "route_type",
                                                                "route_version",
                                                                "svd_type",
                                                                "tag",
                                                                "tbl_version",
                                                                "traffic_index",
                                                                "version") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__setattr__(name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "route"

                                                    self.ipv6_rib_edm_path = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__setattr__(name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("address",
                                                                        "backup_pathid",
                                                                        "binding_label",
                                                                        "flags",
                                                                        "flags64",
                                                                        "has_labelstk",
                                                                        "information_source",
                                                                        "interface_name",
                                                                        "labelstk",
                                                                        "load_metric",
                                                                        "looped",
                                                                        "metric",
                                                                        "mpls_feid",
                                                                        "mvpn_present",
                                                                        "next_hop_afi",
                                                                        "next_hop_id",
                                                                        "next_hop_id_refcount",
                                                                        "next_hop_safi",
                                                                        "next_hop_table_id",
                                                                        "next_hop_table_name",
                                                                        "next_hop_vrf_name",
                                                                        "nhid_feid",
                                                                        "num_labels",
                                                                        "number_of_extended_communities",
                                                                        "ospf_area_id",
                                                                        "path_rt_present",
                                                                        "pathid",
                                                                        "private_flags",
                                                                        "ref_cnt_of_backup",
                                                                        "remote_backup_addr",
                                                                        "route_label",
                                                                        "segmented_nexthop_present",
                                                                        "source_asrt_present",
                                                                        "source_rd_present",
                                                                        "tunnel_id",
                                                                        "v6_information_source",
                                                                        "v6_nexthop",
                                                                        "vrf_import_rt_present") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        return (
                                                            self.address.is_set or
                                                            self.backup_pathid.is_set or
                                                            self.binding_label.is_set or
                                                            self.flags.is_set or
                                                            self.flags64.is_set or
                                                            self.has_labelstk.is_set or
                                                            self.information_source.is_set or
                                                            self.interface_name.is_set or
                                                            self.load_metric.is_set or
                                                            self.looped.is_set or
                                                            self.metric.is_set or
                                                            self.mpls_feid.is_set or
                                                            self.mvpn_present.is_set or
                                                            self.next_hop_afi.is_set or
                                                            self.next_hop_id.is_set or
                                                            self.next_hop_id_refcount.is_set or
                                                            self.next_hop_safi.is_set or
                                                            self.next_hop_table_id.is_set or
                                                            self.next_hop_table_name.is_set or
                                                            self.next_hop_vrf_name.is_set or
                                                            self.nhid_feid.is_set or
                                                            self.num_labels.is_set or
                                                            self.number_of_extended_communities.is_set or
                                                            self.ospf_area_id.is_set or
                                                            self.path_rt_present.is_set or
                                                            self.pathid.is_set or
                                                            self.private_flags.is_set or
                                                            self.ref_cnt_of_backup.is_set or
                                                            self.route_label.is_set or
                                                            self.segmented_nexthop_present.is_set or
                                                            self.source_asrt_present.is_set or
                                                            self.source_rd_present.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.v6_information_source.is_set or
                                                            self.v6_nexthop.is_set or
                                                            self.vrf_import_rt_present.is_set)

                                                    def has_operation(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.address.yfilter != YFilter.not_set or
                                                            self.backup_pathid.yfilter != YFilter.not_set or
                                                            self.binding_label.yfilter != YFilter.not_set or
                                                            self.flags.yfilter != YFilter.not_set or
                                                            self.flags64.yfilter != YFilter.not_set or
                                                            self.has_labelstk.yfilter != YFilter.not_set or
                                                            self.information_source.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.labelstk.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.looped.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.mpls_feid.yfilter != YFilter.not_set or
                                                            self.mvpn_present.yfilter != YFilter.not_set or
                                                            self.next_hop_afi.yfilter != YFilter.not_set or
                                                            self.next_hop_id.yfilter != YFilter.not_set or
                                                            self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                            self.next_hop_safi.yfilter != YFilter.not_set or
                                                            self.next_hop_table_id.yfilter != YFilter.not_set or
                                                            self.next_hop_table_name.yfilter != YFilter.not_set or
                                                            self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                            self.nhid_feid.yfilter != YFilter.not_set or
                                                            self.num_labels.yfilter != YFilter.not_set or
                                                            self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                            self.ospf_area_id.yfilter != YFilter.not_set or
                                                            self.path_rt_present.yfilter != YFilter.not_set or
                                                            self.pathid.yfilter != YFilter.not_set or
                                                            self.private_flags.yfilter != YFilter.not_set or
                                                            self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                            self.remote_backup_addr.yfilter != YFilter.not_set or
                                                            self.route_label.yfilter != YFilter.not_set or
                                                            self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                            self.source_asrt_present.yfilter != YFilter.not_set or
                                                            self.source_rd_present.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.v6_information_source.yfilter != YFilter.not_set or
                                                            self.v6_nexthop.yfilter != YFilter.not_set or
                                                            self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.address.get_name_leafdata())
                                                        if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                        if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                        if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags.get_name_leafdata())
                                                        if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags64.get_name_leafdata())
                                                        if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                        if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.information_source.get_name_leafdata())
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.looped.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                        if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                        if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                        if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                        if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                        if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                        if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                        if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                        if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                        if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                        if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                        if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                        if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                        if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                        if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pathid.get_name_leafdata())
                                                        if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                        if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                        if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.route_label.get_name_leafdata())
                                                        if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                        if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                        if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                        if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                        if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                        leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                        leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "address"):
                                                            self.address = value
                                                            self.address.value_namespace = name_space
                                                            self.address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-pathid"):
                                                            self.backup_pathid = value
                                                            self.backup_pathid.value_namespace = name_space
                                                            self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "binding-label"):
                                                            self.binding_label = value
                                                            self.binding_label.value_namespace = name_space
                                                            self.binding_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags"):
                                                            self.flags = value
                                                            self.flags.value_namespace = name_space
                                                            self.flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags64"):
                                                            self.flags64 = value
                                                            self.flags64.value_namespace = name_space
                                                            self.flags64.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "has-labelstk"):
                                                            self.has_labelstk = value
                                                            self.has_labelstk.value_namespace = name_space
                                                            self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "information-source"):
                                                            self.information_source = value
                                                            self.information_source.value_namespace = name_space
                                                            self.information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "labelstk"):
                                                            self.labelstk.append(value)
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "looped"):
                                                            self.looped = value
                                                            self.looped.value_namespace = name_space
                                                            self.looped.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-feid"):
                                                            self.mpls_feid = value
                                                            self.mpls_feid.value_namespace = name_space
                                                            self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mvpn-present"):
                                                            self.mvpn_present = value
                                                            self.mvpn_present.value_namespace = name_space
                                                            self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-afi"):
                                                            self.next_hop_afi = value
                                                            self.next_hop_afi.value_namespace = name_space
                                                            self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id"):
                                                            self.next_hop_id = value
                                                            self.next_hop_id.value_namespace = name_space
                                                            self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id-refcount"):
                                                            self.next_hop_id_refcount = value
                                                            self.next_hop_id_refcount.value_namespace = name_space
                                                            self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-safi"):
                                                            self.next_hop_safi = value
                                                            self.next_hop_safi.value_namespace = name_space
                                                            self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-id"):
                                                            self.next_hop_table_id = value
                                                            self.next_hop_table_id.value_namespace = name_space
                                                            self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-name"):
                                                            self.next_hop_table_name = value
                                                            self.next_hop_table_name.value_namespace = name_space
                                                            self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-vrf-name"):
                                                            self.next_hop_vrf_name = value
                                                            self.next_hop_vrf_name.value_namespace = name_space
                                                            self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "nhid-feid"):
                                                            self.nhid_feid = value
                                                            self.nhid_feid.value_namespace = name_space
                                                            self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-labels"):
                                                            self.num_labels = value
                                                            self.num_labels.value_namespace = name_space
                                                            self.num_labels.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "number-of-extended-communities"):
                                                            self.number_of_extended_communities = value
                                                            self.number_of_extended_communities.value_namespace = name_space
                                                            self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ospf-area-id"):
                                                            self.ospf_area_id = value
                                                            self.ospf_area_id.value_namespace = name_space
                                                            self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "path-rt-present"):
                                                            self.path_rt_present = value
                                                            self.path_rt_present.value_namespace = name_space
                                                            self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pathid"):
                                                            self.pathid = value
                                                            self.pathid.value_namespace = name_space
                                                            self.pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "private-flags"):
                                                            self.private_flags = value
                                                            self.private_flags.value_namespace = name_space
                                                            self.private_flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ref-cnt-of-backup"):
                                                            self.ref_cnt_of_backup = value
                                                            self.ref_cnt_of_backup.value_namespace = name_space
                                                            self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-backup-addr"):
                                                            self.remote_backup_addr.append(value)
                                                        if(value_path == "route-label"):
                                                            self.route_label = value
                                                            self.route_label.value_namespace = name_space
                                                            self.route_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segmented-nexthop-present"):
                                                            self.segmented_nexthop_present = value
                                                            self.segmented_nexthop_present.value_namespace = name_space
                                                            self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-asrt-present"):
                                                            self.source_asrt_present = value
                                                            self.source_asrt_present.value_namespace = name_space
                                                            self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-rd-present"):
                                                            self.source_rd_present = value
                                                            self.source_rd_present.value_namespace = name_space
                                                            self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-information-source"):
                                                            self.v6_information_source = value
                                                            self.v6_information_source.value_namespace = name_space
                                                            self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-nexthop"):
                                                            self.v6_nexthop = value
                                                            self.v6_nexthop.value_namespace = name_space
                                                            self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-import-rt-present"):
                                                            self.vrf_import_rt_present = value
                                                            self.vrf_import_rt_present.value_namespace = name_space
                                                            self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv6-rib-edm-path"):
                                                        for c in self.ipv6_rib_edm_path:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.ipv6_rib_edm_path.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv6-rib-edm-path"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.active.is_set or
                                                    self.address.is_set or
                                                    self.attribute_identity.is_set or
                                                    self.client_id.is_set or
                                                    self.distance.is_set or
                                                    self.diversion.is_set or
                                                    self.diversion_distance.is_set or
                                                    self.diversion_proto_name.is_set or
                                                    self.extended_flags.is_set or
                                                    self.flags.is_set or
                                                    self.flow_tag.is_set or
                                                    self.fwd_class.is_set or
                                                    self.instance.is_set or
                                                    self.interface_name.is_set or
                                                    self.metric.is_set or
                                                    self.next_hop_address.is_set or
                                                    self.paths_count.is_set or
                                                    self.pic_count.is_set or
                                                    self.prefix.is_set or
                                                    self.prefix_length.is_set or
                                                    self.prefix_length_xr.is_set or
                                                    self.priority.is_set or
                                                    self.protocol_id.is_set or
                                                    self.protocol_name.is_set or
                                                    self.qos_group.is_set or
                                                    self.route_age.is_set or
                                                    self.route_label.is_set or
                                                    self.route_modify_time.is_set or
                                                    self.route_precedence.is_set or
                                                    self.route_type.is_set or
                                                    self.route_version.is_set or
                                                    self.svd_type.is_set or
                                                    self.tag.is_set or
                                                    self.tbl_version.is_set or
                                                    self.traffic_index.is_set or
                                                    self.version.is_set or
                                                    (self.route_path is not None and self.route_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.active.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.attribute_identity.yfilter != YFilter.not_set or
                                                    self.client_id.yfilter != YFilter.not_set or
                                                    self.distance.yfilter != YFilter.not_set or
                                                    self.diversion.yfilter != YFilter.not_set or
                                                    self.diversion_distance.yfilter != YFilter.not_set or
                                                    self.diversion_proto_name.yfilter != YFilter.not_set or
                                                    self.extended_flags.yfilter != YFilter.not_set or
                                                    self.flags.yfilter != YFilter.not_set or
                                                    self.flow_tag.yfilter != YFilter.not_set or
                                                    self.fwd_class.yfilter != YFilter.not_set or
                                                    self.instance.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.next_hop_address.yfilter != YFilter.not_set or
                                                    self.paths_count.yfilter != YFilter.not_set or
                                                    self.pic_count.yfilter != YFilter.not_set or
                                                    self.prefix.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set or
                                                    self.prefix_length_xr.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set or
                                                    self.protocol_id.yfilter != YFilter.not_set or
                                                    self.protocol_name.yfilter != YFilter.not_set or
                                                    self.qos_group.yfilter != YFilter.not_set or
                                                    self.route_age.yfilter != YFilter.not_set or
                                                    self.route_label.yfilter != YFilter.not_set or
                                                    self.route_modify_time.yfilter != YFilter.not_set or
                                                    self.route_precedence.yfilter != YFilter.not_set or
                                                    self.route_type.yfilter != YFilter.not_set or
                                                    self.route_version.yfilter != YFilter.not_set or
                                                    self.svd_type.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tbl_version.yfilter != YFilter.not_set or
                                                    self.traffic_index.yfilter != YFilter.not_set or
                                                    self.version.yfilter != YFilter.not_set or
                                                    (self.route_path is not None and self.route_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.active.get_name_leafdata())
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.client_id.get_name_leafdata())
                                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.distance.get_name_leafdata())
                                                if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion.get_name_leafdata())
                                                if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                                if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                                if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                                if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_age.get_name_leafdata())
                                                if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_label.get_name_leafdata())
                                                if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_type.get_name_leafdata())
                                                if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_version.get_name_leafdata())
                                                if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.version.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-path"):
                                                    if (self.route_path is None):
                                                        self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                        self.route_path.parent = self
                                                        self._children_name_map["route_path"] = "route-path"
                                                    return self.route_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "interface-name" or name == "metric" or name == "next-hop-address" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "active"):
                                                    self.active = value
                                                    self.active.value_namespace = name_space
                                                    self.active.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "attribute-identity"):
                                                    self.attribute_identity = value
                                                    self.attribute_identity.value_namespace = name_space
                                                    self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                if(value_path == "client-id"):
                                                    self.client_id = value
                                                    self.client_id.value_namespace = name_space
                                                    self.client_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "distance"):
                                                    self.distance = value
                                                    self.distance.value_namespace = name_space
                                                    self.distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion"):
                                                    self.diversion = value
                                                    self.diversion.value_namespace = name_space
                                                    self.diversion.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-distance"):
                                                    self.diversion_distance = value
                                                    self.diversion_distance.value_namespace = name_space
                                                    self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-proto-name"):
                                                    self.diversion_proto_name = value
                                                    self.diversion_proto_name.value_namespace = name_space
                                                    self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "extended-flags"):
                                                    self.extended_flags = value
                                                    self.extended_flags.value_namespace = name_space
                                                    self.extended_flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flags"):
                                                    self.flags = value
                                                    self.flags.value_namespace = name_space
                                                    self.flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flow-tag"):
                                                    self.flow_tag = value
                                                    self.flow_tag.value_namespace = name_space
                                                    self.flow_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fwd-class"):
                                                    self.fwd_class = value
                                                    self.fwd_class.value_namespace = name_space
                                                    self.fwd_class.value_namespace_prefix = name_space_prefix
                                                if(value_path == "instance"):
                                                    self.instance = value
                                                    self.instance.value_namespace = name_space
                                                    self.instance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "next-hop-address"):
                                                    self.next_hop_address = value
                                                    self.next_hop_address.value_namespace = name_space
                                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "paths-count"):
                                                    self.paths_count = value
                                                    self.paths_count.value_namespace = name_space
                                                    self.paths_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pic-count"):
                                                    self.pic_count = value
                                                    self.pic_count.value_namespace = name_space
                                                    self.pic_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix"):
                                                    self.prefix = value
                                                    self.prefix.value_namespace = name_space
                                                    self.prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length-xr"):
                                                    self.prefix_length_xr = value
                                                    self.prefix_length_xr.value_namespace = name_space
                                                    self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-id"):
                                                    self.protocol_id = value
                                                    self.protocol_id.value_namespace = name_space
                                                    self.protocol_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-name"):
                                                    self.protocol_name = value
                                                    self.protocol_name.value_namespace = name_space
                                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "qos-group"):
                                                    self.qos_group = value
                                                    self.qos_group.value_namespace = name_space
                                                    self.qos_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-age"):
                                                    self.route_age = value
                                                    self.route_age.value_namespace = name_space
                                                    self.route_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-label"):
                                                    self.route_label = value
                                                    self.route_label.value_namespace = name_space
                                                    self.route_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-modify-time"):
                                                    self.route_modify_time = value
                                                    self.route_modify_time.value_namespace = name_space
                                                    self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-precedence"):
                                                    self.route_precedence = value
                                                    self.route_precedence.value_namespace = name_space
                                                    self.route_precedence.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-type"):
                                                    self.route_type = value
                                                    self.route_type.value_namespace = name_space
                                                    self.route_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-version"):
                                                    self.route_version = value
                                                    self.route_version.value_namespace = name_space
                                                    self.route_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "svd-type"):
                                                    self.svd_type = value
                                                    self.svd_type.value_namespace = name_space
                                                    self.svd_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tbl-version"):
                                                    self.tbl_version = value
                                                    self.tbl_version.value_namespace = name_space
                                                    self.tbl_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "traffic-index"):
                                                    self.traffic_index = value
                                                    self.traffic_index.value_namespace = name_space
                                                    self.traffic_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "version"):
                                                    self.version = value
                                                    self.version.value_namespace = name_space
                                                    self.version.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route"):
                                                for c in self.route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class QRoutes(Entity):
                                        """
                                        Quarantine
                                        
                                        .. attribute:: q_route
                                        
                                        	Route information for a specific quarantined address 
                                        	**type**\: list of    :py:class:`QRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__init__()

                                            self.yang_name = "q-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.q_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__setattr__(name, value)


                                        class QRoute(Entity):
                                            """
                                            Route information for a specific
                                            quarantined address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__init__()

                                                self.yang_name = "q-route"
                                                self.yang_parent_name = "q-routes"

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("active",
                                                                "address",
                                                                "attribute_identity",
                                                                "client_id",
                                                                "distance",
                                                                "diversion",
                                                                "diversion_distance",
                                                                "diversion_proto_name",
                                                                "extended_flags",
                                                                "flags",
                                                                "flow_tag",
                                                                "fwd_class",
                                                                "instance",
                                                                "metric",
                                                                "paths_count",
                                                                "pic_count",
                                                                "prefix",
                                                                "prefix_length",
                                                                "prefix_length_xr",
                                                                "priority",
                                                                "protocol_id",
                                                                "protocol_name",
                                                                "qos_group",
                                                                "route_age",
                                                                "route_label",
                                                                "route_modify_time",
                                                                "route_precedence",
                                                                "route_type",
                                                                "route_version",
                                                                "svd_type",
                                                                "tag",
                                                                "tbl_version",
                                                                "traffic_index",
                                                                "version") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__setattr__(name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "q-route"

                                                    self.ipv6_rib_edm_path = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__setattr__(name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("address",
                                                                        "backup_pathid",
                                                                        "binding_label",
                                                                        "flags",
                                                                        "flags64",
                                                                        "has_labelstk",
                                                                        "information_source",
                                                                        "interface_name",
                                                                        "labelstk",
                                                                        "load_metric",
                                                                        "looped",
                                                                        "metric",
                                                                        "mpls_feid",
                                                                        "mvpn_present",
                                                                        "next_hop_afi",
                                                                        "next_hop_id",
                                                                        "next_hop_id_refcount",
                                                                        "next_hop_safi",
                                                                        "next_hop_table_id",
                                                                        "next_hop_table_name",
                                                                        "next_hop_vrf_name",
                                                                        "nhid_feid",
                                                                        "num_labels",
                                                                        "number_of_extended_communities",
                                                                        "ospf_area_id",
                                                                        "path_rt_present",
                                                                        "pathid",
                                                                        "private_flags",
                                                                        "ref_cnt_of_backup",
                                                                        "remote_backup_addr",
                                                                        "route_label",
                                                                        "segmented_nexthop_present",
                                                                        "source_asrt_present",
                                                                        "source_rd_present",
                                                                        "tunnel_id",
                                                                        "v6_information_source",
                                                                        "v6_nexthop",
                                                                        "vrf_import_rt_present") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        return (
                                                            self.address.is_set or
                                                            self.backup_pathid.is_set or
                                                            self.binding_label.is_set or
                                                            self.flags.is_set or
                                                            self.flags64.is_set or
                                                            self.has_labelstk.is_set or
                                                            self.information_source.is_set or
                                                            self.interface_name.is_set or
                                                            self.load_metric.is_set or
                                                            self.looped.is_set or
                                                            self.metric.is_set or
                                                            self.mpls_feid.is_set or
                                                            self.mvpn_present.is_set or
                                                            self.next_hop_afi.is_set or
                                                            self.next_hop_id.is_set or
                                                            self.next_hop_id_refcount.is_set or
                                                            self.next_hop_safi.is_set or
                                                            self.next_hop_table_id.is_set or
                                                            self.next_hop_table_name.is_set or
                                                            self.next_hop_vrf_name.is_set or
                                                            self.nhid_feid.is_set or
                                                            self.num_labels.is_set or
                                                            self.number_of_extended_communities.is_set or
                                                            self.ospf_area_id.is_set or
                                                            self.path_rt_present.is_set or
                                                            self.pathid.is_set or
                                                            self.private_flags.is_set or
                                                            self.ref_cnt_of_backup.is_set or
                                                            self.route_label.is_set or
                                                            self.segmented_nexthop_present.is_set or
                                                            self.source_asrt_present.is_set or
                                                            self.source_rd_present.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.v6_information_source.is_set or
                                                            self.v6_nexthop.is_set or
                                                            self.vrf_import_rt_present.is_set)

                                                    def has_operation(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.address.yfilter != YFilter.not_set or
                                                            self.backup_pathid.yfilter != YFilter.not_set or
                                                            self.binding_label.yfilter != YFilter.not_set or
                                                            self.flags.yfilter != YFilter.not_set or
                                                            self.flags64.yfilter != YFilter.not_set or
                                                            self.has_labelstk.yfilter != YFilter.not_set or
                                                            self.information_source.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.labelstk.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.looped.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.mpls_feid.yfilter != YFilter.not_set or
                                                            self.mvpn_present.yfilter != YFilter.not_set or
                                                            self.next_hop_afi.yfilter != YFilter.not_set or
                                                            self.next_hop_id.yfilter != YFilter.not_set or
                                                            self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                            self.next_hop_safi.yfilter != YFilter.not_set or
                                                            self.next_hop_table_id.yfilter != YFilter.not_set or
                                                            self.next_hop_table_name.yfilter != YFilter.not_set or
                                                            self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                            self.nhid_feid.yfilter != YFilter.not_set or
                                                            self.num_labels.yfilter != YFilter.not_set or
                                                            self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                            self.ospf_area_id.yfilter != YFilter.not_set or
                                                            self.path_rt_present.yfilter != YFilter.not_set or
                                                            self.pathid.yfilter != YFilter.not_set or
                                                            self.private_flags.yfilter != YFilter.not_set or
                                                            self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                            self.remote_backup_addr.yfilter != YFilter.not_set or
                                                            self.route_label.yfilter != YFilter.not_set or
                                                            self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                            self.source_asrt_present.yfilter != YFilter.not_set or
                                                            self.source_rd_present.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.v6_information_source.yfilter != YFilter.not_set or
                                                            self.v6_nexthop.yfilter != YFilter.not_set or
                                                            self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.address.get_name_leafdata())
                                                        if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                        if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                        if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags.get_name_leafdata())
                                                        if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags64.get_name_leafdata())
                                                        if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                        if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.information_source.get_name_leafdata())
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.looped.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                        if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                        if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                        if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                        if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                        if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                        if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                        if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                        if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                        if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                        if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                        if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                        if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                        if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                        if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pathid.get_name_leafdata())
                                                        if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                        if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                        if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.route_label.get_name_leafdata())
                                                        if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                        if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                        if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                        if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                        if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                        leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                        leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "address"):
                                                            self.address = value
                                                            self.address.value_namespace = name_space
                                                            self.address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-pathid"):
                                                            self.backup_pathid = value
                                                            self.backup_pathid.value_namespace = name_space
                                                            self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "binding-label"):
                                                            self.binding_label = value
                                                            self.binding_label.value_namespace = name_space
                                                            self.binding_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags"):
                                                            self.flags = value
                                                            self.flags.value_namespace = name_space
                                                            self.flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags64"):
                                                            self.flags64 = value
                                                            self.flags64.value_namespace = name_space
                                                            self.flags64.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "has-labelstk"):
                                                            self.has_labelstk = value
                                                            self.has_labelstk.value_namespace = name_space
                                                            self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "information-source"):
                                                            self.information_source = value
                                                            self.information_source.value_namespace = name_space
                                                            self.information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "labelstk"):
                                                            self.labelstk.append(value)
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "looped"):
                                                            self.looped = value
                                                            self.looped.value_namespace = name_space
                                                            self.looped.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-feid"):
                                                            self.mpls_feid = value
                                                            self.mpls_feid.value_namespace = name_space
                                                            self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mvpn-present"):
                                                            self.mvpn_present = value
                                                            self.mvpn_present.value_namespace = name_space
                                                            self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-afi"):
                                                            self.next_hop_afi = value
                                                            self.next_hop_afi.value_namespace = name_space
                                                            self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id"):
                                                            self.next_hop_id = value
                                                            self.next_hop_id.value_namespace = name_space
                                                            self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id-refcount"):
                                                            self.next_hop_id_refcount = value
                                                            self.next_hop_id_refcount.value_namespace = name_space
                                                            self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-safi"):
                                                            self.next_hop_safi = value
                                                            self.next_hop_safi.value_namespace = name_space
                                                            self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-id"):
                                                            self.next_hop_table_id = value
                                                            self.next_hop_table_id.value_namespace = name_space
                                                            self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-name"):
                                                            self.next_hop_table_name = value
                                                            self.next_hop_table_name.value_namespace = name_space
                                                            self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-vrf-name"):
                                                            self.next_hop_vrf_name = value
                                                            self.next_hop_vrf_name.value_namespace = name_space
                                                            self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "nhid-feid"):
                                                            self.nhid_feid = value
                                                            self.nhid_feid.value_namespace = name_space
                                                            self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-labels"):
                                                            self.num_labels = value
                                                            self.num_labels.value_namespace = name_space
                                                            self.num_labels.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "number-of-extended-communities"):
                                                            self.number_of_extended_communities = value
                                                            self.number_of_extended_communities.value_namespace = name_space
                                                            self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ospf-area-id"):
                                                            self.ospf_area_id = value
                                                            self.ospf_area_id.value_namespace = name_space
                                                            self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "path-rt-present"):
                                                            self.path_rt_present = value
                                                            self.path_rt_present.value_namespace = name_space
                                                            self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pathid"):
                                                            self.pathid = value
                                                            self.pathid.value_namespace = name_space
                                                            self.pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "private-flags"):
                                                            self.private_flags = value
                                                            self.private_flags.value_namespace = name_space
                                                            self.private_flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ref-cnt-of-backup"):
                                                            self.ref_cnt_of_backup = value
                                                            self.ref_cnt_of_backup.value_namespace = name_space
                                                            self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-backup-addr"):
                                                            self.remote_backup_addr.append(value)
                                                        if(value_path == "route-label"):
                                                            self.route_label = value
                                                            self.route_label.value_namespace = name_space
                                                            self.route_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segmented-nexthop-present"):
                                                            self.segmented_nexthop_present = value
                                                            self.segmented_nexthop_present.value_namespace = name_space
                                                            self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-asrt-present"):
                                                            self.source_asrt_present = value
                                                            self.source_asrt_present.value_namespace = name_space
                                                            self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-rd-present"):
                                                            self.source_rd_present = value
                                                            self.source_rd_present.value_namespace = name_space
                                                            self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-information-source"):
                                                            self.v6_information_source = value
                                                            self.v6_information_source.value_namespace = name_space
                                                            self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-nexthop"):
                                                            self.v6_nexthop = value
                                                            self.v6_nexthop.value_namespace = name_space
                                                            self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-import-rt-present"):
                                                            self.vrf_import_rt_present = value
                                                            self.vrf_import_rt_present.value_namespace = name_space
                                                            self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv6-rib-edm-path"):
                                                        for c in self.ipv6_rib_edm_path:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.ipv6_rib_edm_path.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv6-rib-edm-path"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.active.is_set or
                                                    self.address.is_set or
                                                    self.attribute_identity.is_set or
                                                    self.client_id.is_set or
                                                    self.distance.is_set or
                                                    self.diversion.is_set or
                                                    self.diversion_distance.is_set or
                                                    self.diversion_proto_name.is_set or
                                                    self.extended_flags.is_set or
                                                    self.flags.is_set or
                                                    self.flow_tag.is_set or
                                                    self.fwd_class.is_set or
                                                    self.instance.is_set or
                                                    self.metric.is_set or
                                                    self.paths_count.is_set or
                                                    self.pic_count.is_set or
                                                    self.prefix.is_set or
                                                    self.prefix_length.is_set or
                                                    self.prefix_length_xr.is_set or
                                                    self.priority.is_set or
                                                    self.protocol_id.is_set or
                                                    self.protocol_name.is_set or
                                                    self.qos_group.is_set or
                                                    self.route_age.is_set or
                                                    self.route_label.is_set or
                                                    self.route_modify_time.is_set or
                                                    self.route_precedence.is_set or
                                                    self.route_type.is_set or
                                                    self.route_version.is_set or
                                                    self.svd_type.is_set or
                                                    self.tag.is_set or
                                                    self.tbl_version.is_set or
                                                    self.traffic_index.is_set or
                                                    self.version.is_set or
                                                    (self.route_path is not None and self.route_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.active.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.attribute_identity.yfilter != YFilter.not_set or
                                                    self.client_id.yfilter != YFilter.not_set or
                                                    self.distance.yfilter != YFilter.not_set or
                                                    self.diversion.yfilter != YFilter.not_set or
                                                    self.diversion_distance.yfilter != YFilter.not_set or
                                                    self.diversion_proto_name.yfilter != YFilter.not_set or
                                                    self.extended_flags.yfilter != YFilter.not_set or
                                                    self.flags.yfilter != YFilter.not_set or
                                                    self.flow_tag.yfilter != YFilter.not_set or
                                                    self.fwd_class.yfilter != YFilter.not_set or
                                                    self.instance.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.paths_count.yfilter != YFilter.not_set or
                                                    self.pic_count.yfilter != YFilter.not_set or
                                                    self.prefix.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set or
                                                    self.prefix_length_xr.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set or
                                                    self.protocol_id.yfilter != YFilter.not_set or
                                                    self.protocol_name.yfilter != YFilter.not_set or
                                                    self.qos_group.yfilter != YFilter.not_set or
                                                    self.route_age.yfilter != YFilter.not_set or
                                                    self.route_label.yfilter != YFilter.not_set or
                                                    self.route_modify_time.yfilter != YFilter.not_set or
                                                    self.route_precedence.yfilter != YFilter.not_set or
                                                    self.route_type.yfilter != YFilter.not_set or
                                                    self.route_version.yfilter != YFilter.not_set or
                                                    self.svd_type.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tbl_version.yfilter != YFilter.not_set or
                                                    self.traffic_index.yfilter != YFilter.not_set or
                                                    self.version.yfilter != YFilter.not_set or
                                                    (self.route_path is not None and self.route_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "q-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.active.get_name_leafdata())
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.client_id.get_name_leafdata())
                                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.distance.get_name_leafdata())
                                                if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion.get_name_leafdata())
                                                if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                                if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                                if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_age.get_name_leafdata())
                                                if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_label.get_name_leafdata())
                                                if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_type.get_name_leafdata())
                                                if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_version.get_name_leafdata())
                                                if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.version.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-path"):
                                                    if (self.route_path is None):
                                                        self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                        self.route_path.parent = self
                                                        self._children_name_map["route_path"] = "route-path"
                                                    return self.route_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "active"):
                                                    self.active = value
                                                    self.active.value_namespace = name_space
                                                    self.active.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "attribute-identity"):
                                                    self.attribute_identity = value
                                                    self.attribute_identity.value_namespace = name_space
                                                    self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                if(value_path == "client-id"):
                                                    self.client_id = value
                                                    self.client_id.value_namespace = name_space
                                                    self.client_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "distance"):
                                                    self.distance = value
                                                    self.distance.value_namespace = name_space
                                                    self.distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion"):
                                                    self.diversion = value
                                                    self.diversion.value_namespace = name_space
                                                    self.diversion.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-distance"):
                                                    self.diversion_distance = value
                                                    self.diversion_distance.value_namespace = name_space
                                                    self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-proto-name"):
                                                    self.diversion_proto_name = value
                                                    self.diversion_proto_name.value_namespace = name_space
                                                    self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "extended-flags"):
                                                    self.extended_flags = value
                                                    self.extended_flags.value_namespace = name_space
                                                    self.extended_flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flags"):
                                                    self.flags = value
                                                    self.flags.value_namespace = name_space
                                                    self.flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flow-tag"):
                                                    self.flow_tag = value
                                                    self.flow_tag.value_namespace = name_space
                                                    self.flow_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fwd-class"):
                                                    self.fwd_class = value
                                                    self.fwd_class.value_namespace = name_space
                                                    self.fwd_class.value_namespace_prefix = name_space_prefix
                                                if(value_path == "instance"):
                                                    self.instance = value
                                                    self.instance.value_namespace = name_space
                                                    self.instance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "paths-count"):
                                                    self.paths_count = value
                                                    self.paths_count.value_namespace = name_space
                                                    self.paths_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pic-count"):
                                                    self.pic_count = value
                                                    self.pic_count.value_namespace = name_space
                                                    self.pic_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix"):
                                                    self.prefix = value
                                                    self.prefix.value_namespace = name_space
                                                    self.prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length-xr"):
                                                    self.prefix_length_xr = value
                                                    self.prefix_length_xr.value_namespace = name_space
                                                    self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-id"):
                                                    self.protocol_id = value
                                                    self.protocol_id.value_namespace = name_space
                                                    self.protocol_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-name"):
                                                    self.protocol_name = value
                                                    self.protocol_name.value_namespace = name_space
                                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "qos-group"):
                                                    self.qos_group = value
                                                    self.qos_group.value_namespace = name_space
                                                    self.qos_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-age"):
                                                    self.route_age = value
                                                    self.route_age.value_namespace = name_space
                                                    self.route_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-label"):
                                                    self.route_label = value
                                                    self.route_label.value_namespace = name_space
                                                    self.route_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-modify-time"):
                                                    self.route_modify_time = value
                                                    self.route_modify_time.value_namespace = name_space
                                                    self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-precedence"):
                                                    self.route_precedence = value
                                                    self.route_precedence.value_namespace = name_space
                                                    self.route_precedence.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-type"):
                                                    self.route_type = value
                                                    self.route_type.value_namespace = name_space
                                                    self.route_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-version"):
                                                    self.route_version = value
                                                    self.route_version.value_namespace = name_space
                                                    self.route_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "svd-type"):
                                                    self.svd_type = value
                                                    self.svd_type.value_namespace = name_space
                                                    self.svd_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tbl-version"):
                                                    self.tbl_version = value
                                                    self.tbl_version.value_namespace = name_space
                                                    self.tbl_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "traffic-index"):
                                                    self.traffic_index = value
                                                    self.traffic_index.value_namespace = name_space
                                                    self.traffic_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "version"):
                                                    self.version = value
                                                    self.version.value_namespace = name_space
                                                    self.version.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.q_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.q_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "q-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "q-route"):
                                                for c in self.q_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.q_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "q-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class BackupRoutes(Entity):
                                        """
                                        Backup route information for the given
                                        table
                                        
                                        .. attribute:: backup_route
                                        
                                        	Route information for a specific backup address 
                                        	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__init__()

                                            self.yang_name = "backup-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"

                                            self.backup_route = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__setattr__(name, value)


                                        class BackupRoute(Entity):
                                            """
                                            Route information for a specific backup
                                            address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: protoid
                                            
                                            	Proto ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__init__()

                                                self.yang_name = "backup-route"
                                                self.yang_parent_name = "backup-routes"

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.protoid = YLeaf(YType.int32, "protoid")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("active",
                                                                "address",
                                                                "attribute_identity",
                                                                "client_id",
                                                                "distance",
                                                                "diversion",
                                                                "diversion_distance",
                                                                "diversion_proto_name",
                                                                "extended_flags",
                                                                "flags",
                                                                "flow_tag",
                                                                "fwd_class",
                                                                "instance",
                                                                "metric",
                                                                "paths_count",
                                                                "pic_count",
                                                                "prefix",
                                                                "prefix_length",
                                                                "prefix_length_xr",
                                                                "priority",
                                                                "protocol_id",
                                                                "protocol_name",
                                                                "protoid",
                                                                "qos_group",
                                                                "route_age",
                                                                "route_label",
                                                                "route_modify_time",
                                                                "route_precedence",
                                                                "route_type",
                                                                "route_version",
                                                                "svd_type",
                                                                "tag",
                                                                "tbl_version",
                                                                "traffic_index",
                                                                "version") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__setattr__(name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of    :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "backup-route"

                                                    self.ipv6_rib_edm_path = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__setattr__(name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Labels for this path
                                                    	**type**\:  list of int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\:  list of str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.labelstk = YLeafList(YType.uint32, "labelstk")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.remote_backup_addr = YLeafList(YType.str, "remote-backup-addr")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("address",
                                                                        "backup_pathid",
                                                                        "binding_label",
                                                                        "flags",
                                                                        "flags64",
                                                                        "has_labelstk",
                                                                        "information_source",
                                                                        "interface_name",
                                                                        "labelstk",
                                                                        "load_metric",
                                                                        "looped",
                                                                        "metric",
                                                                        "mpls_feid",
                                                                        "mvpn_present",
                                                                        "next_hop_afi",
                                                                        "next_hop_id",
                                                                        "next_hop_id_refcount",
                                                                        "next_hop_safi",
                                                                        "next_hop_table_id",
                                                                        "next_hop_table_name",
                                                                        "next_hop_vrf_name",
                                                                        "nhid_feid",
                                                                        "num_labels",
                                                                        "number_of_extended_communities",
                                                                        "ospf_area_id",
                                                                        "path_rt_present",
                                                                        "pathid",
                                                                        "private_flags",
                                                                        "ref_cnt_of_backup",
                                                                        "remote_backup_addr",
                                                                        "route_label",
                                                                        "segmented_nexthop_present",
                                                                        "source_asrt_present",
                                                                        "source_rd_present",
                                                                        "tunnel_id",
                                                                        "v6_information_source",
                                                                        "v6_nexthop",
                                                                        "vrf_import_rt_present") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.yfilter != YFilter.not_set):
                                                                return True
                                                        return (
                                                            self.address.is_set or
                                                            self.backup_pathid.is_set or
                                                            self.binding_label.is_set or
                                                            self.flags.is_set or
                                                            self.flags64.is_set or
                                                            self.has_labelstk.is_set or
                                                            self.information_source.is_set or
                                                            self.interface_name.is_set or
                                                            self.load_metric.is_set or
                                                            self.looped.is_set or
                                                            self.metric.is_set or
                                                            self.mpls_feid.is_set or
                                                            self.mvpn_present.is_set or
                                                            self.next_hop_afi.is_set or
                                                            self.next_hop_id.is_set or
                                                            self.next_hop_id_refcount.is_set or
                                                            self.next_hop_safi.is_set or
                                                            self.next_hop_table_id.is_set or
                                                            self.next_hop_table_name.is_set or
                                                            self.next_hop_vrf_name.is_set or
                                                            self.nhid_feid.is_set or
                                                            self.num_labels.is_set or
                                                            self.number_of_extended_communities.is_set or
                                                            self.ospf_area_id.is_set or
                                                            self.path_rt_present.is_set or
                                                            self.pathid.is_set or
                                                            self.private_flags.is_set or
                                                            self.ref_cnt_of_backup.is_set or
                                                            self.route_label.is_set or
                                                            self.segmented_nexthop_present.is_set or
                                                            self.source_asrt_present.is_set or
                                                            self.source_rd_present.is_set or
                                                            self.tunnel_id.is_set or
                                                            self.v6_information_source.is_set or
                                                            self.v6_nexthop.is_set or
                                                            self.vrf_import_rt_present.is_set)

                                                    def has_operation(self):
                                                        for leaf in self.labelstk.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        for leaf in self.remote_backup_addr.getYLeafs():
                                                            if (leaf.is_set):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.address.yfilter != YFilter.not_set or
                                                            self.backup_pathid.yfilter != YFilter.not_set or
                                                            self.binding_label.yfilter != YFilter.not_set or
                                                            self.flags.yfilter != YFilter.not_set or
                                                            self.flags64.yfilter != YFilter.not_set or
                                                            self.has_labelstk.yfilter != YFilter.not_set or
                                                            self.information_source.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.labelstk.yfilter != YFilter.not_set or
                                                            self.load_metric.yfilter != YFilter.not_set or
                                                            self.looped.yfilter != YFilter.not_set or
                                                            self.metric.yfilter != YFilter.not_set or
                                                            self.mpls_feid.yfilter != YFilter.not_set or
                                                            self.mvpn_present.yfilter != YFilter.not_set or
                                                            self.next_hop_afi.yfilter != YFilter.not_set or
                                                            self.next_hop_id.yfilter != YFilter.not_set or
                                                            self.next_hop_id_refcount.yfilter != YFilter.not_set or
                                                            self.next_hop_safi.yfilter != YFilter.not_set or
                                                            self.next_hop_table_id.yfilter != YFilter.not_set or
                                                            self.next_hop_table_name.yfilter != YFilter.not_set or
                                                            self.next_hop_vrf_name.yfilter != YFilter.not_set or
                                                            self.nhid_feid.yfilter != YFilter.not_set or
                                                            self.num_labels.yfilter != YFilter.not_set or
                                                            self.number_of_extended_communities.yfilter != YFilter.not_set or
                                                            self.ospf_area_id.yfilter != YFilter.not_set or
                                                            self.path_rt_present.yfilter != YFilter.not_set or
                                                            self.pathid.yfilter != YFilter.not_set or
                                                            self.private_flags.yfilter != YFilter.not_set or
                                                            self.ref_cnt_of_backup.yfilter != YFilter.not_set or
                                                            self.remote_backup_addr.yfilter != YFilter.not_set or
                                                            self.route_label.yfilter != YFilter.not_set or
                                                            self.segmented_nexthop_present.yfilter != YFilter.not_set or
                                                            self.source_asrt_present.yfilter != YFilter.not_set or
                                                            self.source_rd_present.yfilter != YFilter.not_set or
                                                            self.tunnel_id.yfilter != YFilter.not_set or
                                                            self.v6_information_source.yfilter != YFilter.not_set or
                                                            self.v6_nexthop.yfilter != YFilter.not_set or
                                                            self.vrf_import_rt_present.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6-rib-edm-path" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.address.get_name_leafdata())
                                                        if (self.backup_pathid.is_set or self.backup_pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_pathid.get_name_leafdata())
                                                        if (self.binding_label.is_set or self.binding_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.binding_label.get_name_leafdata())
                                                        if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags.get_name_leafdata())
                                                        if (self.flags64.is_set or self.flags64.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flags64.get_name_leafdata())
                                                        if (self.has_labelstk.is_set or self.has_labelstk.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.has_labelstk.get_name_leafdata())
                                                        if (self.information_source.is_set or self.information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.information_source.get_name_leafdata())
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.load_metric.is_set or self.load_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.load_metric.get_name_leafdata())
                                                        if (self.looped.is_set or self.looped.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.looped.get_name_leafdata())
                                                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.metric.get_name_leafdata())
                                                        if (self.mpls_feid.is_set or self.mpls_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_feid.get_name_leafdata())
                                                        if (self.mvpn_present.is_set or self.mvpn_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mvpn_present.get_name_leafdata())
                                                        if (self.next_hop_afi.is_set or self.next_hop_afi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_afi.get_name_leafdata())
                                                        if (self.next_hop_id.is_set or self.next_hop_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id.get_name_leafdata())
                                                        if (self.next_hop_id_refcount.is_set or self.next_hop_id_refcount.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_id_refcount.get_name_leafdata())
                                                        if (self.next_hop_safi.is_set or self.next_hop_safi.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_safi.get_name_leafdata())
                                                        if (self.next_hop_table_id.is_set or self.next_hop_table_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_id.get_name_leafdata())
                                                        if (self.next_hop_table_name.is_set or self.next_hop_table_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_table_name.get_name_leafdata())
                                                        if (self.next_hop_vrf_name.is_set or self.next_hop_vrf_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.next_hop_vrf_name.get_name_leafdata())
                                                        if (self.nhid_feid.is_set or self.nhid_feid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.nhid_feid.get_name_leafdata())
                                                        if (self.num_labels.is_set or self.num_labels.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_labels.get_name_leafdata())
                                                        if (self.number_of_extended_communities.is_set or self.number_of_extended_communities.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.number_of_extended_communities.get_name_leafdata())
                                                        if (self.ospf_area_id.is_set or self.ospf_area_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ospf_area_id.get_name_leafdata())
                                                        if (self.path_rt_present.is_set or self.path_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.path_rt_present.get_name_leafdata())
                                                        if (self.pathid.is_set or self.pathid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pathid.get_name_leafdata())
                                                        if (self.private_flags.is_set or self.private_flags.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.private_flags.get_name_leafdata())
                                                        if (self.ref_cnt_of_backup.is_set or self.ref_cnt_of_backup.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ref_cnt_of_backup.get_name_leafdata())
                                                        if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.route_label.get_name_leafdata())
                                                        if (self.segmented_nexthop_present.is_set or self.segmented_nexthop_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segmented_nexthop_present.get_name_leafdata())
                                                        if (self.source_asrt_present.is_set or self.source_asrt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_asrt_present.get_name_leafdata())
                                                        if (self.source_rd_present.is_set or self.source_rd_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.source_rd_present.get_name_leafdata())
                                                        if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                                                        if (self.v6_information_source.is_set or self.v6_information_source.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_information_source.get_name_leafdata())
                                                        if (self.v6_nexthop.is_set or self.v6_nexthop.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.v6_nexthop.get_name_leafdata())
                                                        if (self.vrf_import_rt_present.is_set or self.vrf_import_rt_present.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vrf_import_rt_present.get_name_leafdata())

                                                        leaf_name_data.extend(self.labelstk.get_name_leafdata())

                                                        leaf_name_data.extend(self.remote_backup_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "address" or name == "backup-pathid" or name == "binding-label" or name == "flags" or name == "flags64" or name == "has-labelstk" or name == "information-source" or name == "interface-name" or name == "labelstk" or name == "load-metric" or name == "looped" or name == "metric" or name == "mpls-feid" or name == "mvpn-present" or name == "next-hop-afi" or name == "next-hop-id" or name == "next-hop-id-refcount" or name == "next-hop-safi" or name == "next-hop-table-id" or name == "next-hop-table-name" or name == "next-hop-vrf-name" or name == "nhid-feid" or name == "num-labels" or name == "number-of-extended-communities" or name == "ospf-area-id" or name == "path-rt-present" or name == "pathid" or name == "private-flags" or name == "ref-cnt-of-backup" or name == "remote-backup-addr" or name == "route-label" or name == "segmented-nexthop-present" or name == "source-asrt-present" or name == "source-rd-present" or name == "tunnel-id" or name == "v6-information-source" or name == "v6-nexthop" or name == "vrf-import-rt-present"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "address"):
                                                            self.address = value
                                                            self.address.value_namespace = name_space
                                                            self.address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "backup-pathid"):
                                                            self.backup_pathid = value
                                                            self.backup_pathid.value_namespace = name_space
                                                            self.backup_pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "binding-label"):
                                                            self.binding_label = value
                                                            self.binding_label.value_namespace = name_space
                                                            self.binding_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags"):
                                                            self.flags = value
                                                            self.flags.value_namespace = name_space
                                                            self.flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flags64"):
                                                            self.flags64 = value
                                                            self.flags64.value_namespace = name_space
                                                            self.flags64.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "has-labelstk"):
                                                            self.has_labelstk = value
                                                            self.has_labelstk.value_namespace = name_space
                                                            self.has_labelstk.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "information-source"):
                                                            self.information_source = value
                                                            self.information_source.value_namespace = name_space
                                                            self.information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "labelstk"):
                                                            self.labelstk.append(value)
                                                        if(value_path == "load-metric"):
                                                            self.load_metric = value
                                                            self.load_metric.value_namespace = name_space
                                                            self.load_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "looped"):
                                                            self.looped = value
                                                            self.looped.value_namespace = name_space
                                                            self.looped.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "metric"):
                                                            self.metric = value
                                                            self.metric.value_namespace = name_space
                                                            self.metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-feid"):
                                                            self.mpls_feid = value
                                                            self.mpls_feid.value_namespace = name_space
                                                            self.mpls_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mvpn-present"):
                                                            self.mvpn_present = value
                                                            self.mvpn_present.value_namespace = name_space
                                                            self.mvpn_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-afi"):
                                                            self.next_hop_afi = value
                                                            self.next_hop_afi.value_namespace = name_space
                                                            self.next_hop_afi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id"):
                                                            self.next_hop_id = value
                                                            self.next_hop_id.value_namespace = name_space
                                                            self.next_hop_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-id-refcount"):
                                                            self.next_hop_id_refcount = value
                                                            self.next_hop_id_refcount.value_namespace = name_space
                                                            self.next_hop_id_refcount.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-safi"):
                                                            self.next_hop_safi = value
                                                            self.next_hop_safi.value_namespace = name_space
                                                            self.next_hop_safi.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-id"):
                                                            self.next_hop_table_id = value
                                                            self.next_hop_table_id.value_namespace = name_space
                                                            self.next_hop_table_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-table-name"):
                                                            self.next_hop_table_name = value
                                                            self.next_hop_table_name.value_namespace = name_space
                                                            self.next_hop_table_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "next-hop-vrf-name"):
                                                            self.next_hop_vrf_name = value
                                                            self.next_hop_vrf_name.value_namespace = name_space
                                                            self.next_hop_vrf_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "nhid-feid"):
                                                            self.nhid_feid = value
                                                            self.nhid_feid.value_namespace = name_space
                                                            self.nhid_feid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-labels"):
                                                            self.num_labels = value
                                                            self.num_labels.value_namespace = name_space
                                                            self.num_labels.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "number-of-extended-communities"):
                                                            self.number_of_extended_communities = value
                                                            self.number_of_extended_communities.value_namespace = name_space
                                                            self.number_of_extended_communities.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ospf-area-id"):
                                                            self.ospf_area_id = value
                                                            self.ospf_area_id.value_namespace = name_space
                                                            self.ospf_area_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "path-rt-present"):
                                                            self.path_rt_present = value
                                                            self.path_rt_present.value_namespace = name_space
                                                            self.path_rt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pathid"):
                                                            self.pathid = value
                                                            self.pathid.value_namespace = name_space
                                                            self.pathid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "private-flags"):
                                                            self.private_flags = value
                                                            self.private_flags.value_namespace = name_space
                                                            self.private_flags.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ref-cnt-of-backup"):
                                                            self.ref_cnt_of_backup = value
                                                            self.ref_cnt_of_backup.value_namespace = name_space
                                                            self.ref_cnt_of_backup.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-backup-addr"):
                                                            self.remote_backup_addr.append(value)
                                                        if(value_path == "route-label"):
                                                            self.route_label = value
                                                            self.route_label.value_namespace = name_space
                                                            self.route_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segmented-nexthop-present"):
                                                            self.segmented_nexthop_present = value
                                                            self.segmented_nexthop_present.value_namespace = name_space
                                                            self.segmented_nexthop_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-asrt-present"):
                                                            self.source_asrt_present = value
                                                            self.source_asrt_present.value_namespace = name_space
                                                            self.source_asrt_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "source-rd-present"):
                                                            self.source_rd_present = value
                                                            self.source_rd_present.value_namespace = name_space
                                                            self.source_rd_present.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-id"):
                                                            self.tunnel_id = value
                                                            self.tunnel_id.value_namespace = name_space
                                                            self.tunnel_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-information-source"):
                                                            self.v6_information_source = value
                                                            self.v6_information_source.value_namespace = name_space
                                                            self.v6_information_source.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "v6-nexthop"):
                                                            self.v6_nexthop = value
                                                            self.v6_nexthop.value_namespace = name_space
                                                            self.v6_nexthop.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vrf-import-rt-present"):
                                                            self.vrf_import_rt_present = value
                                                            self.vrf_import_rt_present.value_namespace = name_space
                                                            self.vrf_import_rt_present.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.ipv6_rib_edm_path:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv6-rib-edm-path"):
                                                        for c in self.ipv6_rib_edm_path:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.ipv6_rib_edm_path.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv6-rib-edm-path"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.active.is_set or
                                                    self.address.is_set or
                                                    self.attribute_identity.is_set or
                                                    self.client_id.is_set or
                                                    self.distance.is_set or
                                                    self.diversion.is_set or
                                                    self.diversion_distance.is_set or
                                                    self.diversion_proto_name.is_set or
                                                    self.extended_flags.is_set or
                                                    self.flags.is_set or
                                                    self.flow_tag.is_set or
                                                    self.fwd_class.is_set or
                                                    self.instance.is_set or
                                                    self.metric.is_set or
                                                    self.paths_count.is_set or
                                                    self.pic_count.is_set or
                                                    self.prefix.is_set or
                                                    self.prefix_length.is_set or
                                                    self.prefix_length_xr.is_set or
                                                    self.priority.is_set or
                                                    self.protocol_id.is_set or
                                                    self.protocol_name.is_set or
                                                    self.protoid.is_set or
                                                    self.qos_group.is_set or
                                                    self.route_age.is_set or
                                                    self.route_label.is_set or
                                                    self.route_modify_time.is_set or
                                                    self.route_precedence.is_set or
                                                    self.route_type.is_set or
                                                    self.route_version.is_set or
                                                    self.svd_type.is_set or
                                                    self.tag.is_set or
                                                    self.tbl_version.is_set or
                                                    self.traffic_index.is_set or
                                                    self.version.is_set or
                                                    (self.route_path is not None and self.route_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.active.yfilter != YFilter.not_set or
                                                    self.address.yfilter != YFilter.not_set or
                                                    self.attribute_identity.yfilter != YFilter.not_set or
                                                    self.client_id.yfilter != YFilter.not_set or
                                                    self.distance.yfilter != YFilter.not_set or
                                                    self.diversion.yfilter != YFilter.not_set or
                                                    self.diversion_distance.yfilter != YFilter.not_set or
                                                    self.diversion_proto_name.yfilter != YFilter.not_set or
                                                    self.extended_flags.yfilter != YFilter.not_set or
                                                    self.flags.yfilter != YFilter.not_set or
                                                    self.flow_tag.yfilter != YFilter.not_set or
                                                    self.fwd_class.yfilter != YFilter.not_set or
                                                    self.instance.yfilter != YFilter.not_set or
                                                    self.metric.yfilter != YFilter.not_set or
                                                    self.paths_count.yfilter != YFilter.not_set or
                                                    self.pic_count.yfilter != YFilter.not_set or
                                                    self.prefix.yfilter != YFilter.not_set or
                                                    self.prefix_length.yfilter != YFilter.not_set or
                                                    self.prefix_length_xr.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set or
                                                    self.protocol_id.yfilter != YFilter.not_set or
                                                    self.protocol_name.yfilter != YFilter.not_set or
                                                    self.protoid.yfilter != YFilter.not_set or
                                                    self.qos_group.yfilter != YFilter.not_set or
                                                    self.route_age.yfilter != YFilter.not_set or
                                                    self.route_label.yfilter != YFilter.not_set or
                                                    self.route_modify_time.yfilter != YFilter.not_set or
                                                    self.route_precedence.yfilter != YFilter.not_set or
                                                    self.route_type.yfilter != YFilter.not_set or
                                                    self.route_version.yfilter != YFilter.not_set or
                                                    self.svd_type.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tbl_version.yfilter != YFilter.not_set or
                                                    self.traffic_index.yfilter != YFilter.not_set or
                                                    self.version.yfilter != YFilter.not_set or
                                                    (self.route_path is not None and self.route_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "backup-route" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.active.get_name_leafdata())
                                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.address.get_name_leafdata())
                                                if (self.attribute_identity.is_set or self.attribute_identity.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.attribute_identity.get_name_leafdata())
                                                if (self.client_id.is_set or self.client_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.client_id.get_name_leafdata())
                                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.distance.get_name_leafdata())
                                                if (self.diversion.is_set or self.diversion.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion.get_name_leafdata())
                                                if (self.diversion_distance.is_set or self.diversion_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_distance.get_name_leafdata())
                                                if (self.diversion_proto_name.is_set or self.diversion_proto_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.diversion_proto_name.get_name_leafdata())
                                                if (self.extended_flags.is_set or self.extended_flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_flags.get_name_leafdata())
                                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                                if (self.flow_tag.is_set or self.flow_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flow_tag.get_name_leafdata())
                                                if (self.fwd_class.is_set or self.fwd_class.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fwd_class.get_name_leafdata())
                                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                                if (self.paths_count.is_set or self.paths_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.paths_count.get_name_leafdata())
                                                if (self.pic_count.is_set or self.pic_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pic_count.get_name_leafdata())
                                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                                if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                                if (self.protocol_id.is_set or self.protocol_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_id.get_name_leafdata())
                                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                                if (self.protoid.is_set or self.protoid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protoid.get_name_leafdata())
                                                if (self.qos_group.is_set or self.qos_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.qos_group.get_name_leafdata())
                                                if (self.route_age.is_set or self.route_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_age.get_name_leafdata())
                                                if (self.route_label.is_set or self.route_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_label.get_name_leafdata())
                                                if (self.route_modify_time.is_set or self.route_modify_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_modify_time.get_name_leafdata())
                                                if (self.route_precedence.is_set or self.route_precedence.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_precedence.get_name_leafdata())
                                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_type.get_name_leafdata())
                                                if (self.route_version.is_set or self.route_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_version.get_name_leafdata())
                                                if (self.svd_type.is_set or self.svd_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.svd_type.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tbl_version.is_set or self.tbl_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tbl_version.get_name_leafdata())
                                                if (self.traffic_index.is_set or self.traffic_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.traffic_index.get_name_leafdata())
                                                if (self.version.is_set or self.version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.version.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-path"):
                                                    if (self.route_path is None):
                                                        self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                        self.route_path.parent = self
                                                        self._children_name_map["route_path"] = "route-path"
                                                    return self.route_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-path" or name == "active" or name == "address" or name == "attribute-identity" or name == "client-id" or name == "distance" or name == "diversion" or name == "diversion-distance" or name == "diversion-proto-name" or name == "extended-flags" or name == "flags" or name == "flow-tag" or name == "fwd-class" or name == "instance" or name == "metric" or name == "paths-count" or name == "pic-count" or name == "prefix" or name == "prefix-length" or name == "prefix-length-xr" or name == "priority" or name == "protocol-id" or name == "protocol-name" or name == "protoid" or name == "qos-group" or name == "route-age" or name == "route-label" or name == "route-modify-time" or name == "route-precedence" or name == "route-type" or name == "route-version" or name == "svd-type" or name == "tag" or name == "tbl-version" or name == "traffic-index" or name == "version"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "active"):
                                                    self.active = value
                                                    self.active.value_namespace = name_space
                                                    self.active.value_namespace_prefix = name_space_prefix
                                                if(value_path == "address"):
                                                    self.address = value
                                                    self.address.value_namespace = name_space
                                                    self.address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "attribute-identity"):
                                                    self.attribute_identity = value
                                                    self.attribute_identity.value_namespace = name_space
                                                    self.attribute_identity.value_namespace_prefix = name_space_prefix
                                                if(value_path == "client-id"):
                                                    self.client_id = value
                                                    self.client_id.value_namespace = name_space
                                                    self.client_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "distance"):
                                                    self.distance = value
                                                    self.distance.value_namespace = name_space
                                                    self.distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion"):
                                                    self.diversion = value
                                                    self.diversion.value_namespace = name_space
                                                    self.diversion.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-distance"):
                                                    self.diversion_distance = value
                                                    self.diversion_distance.value_namespace = name_space
                                                    self.diversion_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "diversion-proto-name"):
                                                    self.diversion_proto_name = value
                                                    self.diversion_proto_name.value_namespace = name_space
                                                    self.diversion_proto_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "extended-flags"):
                                                    self.extended_flags = value
                                                    self.extended_flags.value_namespace = name_space
                                                    self.extended_flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flags"):
                                                    self.flags = value
                                                    self.flags.value_namespace = name_space
                                                    self.flags.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flow-tag"):
                                                    self.flow_tag = value
                                                    self.flow_tag.value_namespace = name_space
                                                    self.flow_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fwd-class"):
                                                    self.fwd_class = value
                                                    self.fwd_class.value_namespace = name_space
                                                    self.fwd_class.value_namespace_prefix = name_space_prefix
                                                if(value_path == "instance"):
                                                    self.instance = value
                                                    self.instance.value_namespace = name_space
                                                    self.instance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "metric"):
                                                    self.metric = value
                                                    self.metric.value_namespace = name_space
                                                    self.metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "paths-count"):
                                                    self.paths_count = value
                                                    self.paths_count.value_namespace = name_space
                                                    self.paths_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pic-count"):
                                                    self.pic_count = value
                                                    self.pic_count.value_namespace = name_space
                                                    self.pic_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix"):
                                                    self.prefix = value
                                                    self.prefix.value_namespace = name_space
                                                    self.prefix.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length"):
                                                    self.prefix_length = value
                                                    self.prefix_length.value_namespace = name_space
                                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "prefix-length-xr"):
                                                    self.prefix_length_xr = value
                                                    self.prefix_length_xr.value_namespace = name_space
                                                    self.prefix_length_xr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-id"):
                                                    self.protocol_id = value
                                                    self.protocol_id.value_namespace = name_space
                                                    self.protocol_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol-name"):
                                                    self.protocol_name = value
                                                    self.protocol_name.value_namespace = name_space
                                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protoid"):
                                                    self.protoid = value
                                                    self.protoid.value_namespace = name_space
                                                    self.protoid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "qos-group"):
                                                    self.qos_group = value
                                                    self.qos_group.value_namespace = name_space
                                                    self.qos_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-age"):
                                                    self.route_age = value
                                                    self.route_age.value_namespace = name_space
                                                    self.route_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-label"):
                                                    self.route_label = value
                                                    self.route_label.value_namespace = name_space
                                                    self.route_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-modify-time"):
                                                    self.route_modify_time = value
                                                    self.route_modify_time.value_namespace = name_space
                                                    self.route_modify_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-precedence"):
                                                    self.route_precedence = value
                                                    self.route_precedence.value_namespace = name_space
                                                    self.route_precedence.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-type"):
                                                    self.route_type = value
                                                    self.route_type.value_namespace = name_space
                                                    self.route_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-version"):
                                                    self.route_version = value
                                                    self.route_version.value_namespace = name_space
                                                    self.route_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "svd-type"):
                                                    self.svd_type = value
                                                    self.svd_type.value_namespace = name_space
                                                    self.svd_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tbl-version"):
                                                    self.tbl_version = value
                                                    self.tbl_version.value_namespace = name_space
                                                    self.tbl_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "traffic-index"):
                                                    self.traffic_index = value
                                                    self.traffic_index.value_namespace = name_space
                                                    self.traffic_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "version"):
                                                    self.version = value
                                                    self.version.value_namespace = name_space
                                                    self.version.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.backup_route:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.backup_route:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-routes" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "backup-route"):
                                                for c in self.backup_route:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.backup_route.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "backup-route"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.route_table_name.is_set or
                                            (self.adverts is not None and self.adverts.has_data()) or
                                            (self.backup_routes is not None and self.backup_routes.has_data()) or
                                            (self.deleted_routes is not None and self.deleted_routes.has_data()) or
                                            (self.destination_kw is not None and self.destination_kw.has_data()) or
                                            (self.protocol is not None and self.protocol.has_data()) or
                                            (self.q_routes is not None and self.q_routes.has_data()) or
                                            (self.routes is not None and self.routes.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_table_name.yfilter != YFilter.not_set or
                                            (self.adverts is not None and self.adverts.has_operation()) or
                                            (self.backup_routes is not None and self.backup_routes.has_operation()) or
                                            (self.deleted_routes is not None and self.deleted_routes.has_operation()) or
                                            (self.destination_kw is not None and self.destination_kw.has_operation()) or
                                            (self.protocol is not None and self.protocol.has_operation()) or
                                            (self.q_routes is not None and self.q_routes.has_operation()) or
                                            (self.routes is not None and self.routes.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ip-rib-route-table-name" + "[route-table-name='" + self.route_table_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_table_name.is_set or self.route_table_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_table_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "adverts"):
                                            if (self.adverts is None):
                                                self.adverts = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                                self.adverts.parent = self
                                                self._children_name_map["adverts"] = "adverts"
                                            return self.adverts

                                        if (child_yang_name == "backup-routes"):
                                            if (self.backup_routes is None):
                                                self.backup_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                                self.backup_routes.parent = self
                                                self._children_name_map["backup_routes"] = "backup-routes"
                                            return self.backup_routes

                                        if (child_yang_name == "deleted-routes"):
                                            if (self.deleted_routes is None):
                                                self.deleted_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                                self.deleted_routes.parent = self
                                                self._children_name_map["deleted_routes"] = "deleted-routes"
                                            return self.deleted_routes

                                        if (child_yang_name == "destination-kw"):
                                            if (self.destination_kw is None):
                                                self.destination_kw = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                                self.destination_kw.parent = self
                                                self._children_name_map["destination_kw"] = "destination-kw"
                                            return self.destination_kw

                                        if (child_yang_name == "protocol"):
                                            if (self.protocol is None):
                                                self.protocol = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                                self.protocol.parent = self
                                                self._children_name_map["protocol"] = "protocol"
                                            return self.protocol

                                        if (child_yang_name == "q-routes"):
                                            if (self.q_routes is None):
                                                self.q_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                                self.q_routes.parent = self
                                                self._children_name_map["q_routes"] = "q-routes"
                                            return self.q_routes

                                        if (child_yang_name == "routes"):
                                            if (self.routes is None):
                                                self.routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                                self.routes.parent = self
                                                self._children_name_map["routes"] = "routes"
                                            return self.routes

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "adverts" or name == "backup-routes" or name == "deleted-routes" or name == "destination-kw" or name == "protocol" or name == "q-routes" or name == "routes" or name == "route-table-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-table-name"):
                                            self.route_table_name = value
                                            self.route_table_name.value_namespace = name_space
                                            self.route_table_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.ip_rib_route_table_name:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.ip_rib_route_table_name:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ip-rib-route-table-names" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ip-rib-route-table-name"):
                                        for c in self.ip_rib_route_table_name:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ip_rib_route_table_name.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-rib-route-table-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.saf_name.is_set or
                                    (self.ip_rib_route_table_names is not None and self.ip_rib_route_table_names.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.saf_name.yfilter != YFilter.not_set or
                                    (self.ip_rib_route_table_names is not None and self.ip_rib_route_table_names.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "saf" + "[saf-name='" + self.saf_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ip-rib-route-table-names"):
                                    if (self.ip_rib_route_table_names is None):
                                        self.ip_rib_route_table_names = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                        self.ip_rib_route_table_names.parent = self
                                        self._children_name_map["ip_rib_route_table_names"] = "ip-rib-route-table-names"
                                    return self.ip_rib_route_table_names

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-rib-route-table-names" or name == "saf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "saf-name"):
                                    self.saf_name = value
                                    self.saf_name.value_namespace = name_space
                                    self.saf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.saf:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.saf:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "safs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "saf"):
                                for c in self.saf:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.saf.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "saf"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            (self.safs is not None and self.safs.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            (self.safs is not None and self.safs.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "af" + "[af-name='" + self.af_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "safs"):
                            if (self.safs is None):
                                self.safs = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs()
                                self.safs.parent = self
                                self._children_name_map["safs"] = "safs"
                            return self.safs

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "safs" or name == "af-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.af:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.af:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "afs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "af"):
                        for c in self.af:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6RibStdby.Vrfs.Vrf.Afs.Af()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.af.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "af"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.vrf_name.is_set or
                    (self.afs is not None and self.afs.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.afs is not None and self.afs.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/vrfs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "afs"):
                    if (self.afs is None):
                        self.afs = Ipv6RibStdby.Vrfs.Vrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"
                    return self.afs

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "afs" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.vrf:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.vrf:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "vrfs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "vrf"):
                for c in self.vrf:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Ipv6RibStdby.Vrfs.Vrf()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.vrf.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "vrf"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.rib_table_ids is not None and self.rib_table_ids.has_data()) or
            (self.vrfs is not None and self.vrfs.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.rib_table_ids is not None and self.rib_table_ids.has_operation()) or
            (self.vrfs is not None and self.vrfs.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "rib-table-ids"):
            if (self.rib_table_ids is None):
                self.rib_table_ids = Ipv6RibStdby.RibTableIds()
                self.rib_table_ids.parent = self
                self._children_name_map["rib_table_ids"] = "rib-table-ids"
            return self.rib_table_ids

        if (child_yang_name == "vrfs"):
            if (self.vrfs is None):
                self.vrfs = Ipv6RibStdby.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
            return self.vrfs

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "rib-table-ids" or name == "vrfs"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Ipv6RibStdby()
        return self._top_entity

